@@ -277,7 +277,7 @@ public class TopNTypeInterfaceBenchmark
       File indexFile = INDEX_MERGER_V9.persist(
           incIndexes.get(i),
           tmpFile,
-          IndexSpec.DEFAULT,
+          IndexSpec.getDefault(),
           null
       );
 
