@@ -19,7 +19,6 @@
 
 package org.apache.druid.benchmark.indexing;
 
-import org.apache.druid.common.config.NullHandling;
 import org.apache.druid.java.util.common.logger.Logger;
 import org.apache.druid.js.JavaScriptConfig;
 import org.apache.druid.query.aggregation.hyperloglog.HyperUniquesSerde;
@@ -90,10 +89,6 @@ public class IncrementalIndexReadBenchmark
   private static final Logger log = new Logger(IncrementalIndexReadBenchmark.class);
   private static final int RNG_SEED = 9999;
 
-  static {
-    NullHandling.initializeForTests();
-  }
-
   private AppendableIndexSpec appendableIndexSpec;
   private IncrementalIndex incIndex;
   private GeneratorSchemaInfo schemaInfo;
