@@ -162,14 +162,14 @@ public class InPlanningBenchmark
     List<DimensionSchema> columnSchemas = schemaInfo.getDimensionsSpec()
                                                     .getDimensions()
                                                     .stream()
-                                                    .map(x -> new AutoTypeColumnSchema(x.getName(), null))
+                                                    .map(x -> AutoTypeColumnSchema.of(x.getName()))
                                                     .collect(Collectors.toList());
     index = segmentGenerator.generate(
         dataSegment,
         schemaInfo,
         DimensionsSpec.builder().setDimensions(columnSchemas).build(),
         TransformSpec.NONE,
-        IndexSpec.DEFAULT,
+        IndexSpec.getDefault(),
         Granularities.NONE,
         rowsPerSegment
     );
