@@ -101,7 +101,7 @@ public class OssDataSegmentMover implements DataSegmentMover
               .putAll(
                   Maps.filterKeys(
                       loadSpec,
-                      new Predicate<String>()
+                      new Predicate<>()
                       {
                         @Override
                         public boolean apply(String input)
