@@ -25,6 +25,7 @@ import com.fasterxml.jackson.databind.module.SimpleModule;
 import com.google.inject.Binder;
 import org.apache.druid.error.DruidException;
 import org.apache.druid.iceberg.guice.HiveConf;
+import org.apache.druid.iceberg.input.GlueIcebergCatalog;
 import org.apache.druid.iceberg.input.HiveIcebergCatalog;
 import org.apache.druid.iceberg.input.IcebergInputSource;
 import org.apache.druid.iceberg.input.LocalCatalog;
@@ -47,8 +48,8 @@ public class IcebergDruidModule implements DruidModule
                 new NamedType(HiveIcebergCatalog.class, HiveIcebergCatalog.TYPE_KEY),
                 new NamedType(LocalCatalog.class, LocalCatalog.TYPE_KEY),
                 new NamedType(RestIcebergCatalog.class, RestIcebergCatalog.TYPE_KEY),
-                new NamedType(IcebergInputSource.class, IcebergInputSource.TYPE_KEY)
-
+                new NamedType(IcebergInputSource.class, IcebergInputSource.TYPE_KEY),
+                new NamedType(GlueIcebergCatalog.class, GlueIcebergCatalog.TYPE_KEY)
             )
     );
   }
