@@ -58,7 +58,8 @@ public class KafkaEmitterConfigTest
         ImmutableMap.of("env", "preProd"),
         ImmutableMap.<String, String>builder()
                     .put("testKey", "testValue").build(),
-        DEFAULT_PRODUCER_SECRETS
+        DEFAULT_PRODUCER_SECRETS,
+        50L
     );
     String kafkaEmitterConfigString = MAPPER.writeValueAsString(kafkaEmitterConfig);
     KafkaEmitterConfig kafkaEmitterConfigExpected = MAPPER.readerFor(KafkaEmitterConfig.class)
@@ -80,7 +81,8 @@ public class KafkaEmitterConfigTest
         null,
         ImmutableMap.<String, String>builder()
                     .put("testKey", "testValue").build(),
-        DEFAULT_PRODUCER_SECRETS
+        DEFAULT_PRODUCER_SECRETS,
+        null
     );
     String kafkaEmitterConfigString = MAPPER.writeValueAsString(kafkaEmitterConfig);
     KafkaEmitterConfig kafkaEmitterConfigExpected = MAPPER.readerFor(KafkaEmitterConfig.class)
@@ -104,7 +106,8 @@ public class KafkaEmitterConfigTest
         null,
         ImmutableMap.<String, String>builder()
                     .put("testKey", "testValue").build(),
-        DEFAULT_PRODUCER_SECRETS
+        DEFAULT_PRODUCER_SECRETS,
+        null
     );
     String kafkaEmitterConfigString = MAPPER.writeValueAsString(kafkaEmitterConfig);
     KafkaEmitterConfig kafkaEmitterConfigExpected = MAPPER.readerFor(KafkaEmitterConfig.class)
@@ -125,6 +128,7 @@ public class KafkaEmitterConfigTest
         null,
         ImmutableMap.of("env", "preProd"),
         null,
+        null,
         null
     );
     String kafkaEmitterConfigString = MAPPER.writeValueAsString(kafkaEmitterConfig);
@@ -179,6 +183,7 @@ public class KafkaEmitterConfigTest
                 null,
                 null,
                 null,
+                null,
                 null
             )
         ),
@@ -203,6 +208,7 @@ public class KafkaEmitterConfigTest
                 null,
                 null,
                 null,
+                null,
                 null
             )
         ),
@@ -227,6 +233,7 @@ public class KafkaEmitterConfigTest
                 null,
                 null,
                 null,
+                null,
                 null
             )
         ),
@@ -253,6 +260,7 @@ public class KafkaEmitterConfigTest
                 null,
                 null,
                 null,
+                null,
                 null
             )
         ),
@@ -279,6 +287,7 @@ public class KafkaEmitterConfigTest
                 null,
                 null,
                 null,
+                null,
                 null
             )
         ),
@@ -289,6 +298,31 @@ public class KafkaEmitterConfigTest
     );
   }
 
+  @Test
+  public void testDefaultShutdownTimeout() throws IOException
+  {
+    Set<KafkaEmitterConfig.EventType> eventTypeSet = new HashSet<>();
+    eventTypeSet.add(KafkaEmitterConfig.EventType.SEGMENT_METADATA);
+    KafkaEmitterConfig kafkaEmitterConfig = new KafkaEmitterConfig(
+        "hostname",
+        eventTypeSet,
+        null,
+        null,
+        null,
+        "shutdownTest",
+        "clusterNameTest",
+        null,
+        ImmutableMap.<String, String>builder()
+                    .put("testKey", "testValue").build(),
+        DEFAULT_PRODUCER_SECRETS,
+        null
+    );
+    String kafkaEmitterConfigString = MAPPER.writeValueAsString(kafkaEmitterConfig);
+    KafkaEmitterConfig kafkaEmitterConfigExpected = MAPPER.readerFor(KafkaEmitterConfig.class)
+                                                          .readValue(kafkaEmitterConfigString);
+    Assert.assertEquals(Long.MAX_VALUE, (long) kafkaEmitterConfigExpected.getShutdownTimeout());
+  }
+
   private DruidExceptionMatcher operatorExceptionMatcher()
   {
     return new DruidExceptionMatcher(
