@@ -167,4 +167,14 @@ public class AzureAccountConfig
 
     return storageAccountEndpointSuffix;
   }
+
+  public static String createStorageEndpointUrl(String storageAccount, AzureAccountConfig config)
+  {
+    if ("azurite".equals(config.getProtocol())) {
+      // Used by Azurite container in tests
+      return "http://" + config.getBlobStorageEndpoint() + "/" + storageAccount;
+    } else {
+      return "https://" + storageAccount + "." + config.getBlobStorageEndpoint();
+    }
+  }
 }
