@@ -19,10 +19,11 @@
 
 package org.apache.druid.storage.azure;
 
+import com.azure.storage.blob.models.BlobStorageException;
 import com.google.common.base.Optional;
 import com.google.inject.Inject;
-import com.microsoft.azure.storage.StorageException;
 import org.apache.druid.common.utils.CurrentTimeMillisSupplier;
+import org.apache.druid.guice.annotations.Global;
 import org.apache.druid.java.util.common.IOE;
 import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.java.util.common.logger.Logger;
@@ -31,7 +32,6 @@ import org.apache.druid.tasklogs.TaskLogs;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
-import java.net.URISyntaxException;
 import java.util.Date;
 
 /**
@@ -54,7 +54,7 @@ public class AzureTaskLogs implements TaskLogs
       AzureTaskLogsConfig config,
       AzureInputDataConfig inputDataConfig,
       AzureAccountConfig accountConfig,
-      AzureStorage azureStorage,
+      @Global AzureStorage azureStorage,
       AzureCloudBlobIterableFactory azureCloudBlobIterableFactory,
       CurrentTimeMillisSupplier timeSupplier)
   {
@@ -93,38 +93,46 @@ public class AzureTaskLogs implements TaskLogs
   private void pushTaskFile(final File logFile, String taskKey)
   {
     try {
-      AzureUtils.retryAzureOperation(
-          () -> {
-            azureStorage.uploadBlockBlob(logFile, config.getContainer(), taskKey);
-            return null;
-          },
-          config.getMaxTries()
-      );
+      azureStorage.uploadBlockBlob(logFile, config.getContainer(), taskKey, accountConfig.getMaxTries());
     }
     catch (Exception e) {
       throw new RuntimeException(e);
     }
   }
 
+  @Override
+  public void pushTaskPayload(String taskid, File taskPayloadFile)
+  {
+    final String taskKey = getTaskPayloadKey(taskid);
+    log.info("Pushing task payload [%s] to location [%s]", taskPayloadFile, taskKey);
+    pushTaskFile(taskPayloadFile, taskKey);
+  }
+
+  @Override
+  public Optional<InputStream> streamTaskPayload(String taskid) throws IOException
+  {
+    return streamTaskFile(0, getTaskPayloadKey(taskid));
+  }
+
   @Override
   public Optional<InputStream> streamTaskLog(final String taskid, final long offset) throws IOException
   {
-    return streamTaskFile(taskid, offset, getTaskLogKey(taskid));
+    return streamTaskFile(offset, getTaskLogKey(taskid));
   }
 
   @Override
   public Optional<InputStream> streamTaskReports(String taskid) throws IOException
   {
-    return streamTaskFile(taskid, 0, getTaskReportsKey(taskid));
+    return streamTaskFile(0, getTaskReportsKey(taskid));
   }
 
   @Override
   public Optional<InputStream> streamTaskStatus(String taskid) throws IOException
   {
-    return streamTaskFile(taskid, 0, getTaskStatusKey(taskid));
+    return streamTaskFile(0, getTaskStatusKey(taskid));
   }
 
-  private Optional<InputStream> streamTaskFile(final String taskid, final long offset, String taskKey)
+  private Optional<InputStream> streamTaskFile(final long offset, String taskKey)
       throws IOException
   {
     final String container = config.getContainer();
@@ -153,7 +161,7 @@ public class AzureTaskLogs implements TaskLogs
         throw new IOException(e);
       }
     }
-    catch (StorageException | URISyntaxException e) {
+    catch (BlobStorageException e) {
       throw new IOE(e, "Failed to stream logs from: %s", taskKey);
     }
   }
@@ -173,6 +181,11 @@ public class AzureTaskLogs implements TaskLogs
     return StringUtils.format("%s/%s/status.json", config.getPrefix(), taskid);
   }
 
+  private String getTaskPayloadKey(String taskid)
+  {
+    return StringUtils.format("%s/%s/task.json", config.getPrefix(), taskid);
+  }
+
   @Override
   public void killAll() throws IOException
   {
