@@ -21,7 +21,6 @@ package org.apache.druid.storage.azure;
 
 import com.fasterxml.jackson.annotation.JsonProperty;
 
-import javax.validation.constraints.Min;
 import javax.validation.constraints.NotNull;
 
 /**
@@ -37,19 +36,14 @@ public class AzureTaskLogsConfig
   @NotNull
   private String prefix = null;
 
-  @JsonProperty
-  @Min(1)
-  private int maxTries = 3;
-
   public AzureTaskLogsConfig()
   {
   }
 
-  public AzureTaskLogsConfig(String container, String prefix, int maxTries)
+  public AzureTaskLogsConfig(String container, String prefix)
   {
     this.container = container;
     this.prefix = prefix;
-    this.maxTries = maxTries;
   }
 
   public String getContainer()
@@ -61,9 +55,4 @@ public class AzureTaskLogsConfig
   {
     return prefix;
   }
-
-  public int getMaxTries()
-  {
-    return maxTries;
-  }
 }
