@@ -45,10 +45,9 @@ import org.apache.druid.storage.azure.AzureStorage;
 import org.apache.druid.storage.azure.blob.CloudBlobHolder;
 import org.easymock.EasyMock;
 import org.easymock.EasyMockSupport;
-import org.junit.After;
-import org.junit.Assert;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 
 import java.net.URI;
 import java.nio.file.FileSystems;
@@ -57,23 +56,28 @@ import java.nio.file.Paths;
 import java.util.EnumSet;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Locale;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+
 public class AzureStorageAccountInputSourceTest extends EasyMockSupport
 {
   private static final String BLOB_NAME = "blob";
   private static final URI PREFIX_URI;
-  private final List<URI> EMPTY_URIS = ImmutableList.of();
-  private final List<URI> EMPTY_PREFIXES = ImmutableList.of();
-  private final List<CloudObjectLocation> EMPTY_OBJECTS = ImmutableList.of();
   private static final String STORAGE_ACCOUNT = "STORAGE_ACCOUNT";
   private static final String DEFAULT_STORAGE_ACCOUNT = "DEFAULT_STORAGE_ACCOUNT";
   private static final String CONTAINER = "CONTAINER";
   private static final String BLOB_PATH = "BLOB_PATH.csv";
-  private static final CloudObjectLocation CLOUD_OBJECT_LOCATION_1 = new CloudObjectLocation(STORAGE_ACCOUNT, CONTAINER + "/" + BLOB_PATH);
+  private static final CloudObjectLocation CLOUD_OBJECT_LOCATION_1 = new CloudObjectLocation(
+      STORAGE_ACCOUNT,
+      CONTAINER + "/" + BLOB_PATH
+  );
   private static final int MAX_LISTING_LENGTH = 10;
-
   private static final InputFormat INPUT_FORMAT = new JsonInputFormat(
       new JSONPathSpec(true, null),
       null,
@@ -82,72 +86,85 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
       null
   );
 
+  private final List<URI> EMPTY_URIS = ImmutableList.of();
+  private final List<URI> EMPTY_PREFIXES = ImmutableList.of();
+  private final List<CloudObjectLocation> EMPTY_OBJECTS = ImmutableList.of();
   private AzureStorage storage;
   private AzureEntityFactory entityFactory;
   private AzureCloudBlobIterableFactory azureCloudBlobIterableFactory;
   private AzureInputDataConfig inputDataConfig;
   private AzureStorageAccountInputSourceConfig azureStorageAccountInputSourceConfig;
   private AzureAccountConfig azureAccountConfig;
-
   private InputSplit<List<CloudObjectLocation>> inputSplit;
-  private AzureEntity azureEntity1;
-  private CloudBlobHolder cloudBlobDruid1;
+  private AzureEntity azureEntity;
+  private CloudBlobHolder cloudBlobDruid;
   private AzureCloudBlobIterable azureCloudBlobIterable;
 
-  private AzureStorageAccountInputSource azureInputSource;
-
   static {
     try {
-      PREFIX_URI = new URI(AzureStorageAccountInputSource.SCHEME + "://" + STORAGE_ACCOUNT + "/" + CONTAINER + "/" + BLOB_NAME);
+      PREFIX_URI = new URI(
+          AzureStorageAccountInputSource.SCHEME + "://" + STORAGE_ACCOUNT + "/" + CONTAINER + "/" + BLOB_NAME
+      );
     }
     catch (Exception e) {
       throw new RuntimeException(e);
     }
   }
 
-  @Before
+  @BeforeEach
   public void setup()
   {
     storage = createMock(AzureStorage.class);
     entityFactory = createMock(AzureEntityFactory.class);
     inputSplit = createMock(InputSplit.class);
-    azureEntity1 = createMock(AzureEntity.class);
+    azureEntity = createMock(AzureEntity.class);
     azureCloudBlobIterableFactory = createMock(AzureCloudBlobIterableFactory.class);
     inputDataConfig = createMock(AzureInputDataConfig.class);
-    cloudBlobDruid1 = createMock(CloudBlobHolder.class);
+    cloudBlobDruid = createMock(CloudBlobHolder.class);
     azureCloudBlobIterable = createMock(AzureCloudBlobIterable.class);
     azureStorageAccountInputSourceConfig = createMock(AzureStorageAccountInputSourceConfig.class);
     azureAccountConfig = createMock(AzureAccountConfig.class);
     EasyMock.expect(azureAccountConfig.getAccount()).andReturn(DEFAULT_STORAGE_ACCOUNT).anyTimes();
   }
 
-  @Test(expected = IllegalArgumentException.class)
+  @Test
   public void test_constructor_emptyUrisEmptyPrefixesEmptyObjects_throwsIllegalArgumentException()
   {
     replayAll();
-    azureInputSource = new AzureStorageAccountInputSource(
-        entityFactory,
-        azureCloudBlobIterableFactory,
-        inputDataConfig,
-        azureAccountConfig,
-        EMPTY_URIS,
-        EMPTY_PREFIXES,
-        EMPTY_OBJECTS,
-        null,
-        azureStorageAccountInputSourceConfig,
-        null
+
+    //noinspection ResultOfObjectAllocationIgnored
+    assertThrows(
+        IllegalArgumentException.class,
+        () -> new AzureStorageAccountInputSource(
+            entityFactory,
+            azureCloudBlobIterableFactory,
+            inputDataConfig,
+            azureAccountConfig,
+            EMPTY_URIS,
+            EMPTY_PREFIXES,
+            EMPTY_OBJECTS,
+            null,
+            azureStorageAccountInputSourceConfig,
+            null
+        )
     );
   }
 
   @Test
   public void test_createEntity_returnsExpectedEntity()
   {
-    EasyMock.expect(entityFactory.create(EasyMock.eq(CLOUD_OBJECT_LOCATION_1), EasyMock.anyObject(AzureStorage.class), EasyMock.eq(AzureStorageAccountInputSource.SCHEME))).andReturn(azureEntity1);
+    EasyMock.expect(
+        entityFactory.create(
+            EasyMock.eq(CLOUD_OBJECT_LOCATION_1),
+            EasyMock.anyObject(AzureStorage.class),
+            EasyMock.eq(AzureStorageAccountInputSource.SCHEME)
+        )
+    ).andReturn(azureEntity);
     EasyMock.expect(inputSplit.get()).andReturn(ImmutableList.of(CLOUD_OBJECT_LOCATION_1)).times(2);
     replayAll();
 
     List<CloudObjectLocation> objects = ImmutableList.of(CLOUD_OBJECT_LOCATION_1);
-    azureInputSource = new AzureStorageAccountInputSource(
+    final AzureStorageAccountInputSource azureInputSource = new AzureStorageAccountInputSource(
         entityFactory,
         azureCloudBlobIterableFactory,
         inputDataConfig,
@@ -160,9 +177,9 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
         null
     );
 
-    Assert.assertEquals(1, inputSplit.get().size());
+    assertEquals(1, inputSplit.get().size());
     AzureEntity actualAzureEntity = azureInputSource.createEntity(inputSplit.get().get(0));
-    Assert.assertSame(azureEntity1, actualAzureEntity);
+    assertSame(azureEntity, actualAzureEntity);
     verifyAll();
   }
 
@@ -171,19 +188,24 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
   {
     List<URI> prefixes = ImmutableList.of(PREFIX_URI);
     List<List<CloudObjectLocation>> expectedCloudLocations = ImmutableList.of(ImmutableList.of(CLOUD_OBJECT_LOCATION_1));
-    List<CloudBlobHolder> expectedCloudBlobs = ImmutableList.of(cloudBlobDruid1);
+    List<CloudBlobHolder> expectedCloudBlobs = ImmutableList.of(cloudBlobDruid);
     Iterator<CloudBlobHolder> expectedCloudBlobsIterator = expectedCloudBlobs.iterator();
     EasyMock.expect(inputDataConfig.getMaxListingLength()).andReturn(MAX_LISTING_LENGTH);
-    EasyMock.expect(azureCloudBlobIterableFactory.create(EasyMock.eq(prefixes), EasyMock.eq(MAX_LISTING_LENGTH), EasyMock.anyObject(AzureStorage.class))).andReturn(
-        azureCloudBlobIterable);
+    EasyMock.expect(
+        azureCloudBlobIterableFactory.create(
+            EasyMock.eq(prefixes),
+            EasyMock.eq(MAX_LISTING_LENGTH),
+            EasyMock.anyObject(AzureStorage.class)
+        )
+    ).andReturn(azureCloudBlobIterable);
     EasyMock.expect(azureCloudBlobIterable.iterator()).andReturn(expectedCloudBlobsIterator);
-    EasyMock.expect(cloudBlobDruid1.getStorageAccount()).andReturn(STORAGE_ACCOUNT).anyTimes();
-    EasyMock.expect(cloudBlobDruid1.getContainerName()).andReturn(CONTAINER).anyTimes();
-    EasyMock.expect(cloudBlobDruid1.getName()).andReturn(BLOB_PATH).anyTimes();
-    EasyMock.expect(cloudBlobDruid1.getBlobLength()).andReturn(100L).anyTimes();
+    EasyMock.expect(cloudBlobDruid.getStorageAccount()).andReturn(STORAGE_ACCOUNT).anyTimes();
+    EasyMock.expect(cloudBlobDruid.getContainerName()).andReturn(CONTAINER).anyTimes();
+    EasyMock.expect(cloudBlobDruid.getName()).andReturn(BLOB_PATH).anyTimes();
+    EasyMock.expect(cloudBlobDruid.getBlobLength()).andReturn(100L).anyTimes();
     replayAll();
 
-    azureInputSource = new AzureStorageAccountInputSource(
+    final AzureStorageAccountInputSource azureInputSource = new AzureStorageAccountInputSource(
         entityFactory,
         azureCloudBlobIterableFactory,
         inputDataConfig,
@@ -201,10 +223,11 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
         new MaxSizeSplitHintSpec(null, 1)
     );
 
-    List<List<CloudObjectLocation>> actualCloudLocationList = cloudObjectStream.map(InputSplit::get)
+    List<List<CloudObjectLocation>> actualCloudLocationList = cloudObjectStream
+        .map(InputSplit::get)
         .collect(Collectors.toList());
     verifyAll();
-    Assert.assertEquals(expectedCloudLocations, actualCloudLocationList);
+    assertEquals(expectedCloudLocations, actualCloudLocationList);
   }
 
   @Test
@@ -212,7 +235,7 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
   {
     List<URI> prefixes = ImmutableList.of(PREFIX_URI);
     List<List<CloudObjectLocation>> expectedCloudLocations = ImmutableList.of(ImmutableList.of(CLOUD_OBJECT_LOCATION_1));
-    List<CloudBlobHolder> expectedCloudBlobs = ImmutableList.of(cloudBlobDruid1);
+    List<CloudBlobHolder> expectedCloudBlobs = ImmutableList.of(cloudBlobDruid);
     Iterator<CloudBlobHolder> expectedCloudBlobsIterator = expectedCloudBlobs.iterator();
     String objectGlob = "**.csv";
 
@@ -224,17 +247,22 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
     );
 
     EasyMock.expect(inputDataConfig.getMaxListingLength()).andReturn(MAX_LISTING_LENGTH);
-    EasyMock.expect(azureCloudBlobIterableFactory.create(EasyMock.eq(prefixes), EasyMock.eq(MAX_LISTING_LENGTH), EasyMock.anyObject(AzureStorage.class))).andReturn(
-        azureCloudBlobIterable);
+    EasyMock.expect(
+        azureCloudBlobIterableFactory.create(
+            EasyMock.eq(prefixes),
+            EasyMock.eq(MAX_LISTING_LENGTH),
+            EasyMock.anyObject(AzureStorage.class)
+        )
+    ).andReturn(azureCloudBlobIterable);
     EasyMock.expect(azureCloudBlobIterable.iterator()).andReturn(expectedCloudBlobsIterator);
-    EasyMock.expect(cloudBlobDruid1.getStorageAccount()).andReturn(STORAGE_ACCOUNT).anyTimes();
-    EasyMock.expect(cloudBlobDruid1.getBlobLength()).andReturn(100L).anyTimes();
-    EasyMock.expect(cloudBlobDruid1.getContainerName()).andReturn(CONTAINER).anyTimes();
-    EasyMock.expect(cloudBlobDruid1.getName()).andReturn(BLOB_PATH).anyTimes();
+    EasyMock.expect(cloudBlobDruid.getStorageAccount()).andReturn(STORAGE_ACCOUNT).anyTimes();
+    EasyMock.expect(cloudBlobDruid.getBlobLength()).andReturn(100L).anyTimes();
+    EasyMock.expect(cloudBlobDruid.getContainerName()).andReturn(CONTAINER).anyTimes();
+    EasyMock.expect(cloudBlobDruid.getName()).andReturn(BLOB_PATH).anyTimes();
 
     replayAll();
 
-    azureInputSource = new AzureStorageAccountInputSource(
+    final AzureStorageAccountInputSource azureInputSource = new AzureStorageAccountInputSource(
         entityFactory,
         azureCloudBlobIterableFactory,
         inputDataConfig,
@@ -252,10 +280,11 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
         new MaxSizeSplitHintSpec(null, 1)
     );
 
-    List<List<CloudObjectLocation>> actualCloudLocationList = cloudObjectStream.map(InputSplit::get)
+    List<List<CloudObjectLocation>> actualCloudLocationList = cloudObjectStream
+        .map(InputSplit::get)
         .collect(Collectors.toList());
     verifyAll();
-    Assert.assertEquals(expectedCloudLocations, actualCloudLocationList);
+    assertEquals(expectedCloudLocations, actualCloudLocationList);
   }
 
   @Test
@@ -265,7 +294,7 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
     EasyMock.expect(inputSplit.get()).andReturn(ImmutableList.of(CLOUD_OBJECT_LOCATION_1));
     replayAll();
 
-    azureInputSource = new AzureStorageAccountInputSource(
+    final AzureStorageAccountInputSource azureInputSource = new AzureStorageAccountInputSource(
         entityFactory,
         azureCloudBlobIterableFactory,
         inputDataConfig,
@@ -279,30 +308,33 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
     );
 
     SplittableInputSource<List<CloudObjectLocation>> newInputSource = azureInputSource.withSplit(inputSplit);
-    Assert.assertTrue(newInputSource.isSplittable());
+    assertTrue(newInputSource.isSplittable());
     verifyAll();
   }
 
   @Test
   public void test_toString_returnsExpectedString()
   {
-    List<URI> prefixes = ImmutableList.of(PREFIX_URI);
-    azureInputSource = new AzureStorageAccountInputSource(
+    final AzureStorageAccountInputSource azureInputSource = new AzureStorageAccountInputSource(
         entityFactory,
         azureCloudBlobIterableFactory,
         inputDataConfig,
         azureAccountConfig,
         EMPTY_URIS,
-        prefixes,
+        ImmutableList.of(PREFIX_URI),
         EMPTY_OBJECTS,
         null,
         azureStorageAccountInputSourceConfig,
         null
     );
-    String azureStorageAccountInputSourceString = azureInputSource.toString();
-    Assert.assertEquals(
-        "AzureStorageAccountInputSource{uris=[], prefixes=[azureStorage://STORAGE_ACCOUNT/CONTAINER/blob], objects=[], objectGlob=null, azureStorageAccountInputSourceConfig=" + azureStorageAccountInputSourceConfig + "}",
-        azureStorageAccountInputSourceString
+
+    assertEquals(
+        String.format(
+            Locale.ENGLISH,
+            "AzureStorageAccountInputSource{uris=[], prefixes=[azureStorage://STORAGE_ACCOUNT/CONTAINER/blob], objects=[], objectGlob=null, azureStorageAccountInputSourceConfig=%s}",
+            azureStorageAccountInputSourceConfig
+        ),
+        azureInputSource.toString()
     );
   }
 
@@ -310,7 +342,7 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
   public void test_toString_withAllSystemFields_returnsExpectedString()
   {
     List<URI> prefixes = ImmutableList.of(PREFIX_URI);
-    azureInputSource = new AzureStorageAccountInputSource(
+    final AzureStorageAccountInputSource azureInputSource = new AzureStorageAccountInputSource(
         entityFactory,
         azureCloudBlobIterableFactory,
         inputDataConfig,
@@ -325,15 +357,15 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
 
     String azureStorageAccountInputSourceString = azureInputSource.toString();
 
-    Assert.assertEquals(
+    assertEquals(
         "AzureStorageAccountInputSource{"
-            + "uris=[], "
-            + "prefixes=[azureStorage://STORAGE_ACCOUNT/CONTAINER/blob], "
-            + "objects=[], "
-            + "objectGlob=null, "
-            + "azureStorageAccountInputSourceConfig=" + azureStorageAccountInputSourceConfig + ", "
-            + "systemFields=[__file_uri, __file_bucket, __file_path]"
-            + "}",
+        + "uris=[], "
+        + "prefixes=[azureStorage://STORAGE_ACCOUNT/CONTAINER/blob], "
+        + "objects=[], "
+        + "objectGlob=null, "
+        + "azureStorageAccountInputSourceConfig=" + azureStorageAccountInputSourceConfig + ", "
+        + "systemFields=[__file_uri, __file_bucket, __file_path]"
+        + "}",
         azureStorageAccountInputSourceString
     );
   }
@@ -342,7 +374,7 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
   public void test_getTypes_returnsExpectedTypes()
   {
     List<URI> prefixes = ImmutableList.of(PREFIX_URI);
-    azureInputSource = new AzureStorageAccountInputSource(
+    final AzureStorageAccountInputSource azureInputSource = new AzureStorageAccountInputSource(
         entityFactory,
         azureCloudBlobIterableFactory,
         inputDataConfig,
@@ -354,13 +386,13 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
         azureStorageAccountInputSourceConfig,
         null
     );
-    Assert.assertEquals(ImmutableSet.of(AzureStorageAccountInputSource.SCHEME), azureInputSource.getTypes());
+    assertEquals(ImmutableSet.of(AzureStorageAccountInputSource.SCHEME), azureInputSource.getTypes());
   }
 
   @Test
   public void test_systemFields()
   {
-    azureInputSource = (AzureStorageAccountInputSource) new AzureStorageAccountInputSource(
+    final AzureStorageAccountInputSource azureInputSource = new AzureStorageAccountInputSource(
         entityFactory,
         azureCloudBlobIterableFactory,
         inputDataConfig,
@@ -373,7 +405,7 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
         new SystemFields(EnumSet.of(SystemField.URI, SystemField.BUCKET, SystemField.PATH))
     );
 
-    Assert.assertEquals(
+    assertEquals(
         EnumSet.of(SystemField.URI, SystemField.BUCKET, SystemField.PATH),
         azureInputSource.getConfiguredSystemFields()
     );
@@ -385,19 +417,31 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
         (containerName, blobPath, storage) -> null
     );
 
-    Assert.assertEquals("azureStorage://foo/container/bar", azureInputSource.getSystemFieldValue(entity, SystemField.URI));
-    Assert.assertEquals("foo", azureInputSource.getSystemFieldValue(entity, SystemField.BUCKET));
-    Assert.assertEquals("container/bar", azureInputSource.getSystemFieldValue(entity, SystemField.PATH));
+    assertEquals(
+        "azureStorage://foo/container/bar",
+        azureInputSource.getSystemFieldValue(entity, SystemField.URI)
+    );
+    assertEquals("foo", azureInputSource.getSystemFieldValue(entity, SystemField.BUCKET));
+    assertEquals("container/bar", azureInputSource.getSystemFieldValue(entity, SystemField.PATH));
   }
 
   @Test
   public void abidesEqualsContract()
   {
-    EqualsVerifier.forClass(AzureStorageAccountInputSource.class)
+    EqualsVerifier
+        .forClass(AzureStorageAccountInputSource.class)
         .usingGetClass()
         .withPrefabValues(Logger.class, new Logger(AzureStorage.class), new Logger(AzureStorage.class))
-        .withPrefabValues(BlobContainerClient.class, new BlobContainerClientBuilder().buildClient(), new BlobContainerClientBuilder().buildClient())
-        .withPrefabValues(AzureIngestClientFactory.class, new AzureIngestClientFactory(null, null), new AzureIngestClientFactory(null, null))
+        .withPrefabValues(
+            BlobContainerClient.class,
+            new BlobContainerClientBuilder().buildClient(),
+            new BlobContainerClientBuilder().buildClient()
+        )
+        .withPrefabValues(
+            AzureIngestClientFactory.class,
+            new AzureIngestClientFactory(null, null),
+            new AzureIngestClientFactory(null, null)
+        )
         .withIgnoredFields("entityFactory")
         .withIgnoredFields("azureCloudBlobIterableFactory")
         .withNonnullFields("inputDataConfig")
@@ -415,9 +459,8 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
     Pair<String, String> storageLocation = AzureStorageAccountInputSource.getContainerAndPathFromObjectLocation(
         CLOUD_OBJECT_LOCATION_1
     );
-    Assert.assertEquals(CONTAINER, storageLocation.lhs);
-    Assert.assertEquals(BLOB_PATH, storageLocation.rhs);
-
+    assertEquals(CONTAINER, storageLocation.lhs);
+    assertEquals(BLOB_PATH, storageLocation.rhs);
   }
 
   @Test
@@ -426,12 +469,11 @@ public class AzureStorageAccountInputSourceTest extends EasyMockSupport
     Pair<String, String> storageLocation = AzureStorageAccountInputSource.getContainerAndPathFromObjectLocation(
         new CloudObjectLocation(STORAGE_ACCOUNT, CONTAINER)
     );
-    Assert.assertEquals(CONTAINER, storageLocation.lhs);
-    Assert.assertEquals("", storageLocation.rhs);
-
+    assertEquals(CONTAINER, storageLocation.lhs);
+    assertEquals("", storageLocation.rhs);
   }
 
-  @After
+  @AfterEach
   public void cleanup()
   {
     resetAll();
