@@ -21,6 +21,7 @@ package org.apache.druid.query.aggregation.datasketches.theta.oldapi;
 
 import com.fasterxml.jackson.annotation.JsonCreator;
 import com.fasterxml.jackson.annotation.JsonProperty;
+import org.apache.druid.query.aggregation.AggregatorFactory;
 import org.apache.druid.query.aggregation.datasketches.theta.SketchMergeAggregatorFactory;
 
 /**
@@ -36,4 +37,10 @@ public class OldSketchBuildAggregatorFactory extends SketchMergeAggregatorFactor
   {
     super(name, fieldName, size, true, false, null);
   }
+
+  @Override
+  public AggregatorFactory withName(String newName)
+  {
+    return new OldSketchBuildAggregatorFactory(newName, getFieldName(), getSize());
+  }
 }
