@@ -26,7 +26,6 @@ import com.google.inject.Injector;
 import org.apache.commons.lang3.ArrayUtils;
 import org.apache.druid.client.coordinator.Coordinator;
 import org.apache.druid.concurrent.LifecycleLock;
-import org.apache.druid.discovery.DruidLeaderClient;
 import org.apache.druid.guice.ManageLifecycle;
 import org.apache.druid.guice.annotations.Smile;
 import org.apache.druid.java.util.common.FileUtils;
@@ -38,9 +37,10 @@ import org.apache.druid.java.util.common.concurrent.ScheduledExecutors;
 import org.apache.druid.java.util.common.lifecycle.LifecycleStart;
 import org.apache.druid.java.util.common.lifecycle.LifecycleStop;
 import org.apache.druid.java.util.emitter.EmittingLogger;
-import org.apache.druid.java.util.http.client.Request;
 import org.apache.druid.java.util.http.client.response.BytesFullResponseHandler;
 import org.apache.druid.java.util.http.client.response.BytesFullResponseHolder;
+import org.apache.druid.rpc.RequestBuilder;
+import org.apache.druid.rpc.ServiceClient;
 import org.apache.druid.security.basic.BasicAuthCommonCacheConfig;
 import org.apache.druid.security.basic.BasicAuthUtils;
 import org.apache.druid.security.basic.authentication.BasicHTTPAuthenticator;
@@ -74,7 +74,7 @@ public class CoordinatorPollingBasicAuthenticatorCacheManager implements BasicAu
   private final Injector injector;
   private final ObjectMapper objectMapper;
   private final LifecycleLock lifecycleLock = new LifecycleLock();
-  private final DruidLeaderClient druidLeaderClient;
+  private final ServiceClient coordinatorClient;
   private final BasicAuthCommonCacheConfig commonCacheConfig;
   private final ScheduledExecutorService exec;
 
@@ -83,7 +83,7 @@ public class CoordinatorPollingBasicAuthenticatorCacheManager implements BasicAu
       Injector injector,
       BasicAuthCommonCacheConfig commonCacheConfig,
       @Smile ObjectMapper objectMapper,
-      @Coordinator DruidLeaderClient druidLeaderClient
+      @Coordinator ServiceClient coordinatorClient
   )
   {
     this.exec = Execs.scheduledSingleThreaded("BasicAuthenticatorCacheManager-Exec--%d");
@@ -92,7 +92,7 @@ public class CoordinatorPollingBasicAuthenticatorCacheManager implements BasicAu
     this.objectMapper = objectMapper;
     this.cachedUserMaps = new ConcurrentHashMap<>();
     this.authenticatorPrefixes = new HashSet<>();
-    this.druidLeaderClient = druidLeaderClient;
+    this.coordinatorClient = coordinatorClient;
   }
 
   @LifecycleStart
@@ -254,11 +254,11 @@ public class CoordinatorPollingBasicAuthenticatorCacheManager implements BasicAu
   private Map<String, BasicAuthenticatorUser> tryFetchUserMapFromCoordinator(String prefix) throws Exception
   {
     Map<String, BasicAuthenticatorUser> userMap = null;
-    Request req = druidLeaderClient.makeRequest(
+    RequestBuilder req = new RequestBuilder(
         HttpMethod.GET,
         StringUtils.format("/druid-ext/basic-security/authentication/db/%s/cachedSerializedUserMap", prefix)
     );
-    BytesFullResponseHolder responseHolder = druidLeaderClient.go(
+    BytesFullResponseHolder responseHolder = coordinatorClient.request(
         req,
         new BytesFullResponseHandler()
     );
