@@ -25,7 +25,6 @@ import com.fasterxml.jackson.annotation.JsonTypeName;
 import com.google.inject.Provider;
 import org.apache.druid.java.util.common.IAE;
 import org.apache.druid.java.util.common.logger.Logger;
-import org.apache.druid.security.basic.BasicAuthUtils;
 import org.apache.druid.security.basic.BasicSecurityAuthenticationException;
 import org.apache.druid.security.basic.authentication.db.cache.BasicAuthenticatorCacheManager;
 import org.apache.druid.security.basic.authentication.entity.BasicAuthenticatorCredentials;
@@ -42,6 +41,7 @@ public class MetadataStoreCredentialsValidator implements CredentialsValidator
 {
   private static final Logger LOG = new Logger(MetadataStoreCredentialsValidator.class);
   private final Provider<BasicAuthenticatorCacheManager> cacheManager;
+  private final PasswordHashGenerator hashGenerator = new PasswordHashGenerator();
 
   @JsonCreator
   public MetadataStoreCredentialsValidator(
@@ -74,7 +74,7 @@ public class MetadataStoreCredentialsValidator implements CredentialsValidator
       return null;
     }
 
-    byte[] recalculatedHash = BasicAuthUtils.hashPassword(
+    byte[] recalculatedHash = hashGenerator.getOrComputePasswordHash(
         password,
         credentials.getSalt(),
         credentials.getIterations()
