@@ -23,6 +23,7 @@ import com.fasterxml.jackson.databind.ObjectMapper;
 import com.fasterxml.jackson.dataformat.smile.SmileFactory;
 import com.google.common.collect.ImmutableMap;
 import com.google.common.collect.ImmutableSet;
+import org.apache.druid.audit.AuditManager;
 import org.apache.druid.metadata.DefaultPasswordProvider;
 import org.apache.druid.metadata.MetadataStorageTablesConfig;
 import org.apache.druid.metadata.TestDerbyConnector;
@@ -35,7 +36,10 @@ import org.apache.druid.security.basic.authentication.endpoint.CoordinatorBasicA
 import org.apache.druid.security.basic.authentication.entity.BasicAuthenticatorCredentialUpdate;
 import org.apache.druid.security.basic.authentication.entity.BasicAuthenticatorCredentials;
 import org.apache.druid.security.basic.authentication.entity.BasicAuthenticatorUser;
+import org.apache.druid.security.basic.authentication.validator.PasswordHashGenerator;
+import org.apache.druid.server.security.AuthConfig;
 import org.apache.druid.server.security.AuthValidator;
+import org.apache.druid.server.security.AuthenticationResult;
 import org.apache.druid.server.security.AuthenticatorMapper;
 import org.easymock.EasyMock;
 import org.junit.After;
@@ -50,6 +54,7 @@ import org.mockito.junit.MockitoJUnitRunner;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.ws.rs.core.Response;
+import java.util.Collections;
 import java.util.Map;
 import java.util.Set;
 
@@ -68,6 +73,9 @@ public class CoordinatorBasicAuthenticatorResourceTest
 
   @Mock
   private AuthValidator authValidator;
+
+  @Mock
+  private AuditManager auditManager;
   private BasicAuthenticatorResource resource;
   private CoordinatorBasicAuthenticatorMetadataStorageUpdater storageUpdater;
   private HttpServletRequest req;
@@ -77,6 +85,13 @@ public class CoordinatorBasicAuthenticatorResourceTest
   public void setUp()
   {
     req = EasyMock.createStrictMock(HttpServletRequest.class);
+    EasyMock.expect(req.getHeader(AuditManager.X_DRUID_AUTHOR)).andReturn("author").anyTimes();
+    EasyMock.expect(req.getHeader(AuditManager.X_DRUID_COMMENT)).andReturn("comment").anyTimes();
+    EasyMock.expect(req.getAttribute(AuthConfig.DRUID_AUTHENTICATION_RESULT)).andReturn(
+        new AuthenticationResult("id", "authorizer", "authBy", Collections.emptyMap())
+    ).anyTimes();
+    EasyMock.expect(req.getRemoteAddr()).andReturn("127.0.0.1").anyTimes();
+    EasyMock.replay(req);
 
     objectMapper = new ObjectMapper(new SmileFactory());
     TestDerbyConnector connector = derbyConnectorRule.getConnector();
@@ -145,7 +160,8 @@ public class CoordinatorBasicAuthenticatorResourceTest
             authenticatorMapper,
             objectMapper
         ),
-        authValidator
+        authValidator,
+        auditManager
     );
 
     storageUpdater.start();
@@ -155,12 +171,15 @@ public class CoordinatorBasicAuthenticatorResourceTest
   public void tearDown()
   {
     storageUpdater.stop();
+    if (req != null) {
+      EasyMock.verify(req);
+    }
   }
 
   @Test
   public void testInvalidAuthenticator()
   {
-    Response response = resource.getAllUsers(req, "invalidName");
+    Response response = resource.getAllUsers(mockHttpRequestNoAudit(), "invalidName");
     Assert.assertEquals(400, response.getStatus());
     Assert.assertEquals(
         errorMapWithMsg("Basic authenticator with name [invalidName] does not exist."),
@@ -171,13 +190,13 @@ public class CoordinatorBasicAuthenticatorResourceTest
   @Test
   public void testGetAllUsers()
   {
-    Response response = resource.getAllUsers(req, AUTHENTICATOR_NAME);
+    Response response = resource.getAllUsers(mockHttpRequestNoAudit(), AUTHENTICATOR_NAME);
     Assert.assertEquals(200, response.getStatus());
     Assert.assertEquals(ImmutableSet.of(BasicAuthUtils.ADMIN_NAME, BasicAuthUtils.INTERNAL_USER_NAME), response.getEntity());
 
-    resource.createUser(req, AUTHENTICATOR_NAME, "druid");
-    resource.createUser(req, AUTHENTICATOR_NAME, "druid2");
-    resource.createUser(req, AUTHENTICATOR_NAME, "druid3");
+    resource.createUser(mockHttpRequest(), AUTHENTICATOR_NAME, "druid");
+    resource.createUser(mockHttpRequest(), AUTHENTICATOR_NAME, "druid2");
+    resource.createUser(mockHttpRequest(), AUTHENTICATOR_NAME, "druid3");
 
     Set<String> expectedUsers = ImmutableSet.of(
         BasicAuthUtils.ADMIN_NAME,
@@ -187,12 +206,12 @@ public class CoordinatorBasicAuthenticatorResourceTest
         "druid3"
     );
 
-    response = resource.getAllUsers(req, AUTHENTICATOR_NAME);
+    response = resource.getAllUsers(mockHttpRequestNoAudit(), AUTHENTICATOR_NAME);
     Assert.assertEquals(200, response.getStatus());
     Assert.assertEquals(expectedUsers, response.getEntity());
 
     // Verify cached user map is also getting updated
-    response = resource.getCachedSerializedUserMap(req, AUTHENTICATOR_NAME);
+    response = resource.getCachedSerializedUserMap(mockHttpRequestNoAudit(), AUTHENTICATOR_NAME);
     Assert.assertEquals(200, response.getStatus());
     Assert.assertTrue(response.getEntity() instanceof byte[]);
     Map<String, BasicAuthenticatorUser> cachedUserMap = BasicAuthUtils.deserializeAuthenticatorUserMap(objectMapper, (byte[]) response.getEntity());
@@ -211,17 +230,17 @@ public class CoordinatorBasicAuthenticatorResourceTest
   @Test
   public void testGetAllUsersSeparateDatabaseTables()
   {
-    Response response = resource.getAllUsers(req, AUTHENTICATOR_NAME);
+    Response response = resource.getAllUsers(mockHttpRequestNoAudit(), AUTHENTICATOR_NAME);
     Assert.assertEquals(200, response.getStatus());
     Assert.assertEquals(ImmutableSet.of(BasicAuthUtils.ADMIN_NAME, BasicAuthUtils.INTERNAL_USER_NAME), response.getEntity());
 
-    resource.createUser(req, AUTHENTICATOR_NAME, "druid");
-    resource.createUser(req, AUTHENTICATOR_NAME, "druid2");
-    resource.createUser(req, AUTHENTICATOR_NAME, "druid3");
+    resource.createUser(mockHttpRequest(), AUTHENTICATOR_NAME, "druid");
+    resource.createUser(mockHttpRequest(), AUTHENTICATOR_NAME, "druid2");
+    resource.createUser(mockHttpRequest(), AUTHENTICATOR_NAME, "druid3");
 
-    resource.createUser(req, AUTHENTICATOR_NAME2, "druid4");
-    resource.createUser(req, AUTHENTICATOR_NAME2, "druid5");
-    resource.createUser(req, AUTHENTICATOR_NAME2, "druid6");
+    resource.createUser(mockHttpRequest(), AUTHENTICATOR_NAME2, "druid4");
+    resource.createUser(mockHttpRequest(), AUTHENTICATOR_NAME2, "druid5");
+    resource.createUser(mockHttpRequest(), AUTHENTICATOR_NAME2, "druid6");
 
     Set<String> expectedUsers = ImmutableSet.of(
         BasicAuthUtils.ADMIN_NAME,
@@ -239,12 +258,12 @@ public class CoordinatorBasicAuthenticatorResourceTest
         "druid6"
     );
 
-    response = resource.getAllUsers(req, AUTHENTICATOR_NAME);
+    response = resource.getAllUsers(mockHttpRequestNoAudit(), AUTHENTICATOR_NAME);
     Assert.assertEquals(200, response.getStatus());
     Assert.assertEquals(expectedUsers, response.getEntity());
 
     // Verify cached user map for AUTHENTICATOR_NAME authenticator is also getting updated
-    response = resource.getCachedSerializedUserMap(req, AUTHENTICATOR_NAME);
+    response = resource.getCachedSerializedUserMap(mockHttpRequestNoAudit(), AUTHENTICATOR_NAME);
     Assert.assertEquals(200, response.getStatus());
     Assert.assertTrue(response.getEntity() instanceof byte[]);
 
@@ -260,12 +279,12 @@ public class CoordinatorBasicAuthenticatorResourceTest
     Assert.assertNotNull(cachedUserMap.get("druid3"));
     Assert.assertEquals(cachedUserMap.get("druid3").getName(), "druid3");
 
-    response = resource.getAllUsers(req, AUTHENTICATOR_NAME2);
+    response = resource.getAllUsers(mockHttpRequestNoAudit(), AUTHENTICATOR_NAME2);
     Assert.assertEquals(200, response.getStatus());
     Assert.assertEquals(expectedUsers2, response.getEntity());
 
     // Verify cached user map for each AUTHENTICATOR_NAME2 is also getting updated
-    response = resource.getCachedSerializedUserMap(req, AUTHENTICATOR_NAME2);
+    response = resource.getCachedSerializedUserMap(mockHttpRequestNoAudit(), AUTHENTICATOR_NAME2);
     Assert.assertEquals(200, response.getStatus());
     Assert.assertTrue(response.getEntity() instanceof byte[]);
 
@@ -285,29 +304,29 @@ public class CoordinatorBasicAuthenticatorResourceTest
   @Test
   public void testCreateDeleteUser()
   {
-    Response response = resource.createUser(req, AUTHENTICATOR_NAME, "druid");
+    Response response = resource.createUser(mockHttpRequest(), AUTHENTICATOR_NAME, "druid");
     Assert.assertEquals(200, response.getStatus());
 
-    response = resource.getUser(req, AUTHENTICATOR_NAME, "druid");
+    response = resource.getUser(mockHttpRequestNoAudit(), AUTHENTICATOR_NAME, "druid");
     Assert.assertEquals(200, response.getStatus());
     BasicAuthenticatorUser expectedUser = new BasicAuthenticatorUser("druid", null);
     Assert.assertEquals(expectedUser, response.getEntity());
 
-    response = resource.deleteUser(req, AUTHENTICATOR_NAME, "druid");
+    response = resource.deleteUser(mockHttpRequest(), AUTHENTICATOR_NAME, "druid");
     Assert.assertEquals(200, response.getStatus());
 
-    response = resource.getCachedSerializedUserMap(req, AUTHENTICATOR_NAME);
+    response = resource.getCachedSerializedUserMap(mockHttpRequestNoAudit(), AUTHENTICATOR_NAME);
     Assert.assertEquals(200, response.getStatus());
     Assert.assertTrue(response.getEntity() instanceof byte[]);
     Map<String, BasicAuthenticatorUser> cachedUserMap = BasicAuthUtils.deserializeAuthenticatorUserMap(objectMapper, (byte[]) response.getEntity());
     Assert.assertNotNull(cachedUserMap);
     Assert.assertNull(cachedUserMap.get("druid"));
 
-    response = resource.deleteUser(req, AUTHENTICATOR_NAME, "druid");
+    response = resource.deleteUser(mockHttpRequestNoAudit(), AUTHENTICATOR_NAME, "druid");
     Assert.assertEquals(400, response.getStatus());
     Assert.assertEquals(errorMapWithMsg("User [druid] does not exist."), response.getEntity());
 
-    response = resource.getUser(req, AUTHENTICATOR_NAME, "druid");
+    response = resource.getUser(mockHttpRequestNoAudit(), AUTHENTICATOR_NAME, "druid");
     Assert.assertEquals(400, response.getStatus());
     Assert.assertEquals(errorMapWithMsg("User [druid] does not exist."), response.getEntity());
   }
@@ -315,18 +334,18 @@ public class CoordinatorBasicAuthenticatorResourceTest
   @Test
   public void testUserCredentials()
   {
-    Response response = resource.createUser(req, AUTHENTICATOR_NAME, "druid");
+    Response response = resource.createUser(mockHttpRequest(), AUTHENTICATOR_NAME, "druid");
     Assert.assertEquals(200, response.getStatus());
 
     response = resource.updateUserCredentials(
-        req,
+        mockHttpRequest(),
         AUTHENTICATOR_NAME,
         "druid",
         new BasicAuthenticatorCredentialUpdate("helloworld", null)
     );
     Assert.assertEquals(200, response.getStatus());
 
-    response = resource.getUser(req, AUTHENTICATOR_NAME, "druid");
+    response = resource.getUser(mockHttpRequestNoAudit(), AUTHENTICATOR_NAME, "druid");
     Assert.assertEquals(200, response.getStatus());
     BasicAuthenticatorUser actualUser = (BasicAuthenticatorUser) response.getEntity();
     Assert.assertEquals("druid", actualUser.getName());
@@ -336,17 +355,17 @@ public class CoordinatorBasicAuthenticatorResourceTest
     byte[] hash = credentials.getHash();
     int iterations = credentials.getIterations();
     Assert.assertEquals(BasicAuthUtils.SALT_LENGTH, salt.length);
-    Assert.assertEquals(BasicAuthUtils.KEY_LENGTH / 8, hash.length);
+    Assert.assertEquals(PasswordHashGenerator.KEY_LENGTH / 8, hash.length);
     Assert.assertEquals(BasicAuthUtils.DEFAULT_KEY_ITERATIONS, iterations);
 
-    byte[] recalculatedHash = BasicAuthUtils.hashPassword(
+    byte[] recalculatedHash = PasswordHashGenerator.computePasswordHash(
         "helloworld".toCharArray(),
         salt,
         iterations
     );
     Assert.assertArrayEquals(recalculatedHash, hash);
 
-    response = resource.getCachedSerializedUserMap(req, AUTHENTICATOR_NAME);
+    response = resource.getCachedSerializedUserMap(mockHttpRequestNoAudit(), AUTHENTICATOR_NAME);
     Assert.assertEquals(200, response.getStatus());
     Assert.assertTrue(response.getEntity() instanceof byte[]);
     Map<String, BasicAuthenticatorUser> cachedUserMap = BasicAuthUtils.deserializeAuthenticatorUserMap(objectMapper, (byte[]) response.getEntity());
@@ -359,25 +378,25 @@ public class CoordinatorBasicAuthenticatorResourceTest
     hash = cachedUserCredentials.getHash();
     iterations = cachedUserCredentials.getIterations();
     Assert.assertEquals(BasicAuthUtils.SALT_LENGTH, salt.length);
-    Assert.assertEquals(BasicAuthUtils.KEY_LENGTH / 8, hash.length);
+    Assert.assertEquals(PasswordHashGenerator.KEY_LENGTH / 8, hash.length);
     Assert.assertEquals(BasicAuthUtils.DEFAULT_KEY_ITERATIONS, iterations);
 
-    recalculatedHash = BasicAuthUtils.hashPassword(
+    recalculatedHash = PasswordHashGenerator.computePasswordHash(
         "helloworld".toCharArray(),
         salt,
         iterations
     );
     Assert.assertArrayEquals(recalculatedHash, hash);
 
-    response = resource.deleteUser(req, AUTHENTICATOR_NAME, "druid");
+    response = resource.deleteUser(mockHttpRequest(), AUTHENTICATOR_NAME, "druid");
     Assert.assertEquals(200, response.getStatus());
 
-    response = resource.getUser(req, AUTHENTICATOR_NAME, "druid");
+    response = resource.getUser(mockHttpRequestNoAudit(), AUTHENTICATOR_NAME, "druid");
     Assert.assertEquals(400, response.getStatus());
     Assert.assertEquals(errorMapWithMsg("User [druid] does not exist."), response.getEntity());
 
     response = resource.updateUserCredentials(
-        req,
+        mockHttpRequestNoAudit(),
         AUTHENTICATOR_NAME,
         "druid",
         new BasicAuthenticatorCredentialUpdate("helloworld", null)
@@ -386,6 +405,36 @@ public class CoordinatorBasicAuthenticatorResourceTest
     Assert.assertEquals(errorMapWithMsg("User [druid] does not exist."), response.getEntity());
   }
 
+  private HttpServletRequest mockHttpRequestNoAudit()
+  {
+    if (req != null) {
+      EasyMock.verify(req);
+    }
+    req = EasyMock.createStrictMock(HttpServletRequest.class);
+    EasyMock.replay(req);
+    return req;
+  }
+
+  private HttpServletRequest mockHttpRequest()
+  {
+    if (req != null) {
+      EasyMock.verify(req);
+    }
+    req = EasyMock.createStrictMock(HttpServletRequest.class);
+    EasyMock.expect(req.getHeader(AuditManager.X_DRUID_AUTHOR)).andReturn("author").once();
+    EasyMock.expect(req.getHeader(AuditManager.X_DRUID_COMMENT)).andReturn("comment").once();
+    EasyMock.expect(req.getAttribute(AuthConfig.DRUID_AUTHENTICATION_RESULT)).andReturn(
+        new AuthenticationResult("id", "authorizer", "authBy", Collections.emptyMap())
+    ).once();
+    EasyMock.expect(req.getRemoteAddr()).andReturn("127.0.0.1").once();
+    EasyMock.expect(req.getMethod()).andReturn("GET").once();
+    EasyMock.expect(req.getRequestURI()).andReturn("uri").once();
+    EasyMock.expect(req.getQueryString()).andReturn("a=b").once();
+    EasyMock.replay(req);
+
+    return req;
+  }
+
   private static Map<String, String> errorMapWithMsg(String errorMsg)
   {
     return ImmutableMap.of("error", errorMsg);
