@@ -26,7 +26,6 @@ import org.apache.druid.indexing.kafka.KafkaConsumerConfigs;
 import org.apache.druid.java.util.common.FileUtils;
 import org.apache.druid.java.util.common.StringUtils;
 import org.apache.kafka.clients.admin.Admin;
-import org.apache.kafka.clients.consumer.KafkaConsumer;
 import org.apache.kafka.clients.producer.KafkaProducer;
 import org.apache.kafka.common.serialization.ByteArraySerializer;
 import org.apache.kafka.common.utils.Time;
@@ -95,7 +94,7 @@ public class TestBroker implements Closeable
 
   public int getPort()
   {
-    return server.socketServer().config().port();
+    return server.advertisedListeners().apply(0).port();
   }
 
   public KafkaProducer<byte[], byte[]> newProducer()
@@ -115,11 +114,6 @@ public class TestBroker implements Closeable
     return props;
   }
 
-  public KafkaConsumer<byte[], byte[]> newConsumer()
-  {
-    return new KafkaConsumer<>(consumerProperties());
-  }
-
   public Map<String, Object> producerProperties()
   {
     final Map<String, Object> props = new HashMap<>();
