@@ -53,7 +53,7 @@ public class VarianceTopNQueryTest extends InitializedNullHandlingTest
   @Parameterized.Parameters(name = "{0}")
   public static Iterable<Object[]> constructorFeeder()
   {
-    return QueryRunnerTestHelper.transformToConstructionFeeder(TopNQueryRunnerTest.queryRunners());
+    return QueryRunnerTestHelper.transformToConstructionFeeder(TopNQueryRunnerTest.queryRunners(true));
   }
 
   private final QueryRunner<Result<TopNResultValue>> runner;
