@@ -20,6 +20,7 @@
 package org.apache.druid.indexing.overlord.sampler;
 
 import com.google.common.collect.ImmutableMap;
+import org.apache.druid.java.util.common.logger.Logger;
 
 import javax.ws.rs.core.Response;
 import javax.ws.rs.ext.ExceptionMapper;
@@ -28,13 +29,20 @@ import javax.ws.rs.ext.Provider;
 @Provider
 public class SamplerExceptionMapper implements ExceptionMapper<SamplerException>
 {
+  private static final Logger LOG = new Logger(SamplerExceptionMapper.class);
+
   @Override
   public Response toResponse(SamplerException exception)
   {
+    String message = exception.getMessage() == null ? "The sampler encountered an issue" : exception.getMessage();
+
+    // Logging the stack trace and returning the exception message in the response
+    LOG.error(exception, message);
+
     return Response.status(Response.Status.BAD_REQUEST)
                    .entity(ImmutableMap.of(
                        "error",
-                       exception.getMessage() == null ? "The sampler encountered an issue" : exception.getMessage()
+                       message
                    ))
                    .build();
   }
