@@ -23,6 +23,9 @@ import com.fasterxml.jackson.annotation.JsonProperty;
 import com.fasterxml.jackson.databind.ObjectMapper;
 import com.google.common.base.Preconditions;
 import com.google.common.collect.ImmutableList;
+import org.apache.druid.common.config.Configs;
+import org.apache.druid.error.DruidException;
+import org.apache.druid.error.InvalidInput;
 import org.apache.druid.guice.annotations.Json;
 import org.apache.druid.indexing.overlord.IndexerMetadataStorageCoordinator;
 import org.apache.druid.indexing.overlord.TaskMaster;
@@ -45,6 +48,11 @@ import java.util.Map;
 
 public abstract class SeekableStreamSupervisorSpec implements SupervisorSpec
 {
+  protected static final String ILLEGAL_INPUT_SOURCE_UPDATE_ERROR_MESSAGE = "Update of the input source stream from [%s] to [%s] is not supported for a running supervisor."
+                                                                   + "%nTo perform the update safely, follow these steps:"
+                                                                   + "%n(1) Suspend this supervisor, reset its offsets and then terminate it. "
+                                                                   + "%n(2) Create a new supervisor with the new input source stream."
+                                                                   + "%nNote that doing the reset can cause data duplication or loss if any topic used in the old supervisor is included in the new one too.";
 
   private static SeekableStreamSupervisorIngestionSpec checkIngestionSchema(
       SeekableStreamSupervisorIngestionSpec ingestionSchema
@@ -56,6 +64,7 @@ public abstract class SeekableStreamSupervisorSpec implements SupervisorSpec
     return ingestionSchema;
   }
 
+  protected final String id;
   protected final TaskStorage taskStorage;
   protected final TaskMaster taskMaster;
   protected final IndexerMetadataStorageCoordinator indexerMetadataStorageCoordinator;
@@ -70,7 +79,13 @@ public abstract class SeekableStreamSupervisorSpec implements SupervisorSpec
   private final boolean suspended;
   protected final SupervisorStateManagerConfig supervisorStateManagerConfig;
 
+  /**
+   * Base constructor for SeekableStreamSupervisors.
+   * The unique identifier for the supervisor. A null {@code id} implies the constructor will use the
+   * non-null `dataSource` in `ingestionSchema` for backwards compatibility.
+   */
   public SeekableStreamSupervisorSpec(
+      @Nullable final String id,
       final SeekableStreamSupervisorIngestionSpec ingestionSchema,
       @Nullable Map<String, Object> context,
       Boolean suspended,
@@ -86,6 +101,10 @@ public abstract class SeekableStreamSupervisorSpec implements SupervisorSpec
   )
   {
     this.ingestionSchema = checkIngestionSchema(ingestionSchema);
+    this.id = Preconditions.checkNotNull(
+        Configs.valueOrDefault(id, ingestionSchema.getDataSchema().getDataSource()),
+        "spec id cannot be null!"
+    );
     this.context = context;
 
     this.taskStorage = taskStorage;
@@ -143,10 +162,15 @@ public abstract class SeekableStreamSupervisorSpec implements SupervisorSpec
     return emitter;
   }
 
+  /**
+   * Returns the identifier for this supervisor.
+   * If unspecified, defaults to the dataSource being written to.
+   */
   @Override
+  @JsonProperty
   public String getId()
   {
-    return ingestionSchema.getDataSchema().getDataSource();
+    return id;
   }
 
   public DruidMonitorSchedulerConfig getMonitorSchedulerConfig()
@@ -202,6 +226,35 @@ public abstract class SeekableStreamSupervisorSpec implements SupervisorSpec
     return suspended;
   }
 
+  /**
+   * Default implementation that prevents unsupported evolution of the supervisor spec
+   * <ul>
+   * <li>You cannot migrate between types of supervisors.</li>
+   * <li>You cannot change the input source stream of a running supervisor.</li>
+   * </ul>
+   * @param proposedSpec the proposed supervisor spec
+   * @throws DruidException if the proposed spec update is not allowed
+   */
+  @Override
+  public void validateSpecUpdateTo(SupervisorSpec proposedSpec) throws DruidException
+  {
+    if (!(proposedSpec instanceof SeekableStreamSupervisorSpec)) {
+      throw InvalidInput.exception(
+          "Cannot update supervisor spec from type[%s] to type[%s]", getClass().getSimpleName(), proposedSpec.getClass().getSimpleName()
+      );
+    }
+    SeekableStreamSupervisorSpec other = (SeekableStreamSupervisorSpec) proposedSpec;
+    if (this.getSource() == null || other.getSource() == null) {
+      // Not likely to happen, but covering just in case.
+      throw InvalidInput.exception("Cannot update supervisor spec since one or both of "
+                                   + "the specs have not provided an input source stream in the 'ioConfig'.");
+    }
+
+    if (!this.getSource().equals(other.getSource())) {
+      throw InvalidInput.exception(ILLEGAL_INPUT_SOURCE_UPDATE_ERROR_MESSAGE, this.getSource(), other.getSource());
+    }
+  }
+
   protected abstract SeekableStreamSupervisorSpec toggleSuspend(boolean suspend);
 
 }
