@@ -20,7 +20,9 @@
 package org.apache.druid.indexing.seekablestream.supervisor.autoscaler;
 
 import com.fasterxml.jackson.annotation.JsonCreator;
+import com.fasterxml.jackson.annotation.JsonInclude;
 import com.fasterxml.jackson.annotation.JsonProperty;
+import com.google.common.base.Preconditions;
 import org.apache.druid.indexing.overlord.supervisor.Supervisor;
 import org.apache.druid.indexing.overlord.supervisor.SupervisorSpec;
 import org.apache.druid.indexing.overlord.supervisor.autoscaler.AggregateFunction;
@@ -29,7 +31,9 @@ import org.apache.druid.indexing.seekablestream.supervisor.SeekableStreamSupervi
 import org.apache.druid.java.util.emitter.service.ServiceEmitter;
 
 import javax.annotation.Nullable;
+import java.util.Objects;
 
+@JsonInclude(JsonInclude.Include.NON_NULL)
 public class LagBasedAutoScalerConfig implements AutoScalerConfig
 {
   private final long lagCollectionIntervalMillis;
@@ -42,11 +46,13 @@ public class LagBasedAutoScalerConfig implements AutoScalerConfig
   private final double triggerScaleInFractionThreshold;
   private int taskCountMax;
   private int taskCountMin;
+  private Integer taskCountStart;
   private final int scaleInStep;
   private final int scaleOutStep;
   private final boolean enableTaskAutoScaler;
   private final long minTriggerScaleActionFrequencyMillis;
   private final AggregateFunction lagAggregate;
+  private final Double stopTaskCountRatio;
 
   @JsonCreator
   public LagBasedAutoScalerConfig(
@@ -59,12 +65,14 @@ public class LagBasedAutoScalerConfig implements AutoScalerConfig
           @Nullable @JsonProperty("triggerScaleOutFractionThreshold") Double triggerScaleOutFractionThreshold,
           @Nullable @JsonProperty("triggerScaleInFractionThreshold") Double triggerScaleInFractionThreshold,
           @JsonProperty("taskCountMax") Integer taskCountMax,
+          @Nullable @JsonProperty("taskCountStart") Integer taskCountStart,
           @JsonProperty("taskCountMin") Integer taskCountMin,
           @Nullable @JsonProperty("scaleInStep") Integer scaleInStep,
           @Nullable @JsonProperty("scaleOutStep") Integer scaleOutStep,
           @Nullable @JsonProperty("enableTaskAutoScaler") Boolean enableTaskAutoScaler,
           @Nullable @JsonProperty("minTriggerScaleActionFrequencyMillis") Long minTriggerScaleActionFrequencyMillis,
-          @Nullable @JsonProperty("lagAggregate") AggregateFunction lagAggregate
+          @Nullable @JsonProperty("lagAggregate") AggregateFunction lagAggregate,
+          @Nullable @JsonProperty("stopTaskCountRatio") Double stopTaskCountRatio
   )
   {
     this.enableTaskAutoScaler = enableTaskAutoScaler != null ? enableTaskAutoScaler : false;
@@ -85,15 +93,24 @@ public class LagBasedAutoScalerConfig implements AutoScalerConfig
         throw new RuntimeException("taskCountMax or taskCountMin can't be null!");
       } else if (taskCountMax < taskCountMin) {
         throw new RuntimeException("taskCountMax can't lower than taskCountMin!");
+      } else if (taskCountStart != null && (taskCountStart > taskCountMax || taskCountStart < taskCountMin)) {
+        throw new RuntimeException("taskCountMin <= taskCountStart <= taskCountMax");
       }
       this.taskCountMax = taskCountMax;
       this.taskCountMin = taskCountMin;
+      this.taskCountStart = taskCountStart;
     }
 
     this.scaleInStep = scaleInStep != null ? scaleInStep : 1;
     this.scaleOutStep = scaleOutStep != null ? scaleOutStep : 2;
     this.minTriggerScaleActionFrequencyMillis = minTriggerScaleActionFrequencyMillis
         != null ? minTriggerScaleActionFrequencyMillis : 600000;
+
+    Preconditions.checkArgument(
+        stopTaskCountRatio == null || (stopTaskCountRatio > 0.0 && stopTaskCountRatio <= 1.0),
+        "0.0 < stopTaskCountRatio <= 1.0"
+    );
+    this.stopTaskCountRatio = stopTaskCountRatio;
   }
 
   @JsonProperty
@@ -158,6 +175,14 @@ public class LagBasedAutoScalerConfig implements AutoScalerConfig
     return taskCountMin;
   }
 
+  @Override
+  @JsonProperty
+  @Nullable
+  public Integer getTaskCountStart()
+  {
+    return taskCountStart;
+  }
+
   @Override
   public SupervisorTaskAutoScaler createAutoScaler(Supervisor supervisor, SupervisorSpec spec, ServiceEmitter emitter)
   {
@@ -197,6 +222,14 @@ public class LagBasedAutoScalerConfig implements AutoScalerConfig
     return lagAggregate;
   }
 
+  @Override
+  @JsonProperty
+  @Nullable
+  public Double getStopTaskCountRatio()
+  {
+    return stopTaskCountRatio;
+  }
+
   @Override
   public String toString()
   {
@@ -204,6 +237,7 @@ public class LagBasedAutoScalerConfig implements AutoScalerConfig
             "enableTaskAutoScaler=" + enableTaskAutoScaler +
             ", taskCountMax=" + taskCountMax +
             ", taskCountMin=" + taskCountMin +
+            ", taskCountStart=" + taskCountStart +
             ", minTriggerScaleActionFrequencyMillis=" + minTriggerScaleActionFrequencyMillis +
             ", lagCollectionIntervalMillis=" + lagCollectionIntervalMillis +
             ", lagCollectionIntervalMillis=" + lagCollectionIntervalMillis +
@@ -216,6 +250,63 @@ public class LagBasedAutoScalerConfig implements AutoScalerConfig
             ", scaleInStep=" + scaleInStep +
             ", scaleOutStep=" + scaleOutStep +
             ", lagAggregate=" + lagAggregate +
+            ", stopTaskCountRatio=" + stopTaskCountRatio +
             '}';
   }
+
+
+  @Override
+  public boolean equals(Object o)
+  {
+    if (this == o) {
+      return true;
+    }
+    if (o == null || getClass() != o.getClass()) {
+      return false;
+    }
+
+    LagBasedAutoScalerConfig that = (LagBasedAutoScalerConfig) o;
+
+    return lagCollectionIntervalMillis == that.lagCollectionIntervalMillis &&
+           lagCollectionRangeMillis == that.lagCollectionRangeMillis &&
+           scaleActionStartDelayMillis == that.scaleActionStartDelayMillis &&
+           scaleActionPeriodMillis == that.scaleActionPeriodMillis &&
+           scaleOutThreshold == that.scaleOutThreshold &&
+           scaleInThreshold == that.scaleInThreshold &&
+           Double.compare(that.triggerScaleOutFractionThreshold, triggerScaleOutFractionThreshold) == 0 &&
+           Double.compare(that.triggerScaleInFractionThreshold, triggerScaleInFractionThreshold) == 0 &&
+           taskCountMax == that.taskCountMax &&
+           taskCountMin == that.taskCountMin &&
+           scaleInStep == that.scaleInStep &&
+           scaleOutStep == that.scaleOutStep &&
+           enableTaskAutoScaler == that.enableTaskAutoScaler &&
+           minTriggerScaleActionFrequencyMillis == that.minTriggerScaleActionFrequencyMillis &&
+           Objects.equals(taskCountStart, that.taskCountStart) &&
+           lagAggregate == that.lagAggregate &&
+           Objects.equals(stopTaskCountRatio, that.stopTaskCountRatio);
+  }
+
+  @Override
+  public int hashCode()
+  {
+    return Objects.hash(
+        lagCollectionIntervalMillis,
+        lagCollectionRangeMillis,
+        scaleActionStartDelayMillis,
+        scaleActionPeriodMillis,
+        scaleOutThreshold,
+        scaleInThreshold,
+        triggerScaleOutFractionThreshold,
+        triggerScaleInFractionThreshold,
+        taskCountMax,
+        taskCountMin,
+        taskCountStart,
+        scaleInStep,
+        scaleOutStep,
+        enableTaskAutoScaler,
+        minTriggerScaleActionFrequencyMillis,
+        lagAggregate,
+        stopTaskCountRatio
+    );
+  }
 }
