@@ -96,6 +96,7 @@ import org.apache.druid.segment.loading.StorageLocation;
 import org.apache.druid.segment.loading.StorageLocationConfig;
 import org.apache.druid.segment.loading.TombstoneLoadSpec;
 import org.apache.druid.segment.metadata.CentralizedDatasourceSchemaConfig;
+import org.apache.druid.segment.nested.NestedCommonFormatColumnFormatSpec;
 import org.apache.druid.segment.realtime.NoopChatHandlerProvider;
 import org.apache.druid.segment.realtime.WindowedCursorFactory;
 import org.apache.druid.segment.transform.CompactionTransformSpec;
@@ -156,6 +157,9 @@ public class CompactionTaskRunTest extends IngestionTestBase
       0
   );
 
+  private static final NestedCommonFormatColumnFormatSpec DEFAULT_NESTED_SPEC =
+      NestedCommonFormatColumnFormatSpec.getEffectiveFormatSpec(null, IndexSpec.getDefault().getEffectiveSpec());
+
   private static final List<String> TEST_ROWS = ImmutableList.of(
       "2014-01-01T00:00:10Z,a,1\n",
       "2014-01-01T00:00:10Z,b,2\n",
@@ -254,7 +258,7 @@ public class CompactionTaskRunTest extends IngestionTestBase
         expectedDims,
         ImmutableList.of(expectedMetric),
         null,
-        IndexSpec.DEFAULT,
+        IndexSpec.getDefault().getEffectiveSpec(),
         new UniformGranularitySpec(
             segmentGranularity,
             queryGranularity,
@@ -385,7 +389,7 @@ public class CompactionTaskRunTest extends IngestionTestBase
             ),
             ImmutableList.of(expectedLongSumMetric),
             null,
-            compactionTask.getTuningConfig().getIndexSpec(),
+            compactionTask.getTuningConfig().getIndexSpec().getEffectiveSpec(),
             new UniformGranularitySpec(
                 Granularities.HOUR,
                 Granularities.MINUTE,
@@ -770,7 +774,7 @@ public class CompactionTaskRunTest extends IngestionTestBase
         ),
         ImmutableList.of(expectedLongSumMetric),
         compactionTask.getTransformSpec(),
-        IndexSpec.DEFAULT,
+        IndexSpec.getDefault().getEffectiveSpec(),
         new UniformGranularitySpec(
             Granularities.DAY,
             Granularities.MINUTE,
@@ -825,7 +829,7 @@ public class CompactionTaskRunTest extends IngestionTestBase
         ),
         ImmutableList.of(expectedCountMetric, expectedLongSumMetric),
         compactionTask.getTransformSpec(),
-        IndexSpec.DEFAULT,
+        IndexSpec.getDefault().getEffectiveSpec(),
         new UniformGranularitySpec(
             Granularities.DAY,
             Granularities.MINUTE,
@@ -1602,6 +1606,7 @@ public class CompactionTaskRunTest extends IngestionTestBase
 
     List<String> rowsFromSegment = new ArrayList<>();
     for (DataSegment segment : segments) {
+      segmentCacheManager.load(segment);
       final File segmentFile = segmentCacheManager.getSegmentFiles(segment);
 
       final WindowedCursorFactory windowed = new WindowedCursorFactory(
@@ -1656,10 +1661,10 @@ public class CompactionTaskRunTest extends IngestionTestBase
         new TimestampSpec("ts", "auto", null),
         DimensionsSpec.builder()
                       .setDimensions(Arrays.asList(
-                          new AutoTypeColumnSchema("ts", ColumnType.STRING),
-                          new AutoTypeColumnSchema("dim", null),
-                          new AutoTypeColumnSchema("x", ColumnType.LONG),
-                          new AutoTypeColumnSchema("y", ColumnType.LONG)
+                          new AutoTypeColumnSchema("ts", ColumnType.STRING, null),
+                          AutoTypeColumnSchema.of("dim"),
+                          new AutoTypeColumnSchema("x", ColumnType.LONG, null),
+                          new AutoTypeColumnSchema("y", ColumnType.LONG, null)
                       ))
                       .build(),
         "|",
@@ -1697,10 +1702,10 @@ public class CompactionTaskRunTest extends IngestionTestBase
               DimensionsSpec.builder()
                             .setDimensions(Arrays.asList(
                                 // check explicitly specified types are preserved
-                                new AutoTypeColumnSchema("ts", ColumnType.STRING),
-                                new AutoTypeColumnSchema("dim", null),
-                                new AutoTypeColumnSchema("x", ColumnType.LONG),
-                                new AutoTypeColumnSchema("y", ColumnType.LONG)
+                                new AutoTypeColumnSchema("ts", ColumnType.STRING, DEFAULT_NESTED_SPEC),
+                                new AutoTypeColumnSchema("dim", null, DEFAULT_NESTED_SPEC),
+                                new AutoTypeColumnSchema("x", ColumnType.LONG, DEFAULT_NESTED_SPEC),
+                                new AutoTypeColumnSchema("y", ColumnType.LONG, DEFAULT_NESTED_SPEC)
                             ))
                             .build(),
               expectedLongSumMetric
@@ -1722,6 +1727,7 @@ public class CompactionTaskRunTest extends IngestionTestBase
 
     List<String> rowsFromSegment = new ArrayList<>();
     for (DataSegment segment : segments) {
+      segmentCacheManager.load(segment);
       final File segmentFile = segmentCacheManager.getSegmentFiles(segment);
 
       final WindowedCursorFactory windowed = new WindowedCursorFactory(
@@ -1779,11 +1785,11 @@ public class CompactionTaskRunTest extends IngestionTestBase
         new TimestampSpec("ts", "auto", null),
         DimensionsSpec.builder()
                       .setDimensions(Arrays.asList(
-                          new AutoTypeColumnSchema("x", ColumnType.LONG),
+                          new AutoTypeColumnSchema("x", ColumnType.LONG, null),
                           new LongDimensionSchema("__time"),
-                          new AutoTypeColumnSchema("ts", ColumnType.STRING),
-                          new AutoTypeColumnSchema("dim", null),
-                          new AutoTypeColumnSchema("y", ColumnType.LONG)
+                          new AutoTypeColumnSchema("ts", ColumnType.STRING, null),
+                          AutoTypeColumnSchema.of("dim"),
+                          new AutoTypeColumnSchema("y", ColumnType.LONG, null)
                       ))
                       .setForceSegmentSortByTime(false)
                       .build(),
@@ -1822,11 +1828,11 @@ public class CompactionTaskRunTest extends IngestionTestBase
             DimensionsSpec.builder()
                           .setDimensions(Arrays.asList(
                               // check explicitly that time ordering is preserved
-                              new AutoTypeColumnSchema("x", ColumnType.LONG),
+                              new AutoTypeColumnSchema("x", ColumnType.LONG, DEFAULT_NESTED_SPEC),
                               new LongDimensionSchema("__time"),
-                              new AutoTypeColumnSchema("ts", ColumnType.STRING),
-                              new AutoTypeColumnSchema("dim", null),
-                              new AutoTypeColumnSchema("y", ColumnType.LONG)
+                              new AutoTypeColumnSchema("ts", ColumnType.STRING, DEFAULT_NESTED_SPEC),
+                              new AutoTypeColumnSchema("dim", null, DEFAULT_NESTED_SPEC),
+                              new AutoTypeColumnSchema("y", ColumnType.LONG, DEFAULT_NESTED_SPEC)
                           ))
                           .setForceSegmentSortByTime(false)
                           .build(),
@@ -1847,6 +1853,7 @@ public class CompactionTaskRunTest extends IngestionTestBase
     final SegmentCacheManager segmentCacheManager = segmentCacheManagerFactory.manufacturate(cacheDir);
 
     List<String> rowsFromSegment = new ArrayList<>();
+    segmentCacheManager.load(compactSegment);
     final File segmentFile = segmentCacheManager.getSegmentFiles(compactSegment);
 
     final QueryableIndex queryableIndex = testUtils.getTestIndexIO().loadIndex(segmentFile);
@@ -2082,7 +2089,7 @@ public class CompactionTaskRunTest extends IngestionTestBase
         .jsonMapper(objectMapper)
         .taskWorkDir(temporaryFolder.newFolder())
         .indexIO(getIndexIO())
-        .indexMergerV9(getIndexMergerV9Factory().create(task.getContextValue(Tasks.STORE_EMPTY_COLUMNS_KEY, true)))
+        .indexMerger(getIndexMergerV9Factory().create(task.getContextValue(Tasks.STORE_EMPTY_COLUMNS_KEY, true)))
         .taskReportFileWriter(new SingleFileTaskReportFileWriter(reportsFile))
         .authorizerMapper(AuthTestUtils.TEST_AUTHORIZER_MAPPER)
         .chatHandlerProvider(new NoopChatHandlerProvider())
@@ -2103,6 +2110,7 @@ public class CompactionTaskRunTest extends IngestionTestBase
 
     List<String> rowsFromSegment = new ArrayList<>();
     for (DataSegment segment : segments) {
+      segmentCacheManager.load(segment);
       final File segmentFile = segmentCacheManager.getSegmentFiles(segment);
 
       final WindowedCursorFactory windowed = new WindowedCursorFactory(
