@@ -610,8 +610,8 @@ public class ConcurrentReplaceAndStreamingAppendTest extends IngestionTestBase
     final Throwable throwable = Throwables.getRootCause(exception);
     Assert.assertEquals(
         StringUtils.format(
-            "Segments[[%s]] are not covered by locks[[]] for task[%s]",
-            segmentV10, replaceTask.getId()
+            "Segment IDs[[%s]] are not covered by locks[[]] for task[%s]",
+            segmentV10.getId(), replaceTask.getId()
         ),
         throwable.getMessage()
     );
@@ -680,16 +680,10 @@ public class ConcurrentReplaceAndStreamingAppendTest extends IngestionTestBase
   private static DataSegment asSegment(SegmentIdWithShardSpec pendingSegment)
   {
     final SegmentId id = pendingSegment.asSegmentId();
-    return new DataSegment(
-        id,
-        Collections.singletonMap(id.toString(), id.toString()),
-        Collections.emptyList(),
-        Collections.emptyList(),
-        pendingSegment.getShardSpec(),
-        null,
-        0,
-        0
-    );
+    return DataSegment.builder(id)
+                      .loadSpec(Collections.singletonMap(id.toString(), id.toString()))
+                      .shardSpec(pendingSegment.getShardSpec())
+                      .build();
   }
 
   private void verifyIntervalHasUsedSegments(Interval interval, DataSegment... expectedSegments)
