@@ -376,7 +376,7 @@ public class TaskLifecycleTest extends InitializedNullHandlingTest
     // initialize variables
     announcedSinks = 0;
     pushedSegments = 0;
-    indexSpec = IndexSpec.DEFAULT;
+    indexSpec = IndexSpec.getDefault();
     emitter = newMockEmitter();
     EmittingLogger.registerEmitter(emitter);
     mapper = TEST_UTILS.getTestObjectMapper();
@@ -562,7 +562,6 @@ public class TaskLifecycleTest extends InitializedNullHandlingTest
     );
     taskConfig = new TaskConfigBuilder()
         .setBaseDir(temporaryFolder.newFolder().toString())
-        .setDefaultRowFlushBoundary(50000)
         .setTmpStorageBytesPerTask(-1L)
         .build();
 
