@@ -19,35 +19,47 @@
 
 package org.apache.druid.indexing.overlord;
 
+import com.google.common.base.Optional;
+import org.apache.commons.io.IOUtils;
 import org.apache.druid.indexer.TaskState;
 import org.apache.druid.indexer.TaskStatus;
 import org.apache.druid.indexing.common.MultipleFileTaskReportFileWriter;
 import org.apache.druid.indexing.common.TaskStorageDirTracker;
 import org.apache.druid.indexing.common.TaskToolbox;
 import org.apache.druid.indexing.common.TaskToolboxFactory;
-import org.apache.druid.indexing.common.actions.TaskActionClient;
 import org.apache.druid.indexing.common.config.TaskConfig;
-import org.apache.druid.indexing.common.task.AbstractTask;
+import org.apache.druid.indexing.common.task.NoopTask;
+import org.apache.druid.indexing.common.task.Task;
 import org.apache.druid.indexing.common.task.TestAppenderatorsManager;
 import org.apache.druid.indexing.worker.config.WorkerConfig;
 import org.apache.druid.jackson.DefaultObjectMapper;
+import org.apache.druid.java.util.common.StringUtils;
+import org.apache.druid.java.util.common.logger.Logger;
 import org.apache.druid.server.DruidNode;
 import org.apache.druid.tasklogs.NoopTaskLogs;
 import org.junit.Assert;
+import org.junit.Before;
 import org.junit.Test;
 
+import java.io.InputStream;
+import java.nio.charset.StandardCharsets;
+import java.util.Map;
+import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.Future;
 
 public class ThreadingTaskRunnerTest
 {
+  private static final Logger log = new Logger(ThreadingTaskRunnerTest.class);
 
-  @Test
-  public void testTaskStatusWhenTaskThrowsExceptionWhileRunning() throws ExecutionException, InterruptedException
+  private ThreadingTaskRunner runner;
+
+  @Before
+  public void setup()
   {
     final TaskConfig taskConfig = ForkingTaskRunnerTest.makeDefaultTaskConfigBuilder().build();
     final WorkerConfig workerConfig = new WorkerConfig();
-    ThreadingTaskRunner runner = new ThreadingTaskRunner(
+    runner = new ThreadingTaskRunner(
         mockTaskToolboxFactory(),
         taskConfig,
         workerConfig,
@@ -55,29 +67,16 @@ public class ThreadingTaskRunnerTest
         new DefaultObjectMapper(),
         new TestAppenderatorsManager(),
         new MultipleFileTaskReportFileWriter(),
-        new DruidNode("middleManager", "host", false, 8091, null, true, false),
+        new DruidNode("druid/indexer", "host", false, 8091, null, true, false),
         TaskStorageDirTracker.fromConfigs(workerConfig, taskConfig)
     );
+  }
 
-    Future<TaskStatus> statusFuture = runner.run(new AbstractTask("id", "datasource", null)
+  @Test
+  public void testTaskStatusWhenTaskThrowsExceptionWhileRunning() throws ExecutionException, InterruptedException
+  {
+    Future<TaskStatus> statusFuture = runner.run(new NoopTask(null, null, null, 1L, 0L, Map.of())
     {
-      @Override
-      public String getType()
-      {
-        return "test";
-      }
-
-      @Override
-      public boolean isReady(TaskActionClient taskActionClient)
-      {
-        return true;
-      }
-
-      @Override
-      public void stopGracefully(TaskConfig taskConfig)
-      {
-      }
-
       @Override
       public TaskStatus runTask(TaskToolbox toolbox)
       {
@@ -93,6 +92,55 @@ public class ThreadingTaskRunnerTest
     );
   }
 
+  @Test
+  public void test_streamTaskLogs_ofRunningTask_readsFromTaskLogFile() throws Exception
+  {
+    final CountDownLatch taskHasStarted = new CountDownLatch(1);
+    final CountDownLatch finishTask = new CountDownLatch(1);
+    final Task indexerTask = new NoopTask(null, null, null, 1L, 0L, Map.of())
+    {
+      @Override
+      public TaskStatus runTask(TaskToolbox toolbox) throws Exception
+      {
+        log.info("Running test task[%s]", getId());
+
+        taskHasStarted.countDown();
+        finishTask.await();
+
+        return TaskStatus.success(getId());
+      }
+    };
+
+    // Submit the task and wait for it to start
+    final Future<TaskStatus> statusFuture = runner.run(indexerTask);
+    taskHasStarted.await();
+
+    // Stream and verify the contents of the task logs
+    final Optional<InputStream> logStream = runner.streamTaskLog(indexerTask.getId(), 0);
+    Assert.assertTrue(logStream.isPresent());
+
+    try (final InputStream in = logStream.get()) {
+      final String fullTaskLogs = IOUtils.toString(in, StandardCharsets.UTF_8);
+      Assert.assertTrue(
+          fullTaskLogs.contains(
+              StringUtils.format("Running test task[%s]", indexerTask.getId())
+          )
+      );
+    }
+
+    // Finish the task and verify status
+    finishTask.countDown();
+    Assert.assertEquals(
+        TaskStatus.success(indexerTask.getId()),
+        statusFuture.get()
+    );
+
+    // Verify that task logs cannot be streamed anymore as task has finished
+    Assert.assertFalse(
+        runner.streamTaskLog(indexerTask.getId(), 0).isPresent()
+    );
+  }
+
   private static TaskToolboxFactory mockTaskToolboxFactory()
   {
     return new TestTaskToolboxFactory(new TestTaskToolboxFactory.Builder());
