@@ -21,7 +21,7 @@ if ($BUILD_DRUID_CLSUTER); then
   DRUID_HOME=$(dirname `pwd`)
   echo "SET DRUID_HOME: $DRUID_HOME"
 
-  sudo /usr/local/bin/minikube delete
+  /usr/local/bin/k3s-uninstall.sh
   sudo rm -rf $DRUID_HOME/tmp
   sudo rm -rf $DRUID_HOME/druid-operator
   docker ps
