@@ -25,12 +25,6 @@ package org.apache.druid.tests;
  */
 public class TestNGGroup
 {
-  public static final String BATCH_INDEX = "batch-index";
-
-  public static final String INPUT_FORMAT = "input-format";
-
-  public static final String INPUT_SOURCE = "input-source";
-
   public static final String KAFKA_INDEX = "kafka-index";
 
   public static final String KAFKA_INDEX_SLOW = "kafka-index-slow";
@@ -114,18 +108,6 @@ public class TestNGGroup
    */
   public static final String S3_INGESTION = "s3-ingestion";
 
-  /**
-   * This group is not part of CI explicitly. It allows you to run all the tests that have been tested with
-   * against a quickstart deployment of Druid using the instructions in this project's README.
-   * No tests should belong exclusively to this group. It is only meant to be a helper group to run tests against
-   * a local quickstart deployment.
-   *
-   * As you run tests in your environment, mark the tests as quickstart compatible (see
-   * {@link org.apache.druid.tests.indexer.ITIndexerTest}) and add any additional instructions that were needed to
-   * get the tests to work to this project's README.
-   */
-  public static final String QUICKSTART_COMPATIBLE = "quickstart-compatible";
-
   /**
    * This group is not part of CI. To run this group, AWS kinesis configs/credentials for your AWS kinesis must be
    * provided in a file. The path of the file must then be pass to mvn with -Doverride.config.path=<PATH_TO_FILE>
