@@ -374,6 +374,11 @@ public class DruidException extends RuntimeException
      * Means that the requested resource cannot be found.
      */
     NOT_FOUND(404),
+    /**
+     * Indicates that the request could not be completed due to a conflict with
+     * the current state of the target resource.
+     */
+    CONFLICT(409),
     /**
      * Means that some capacity limit was exceeded, this could be due to throttling or due to some system limit
      */
