@@ -20,24 +20,32 @@
 package org.apache.druid.frame.field;
 
 import org.apache.datasketches.memory.Memory;
+import org.apache.druid.frame.Frame;
 import org.apache.druid.frame.key.RowKey;
 import org.apache.druid.frame.key.RowKeyReader;
 import org.apache.druid.query.extraction.ExtractionFn;
+import org.apache.druid.query.rowsandcols.column.Column;
 import org.apache.druid.segment.ColumnValueSelector;
 import org.apache.druid.segment.DimensionSelector;
+import org.apache.druid.segment.column.RowSignature;
 
 import javax.annotation.Nullable;
 
 /**
  * Embeds the logic to read a specific field from row-based frames or from {@link RowKey}.
- *
+ * <p>
  * Most callers should use {@link org.apache.druid.frame.read.FrameReader} or
  * {@link RowKeyReader} rather than using this interface directly.
- *
+ * <p>
  * Stateless and immutable.
  */
 public interface FieldReader
 {
+  /**
+   * Create a {@link Column} which provides accses to the rows in the frame, via the {@link Column#toAccessor()}.
+   */
+  Column makeRACColumn(Frame frame, RowSignature signature, String columnName);
+
   /**
    * Create a {@link ColumnValueSelector} backed by some memory and a moveable pointer.
    */
