@@ -66,15 +66,6 @@ public class OutputChannels
     return new OutputChannels(outputChannels);
   }
 
-  /**
-   * Creates an instance wrapping read-only versions (see {@link OutputChannel#readOnly()}) of all the
-   * provided channels.
-   */
-  public static OutputChannels wrapReadOnly(final List<OutputChannel> outputChannels)
-  {
-    return new OutputChannels(outputChannels.stream().map(OutputChannel::readOnly).collect(Collectors.toList()));
-  }
-
   /**
    * Verifies there is exactly one channel per partition.
    */
@@ -139,13 +130,20 @@ public class OutputChannels
    */
   public OutputChannels readOnly()
   {
-    return wrapReadOnly(outputChannels);
+    if (isReadOnly()) {
+      return this;
+    } else {
+      return new OutputChannels(outputChannels.stream().map(OutputChannel::readOnly).collect(Collectors.toList()));
+    }
   }
 
-  public boolean areReadableChannelsReady()
+  /**
+   * Returns whether this instance is read-only (all channels have {@link OutputChannel#isReadOnly()}).
+   */
+  public boolean isReadOnly()
   {
-    for (final OutputChannel outputChannel : outputChannels) {
-      if (!outputChannel.isReadableChannelReady()) {
+    for (final OutputChannel channel : outputChannels) {
+      if (!channel.isReadOnly()) {
         return false;
       }
     }
