@@ -64,7 +64,7 @@ public abstract class ExprEval<T>
    *                                 {@link ByteBuffer}. Certain types are deserialized more efficiently if allowed
    *                                 to retain references to the provided buffer.
    */
-  public static ExprEval deserialize(
+  public static ExprEval<?> deserialize(
       final ByteBuffer buffer,
       final int offset,
       final int maxSize,
@@ -281,17 +281,40 @@ public abstract class ExprEval<T>
     return Object.class;
   }
 
-  public static ExprEval of(long longValue)
+  /**
+   * Eval that represents a null value of undefined type. Commonly used to represent columns that do not exist.
+   *
+   * Behaviorally equivalent to {@code ofLong(null)}. Generally, this function is preferred if the type is unknown, and
+   * {@code ofLong(null)} is preferred if the type is known to be long.
+   */
+  public static ExprEval<?> ofMissing()
+  {
+    return LongExprEval.OF_NULL;
+  }
+
+  public static ExprEval<?> of(long longValue)
   {
     return new LongExprEval(longValue);
   }
 
-  public static ExprEval of(double doubleValue)
+  public static ExprEval<?> of(double doubleValue)
   {
     return new DoubleExprEval(doubleValue);
   }
 
-  public static ExprEval of(@Nullable String stringValue)
+  /**
+   * Equivalent to {@link #ofString(String)}. Deprecated because the pattern {@code ExprEval.of(null)} for
+   * an "unknown type" null is not recommended-- instead it should be {@link ExprEval#ofMissing()}
+   *
+   * @deprecated use {@link #ofString(String)} instead, which is clearer as to type
+   */
+  @Deprecated
+  public static ExprEval<?> of(@Nullable String stringValue)
+  {
+    return ofString(stringValue);
+  }
+
+  public static ExprEval<?> ofString(@Nullable String stringValue)
   {
     if (stringValue == null) {
       return StringExprEval.OF_NULL;
@@ -299,7 +322,7 @@ public abstract class ExprEval<T>
     return new StringExprEval(stringValue);
   }
 
-  public static ExprEval ofLong(@Nullable Number longValue)
+  public static ExprEval<?> ofLong(@Nullable Number longValue)
   {
     if (longValue == null) {
       return LongExprEval.OF_NULL;
@@ -307,7 +330,7 @@ public abstract class ExprEval<T>
     return new LongExprEval(longValue);
   }
 
-  public static ExprEval ofDouble(@Nullable Number doubleValue)
+  public static ExprEval<?> ofDouble(@Nullable Number doubleValue)
   {
     if (doubleValue == null) {
       return DoubleExprEval.OF_NULL;
@@ -315,7 +338,7 @@ public abstract class ExprEval<T>
     return new DoubleExprEval(doubleValue);
   }
 
-  public static ExprEval ofLongArray(@Nullable Object[] longValue)
+  public static ExprEval<?> ofLongArray(@Nullable Object[] longValue)
   {
     if (longValue == null) {
       return ArrayExprEval.OF_NULL_LONG;
@@ -323,7 +346,7 @@ public abstract class ExprEval<T>
     return new ArrayExprEval(ExpressionType.LONG_ARRAY, longValue);
   }
 
-  public static ExprEval ofDoubleArray(@Nullable Object[] doubleValue)
+  public static ExprEval<?> ofDoubleArray(@Nullable Object[] doubleValue)
   {
     if (doubleValue == null) {
       return ArrayExprEval.OF_NULL_DOUBLE;
@@ -331,7 +354,7 @@ public abstract class ExprEval<T>
     return new ArrayExprEval(ExpressionType.DOUBLE_ARRAY, doubleValue);
   }
 
-  public static ExprEval ofStringArray(@Nullable Object[] stringValue)
+  public static ExprEval<?> ofStringArray(@Nullable Object[] stringValue)
   {
     if (stringValue == null) {
       return ArrayExprEval.OF_NULL_STRING;
@@ -340,7 +363,7 @@ public abstract class ExprEval<T>
   }
 
 
-  public static ExprEval ofArray(ExpressionType outputType, @Nullable Object[] value)
+  public static ExprEval<?> ofArray(ExpressionType outputType, @Nullable Object[] value)
   {
     Preconditions.checkArgument(outputType.isArray(), "Output type %s is not an array", outputType);
     return new ArrayExprEval(outputType, value);
@@ -349,12 +372,12 @@ public abstract class ExprEval<T>
   /**
    * Convert a boolean into a long expression type
    */
-  public static ExprEval ofLongBoolean(boolean value)
+  public static ExprEval<?> ofLongBoolean(boolean value)
   {
     return value ? LongExprEval.TRUE : LongExprEval.FALSE;
   }
 
-  public static ExprEval ofComplex(ExpressionType outputType, @Nullable Object value)
+  public static ExprEval<?> ofComplex(ExpressionType outputType, @Nullable Object value)
   {
     if (ExpressionType.NESTED_DATA.equals(outputType)) {
       return new NestedDataExprEval(value);
@@ -362,7 +385,7 @@ public abstract class ExprEval<T>
     return new ComplexExprEval(outputType, value);
   }
 
-  public static ExprEval bestEffortArray(@Nullable List<?> theList)
+  public static ExprEval<?> bestEffortArray(@Nullable List<?> theList)
   {
     // do not convert empty lists to arrays with a single null element here, because that should have been done
     // by the selectors preparing their ObjectBindings if necessary. If we get to this point it was legitimately
@@ -377,13 +400,13 @@ public abstract class ExprEval<T>
   /**
    * Examine java type to find most appropriate expression type
    */
-  public static ExprEval bestEffortOf(@Nullable Object val)
+  public static ExprEval<?> bestEffortOf(@Nullable Object val)
   {
     if (val == null) {
-      return StringExprEval.OF_NULL;
+      return LongExprEval.OF_NULL;
     }
     if (val instanceof ExprEval) {
-      return (ExprEval) val;
+      return (ExprEval<?>) val;
     }
     if (val instanceof String) {
       return new StringExprEval((String) val);
@@ -496,7 +519,7 @@ public abstract class ExprEval<T>
    * @param type  type, or null to be equivalent to {@link #bestEffortOf(Object)}
    * @param value object to be coerced to the type
    */
-  public static ExprEval ofType(@Nullable ExpressionType type, @Nullable Object value)
+  public static ExprEval<?> ofType(@Nullable ExpressionType type, @Nullable Object value)
   {
     if (type == null) {
       return bestEffortOf(value);
@@ -521,7 +544,7 @@ public abstract class ExprEval<T>
         if (value instanceof byte[]) {
           return new StringExprEval(StringUtils.encodeBase64String((byte[]) value));
         }
-        return of(Evals.asString(value));
+        return ofString(Evals.asString(value));
       case LONG:
         if (value instanceof Number) {
           return ofLong((Number) value);
@@ -690,12 +713,6 @@ public abstract class ExprEval<T>
     return value;
   }
 
-  @Nullable
-  public T valueOrDefault()
-  {
-    return value;
-  }
-
   void cacheStringValue(@Nullable String value)
   {
     stringValue = value;
@@ -824,15 +841,6 @@ public abstract class ExprEval<T>
       return ExpressionType.DOUBLE;
     }
 
-    @Override
-    public Number valueOrDefault()
-    {
-      if (value == null) {
-        return null;
-      }
-      return value.doubleValue();
-    }
-
     @Override
     public final boolean asBoolean()
     {
@@ -843,7 +851,7 @@ public abstract class ExprEval<T>
     @Override
     public Object[] asArray()
     {
-      return value == null ? null : new Object[]{valueOrDefault().doubleValue()};
+      return value == null ? null : new Object[]{value.doubleValue()};
     }
 
     @Override
@@ -859,7 +867,7 @@ public abstract class ExprEval<T>
             return ExprEval.of(asLong());
           }
         case STRING:
-          return ExprEval.of(asString());
+          return ExprEval.ofString(asString());
         case ARRAY:
           switch (castTo.getElementType().getType()) {
             case DOUBLE:
@@ -907,15 +915,6 @@ public abstract class ExprEval<T>
       return ExpressionType.LONG;
     }
 
-    @Override
-    public Number valueOrDefault()
-    {
-      if (value == null) {
-        return null;
-      }
-      return value.longValue();
-    }
-
     @Override
     public final boolean asBoolean()
     {
@@ -926,7 +925,7 @@ public abstract class ExprEval<T>
     @Override
     public Object[] asArray()
     {
-      return value == null ? null : new Object[]{valueOrDefault().longValue()};
+      return value == null ? null : new Object[]{value.longValue()};
     }
 
     @Override
@@ -942,7 +941,7 @@ public abstract class ExprEval<T>
         case LONG:
           return this;
         case STRING:
-          return ExprEval.of(asString());
+          return ExprEval.ofString(asString());
         case ARRAY:
           if (value == null) {
             return new ArrayExprEval(castTo, null);
@@ -1307,7 +1306,7 @@ public abstract class ExprEval<T>
       switch (castTo.getType()) {
         case STRING:
           if (value.length == 1) {
-            return ExprEval.of(asString());
+            return ExprEval.ofString(asString());
           }
           return ExprEval.ofType(castTo, null);
         case LONG:
