@@ -19,6 +19,10 @@
 
 package org.apache.druid.query;
 
+import com.fasterxml.jackson.annotation.JsonCreator;
+import com.fasterxml.jackson.annotation.JsonInclude;
+import com.fasterxml.jackson.annotation.JsonInclude.Include;
+import com.fasterxml.jackson.annotation.JsonValue;
 import com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.druid.java.util.common.HumanReadableBytes;
 import org.apache.druid.java.util.common.StringUtils;
@@ -29,6 +33,7 @@ import org.apache.druid.query.filter.TypedInFilter;
 
 import javax.annotation.Nullable;
 import java.io.IOException;
+import java.time.Duration;
 import java.util.Collections;
 import java.util.Map;
 import java.util.Objects;
@@ -55,8 +60,11 @@ public class QueryContext
 {
   private static final QueryContext EMPTY = new QueryContext(null);
 
+  @JsonInclude(value = Include.NON_NULL)
+  @JsonValue
   private final Map<String, Object> context;
 
+  @JsonCreator
   public QueryContext(Map<String, Object> context)
   {
     // There is no semantic difference between an empty and a null context.
@@ -463,6 +471,15 @@ public class QueryContext
     return getLong(QueryContexts.MAX_SCATTER_GATHER_BYTES_KEY, Long.MAX_VALUE);
   }
 
+  public String getEngine()
+  {
+    return QueryContexts.parseString(
+        context,
+        QueryContexts.ENGINE,
+        QueryContexts.DEFAULT_ENGINE
+    );
+  }
+
   public boolean hasTimeout()
   {
     return getTimeout() != QueryContexts.NO_TIMEOUT;
@@ -488,6 +505,15 @@ public class QueryContext
     );
   }
 
+  @Nullable
+  public Duration getTimeoutDuration()
+  {
+    if (hasTimeout()) {
+      return Duration.ofMillis(getTimeout());
+    }
+    return null;
+  }
+
   public long getDefaultTimeout()
   {
     final long defaultTimeout = getLong(QueryContexts.DEFAULT_TIMEOUT_KEY, QueryContexts.DEFAULT_TIMEOUT_MILLIS);
@@ -518,6 +544,32 @@ public class QueryContext
     }
   }
 
+  public long getPerSegmentTimeout()
+  {
+    return getPerSegmentTimeout(QueryContexts.NO_TIMEOUT);
+  }
+
+  public long getPerSegmentTimeout(long defaultPerSegmentTimeout)
+  {
+    final long timeout = getLong(QueryContexts.PER_SEGMENT_TIMEOUT_KEY, defaultPerSegmentTimeout);
+    if (timeout >= 0) {
+      return timeout;
+    }
+
+    throw new BadQueryContextException(
+        StringUtils.format(
+            "Per-segment timeout [%s] must be a non negative value, but was [%d]",
+            QueryContexts.PER_SEGMENT_TIMEOUT_KEY,
+            timeout
+        )
+    );
+  }
+
+  public boolean usePerSegmentTimeout()
+  {
+    return getPerSegmentTimeout() != QueryContexts.NO_TIMEOUT;
+  }
+
   public void verifyMaxScatterGatherBytes(long maxScatterGatherBytesLimit)
   {
     long curr = getLong(QueryContexts.MAX_SCATTER_GATHER_BYTES_KEY, 0);
@@ -551,6 +603,15 @@ public class QueryContext
     );
   }
 
+  public CloneQueryMode getCloneQueryMode()
+  {
+    return getEnum(
+        QueryContexts.CLONE_QUERY_MODE,
+        CloneQueryMode.class,
+        QueryContexts.DEFAULT_CLONE_QUERY_MODE
+    );
+  }
+
   public boolean getEnableRewriteJoinToFilter()
   {
     return getBoolean(
@@ -633,6 +694,17 @@ public class QueryContext
     );
   }
 
+  /**
+   * Returns true if {@link QueryContexts#CTX_FULL_REPORT} is set to true, false if it is set to false or not set.
+   */
+  public boolean getFullReport()
+  {
+    return getBoolean(
+        QueryContexts.CTX_FULL_REPORT,
+        QueryContexts.DEFAULT_CTX_FULL_REPORT
+    );
+  }
+
 
   public QueryResourceId getQueryResourceId()
   {
@@ -679,4 +751,30 @@ public class QueryContext
     );
     return QueryContexts.NATIVE_QUERY_SQL_PLANNING_MODE_DECOUPLED.equals(value);
   }
+
+  public QueryContext override(Map<String, Object> contextOverride)
+  {
+    if (contextOverride == null || contextOverride.isEmpty()) {
+      return this;
+    }
+    return QueryContext.of(QueryContexts.override(asMap(), contextOverride));
+  }
+
+  public QueryContext override(QueryContext queryContext)
+  {
+    if (queryContext == null || queryContext.isEmpty()) {
+      return this;
+    }
+    return override(queryContext.asMap());
+  }
+
+  public boolean isPrePlanned()
+  {
+    return getBoolean(QueryContexts.CTX_PREPLANNED, QueryContexts.DEFAULT_PREPLANNED);
+  }
+
+  public boolean isRealtimeSegmentsOnly()
+  {
+    return getBoolean(QueryContexts.REALTIME_SEGMENTS_ONLY, QueryContexts.DEFAULT_REALTIME_SEGMENTS_ONLY);
+  }
 }
