@@ -24,18 +24,17 @@ import com.fasterxml.jackson.annotation.JsonProperty;
 import com.google.common.collect.ImmutableList;
 import org.apache.druid.java.util.common.IAE;
 import org.apache.druid.java.util.common.ISE;
-import org.apache.druid.query.planning.DataSourceAnalysis;
 import org.apache.druid.query.policy.NoRestrictionPolicy;
 import org.apache.druid.query.policy.Policy;
+import org.apache.druid.query.policy.PolicyEnforcer;
 import org.apache.druid.segment.RestrictedSegment;
-import org.apache.druid.segment.SegmentReference;
+import org.apache.druid.segment.SegmentMapFunction;
 
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Optional;
 import java.util.Set;
-import java.util.function.Function;
 
 /**
  * Reperesents a TableDataSource with policy restriction.
@@ -117,40 +116,27 @@ public class RestrictedDataSource implements DataSource
   }
 
   @Override
-  public boolean isConcrete()
+  public boolean isProcessable()
   {
-    return base.isConcrete();
+    return base.isProcessable();
   }
 
   @Override
-  public Function<SegmentReference, SegmentReference> createSegmentMapFunction(Query query)
+  public SegmentMapFunction createSegmentMapFunction(Query query)
   {
-    final Function<SegmentReference, SegmentReference> segmentMapFn = base.createSegmentMapFunction(query);
-    return baseSegment -> new RestrictedSegment(segmentMapFn.apply(baseSegment), policy);
+    return base.createSegmentMapFunction(query).thenMap(segment -> new RestrictedSegment(segment, policy));
   }
 
   @Override
-  public DataSource withUpdatedDataSource(DataSource newSource)
-  {
-    return create(newSource, policy);
-  }
-
-  @Override
-  public DataSource withPolicies(Map<String, Optional<Policy>> policyMap)
+  public DataSource withPolicies(Map<String, Optional<Policy>> policyMap, PolicyEnforcer policyEnforcer)
   {
     if (!policyMap.containsKey(base.getName())) {
       throw new ISE("Missing policy check result for table [%s]", base.getName());
     }
 
     Optional<Policy> newPolicy = policyMap.getOrDefault(base.getName(), Optional.empty());
-    if (!newPolicy.isPresent()) {
-      throw new ISE(
-          "No restriction found on table [%s], but had policy [%s] before.",
-          base.getName(),
-          policy
-      );
-    }
-    if (newPolicy.get() instanceof NoRestrictionPolicy) {
+    if (newPolicy.isEmpty() || newPolicy.get() instanceof NoRestrictionPolicy) {
+      // allow empty policy, which means no restriction.
       // druid-internal calls with NoRestrictionPolicy: allow
     } else if (newPolicy.get().equals(policy)) {
       // same policy: allow
@@ -164,6 +150,7 @@ public class RestrictedDataSource implements DataSource
     }
     // The only happy path is, newPolicy is NoRestrictionPolicy, which means this comes from an anthenticated and
     // authorized druid-internal request.
+    policyEnforcer.validateOrElseThrow(base, policy);
     return this;
   }
 
@@ -178,13 +165,7 @@ public class RestrictedDataSource implements DataSource
   @Override
   public byte[] getCacheKey()
   {
-    return new byte[0];
-  }
-
-  @Override
-  public DataSourceAnalysis getAnalysis()
-  {
-    return base.getAnalysis();
+    return null;
   }
 
   @Override
