@@ -20,8 +20,8 @@
 package org.apache.druid.query.aggregation.any;
 
 import com.google.common.annotations.VisibleForTesting;
-import org.apache.druid.common.config.NullHandling;
 import org.apache.druid.query.aggregation.VectorAggregator;
+import org.apache.druid.segment.column.TypeStrategies;
 import org.apache.druid.segment.vector.VectorValueSelector;
 
 import javax.annotation.Nullable;
@@ -64,7 +64,7 @@ public abstract class NumericAnyVectorAggregator implements VectorAggregator
   @Override
   public void init(ByteBuffer buf, int position)
   {
-    buf.put(position, NullHandling.IS_NULL_BYTE);
+    buf.put(position, TypeStrategies.IS_NULL_BYTE);
     initValue(buf, position + FOUND_VALUE_OFFSET);
   }
 
@@ -85,7 +85,7 @@ public abstract class NumericAnyVectorAggregator implements VectorAggregator
       }
       // There are no nulls, so try to put a value from the value selector
       if (putAnyValueFromRow(buf, position + FOUND_VALUE_OFFSET, startRow, endRow)) {
-        buf.put(position, (byte) (BYTE_FLAG_FOUND_MASK | NullHandling.IS_NOT_NULL_BYTE));
+        buf.put(position, (byte) (BYTE_FLAG_FOUND_MASK | TypeStrategies.IS_NOT_NULL_BYTE));
       }
     }
   }
@@ -123,11 +123,11 @@ public abstract class NumericAnyVectorAggregator implements VectorAggregator
   @VisibleForTesting
   boolean isValueNull(ByteBuffer buf, int position)
   {
-    return (buf.get(position) & BYTE_FLAG_NULL_MASK) == NullHandling.IS_NULL_BYTE;
+    return (buf.get(position) & BYTE_FLAG_NULL_MASK) == TypeStrategies.IS_NULL_BYTE;
   }
 
   private void putNull(ByteBuffer buf, int position)
   {
-    buf.put(position, (byte) (BYTE_FLAG_FOUND_MASK | NullHandling.IS_NULL_BYTE));
+    buf.put(position, (byte) (BYTE_FLAG_FOUND_MASK | TypeStrategies.IS_NULL_BYTE));
   }
 }
