@@ -26,6 +26,7 @@ import org.apache.druid.collections.bitmap.BitmapFactory;
 import org.apache.druid.collections.bitmap.ImmutableBitmap;
 import org.apache.druid.collections.bitmap.MutableBitmap;
 import org.apache.druid.java.util.common.NonnullPair;
+import org.apache.druid.java.util.common.io.Closer;
 import org.apache.druid.query.DefaultBitmapResultFactory;
 import org.apache.druid.query.Order;
 import org.apache.druid.query.dimension.DimensionSpec;
@@ -34,9 +35,8 @@ import org.apache.druid.query.extraction.IdentityExtractionFn;
 import org.apache.druid.query.filter.ColumnIndexSelector;
 import org.apache.druid.query.filter.Filter;
 import org.apache.druid.query.search.CursorOnlyStrategy.CursorBasedExecutor;
-import org.apache.druid.segment.ColumnSelectorColumnIndexSelector;
+import org.apache.druid.segment.ColumnCache;
 import org.apache.druid.segment.Cursors;
-import org.apache.druid.segment.DeprecatedQueryableIndexColumnSelector;
 import org.apache.druid.segment.QueryableIndex;
 import org.apache.druid.segment.Segment;
 import org.apache.druid.segment.VirtualColumns;
@@ -47,6 +47,7 @@ import org.apache.druid.segment.index.BitmapColumnIndex;
 import org.apache.druid.segment.index.semantic.DictionaryEncodedStringValueIndex;
 import org.joda.time.Interval;
 
+import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
@@ -79,48 +80,49 @@ public class UseIndexesStrategy extends SearchStrategy
       return Collections.singletonList(new CursorBasedExecutor(query, segment, searchDims));
     }
 
-    final ColumnIndexSelector selector = new ColumnSelectorColumnIndexSelector(
-        index.getBitmapFactoryForDimensions(),
-        query.getVirtualColumns(),
-        new DeprecatedQueryableIndexColumnSelector(index)
-    );
+    try (final Closer closer = Closer.create()) {
+      final ColumnIndexSelector selector = new ColumnCache(index, query.getVirtualColumns(), closer);
 
-    // pair of bitmap dims and non-bitmap dims
-    final NonnullPair<List<DimensionSpec>, List<DimensionSpec>> pair = partitionDimensionList(
-        segment,
-        selector,
-        searchDims
-    );
-    final List<DimensionSpec> bitmapSuppDims = pair.lhs;
-    final List<DimensionSpec> nonBitmapSuppDims = pair.rhs;
+      // pair of bitmap dims and non-bitmap dims
+      final NonnullPair<List<DimensionSpec>, List<DimensionSpec>> pair = partitionDimensionList(
+          segment,
+          selector,
+          searchDims
+      );
+      final List<DimensionSpec> bitmapSuppDims = pair.lhs;
+      final List<DimensionSpec> nonBitmapSuppDims = pair.rhs;
 
-    if (!bitmapSuppDims.isEmpty()) {
-      // Index-only plan is used only when any filter is not specified or the filter supports bitmap indexes.
-      //
-      // Note: if some filters support bitmap indexes but others are not, the current implementation always employs
-      // the cursor-based plan. This can be more optimized. One possible optimization is generating a bitmap index
-      // from the non-bitmap-support filter, and then use it to compute the filtered result by intersecting bitmaps.
-      if ((filter == null || filter.getBitmapColumnIndex(selector) != null)
-          && Cursors.getTimeOrdering(index.getOrdering()) == Order.ASCENDING) {
-        final ImmutableBitmap timeFilteredBitmap = makeTimeFilteredBitmap(
-            index,
-            segment,
-            query.getVirtualColumns(),
-            filter,
-            interval
-        );
-        builder.add(new IndexOnlyExecutor(query, segment, timeFilteredBitmap, bitmapSuppDims));
-      } else {
-        // Fall back to cursor-based execution strategy
-        nonBitmapSuppDims.addAll(bitmapSuppDims);
+      if (!bitmapSuppDims.isEmpty()) {
+        // Index-only plan is used only when any filter is not specified or the filter supports bitmap indexes.
+        //
+        // Note: if some filters support bitmap indexes but others are not, the current implementation always employs
+        // the cursor-based plan. This can be more optimized. One possible optimization is generating a bitmap index
+        // from the non-bitmap-support filter, and then use it to compute the filtered result by intersecting bitmaps.
+        if ((filter == null || filter.getBitmapColumnIndex(selector) != null)
+            && Cursors.getTimeOrdering(index.getOrdering()) == Order.ASCENDING) {
+          final ImmutableBitmap timeFilteredBitmap = makeTimeFilteredBitmap(
+              index,
+              segment,
+              query.getVirtualColumns(),
+              filter,
+              interval
+          );
+          builder.add(new IndexOnlyExecutor(query, segment, timeFilteredBitmap, bitmapSuppDims));
+        } else {
+          // Fall back to cursor-based execution strategy
+          nonBitmapSuppDims.addAll(bitmapSuppDims);
+        }
       }
-    }
 
-    if (!nonBitmapSuppDims.isEmpty()) {
-      builder.add(new CursorBasedExecutor(query, segment, nonBitmapSuppDims));
-    }
+      if (!nonBitmapSuppDims.isEmpty()) {
+        builder.add(new CursorBasedExecutor(query, segment, nonBitmapSuppDims));
+      }
 
-    return builder.build();
+      return builder.build();
+    }
+    catch (IOException e) {
+      throw new RuntimeException(e);
+    }
   }
 
   /**
@@ -169,18 +171,22 @@ public class UseIndexesStrategy extends SearchStrategy
     if (filter == null) {
       baseFilter = null;
     } else {
-      final ColumnIndexSelector selector = new ColumnSelectorColumnIndexSelector(
-          index.getBitmapFactoryForDimensions(),
-          virtualColumns,
-          new DeprecatedQueryableIndexColumnSelector(index)
-      );
-      final BitmapColumnIndex columnIndex = filter.getBitmapColumnIndex(selector);
-      Preconditions.checkNotNull(
-          columnIndex,
-          "filter[%s] should support bitmap",
-          filter
-      );
-      baseFilter = columnIndex.computeBitmapResult(new DefaultBitmapResultFactory(selector.getBitmapFactory()), false);
+      try (final Closer closer = Closer.create()) {
+        final ColumnIndexSelector selector = new ColumnCache(index, virtualColumns, closer);
+        final BitmapColumnIndex columnIndex = filter.getBitmapColumnIndex(selector);
+        Preconditions.checkNotNull(
+            columnIndex,
+            "filter[%s] should support bitmap",
+            filter
+        );
+        baseFilter = columnIndex.computeBitmapResult(
+            new DefaultBitmapResultFactory(selector.getBitmapFactory()),
+            false
+        );
+      }
+      catch (IOException e) {
+        throw new RuntimeException(e);
+      }
     }
 
     final ImmutableBitmap timeFilteredBitmap;
@@ -262,51 +268,30 @@ public class UseIndexesStrategy extends SearchStrategy
       final QueryableIndex index = segment.as(QueryableIndex.class);
       Preconditions.checkArgument(index != null, "Index should not be null");
 
-      ColumnSelectorColumnIndexSelector indexSelector = new ColumnSelectorColumnIndexSelector(
-          index.getBitmapFactoryForDimensions(),
-          query.getVirtualColumns(),
-          new DeprecatedQueryableIndexColumnSelector(index)
-      );
+      try (final Closer closer = Closer.create()) {
+        final ColumnIndexSelector indexSelector = new ColumnCache(index, query.getVirtualColumns(), closer);
 
-      final Object2IntRBTreeMap<SearchHit> retVal = new Object2IntRBTreeMap<>(query.getSort().getComparator());
-      retVal.defaultReturnValue(0);
+        final Object2IntRBTreeMap<SearchHit> retVal = new Object2IntRBTreeMap<>(query.getSort().getComparator());
+        retVal.defaultReturnValue(0);
 
-      final BitmapFactory bitmapFactory = index.getBitmapFactoryForDimensions();
+        final BitmapFactory bitmapFactory = index.getBitmapFactoryForDimensions();
 
-      for (DimensionSpec dimension : dimsToSearch) {
+        for (DimensionSpec dimension : dimsToSearch) {
 
-        final ColumnIndexSupplier indexSupplier = indexSelector.getIndexSupplier(dimension.getDimension());
+          final ColumnIndexSupplier indexSupplier = indexSelector.getIndexSupplier(dimension.getDimension());
 
-        ExtractionFn extractionFn = dimension.getExtractionFn();
-        if (extractionFn == null) {
-          extractionFn = IdentityExtractionFn.getInstance();
-        }
-        // if indexSupplier is null here, it means the column is missing
-        if (indexSupplier == null) {
-          String dimVal = extractionFn.apply(null);
-          if (!searchQuerySpec.accept(dimVal)) {
-            continue;
+          ExtractionFn extractionFn = dimension.getExtractionFn();
+          if (extractionFn == null) {
+            extractionFn = IdentityExtractionFn.getInstance();
           }
-          ImmutableBitmap bitmap = bitmapFactory.complement(bitmapFactory.makeEmptyImmutableBitmap(), index.getNumRows());
-          if (timeFilteredBitmap != null) {
-            bitmap = bitmapFactory.intersection(Arrays.asList(timeFilteredBitmap, bitmap));
-          }
-          if (!bitmap.isEmpty()) {
-            retVal.addTo(new SearchHit(dimension.getOutputName(), dimVal), bitmap.size());
-            if (retVal.size() >= limit) {
-              return retVal;
-            }
-          }
-        } else {
-          // these were checked to be non-null in partitionDimensionList
-          final DictionaryEncodedStringValueIndex bitmapIndex =
-              indexSupplier.as(DictionaryEncodedStringValueIndex.class);
-          for (int i = 0; i < bitmapIndex.getCardinality(); ++i) {
-            String dimVal = extractionFn.apply(bitmapIndex.getValue(i));
+          // if indexSupplier is null here, it means the column is missing
+          if (indexSupplier == null) {
+            String dimVal = extractionFn.apply(null);
             if (!searchQuerySpec.accept(dimVal)) {
               continue;
             }
-            ImmutableBitmap bitmap = bitmapIndex.getBitmap(i);
+            ImmutableBitmap bitmap =
+                bitmapFactory.complement(bitmapFactory.makeEmptyImmutableBitmap(), index.getNumRows());
             if (timeFilteredBitmap != null) {
               bitmap = bitmapFactory.intersection(Arrays.asList(timeFilteredBitmap, bitmap));
             }
@@ -316,11 +301,34 @@ public class UseIndexesStrategy extends SearchStrategy
                 return retVal;
               }
             }
+          } else {
+            // these were checked to be non-null in partitionDimensionList
+            final DictionaryEncodedStringValueIndex bitmapIndex =
+                indexSupplier.as(DictionaryEncodedStringValueIndex.class);
+            for (int i = 0; i < bitmapIndex.getCardinality(); ++i) {
+              String dimVal = extractionFn.apply(bitmapIndex.getValue(i));
+              if (!searchQuerySpec.accept(dimVal)) {
+                continue;
+              }
+              ImmutableBitmap bitmap = bitmapIndex.getBitmap(i);
+              if (timeFilteredBitmap != null) {
+                bitmap = bitmapFactory.intersection(Arrays.asList(timeFilteredBitmap, bitmap));
+              }
+              if (!bitmap.isEmpty()) {
+                retVal.addTo(new SearchHit(dimension.getOutputName(), dimVal), bitmap.size());
+                if (retVal.size() >= limit) {
+                  return retVal;
+                }
+              }
+            }
           }
         }
-      }
 
-      return retVal;
+        return retVal;
+      }
+      catch (IOException e) {
+        throw new RuntimeException(e);
+      }
     }
   }
 }
