@@ -57,21 +57,18 @@ public class StringDimensionIndexer extends DictionaryEncodedColumnIndexer<int[]
   private final MultiValueHandling multiValueHandling;
   private final boolean hasBitmapIndexes;
   private final boolean hasSpatialIndexes;
-  private final boolean useMaxMemoryEstimates;
   private volatile boolean hasMultipleValues = false;
 
   public StringDimensionIndexer(
       @Nullable MultiValueHandling multiValueHandling,
       boolean hasBitmapIndexes,
-      boolean hasSpatialIndexes,
-      boolean useMaxMemoryEstimates
+      boolean hasSpatialIndexes
   )
   {
-    super(new StringDimensionDictionary(!useMaxMemoryEstimates));
+    super(new StringDimensionDictionary());
     this.multiValueHandling = multiValueHandling == null ? MultiValueHandling.ofDefault() : multiValueHandling;
     this.hasBitmapIndexes = hasBitmapIndexes;
     this.hasSpatialIndexes = hasSpatialIndexes;
-    this.useMaxMemoryEstimates = useMaxMemoryEstimates;
   }
 
   @Override
@@ -79,7 +76,7 @@ public class StringDimensionIndexer extends DictionaryEncodedColumnIndexer<int[]
   {
     final int[] encodedDimensionValues;
     final int oldDictSize = dimLookup.size();
-    final long oldDictSizeInBytes = useMaxMemoryEstimates ? 0 : dimLookup.sizeInBytes();
+    final long oldDictSizeInBytes = dimLookup.sizeInBytes();
 
     // expressions which operate on multi-value string inputs as arrays might spit out arrays, coerce to list
     if (dimValues instanceof Object[]) {
@@ -136,14 +133,9 @@ public class StringDimensionIndexer extends DictionaryEncodedColumnIndexer<int[]
       sortedLookup = null;
     }
 
-    long effectiveSizeBytes;
-    if (useMaxMemoryEstimates) {
-      effectiveSizeBytes = estimateEncodedKeyComponentSize(encodedDimensionValues);
-    } else {
-      // size of encoded array + dictionary size change
-      effectiveSizeBytes = 16L + (long) encodedDimensionValues.length * Integer.BYTES
-                           + (dimLookup.sizeInBytes() - oldDictSizeInBytes);
-    }
+    // size of encoded array + dictionary size change
+    final long effectiveSizeBytes = 16L + ((long) encodedDimensionValues.length * Integer.BYTES)
+                                    + (dimLookup.sizeInBytes() - oldDictSizeInBytes);
     return new EncodedKeyComponent<>(encodedDimensionValues, effectiveSizeBytes);
   }
 
