@@ -19,25 +19,31 @@
 
 package org.apache.druid.segment.column;
 
+import com.fasterxml.jackson.core.JsonProcessingException;
 import com.google.common.base.Preconditions;
 import com.google.common.collect.Ordering;
 import com.google.common.primitives.Floats;
 import com.google.common.primitives.Longs;
+import org.apache.druid.error.DruidException;
 import org.apache.druid.java.util.common.IAE;
 import org.apache.druid.java.util.common.ISE;
 import org.apache.druid.java.util.common.StringUtils;
+import org.apache.druid.segment.nested.StructuredData;
+import org.apache.druid.segment.serde.ColumnSerializerUtils;
 
 import javax.annotation.Nullable;
+import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.util.Arrays;
 import java.util.Comparator;
+import java.util.Objects;
 import java.util.concurrent.ConcurrentHashMap;
 
 public class TypeStrategies
 {
   public static final byte IS_NULL_BYTE = (byte) 1;
   public static final byte IS_NOT_NULL_BYTE = (byte) 0;
-  
+
   public static final int VALUE_OFFSET = Byte.BYTES;
   public static final int NULLABLE_LONG_SIZE = Byte.BYTES + Long.BYTES;
   public static final int NULLABLE_DOUBLE_SIZE = Byte.BYTES + Double.BYTES;
@@ -47,6 +53,7 @@ public class TypeStrategies
   public static final FloatTypeStrategy FLOAT = new FloatTypeStrategy();
   public static final DoubleTypeStrategy DOUBLE = new DoubleTypeStrategy();
   public static final StringTypeStrategy STRING = new StringTypeStrategy();
+  public static final NestedDataTypeStrategy NESTED = new NestedDataTypeStrategy();
   public static final ConcurrentHashMap<String, TypeStrategy<?>> COMPLEX_STRATEGIES = new ConcurrentHashMap<>();
 
   /**
@@ -63,9 +70,9 @@ public class TypeStrategies
 
   /**
    * hmm... this might look familiar... (see ComplexMetrics)
-   *
+   * <p>
    * Register a complex type name -> {@link TypeStrategy} mapping.
-   *
+   * <p>
    * If the specified type name is already used and the supplied {@link TypeStrategy} is not of the
    * same type as the existing value in the map for said key, an {@link ISE} is thrown.
    *
@@ -96,10 +103,10 @@ public class TypeStrategies
    * Clear and set the 'null' byte of a nullable value to {@link TypeStrategies#IS_NULL_BYTE} to a {@link ByteBuffer} at
    * the supplied position. This method does not change the buffer position, limit, or mark, because it does not expect
    * to own the buffer given to it (i.e. buffer aggs)
-   *
+   * <p>
    * Nullable types are stored with a leading byte to indicate if the value is null, followed by the value bytes
    * (if not null)
-   *
+   * <p>
    * layout: | null (byte) | value |
    *
    * @return number of bytes written (always 1)
@@ -114,10 +121,10 @@ public class TypeStrategies
    * Checks if a 'nullable' value's null byte is set to {@link TypeStrategies#IS_NULL_BYTE}. This method will mask the
    * value of the null byte to only check if the null bit is set, meaning that the higher bits can be utilized for
    * flags as necessary (e.g. using high bits to indicate if the value has been set or not for aggregators).
-   *
+   * <p>
    * Note that writing nullable values with the methods of {@link Types} will always clear and set the null byte to
    * either {@link TypeStrategies#IS_NULL_BYTE} or {@link TypeStrategies#IS_NOT_NULL_BYTE}, losing any flag bits.
-   *
+   * <p>
    * layout: | null (byte) | value |
    */
   public static boolean isNullableNull(ByteBuffer buffer, int offset)
@@ -129,9 +136,9 @@ public class TypeStrategies
   /**
    * Write a non-null long value to a {@link ByteBuffer} at the supplied offset. The first byte is always cleared and
    * set to {@link TypeStrategies#IS_NOT_NULL_BYTE}, the long value is written in the next 8 bytes.
-   *
+   * <p>
    * layout: | null (byte) | long |
-   *
+   * <p>
    * This method does not change the buffer position, limit, or mark, because it does not expect to own the buffer
    * given to it (i.e. buffer aggs)
    *
@@ -147,9 +154,9 @@ public class TypeStrategies
   /**
    * Reads a non-null long value from a {@link ByteBuffer} at the supplied offset. This method should only be called
    * if and only if {@link #isNullableNull} for the same offset returns false.
-   *
+   * <p>
    * layout: | null (byte) | long |
-   *
+   * <p>
    * This method does not change the buffer position, limit, or mark, because it does not expect  to own the buffer
    * given to it (i.e. buffer aggs)
    */
@@ -161,9 +168,9 @@ public class TypeStrategies
   /**
    * Write a non-null double value to a {@link ByteBuffer} at the supplied offset. The first byte is always cleared and
    * set to {@link TypeStrategies#IS_NOT_NULL_BYTE}, the double value is written in the next 8 bytes.
-   *
+   * <p>
    * layout: | null (byte) | double |
-   *
+   * <p>
    * This method does not change the buffer position, limit, or mark, because it does not expect to own the buffer
    * given to it (i.e. buffer aggs)
    *
@@ -179,9 +186,9 @@ public class TypeStrategies
   /**
    * Reads a non-null double value from a {@link ByteBuffer} at the supplied offset. This method should only be called
    * if and only if {@link #isNullableNull} for the same offset returns false.
-   *
+   * <p>
    * layout: | null (byte) | double |
-   *
+   * <p>
    * This method does not change the buffer position, limit, or mark, because it does not expect to own the buffer
    * given to it (i.e. buffer aggs)
    */
@@ -193,9 +200,9 @@ public class TypeStrategies
   /**
    * Write a non-null float value to a {@link ByteBuffer} at the supplied offset. The first byte is always cleared and
    * set to {@link TypeStrategies#IS_NOT_NULL_BYTE}, the float value is written in the next 4 bytes.
-   *
+   * <p>
    * layout: | null (byte) | float |
-   *
+   * <p>
    * This method does not change the buffer position, limit, or mark, because it does not expect to own the buffer
    * given to it (i.e. buffer aggs)
    *
@@ -211,9 +218,9 @@ public class TypeStrategies
   /**
    * Reads a non-null float value from a {@link ByteBuffer} at the supplied offset. This method should only be called
    * if and only if {@link #isNullableNull} for the same offset returns false.
-   *
+   * <p>
    * layout: | null (byte) | float |
-   *
+   * <p>
    * This method does not change the buffer position, limit, or mark, because it does not expect to own the buffer
    * given to it (i.e. buffer aggs)
    */
@@ -463,7 +470,7 @@ public class TypeStrategies
   /**
    * Read and write non-null UTF8 encoded String values. Encodes the length in bytes as an integer prefix followed by
    * the actual encoded value bytes.
-   *
+   * <p>
    * format: | length (int) | bytes |
    */
   public static final class StringTypeStrategy implements TypeStrategy<String>
@@ -551,7 +558,7 @@ public class TypeStrategies
    * Read and write a non-null ARRAY which is permitted to have null elements (all elements are always read and written
    * with a {@link NullableTypeStrategy} wrapper on the {@link TypeStrategy} of the
    * {@link TypeSignature#getElementType()}.
-   *
+   * <p>
    * Encodes the number of elements in the array as an integer prefix followed by the actual encoded value bytes of
    * each element serially.
    */
@@ -665,6 +672,7 @@ public class TypeStrategies
         return result;
       }
     }
+
     /**
      * Implements {@link Arrays#equals} but the element equality uses the element's type strategy
      */
@@ -697,4 +705,101 @@ public class TypeStrategies
       return Object[].class;
     }
   }
+
+  public static final class NestedDataTypeStrategy implements TypeStrategy<Object>
+  {
+    @Override
+    public int estimateSizeBytes(Object value)
+    {
+      return Objects.requireNonNull(StructuredData.wrap(value)).getSizeEstimate();
+    }
+
+    @Override
+    public Object read(ByteBuffer buffer)
+    {
+      final int len = buffer.getInt();
+      return fromByteBuffer(buffer, len);
+    }
+
+    @Nullable
+    public StructuredData fromByteBuffer(ByteBuffer buffer, int numBytes)
+    {
+      if (numBytes == 0) {
+        return null;
+      }
+
+      final byte[] bytes = new byte[numBytes];
+      buffer.get(bytes, 0, numBytes);
+      try {
+        return ColumnSerializerUtils.SMILE_MAPPER.readValue(bytes, 0, bytes.length, StructuredData.class);
+      }
+      catch (IOException e) {
+        throw DruidException.defensive(e, "Unable to deserialize value");
+      }
+    }
+
+    @Override
+    public boolean readRetainsBufferReference()
+    {
+      return false;
+    }
+
+    @Override
+    public int write(ByteBuffer buffer, Object value, int maxSizeBytes)
+    {
+      TypeStrategies.checkMaxSize(buffer.remaining(), maxSizeBytes, ColumnType.NESTED_DATA);
+      final byte[] bytes = toBytes(value);
+      final int sizeBytes = Integer.BYTES + bytes.length;
+      if (sizeBytes > maxSizeBytes) {
+        return maxSizeBytes - sizeBytes;
+      }
+      buffer.putInt(bytes.length);
+      buffer.put(bytes);
+      return sizeBytes;
+    }
+
+    @Nullable
+    public byte[] toBytes(@Nullable Object val)
+    {
+      if (val == null) {
+        return new byte[0];
+      }
+      try {
+        return ColumnSerializerUtils.SMILE_MAPPER.writeValueAsBytes(val);
+      }
+      catch (JsonProcessingException e) {
+        throw DruidException.defensive(e, "Unable to serialize value [%s]", val);
+      }
+    }
+
+    @Override
+    public int compare(Object o1, Object o2)
+    {
+      return StructuredData.COMPARATOR.compare(StructuredData.wrap(o1), StructuredData.wrap(o2));
+    }
+
+    @Override
+    public boolean groupable()
+    {
+      return true;
+    }
+
+    @Override
+    public int hashCode(Object o)
+    {
+      return Objects.hashCode(StructuredData.wrap(o));
+    }
+
+    @Override
+    public boolean equals(Object a, Object b)
+    {
+      return Objects.equals(StructuredData.wrap(a), StructuredData.wrap(b));
+    }
+
+    @Override
+    public Class<?> getClazz()
+    {
+      return StructuredData.class;
+    }
+  }
 }
