@@ -21,8 +21,10 @@ package org.apache.druid.segment.filter;
 
 import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.query.BitmapResultFactory;
+import org.apache.druid.query.filter.BooleanUnaryFilter;
 import org.apache.druid.query.filter.ColumnIndexSelector;
 import org.apache.druid.query.filter.Filter;
+import org.apache.druid.query.filter.FilterBundle;
 import org.apache.druid.query.filter.ValueMatcher;
 import org.apache.druid.query.filter.vector.BaseVectorValueMatcher;
 import org.apache.druid.query.filter.vector.ReadableVectorMatch;
@@ -51,7 +53,7 @@ import java.util.Set;
  * @see org.apache.druid.query.filter.IsTrueDimFilter
  * @see org.apache.druid.query.filter.IsFalseDimFilter
  */
-public class IsBooleanFilter implements Filter
+public class IsBooleanFilter implements BooleanUnaryFilter
 {
   private final Filter baseFilter;
   private final boolean isTrue;
@@ -62,72 +64,29 @@ public class IsBooleanFilter implements Filter
     this.isTrue = isTrue;
   }
 
+  public boolean isTrue()
+  {
+    return isTrue;
+  }
+
+  @Override
+  public Filter getBaseFilter()
+  {
+    return baseFilter;
+  }
+
+  @Nullable
+  @Override
+  public BitmapColumnIndex getBitmapColumnIndex(int numRows, FilterBundle.Builder baseBuilder)
+  {
+    return getBitmapColumnIndex(numRows, isTrue, baseBuilder.getBitmapColumnIndex());
+  }
+
   @Nullable
   @Override
   public BitmapColumnIndex getBitmapColumnIndex(ColumnIndexSelector selector)
   {
-    final BitmapColumnIndex baseIndex = baseFilter.getBitmapColumnIndex(selector);
-    if (baseIndex != null && (isTrue || baseIndex.getIndexCapabilities().isInvertible())) {
-      return new BitmapColumnIndex()
-      {
-        @Override
-        public ColumnIndexCapabilities getIndexCapabilities()
-        {
-          return baseIndex.getIndexCapabilities();
-        }
-
-        @Override
-        public int estimatedComputeCost()
-        {
-          return baseIndex.estimatedComputeCost();
-        }
-
-        @Override
-        public <T> T computeBitmapResult(BitmapResultFactory<T> bitmapResultFactory, boolean includeUnknown)
-        {
-          if (isTrue) {
-            return baseIndex.computeBitmapResult(bitmapResultFactory, false);
-          }
-          return bitmapResultFactory.complement(
-              baseIndex.computeBitmapResult(bitmapResultFactory, true),
-              selector.getNumRows()
-          );
-        }
-
-        @Nullable
-        @Override
-        public <T> T computeBitmapResult(
-            BitmapResultFactory<T> bitmapResultFactory,
-            int applyRowCount,
-            int totalRowCount,
-            boolean includeUnknown
-        )
-        {
-          if (isTrue) {
-            return baseIndex.computeBitmapResult(
-                bitmapResultFactory,
-                applyRowCount,
-                totalRowCount,
-                false
-            );
-          }
-
-          final T result = baseIndex.computeBitmapResult(
-              bitmapResultFactory,
-              applyRowCount,
-              totalRowCount,
-              true
-          );
-
-          if (result == null) {
-            return null;
-          }
-
-          return bitmapResultFactory.complement(result, selector.getNumRows());
-        }
-      };
-    }
-    return null;
+    return getBitmapColumnIndex(selector.getNumRows(), isTrue, baseFilter.getBitmapColumnIndex(selector));
   }
 
   @Override
@@ -228,4 +187,71 @@ public class IsBooleanFilter implements Filter
     // to return a different hash from baseFilter
     return Objects.hash(1, baseFilter, isTrue);
   }
+
+  @Nullable
+  private static BitmapColumnIndex getBitmapColumnIndex(int numRows, boolean isTrue, BitmapColumnIndex baseIndex)
+  {
+    if (baseIndex != null && (isTrue || baseIndex.getIndexCapabilities().isInvertible())) {
+      return new BitmapColumnIndex()
+      {
+        @Override
+        public ColumnIndexCapabilities getIndexCapabilities()
+        {
+          return baseIndex.getIndexCapabilities();
+        }
+
+        @Override
+        public int estimatedComputeCost()
+        {
+          // There's no additional cost on is boolean filter, cost will come from child FilterBundle.Builder
+          return 0;
+        }
+
+        @Override
+        public <T> T computeBitmapResult(BitmapResultFactory<T> bitmapResultFactory, boolean includeUnknown)
+        {
+          if (isTrue) {
+            return baseIndex.computeBitmapResult(bitmapResultFactory, false);
+          }
+          return bitmapResultFactory.complement(
+              baseIndex.computeBitmapResult(bitmapResultFactory, true),
+              numRows
+          );
+        }
+
+        @Nullable
+        @Override
+        public <T> T computeBitmapResult(
+            BitmapResultFactory<T> bitmapResultFactory,
+            int applyRowCount,
+            int totalRowCount,
+            boolean includeUnknown
+        )
+        {
+          if (isTrue) {
+            return baseIndex.computeBitmapResult(
+                bitmapResultFactory,
+                applyRowCount,
+                totalRowCount,
+                false
+            );
+          }
+
+          final T result = baseIndex.computeBitmapResult(
+              bitmapResultFactory,
+              applyRowCount,
+              totalRowCount,
+              true
+          );
+
+          if (result == null) {
+            return null;
+          }
+
+          return bitmapResultFactory.complement(result, numRows);
+        }
+      };
+    }
+    return null;
+  }
 }
