@@ -22,7 +22,6 @@ package org.apache.druid.segment.nested;
 import com.google.common.primitives.Ints;
 import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.java.util.common.io.smoosh.FileSmoosher;
-import org.apache.druid.segment.IndexSpec;
 import org.apache.druid.segment.data.ColumnarLongsSerializer;
 import org.apache.druid.segment.data.CompressionFactory;
 import org.apache.druid.segment.writeout.SegmentWriteOutMedium;
@@ -45,11 +44,11 @@ public final class ScalarLongFieldColumnWriter extends GlobalDictionaryEncodedFi
       String columnName,
       String fieldName,
       SegmentWriteOutMedium segmentWriteOutMedium,
-      IndexSpec indexSpec,
+      NestedCommonFormatColumnFormatSpec columnFormatSpec,
       DictionaryIdLookup globalDictionaryIdLookup
   )
   {
-    super(columnName, fieldName, segmentWriteOutMedium, indexSpec, globalDictionaryIdLookup);
+    super(columnName, fieldName, segmentWriteOutMedium, columnFormatSpec, globalDictionaryIdLookup);
   }
 
   @Override
@@ -77,8 +76,8 @@ public final class ScalarLongFieldColumnWriter extends GlobalDictionaryEncodedFi
         medium,
         StringUtils.format("%s.long_column", fieldName),
         ByteOrder.nativeOrder(),
-        indexSpec.getLongEncoding(),
-        indexSpec.getDimensionCompression(),
+        columnFormatSpec.getLongColumnEncoding(),
+        columnFormatSpec.getLongColumnCompression(),
         fieldResourceCloser
     );
     longsSerializer.open();
