@@ -20,6 +20,7 @@
 package org.apache.druid.segment.virtual;
 
 import org.apache.druid.math.expr.Expr;
+import org.apache.druid.math.expr.ExpressionType;
 
 import javax.annotation.Nullable;
 
@@ -28,6 +29,13 @@ public class SingleInputBindings implements Expr.ObjectBinding
   @Nullable
   private Object value;
 
+  private final ExpressionType type;
+
+  public SingleInputBindings(ExpressionType type)
+  {
+    this.type = type;
+  }
+
   @Override
   public Object get(final String name)
   {
@@ -38,4 +46,11 @@ public class SingleInputBindings implements Expr.ObjectBinding
   {
     this.value = value;
   }
+
+  @Nullable
+  @Override
+  public ExpressionType getType(String name)
+  {
+    return type;
+  }
 }
