@@ -40,12 +40,12 @@ public class DruidExceptionMatcher extends DiagnosingMatcher<Throwable>
     );
   }
 
-  public static DruidExceptionMatcher notFound()
+  public static DruidExceptionMatcher unsupported()
   {
     return new DruidExceptionMatcher(
-        DruidException.Persona.USER,
-        DruidException.Category.NOT_FOUND,
-        "notFound"
+        DruidException.Persona.OPERATOR,
+        DruidException.Category.UNSUPPORTED,
+        "general"
     );
   }
 
@@ -63,6 +63,20 @@ public class DruidExceptionMatcher extends DiagnosingMatcher<Throwable>
     );
   }
 
+  public static DruidExceptionMatcher forbidden()
+  {
+    return new DruidExceptionMatcher(DruidException.Persona.USER, DruidException.Category.FORBIDDEN, "general");
+  }
+
+  public static DruidExceptionMatcher conflict()
+  {
+    return new DruidExceptionMatcher(
+        DruidException.Persona.OPERATOR,
+        DruidException.Category.CONFLICT,
+        "general"
+    );
+  }
+
   public static DruidExceptionMatcher defensive()
   {
     return new DruidExceptionMatcher(
