@@ -32,7 +32,7 @@ import org.apache.druid.segment.QueryableIndexCursorFactory;
 import org.apache.druid.segment.SimpleAscendingOffset;
 import org.apache.druid.segment.TestIndex;
 import org.apache.druid.segment.column.BaseColumn;
-import org.apache.druid.segment.column.ColumnHolder;
+import org.apache.druid.segment.column.BaseColumnHolder;
 import org.apache.druid.segment.column.RowSignature;
 import org.apache.druid.testing.InitializedNullHandlingTest;
 import org.junit.Assert;
@@ -57,7 +57,7 @@ public class FieldReaderRACTest extends InitializedNullHandlingTest
     final RowBasedFrameRowsAndColumns rowBasedRAC = new RowBasedFrameRowsAndColumns(frame, siggy);
 
     for (String columnName : siggy.getColumnNames()) {
-      final ColumnHolder colHolder = index.getColumnHolder(columnName);
+      final BaseColumnHolder colHolder = index.getColumnHolder(columnName);
       final boolean multiValue = colHolder.getCapabilities().hasMultipleValues().isTrue();
 
       try (BaseColumn col = colHolder.getColumn()) {
