@@ -57,6 +57,7 @@ import java.util.List;
 import java.util.TimeZone;
 
 /**
+ *
  */
 public class QueryGranularityTest extends InitializedNullHandlingTest
 {
@@ -1040,11 +1041,14 @@ public class QueryGranularityTest extends InitializedNullHandlingTest
     );
 
     ExpressionVirtualColumn column = Granularities.toVirtualColumn(hour, Granularities.GRANULARITY_VIRTUAL_COLUMN_NAME);
-    Assert.assertEquals("timestamp_floor(__time,'PT1H')", column.getExpression());
+    Assert.assertEquals("timestamp_floor(__time,'PT1H',null,'UTC')", column.getExpression());
     column = Granularities.toVirtualColumn(hourWithOrigin, Granularities.GRANULARITY_VIRTUAL_COLUMN_NAME);
-    Assert.assertEquals(ColumnHolder.TIME_COLUMN_NAME, column.getExpression());
+    Assert.assertEquals(
+        "timestamp_floor(__time,'PT1H','2012-01-02T13:00:00.000Z','America/Los_Angeles')",
+        column.getExpression()
+    );
     column = Granularities.toVirtualColumn(hourWithTz, Granularities.GRANULARITY_VIRTUAL_COLUMN_NAME);
-    Assert.assertEquals(ColumnHolder.TIME_COLUMN_NAME, column.getExpression());
+    Assert.assertEquals("timestamp_floor(__time,'PT1H',null,'America/Los_Angeles')", column.getExpression());
     column = Granularities.toVirtualColumn(duration, Granularities.GRANULARITY_VIRTUAL_COLUMN_NAME);
     Assert.assertEquals(ColumnHolder.TIME_COLUMN_NAME, column.getExpression());
     column = Granularities.toVirtualColumn(Granularities.NONE, Granularities.GRANULARITY_VIRTUAL_COLUMN_NAME);
@@ -1052,11 +1056,11 @@ public class QueryGranularityTest extends InitializedNullHandlingTest
     column = Granularities.toVirtualColumn(Granularities.ALL, Granularities.GRANULARITY_VIRTUAL_COLUMN_NAME);
     Assert.assertNull(column);
     column = Granularities.toVirtualColumn(Granularities.HOUR, Granularities.GRANULARITY_VIRTUAL_COLUMN_NAME);
-    Assert.assertEquals("timestamp_floor(__time,'PT1H')", column.getExpression());
+    Assert.assertEquals("timestamp_floor(__time,'PT1H',null,'UTC')", column.getExpression());
     column = Granularities.toVirtualColumn(Granularities.MINUTE, Granularities.GRANULARITY_VIRTUAL_COLUMN_NAME);
-    Assert.assertEquals("timestamp_floor(__time,'PT1M')", column.getExpression());
+    Assert.assertEquals("timestamp_floor(__time,'PT1M',null,'UTC')", column.getExpression());
     column = Granularities.toVirtualColumn(Granularities.FIFTEEN_MINUTE, Granularities.GRANULARITY_VIRTUAL_COLUMN_NAME);
-    Assert.assertEquals("timestamp_floor(__time,'PT15M')", column.getExpression());
+    Assert.assertEquals("timestamp_floor(__time,'PT15M',null,'UTC')", column.getExpression());
   }
 
   @Test
@@ -1070,6 +1074,18 @@ public class QueryGranularityTest extends InitializedNullHandlingTest
         ColumnType.LONG,
         TestExprMacroTable.INSTANCE
     );
+    ExpressionVirtualColumn hourlyPacificTime = new ExpressionVirtualColumn(
+        "v0",
+        "timestamp_floor(__gran, 'PT1H', null, 'America/Los_Angeles')",
+        ColumnType.LONG,
+        TestExprMacroTable.INSTANCE
+    );
+    ExpressionVirtualColumn hourlyIndianTime = new ExpressionVirtualColumn(
+        "v0",
+        "timestamp_floor(__gran, 'PT1H', null, 'Asia/Kolkata')",
+        ColumnType.LONG,
+        TestExprMacroTable.INSTANCE
+    );
     ExpressionVirtualColumn ceilHour = new ExpressionVirtualColumn(
         "v0",
         "timestamp_ceil(__time, 'PT1M')",
@@ -1078,7 +1094,7 @@ public class QueryGranularityTest extends InitializedNullHandlingTest
     );
     ExpressionVirtualColumn floorWithExpression = new ExpressionVirtualColumn(
         "v0",
-        "timestamp_floor(timestamp_parse(timestamp,null,'UTC'), 'PT1M')",
+        "timestamp_floor(timestamp_parse(__time,null,'UTC'), 'PT1M')",
         ColumnType.LONG,
         TestExprMacroTable.INSTANCE
     );
@@ -1097,8 +1113,16 @@ public class QueryGranularityTest extends InitializedNullHandlingTest
     Assert.assertEquals(Granularities.HOUR, Granularities.fromVirtualColumn(hourly));
     Assert.assertEquals(Granularities.DAY, Granularities.fromVirtualColumn(day));
     Assert.assertEquals(Granularities.HOUR, Granularities.fromVirtualColumn(hourlyNonstandardTime));
+    Assert.assertEquals(
+        new PeriodGranularity(new Period("PT1H"), null, DateTimes.inferTzFromString("America/Los_Angeles")),
+        Granularities.fromVirtualColumn(hourlyPacificTime)
+    );
+    Assert.assertEquals(
+        new PeriodGranularity(new Period("PT1H"), null, DateTimes.inferTzFromString("Asia/Kolkata")),
+        Granularities.fromVirtualColumn(hourlyIndianTime)
+    );
     Assert.assertNull(Granularities.fromVirtualColumn(ceilHour));
-    Assert.assertNull(Granularities.fromVirtualColumn(floorWithExpression));
+    Assert.assertEquals(Granularities.MINUTE, Granularities.fromVirtualColumn(floorWithExpression));
     final DateTime origin = DateTimes.of("2012-01-02T05:00:00.000-08:00");
     final DateTimeZone tz = DateTimes.inferTzFromString("America/Los_Angeles");
     final Granularity minuteWithTz = new PeriodGranularity(new Period("PT1M"), null, tz);
@@ -1107,6 +1131,18 @@ public class QueryGranularityTest extends InitializedNullHandlingTest
     Assert.assertEquals(minuteWithOrigin, Granularities.fromVirtualColumn(floorWithOriginTimezone));
   }
 
+  @Test
+  public void testFromVirtualColumnExtra()
+  {
+    ExpressionVirtualColumn literalField = new ExpressionVirtualColumn(
+        "v0",
+        "a",
+        ColumnType.LONG,
+        TestExprMacroTable.INSTANCE
+    );
+    Assert.assertEquals(Granularities.ALL, Granularities.fromVirtualColumn(literalField));
+  }
+
   private void assertBucketStart(final Granularity granularity, final DateTime in, final DateTime expectedInProperTz)
   {
     Assert.assertEquals(
