@@ -20,11 +20,12 @@
 package org.apache.druid.guice;
 
 import com.google.inject.Injector;
-import org.apache.druid.common.config.NullValueHandlingConfig;
+import org.apache.druid.error.ExceptionMatcher;
 import org.apache.druid.java.util.common.ISE;
 import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.math.expr.ExpressionProcessingConfig;
 import org.apache.druid.utils.RuntimeInfo;
+import org.hamcrest.MatcherAssert;
 import org.junit.Assert;
 import org.junit.Test;
 
@@ -145,7 +146,7 @@ public class StartupInjectorBuilderTest
   public void testValidator()
   {
     final Properties propsDefaultValueMode = new Properties();
-    propsDefaultValueMode.put(NullValueHandlingConfig.NULL_HANDLING_CONFIG_STRING, "true");
+    propsDefaultValueMode.put(StartupInjectorBuilder.NULL_HANDLING_CONFIG_STRING, "true");
 
     Throwable t = Assert.assertThrows(
         ISE.class,
@@ -162,7 +163,7 @@ public class StartupInjectorBuilderTest
     );
 
     final Properties propsNo3vl = new Properties();
-    propsNo3vl.put(NullValueHandlingConfig.THREE_VALUE_LOGIC_CONFIG_STRING, "false");
+    propsNo3vl.put(StartupInjectorBuilder.THREE_VALUE_LOGIC_CONFIG_STRING, "false");
     t = Assert.assertThrows(
         ISE.class,
         () -> new StartupInjectorBuilder().withExtensions()
@@ -194,4 +195,62 @@ public class StartupInjectorBuilderTest
         t.getMessage()
     );
   }
+
+  @Test
+  public void verifyInjectorBuild_withDeletedConfig_throwsException()
+  {
+    verifyInjectorBuild_withDeletedConfig_throwsException(
+        "druid.processing.merge.pool.parallelism",
+        "10",
+        "Config[druid.processing.merge.pool.parallelism] has been removed."
+        + " Please use config[druid.processing.merge.parallelism] instead."
+    );
+    verifyInjectorBuild_withDeletedConfig_throwsException(
+        "druid.processing.merge.pool.awaitShutdownMillis",
+        "1000",
+        "Config[druid.processing.merge.pool.awaitShutdownMillis] has been removed."
+        + " Please use config[druid.processing.merge.awaitShutdownMillis] instead."
+    );
+    verifyInjectorBuild_withDeletedConfig_throwsException(
+        "druid.processing.merge.pool.defaultMaxQueryParallelism",
+        "100",
+        "Config[druid.processing.merge.pool.defaultMaxQueryParallelism] has been removed."
+        + " Please use config[druid.processing.merge.defaultMaxQueryParallelism] instead."
+    );
+
+    verifyInjectorBuild_withDeletedConfig_throwsException(
+        "druid.processing.merge.task.targetRunTimeMillis",
+        "10",
+        "Config[druid.processing.merge.task.targetRunTimeMillis] has been removed."
+        + " Please use config[druid.processing.merge.targetRunTimeMillis] instead."
+    );
+    verifyInjectorBuild_withDeletedConfig_throwsException(
+        "druid.processing.merge.task.initialYieldNumRows",
+        "1000",
+        "Config[druid.processing.merge.task.initialYieldNumRows] has been removed."
+        + " Please use config[druid.processing.merge.initialYieldNumRows] instead."
+    );
+    verifyInjectorBuild_withDeletedConfig_throwsException(
+        "druid.processing.merge.task.smallBatchNumRows",
+        "100",
+        "Config[druid.processing.merge.task.smallBatchNumRows] has been removed."
+        + " Please use config[druid.processing.merge.smallBatchNumRows] instead."
+    );
+  }
+
+  private static void verifyInjectorBuild_withDeletedConfig_throwsException(
+      String removedProperty,
+      String dummyValue,
+      String expectedMessage
+  )
+  {
+    final Properties props = new Properties();
+    props.setProperty(removedProperty, dummyValue);
+
+    final StartupInjectorBuilder builder = new StartupInjectorBuilder().withExtensions().withProperties(props);
+    MatcherAssert.assertThat(
+        Assert.assertThrows(ISE.class, builder::build),
+        ExceptionMatcher.of(ISE.class).expectMessageIs(expectedMessage)
+    );
+  }
 }
