@@ -33,6 +33,7 @@ import org.apache.commons.compress.compressors.zstandard.ZstdCompressorOutputStr
 import org.apache.druid.utils.CompressionUtils;
 import org.junit.Assert;
 import org.junit.Before;
+import org.junit.Ignore;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TemporaryFolder;
@@ -553,6 +554,7 @@ public class CompressionUtilsTest
   // If this ever passes, er... fails to fail... then the bug is fixed
   @Test(expected = AssertionError.class)
   // http://bugs.java.com/bugdatabase/view_bug.do?bug_id=7036144
+  @Ignore("This test fails in JDK 21, looks like the bug was fixed in 21.0.9 at least.")
   public void testGunzipBug() throws IOException
   {
     final ByteArrayOutputStream tripleGzByteStream = new ByteArrayOutputStream(GZ_BYTES.length * 3);
