@@ -322,7 +322,7 @@ public class FunctionTest extends InitializedNullHandlingTest
     assertExpr("array_length([1,2,3])", 3L);
     assertExpr("array_length(a)", 4L);
     // nested types only work with typed bindings right now, and pretty limited support for stuff
-    assertExpr("array_length(nestedArray)", 2L, typedBindings);
+    assertExpr("array_length(nestedArray)", 2L, typedBindings, ExprMacroTable.nil());
   }
 
   @Test
@@ -333,7 +333,7 @@ public class FunctionTest extends InitializedNullHandlingTest
     assertArrayExpr("array_offset([1, 2, 3], -1)", null);
     assertExpr("array_offset(a, 2)", "baz");
     // nested types only work with typed bindings right now, and pretty limited support for stuff
-    assertExpr("array_offset(nestedArray, 1)", ImmutableMap.of("x", 4L, "y", 6.6), typedBindings);
+    assertExpr("array_offset(nestedArray, 1)", ImmutableMap.of("x", 4L, "y", 6.6), typedBindings, ExprMacroTable.nil());
   }
 
   @Test
@@ -344,7 +344,7 @@ public class FunctionTest extends InitializedNullHandlingTest
     assertArrayExpr("array_ordinal([1, 2, 3], 0)", null);
     assertExpr("array_ordinal(a, 3)", "baz");
     // nested types only work with typed bindings right now, and pretty limited support for stuff
-    assertExpr("array_ordinal(nestedArray, 2)", ImmutableMap.of("x", 4L, "y", 6.6), typedBindings);
+    assertExpr("array_ordinal(nestedArray, 2)", ImmutableMap.of("x", 4L, "y", 6.6), typedBindings, ExprMacroTable.nil());
   }
 
   @Test
@@ -391,6 +391,107 @@ public class FunctionTest extends InitializedNullHandlingTest
     assertExpr("array_contains([1, null, 2], null)", 1L);
     assertExpr("array_contains([1, null, 2], [null])", 1L);
     assertExpr("array_contains([1, 2], null)", 0L);
+    assertExpr("array_contains([1, 2, 3], [])", 1L);
+    assertExpr("array_contains([], [])", 1L);
+    assertExpr("array_contains([null], [])", 1L);
+    assertExpr("array_contains(['foo', 'bar'], [])", 1L);
+    assertExpr("array_contains(null, [])", null);
+  }
+
+  @Test
+  public void testMvContains()
+  {
+    // Tests where the first argument is a numeric array that does not contain null
+    assertExpr("mv_contains([1, 2, 3], 2)", 1L);
+    assertExpr("mv_contains([1, 2, 3], 4)", 0L);
+    assertExpr("mv_contains([1, 2, 3], [2, 3])", 1L);
+    assertExpr("mv_contains([1, 2, 3], [3, 4])", 0L);
+    assertExpr("mv_contains([1, 2], null)", 0L);
+    assertExpr("mv_contains(b, y)", 1L);
+    assertExpr("mv_contains(b, x)", 0L);
+
+    // Tests where the first argument is a string array that does not contain null
+    assertExpr("mv_contains(a, str1)", 0L);
+    assertExpr("mv_contains(a, x)", 1L);
+
+    // Tests where the first argument is a numeric array that does contain null
+    assertExpr("mv_contains([1, null, 2], 2)", 1L);
+    assertExpr("mv_contains([1, null, 2], 3)", 0L);
+    assertExpr("mv_contains([1, null, 2], [2, 3])", 0L);
+    assertExpr("mv_contains([1, null, 2], [1, 2])", 1L);
+    assertExpr("mv_contains([1, null, 2], [null])", 1L);
+    assertExpr("mv_contains([null, 1], null)", 1L);
+    assertExpr("mv_contains([null, 1], [null])", 1L);
+    assertExpr("mv_contains([1, null, 2], y)", 1L);
+    assertExpr("mv_contains([null, 1], o)", 0L);
+
+    // Tests where the first argument is a string array that does contain null
+    assertExpr("mv_contains(['foo', null, 'bar'], 'foo')", 1L);
+    assertExpr("mv_contains(['foo', null, 'bar'], 'baz')", 0L);
+    assertExpr("mv_contains(['foo', null, 'bar'], null)", 1L);
+    assertExpr("mv_contains(['foo', null, 'bar'], ['foo'])", 1L);
+    assertExpr("mv_contains(['foo', null, 'bar'], ['foo', 'bar'])", 1L);
+    assertExpr("mv_contains(['foo', null, 'bar'], ['foo', 'baz'])", 0L);
+    assertExpr("mv_contains(['foo', null, 'bar'], [null])", 1L);
+    assertExpr("mv_contains(['foo', null, 'bar'], ['foo', null])", 1L);
+    assertExpr("mv_contains([null, 'test'], ['test', 'other'])", 0L);
+
+    // Tests where the first argument is a non-null string
+    assertExpr("mv_contains('test', 'test')", 1L);
+    assertExpr("mv_contains('test', 'other')", 0L);
+    assertExpr("mv_contains('test', ['test'])", 1L);
+    assertExpr("mv_contains('test', ['other'])", 0L);
+    assertExpr("mv_contains('hello', 'hello')", 1L);
+    assertExpr("mv_contains('hello', 'world')", 0L);
+    assertExpr("mv_contains('hello', 42)", 0L);
+    assertExpr("mv_contains('hello', 3.14)", 0L);
+    assertExpr("mv_contains('hello', ['hello'])", 1L);
+    assertExpr("mv_contains('hello', ['hello', 'world'])", 0L);
+    assertExpr("mv_contains('hello', [42])", 0L);
+    assertExpr("mv_contains('hello', [3.14])", 0L);
+    assertExpr("mv_contains('hello', null)", 0L);
+
+    // Tests where the first argument is null
+    assertExpr("mv_contains(null, [3, 4])", 0L);
+    assertExpr("mv_contains(null, null)", 1L);
+    assertExpr("mv_contains(null, 1)", 0L);
+    assertExpr("mv_contains(null, 'test')", 0L);
+    assertExpr("mv_contains(null, [1, 2])", 0L);
+    assertExpr("mv_contains(null, [])", 1L);
+    assertExpr("mv_contains(null, [null])", 1L);
+    assertExpr("mv_contains(null, [null, 1])", 0L);
+
+    // Tests where the first argument is an empty array
+    assertExpr("mv_contains([], 1)", 0L);
+    assertExpr("mv_contains([], [1, 2])", 0L);
+    assertExpr("mv_contains([], [])", 1L);
+    assertExpr("mv_contains([], null)", 1L);
+    assertExpr("mv_contains([], [null])", 1L);
+
+    // Tests where the first argument is a long
+    assertExpr("mv_contains(42, 42)", 1L);
+    assertExpr("mv_contains(42, 43)", 0L);
+    assertExpr("mv_contains(42, 'test')", 0L);
+    assertExpr("mv_contains(42, 42.0)", 0L);
+    assertExpr("mv_contains(42, [42])", 1L);
+    assertExpr("mv_contains(42, [42, 43])", 0L);
+    assertExpr("mv_contains(42, [42, 43, null])", 0L);
+    assertExpr("mv_contains(42, ['test'])", 0L);
+    assertExpr("mv_contains(42, [42.0])", 0L);
+    assertExpr("mv_contains(42, null)", 0L);
+
+    // Tests where the first argument is a double
+    assertExpr("mv_contains(3.14, 3.14)", 1L);
+    assertExpr("mv_contains(3.14, 3)", 0L);
+    assertExpr("mv_contains(3.14, 'pi')", 0L);
+    assertExpr("mv_contains(3.14, 3.14)", 1L);
+    assertExpr("mv_contains(3.14, [3.14])", 1L);
+    assertExpr("mv_contains(3.14, [3.14])", 1L);
+    assertExpr("mv_contains(3.14, [3, 3.14])", 0L);
+    assertExpr("mv_contains(3.14, ['3.14'])", 1L);
+    assertExpr("mv_contains(3.14, [3.14, 6.28])", 0L);
+    assertExpr("mv_contains(3.14, [3.14, 6.28, null])", 0L);
+    assertExpr("mv_contains(3.14, null)", 0L);
   }
 
   @Test
@@ -404,6 +505,100 @@ public class FunctionTest extends InitializedNullHandlingTest
     assertExpr("array_overlap([4, 5, 6], [null])", 0L);
     assertExpr("array_overlap([4, 5, null, 6], null)", 0L);
     assertExpr("array_overlap([4, 5, null, 6], [null])", 1L);
+    assertExpr("array_overlap([1, 2, 3], [])", 0L);
+    assertExpr("array_overlap([], [])", 0L);
+    assertExpr("array_overlap([null], [])", 0L);
+    assertExpr("array_overlap(['foo', 'bar'], [])", 0L);
+    assertExpr("array_overlap(null, [])", null);
+    assertExpr("array_overlap([1, null, 3], [])", 0L);
+  }
+
+  @Test
+  public void testMvOverlap()
+  {
+    // Tests where the first argument is a numeric array that does not contain null
+    assertExpr("mv_overlap([1, 2, 3], [2, 4, 6])", 1L);
+    assertExpr("mv_overlap([1, 2, 3], [4, 5, 6])", 0L);
+    assertExpr("mv_overlap([4, 5, 6], null)", 0L);
+    assertExpr("mv_overlap([4, 5, 6], [null])", 0L);
+    assertExpr("mv_overlap(b, c)", 0L);
+    assertExpr("mv_overlap(c, b)", 0L); // (c, b) = 0L now that 2nd arg is cast to string array
+
+    // Tests where the first argument is a string array that does not contain null
+    assertExpr("mv_overlap(a, emptyArray)", 0L);
+    assertExpr("mv_overlap(a, a)", 1L);
+
+    // Tests where the first argument is a numeric array that does contain null
+    assertExpr("mv_overlap([4, null], [4, 5, 6])", 1L);
+    assertExpr("mv_overlap([7, null], [4, 5, 6])", null);
+    assertExpr("mv_overlap([4, 5, null, 6], [null])", 1L);
+    assertExpr("mv_overlap([4, 5, null, 6], null)", 1L);
+    assertExpr("mv_overlap([null, 1], [null, 2])", 1L);
+    assertExpr("mv_overlap([1, null, 2], b)", 1L);
+    assertExpr("mv_overlap([null, 6], c)", null);
+
+    // Tests where the first argument is a string array that does contain null
+    assertExpr("mv_overlap(['foo', null, 'bar'], ['foo', 'baz'])", 1L);
+    assertExpr("mv_overlap(['foo', null, 'bar'], ['baz', 'qux'])", null);
+    assertExpr("mv_overlap(['foo', null, 'bar'], [null])", 1L);
+    assertExpr("mv_overlap(['foo', null, 'bar'], ['foo', null])", 1L);
+    assertExpr("mv_overlap(['foo', null, 'bar'], null)", 1L);
+    assertExpr("mv_overlap([null, 'hello'], ['hello', 'world'])", 1L);
+    assertExpr("mv_overlap([null, 'hello'], ['world'])", null);
+
+    // Tests where the first argument is a non-null string
+    assertExpr("mv_overlap('test', ['test', 'other'])", 1L);
+    assertExpr("mv_overlap('test', ['other'])", 0L);
+    assertExpr("mv_overlap('hello', 'hello')", 1L);
+    assertExpr("mv_overlap('hello', 'world')", 0L);
+    assertExpr("mv_overlap('hello', 42)", 0L);
+    assertExpr("mv_overlap('hello', 3.14)", 0L);
+    assertExpr("mv_overlap('hello', ['hello', 'world'])", 1L);
+    assertExpr("mv_overlap('hello', ['foo', 'bar'])", 0L);
+    assertExpr("mv_overlap('hello', ['foo', 'bar', null])", 0L);
+    assertExpr("mv_overlap('hello', [42, 43])", 0L);
+    assertExpr("mv_overlap('hello', [42, 43, null])", 0L);
+    assertExpr("mv_overlap('hello', [3.14, 6.28])", 0L);
+    assertExpr("mv_overlap('hello', [3.14, 6.28, null])", 0L);
+    assertExpr("mv_overlap('hello', null)", 0L);
+
+    // Tests where the first argument is null
+    assertExpr("mv_overlap(null, [4, 5, 6])", null);
+    assertExpr("mv_overlap(null, [1, 2])", null);
+    assertExpr("mv_overlap(null, 1)", null);
+    assertExpr("mv_overlap(null, 'test')", null);
+    assertExpr("mv_overlap(null, [])", 0L);
+    assertExpr("mv_overlap(null, [null])", 1L);
+    assertExpr("mv_overlap(null, [null, 1])", 1L);
+
+    // Tests where the first argument is an empty array
+    assertExpr("mv_overlap([], [1, 2])", null);
+    assertExpr("mv_overlap([], [])", 0L);
+    assertExpr("mv_overlap([], [null])", 1L);
+    assertExpr("mv_overlap([], null)", 1L);
+
+    // Tests where the first argument is a long
+    assertExpr("mv_overlap(42, 42)", 1L);
+    assertExpr("mv_overlap(42, 43)", 0L);
+    assertExpr("mv_overlap(42, 'test')", 0L);
+    assertExpr("mv_overlap(42, 42.0)", 0L);
+    assertExpr("mv_overlap(42, [41, 42, 43])", 1L);
+    assertExpr("mv_overlap(42, [40, 41])", 0L);
+    assertExpr("mv_overlap(42, ['test', 'foo'])", 0L);
+    assertExpr("mv_overlap(42, [41.0, 42.0, 43.0])", 0L);
+    assertExpr("mv_overlap(42, null)", 0L);
+
+    // Tests where the first argument is a double
+    assertExpr("mv_overlap(3.14, 3.14)", 1L);
+    assertExpr("mv_overlap(3.14, 2.71)", 0L);
+    assertExpr("mv_overlap(3.14, 'pi')", 0L);
+    assertExpr("mv_overlap(3.14, 3)", 0L);
+    assertExpr("mv_overlap(3.14, [3.14, 6.28])", 1L);
+    assertExpr("mv_overlap(3.14, [3.14, 6.28, null])", 1L);
+    assertExpr("mv_overlap(3.14, [1, 2, 3])", 0L);
+    assertExpr("mv_overlap(3.14, ['pi', '3.14'])", 1L);
+    assertExpr("mv_overlap(3.14, [1.0, 2.0, 3.14])", 1L);
+    assertExpr("mv_overlap(3.14, null)", 0L);
   }
 
   @Test
@@ -758,7 +953,7 @@ public class FunctionTest extends InitializedNullHandlingTest
   }
 
   @Test
-  public void testSizeForatInvalidArgumentType()
+  public void testSizeFormatInvalidArgumentType()
   {
     // x = "foo"
     Throwable t = Assert.assertThrows(
@@ -786,7 +981,7 @@ public class FunctionTest extends InitializedNullHandlingTest
                     .eval(bestEffortBindings)
     );
     Assert.assertEquals(
-        "Function[human_readable_binary_byte_format] needs a LONG as its second argument but got STRING instead",
+        "Function[human_readable_binary_byte_format] needs a LONG as its second argument but got null",
         t.getMessage()
     );
   }
@@ -1291,24 +1486,35 @@ public class FunctionTest extends InitializedNullHandlingTest
   private void assertExpr(final String expression, @Nullable final Object expectedResult)
   {
     for (Expr.ObjectBinding toUse : allBindings) {
-      assertExpr(expression, expectedResult, toUse);
+      assertExpr(expression, expectedResult, toUse, ExprMacroTable.nil());
     }
   }
 
-  private void assertExpr(
+  private void assertArrayExpr(final String expression, @Nullable final Object[] expectedResult)
+  {
+    for (Expr.ObjectBinding toUse : allBindings) {
+      assertArrayExpr(expression, expectedResult, toUse, ExprMacroTable.nil());
+    }
+  }
+
+  /**
+   * Check a bunch of stuff to make sure an expression produces the correct result upon evaluation and is chill
+   */
+  public static void assertExpr(
       final String expression,
       @Nullable final Object expectedResult,
-      Expr.ObjectBinding bindings
+      Expr.ObjectBinding bindings,
+      ExprMacroTable macroTable
   )
   {
-    final Expr expr = Parser.parse(expression, ExprMacroTable.nil());
+    final Expr expr = Parser.parse(expression, macroTable);
     Assert.assertEquals(expression, expectedResult, expr.eval(bindings).value());
 
-    final Expr exprNoFlatten = Parser.parse(expression, ExprMacroTable.nil(), false);
-    final Expr roundTrip = Parser.parse(exprNoFlatten.stringify(), ExprMacroTable.nil());
+    final Expr exprNoFlatten = Parser.parse(expression, macroTable, false);
+    final Expr roundTrip = Parser.parse(exprNoFlatten.stringify(), macroTable);
     Assert.assertEquals(expr.stringify(), expectedResult, roundTrip.eval(bindings).value());
 
-    final Expr roundTripFlatten = Parser.parse(expr.stringify(), ExprMacroTable.nil());
+    final Expr roundTripFlatten = Parser.parse(expr.stringify(), macroTable);
     Assert.assertEquals(expr.stringify(), expectedResult, roundTripFlatten.eval(bindings).value());
 
     final Expr singleThreaded = Expr.singleThreaded(expr, bindings);
@@ -1327,28 +1533,24 @@ public class FunctionTest extends InitializedNullHandlingTest
     Assert.assertArrayEquals(expr.getCacheKey(), roundTripFlatten.getCacheKey());
   }
 
-  private void assertArrayExpr(final String expression, @Nullable final Object[] expectedResult)
-  {
-
-    for (Expr.ObjectBinding toUse : allBindings) {
-      assertArrayExpr(expression, expectedResult, toUse);
-    }
-  }
-
-  private void assertArrayExpr(
+  /**
+   * Check a bunch of stuff to make sure an expression produces the correct array result upon evaluation and is chill
+   */
+  public static void assertArrayExpr(
       final String expression,
       @Nullable final Object[] expectedResult,
-      Expr.ObjectBinding bindings
+      Expr.ObjectBinding bindings,
+      ExprMacroTable macroTable
   )
   {
-    final Expr expr = Parser.parse(expression, ExprMacroTable.nil());
+    final Expr expr = Parser.parse(expression, macroTable);
     Assert.assertArrayEquals(expression, expectedResult, expr.eval(bindings).asArray());
 
-    final Expr exprNoFlatten = Parser.parse(expression, ExprMacroTable.nil(), false);
-    final Expr roundTrip = Parser.parse(exprNoFlatten.stringify(), ExprMacroTable.nil());
+    final Expr exprNoFlatten = Parser.parse(expression, macroTable, false);
+    final Expr roundTrip = Parser.parse(exprNoFlatten.stringify(), macroTable);
     Assert.assertArrayEquals(expression, expectedResult, roundTrip.eval(bindings).asArray());
 
-    final Expr roundTripFlatten = Parser.parse(expr.stringify(), ExprMacroTable.nil());
+    final Expr roundTripFlatten = Parser.parse(expr.stringify(), macroTable);
     Assert.assertArrayEquals(expression, expectedResult, roundTripFlatten.eval(bindings).asArray());
 
     Assert.assertEquals(expr.stringify(), roundTrip.stringify());
