@@ -396,8 +396,8 @@ public class OutputTypeTest extends InitializedNullHandlingTest
   @Test
   public void testEvalAutoConversion()
   {
-    final ExprEval<?> nullStringEval = ExprEval.of(null);
-    final ExprEval<?> stringEval = ExprEval.of("wat");
+    final ExprEval<?> nullStringEval = ExprEval.ofString(null);
+    final ExprEval<?> stringEval = ExprEval.ofString("wat");
     final ExprEval<?> longEval = ExprEval.of(1L);
     final ExprEval<?> doubleEval = ExprEval.of(1.0);
     final ExprEval<?> arrayEval = ExprEval.ofLongArray(new Long[]{1L, 2L, 3L});
