@@ -81,7 +81,7 @@ public class RestrictedDataSourceTest
   @Test
   public void test_isConcrete()
   {
-    Assert.assertTrue(restrictedFooDataSource.isConcrete());
+    Assert.assertTrue(restrictedFooDataSource.isProcessable());
   }
 
   @Test
@@ -104,14 +104,6 @@ public class RestrictedDataSourceTest
     Assert.assertEquals(newRestrictedDataSource.getBase(), barDataSource);
   }
 
-  @Test
-  public void test_withUpdatedDataSource()
-  {
-    RestrictedDataSource newRestrictedDataSource = (RestrictedDataSource) restrictedFooDataSource.withUpdatedDataSource(
-        new TableDataSource("bar"));
-    Assert.assertEquals(newRestrictedDataSource.getBase(), barDataSource);
-  }
-
   @Test
   public void test_equals()
   {
