@@ -54,6 +54,16 @@ public class UnionDataSourceTest
       )
   );
 
+  private final UnionDataSource tableAndInlineUniondataSource = new UnionDataSource(
+      ImmutableList.of(
+          new TableDataSource("foo"),
+          InlineDataSource.fromIterable(
+              Collections.emptyList(),
+              RowSignature.empty()
+          )
+      )
+  );
+
   @Test
   public void test_constructor_empty()
   {
@@ -75,6 +85,15 @@ public class UnionDataSourceTest
     Assert.assertFalse(UnionDataSource.isCompatibleDataSource(new NoopDataSource()));
   }
 
+  @Test
+  public void test_isTableBased()
+  {
+    Assert.assertTrue(unionDataSource.isTableBased());
+    Assert.assertTrue(unionDataSourceWithDuplicates.isTableBased());
+
+    Assert.assertFalse(tableAndInlineUniondataSource.isTableBased());
+  }
+
   @Test
   public void test_getTableNames()
   {
@@ -121,7 +140,7 @@ public class UnionDataSourceTest
   @Test
   public void test_isConcrete()
   {
-    Assert.assertTrue(unionDataSource.isConcrete());
+    Assert.assertTrue(unionDataSource.isProcessable());
   }
 
   @Test
