@@ -19,7 +19,7 @@
 
 package org.apache.druid.query.aggregation.constant;
 
-import org.apache.commons.lang.math.RandomUtils;
+import org.apache.commons.lang3.RandomUtils;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
@@ -57,7 +57,7 @@ public class LongConstantBufferAggregatorTest
   @Test
   public void testFloat()
   {
-    Assert.assertEquals((float) randomVal, aggregator.getFloat(byteBuffer, 0), 0.0001f);
+    Assert.assertEquals(randomVal, aggregator.getFloat(byteBuffer, 0), 0.0001f);
   }
 
   @Test
