@@ -200,7 +200,7 @@ public class GroupByLimitPushDownMultiNodeMergeTest extends InitializedNullHandl
     final File fileA = INDEX_MERGER_V9.persist(
         indexA,
         new File(tmpDir, "A"),
-        IndexSpec.DEFAULT,
+        IndexSpec.getDefault(),
         null
     );
     QueryableIndex qindexA = INDEX_IO.loadIndex(fileA);
@@ -236,7 +236,7 @@ public class GroupByLimitPushDownMultiNodeMergeTest extends InitializedNullHandl
     final File fileB = INDEX_MERGER_V9.persist(
         indexB,
         new File(tmpDir, "B"),
-        IndexSpec.DEFAULT,
+        IndexSpec.getDefault(),
         null
     );
     QueryableIndex qindexB = INDEX_IO.loadIndex(fileB);
@@ -271,7 +271,7 @@ public class GroupByLimitPushDownMultiNodeMergeTest extends InitializedNullHandl
     final File fileC = INDEX_MERGER_V9.persist(
         indexC,
         new File(tmpDir, "C"),
-        IndexSpec.DEFAULT,
+        IndexSpec.getDefault(),
         null
     );
     QueryableIndex qindexC = INDEX_IO.loadIndex(fileC);
@@ -307,7 +307,7 @@ public class GroupByLimitPushDownMultiNodeMergeTest extends InitializedNullHandl
     final File fileD = INDEX_MERGER_V9.persist(
         indexD,
         new File(tmpDir, "D"),
-        IndexSpec.DEFAULT,
+        IndexSpec.getDefault(),
         null
     );
     QueryableIndex qindexD = INDEX_IO.loadIndex(fileD);
@@ -422,7 +422,7 @@ public class GroupByLimitPushDownMultiNodeMergeTest extends InitializedNullHandl
     final File fileE = INDEX_MERGER_V9.persist(
         indexE,
         new File(tmpDir, "E"),
-        IndexSpec.DEFAULT,
+        IndexSpec.getDefault(),
         null
     );
     QueryableIndex qindexE = INDEX_IO.loadIndex(fileE);
@@ -517,7 +517,7 @@ public class GroupByLimitPushDownMultiNodeMergeTest extends InitializedNullHandl
     final File fileF = INDEX_MERGER_V9.persist(
         indexF,
         new File(tmpDir, "F"),
-        IndexSpec.DEFAULT,
+        IndexSpec.getDefault(),
         null
     );
     QueryableIndex qindexF = INDEX_IO.loadIndex(fileF);
