@@ -61,7 +61,7 @@ public class AutoTypeColumnIndexerTest extends InitializedNullHandlingTest
   @Test
   public void testKeySizeEstimation()
   {
-    AutoTypeColumnIndexer indexer = new AutoTypeColumnIndexer("test", null);
+    AutoTypeColumnIndexer indexer = new AutoTypeColumnIndexer("test", null, null);
     Assert.assertEquals(DimensionDictionarySelector.CARDINALITY_UNKNOWN, indexer.getCardinality());
     int baseCardinality = 0;
     Assert.assertEquals(baseCardinality, indexer.globalDictionary.getCardinality());
@@ -442,7 +442,7 @@ public class AutoTypeColumnIndexerTest extends InitializedNullHandlingTest
                                   .withTimestampSpec(new TimestampSpec(TIME_COL, "millis", null))
                                   .withDimensionsSpec(
                                       DimensionsSpec.builder()
-                                                    .setDimensions(ImmutableList.of(new AutoTypeColumnSchema(NESTED_COL, ColumnType.STRING)))
+                                                    .setDimensions(ImmutableList.of(new AutoTypeColumnSchema(NESTED_COL, ColumnType.STRING, null)))
                                                     .useSchemaDiscovery(true)
                                                     .build()
                                   )
@@ -495,7 +495,7 @@ public class AutoTypeColumnIndexerTest extends InitializedNullHandlingTest
   public void testConstantNull()
   {
     int baseCardinality = 0;
-    AutoTypeColumnIndexer indexer = new AutoTypeColumnIndexer("test", null);
+    AutoTypeColumnIndexer indexer = new AutoTypeColumnIndexer("test", null, null);
     EncodedKeyComponent<StructuredData> key;
 
     key = indexer.processRowValsToUnsortedEncodedKeyComponent(null, true);
@@ -520,7 +520,7 @@ public class AutoTypeColumnIndexerTest extends InitializedNullHandlingTest
   public void testConstantString()
   {
     int baseCardinality = 0;
-    AutoTypeColumnIndexer indexer = new AutoTypeColumnIndexer("test", null);
+    AutoTypeColumnIndexer indexer = new AutoTypeColumnIndexer("test", null, null);
     EncodedKeyComponent<StructuredData> key;
 
     key = indexer.processRowValsToUnsortedEncodedKeyComponent("abcd", true);
@@ -544,7 +544,7 @@ public class AutoTypeColumnIndexerTest extends InitializedNullHandlingTest
   public void testConstantLong()
   {
     int baseCardinality = 0;
-    AutoTypeColumnIndexer indexer = new AutoTypeColumnIndexer("test", null);
+    AutoTypeColumnIndexer indexer = new AutoTypeColumnIndexer("test", null, null);
     EncodedKeyComponent<StructuredData> key;
 
     key = indexer.processRowValsToUnsortedEncodedKeyComponent(1234L, true);
@@ -568,7 +568,7 @@ public class AutoTypeColumnIndexerTest extends InitializedNullHandlingTest
   public void testConstantEmptyArray()
   {
     int baseCardinality = 0;
-    AutoTypeColumnIndexer indexer = new AutoTypeColumnIndexer("test", null);
+    AutoTypeColumnIndexer indexer = new AutoTypeColumnIndexer("test", null, null);
     EncodedKeyComponent<StructuredData> key;
 
     key = indexer.processRowValsToUnsortedEncodedKeyComponent(ImmutableList.of(), true);
@@ -592,7 +592,7 @@ public class AutoTypeColumnIndexerTest extends InitializedNullHandlingTest
   public void testConstantArray()
   {
     int baseCardinality = 0;
-    AutoTypeColumnIndexer indexer = new AutoTypeColumnIndexer("test", null);
+    AutoTypeColumnIndexer indexer = new AutoTypeColumnIndexer("test", null, null);
     EncodedKeyComponent<StructuredData> key;
 
     key = indexer.processRowValsToUnsortedEncodedKeyComponent(ImmutableList.of(1L, 2L, 3L), true);
@@ -616,7 +616,7 @@ public class AutoTypeColumnIndexerTest extends InitializedNullHandlingTest
   public void testConstantEmptyObject()
   {
     int baseCardinality = 0;
-    AutoTypeColumnIndexer indexer = new AutoTypeColumnIndexer("test", null);
+    AutoTypeColumnIndexer indexer = new AutoTypeColumnIndexer("test", null, null);
     EncodedKeyComponent<StructuredData> key;
 
     key = indexer.processRowValsToUnsortedEncodedKeyComponent(ImmutableMap.of(), true);
