@@ -65,7 +65,7 @@ public class IndexMergerRollupTest extends InitializedNullHandlingTest
     indexMerger = TestHelper
         .getTestIndexMergerV9(OffHeapMemorySegmentWriteOutMediumFactory.instance());
     indexIO = TestHelper.getTestIndexIO();
-    indexSpec = IndexSpec.DEFAULT;
+    indexSpec = IndexSpec.getDefault();
   }
 
   private void testFirstLastRollup(
