@@ -25,6 +25,7 @@ import org.apache.druid.jackson.DefaultObjectMapper;
 import org.apache.druid.java.util.common.io.smoosh.SmooshedFileMapper;
 import org.apache.druid.math.expr.ExprMacroTable;
 import org.apache.druid.segment.IndexIO.V9IndexLoader;
+import org.apache.druid.segment.column.BaseColumnHolder;
 import org.apache.druid.segment.column.ColumnConfig;
 import org.apache.druid.segment.column.ColumnHolder;
 import org.apache.druid.testing.InitializedNullHandlingTest;
@@ -125,7 +126,7 @@ public class V9IndexLoaderTest extends InitializedNullHandlingTest
     }
 
     @Override
-    ColumnHolder deserializeColumn(
+    BaseColumnHolder deserializeColumn(
         String columnName,
         ObjectMapper mapper,
         ByteBuffer byteBuffer,
