@@ -20,6 +20,7 @@
 package org.apache.druid.segment.data;
 
 import com.google.common.base.Function;
+import com.google.common.base.Supplier;
 import com.google.common.collect.Iterables;
 import com.google.common.collect.Sets;
 import it.unimi.dsi.fastutil.ints.IntArrayList;
@@ -35,6 +36,8 @@ import org.apache.druid.segment.writeout.SegmentWriteOutMedium;
 import org.apache.druid.segment.writeout.TmpFileSegmentWriteOutMediumFactory;
 import org.apache.druid.segment.writeout.WriteOutBytes;
 import org.apache.druid.utils.CloseableUtils;
+import org.hamcrest.MatcherAssert;
+import org.hamcrest.Matchers;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
@@ -150,6 +153,60 @@ public class CompressedColumnarIntsSerializerTest
     }
   }
 
+  @Test
+  public void testLargeColumn() throws IOException
+  {
+    final File columnDir = temporaryFolder.newFolder();
+    final String columnName = "column";
+    final long numRows = 500_000; // enough values that we expect to switch into large-column mode
+
+    try (
+        SegmentWriteOutMedium segmentWriteOutMedium =
+            TmpFileSegmentWriteOutMediumFactory.instance().makeSegmentWriteOutMedium(temporaryFolder.newFolder());
+        FileSmoosher smoosher = new FileSmoosher(columnDir)
+    ) {
+      final Random random = new Random(0);
+      final int fileSizeLimit = 128_000; // limit to 128KB so we switch to large-column mode sooner
+      final CompressedColumnarIntsSerializer serializer = new CompressedColumnarIntsSerializer(
+          columnName,
+          segmentWriteOutMedium,
+          columnName,
+          CompressedColumnarIntsSupplier.MAX_INTS_IN_BUFFER,
+          byteOrder,
+          compressionStrategy,
+          fileSizeLimit,
+          segmentWriteOutMedium.getCloser()
+      );
+      serializer.open();
+
+      for (int i = 0; i < numRows; i++) {
+        serializer.addValue(random.nextInt() ^ Integer.MIN_VALUE);
+      }
+
+      try (SmooshedWriter primaryWriter = smoosher.addWithSmooshedWriter(columnName, serializer.getSerializedSize())) {
+        serializer.writeTo(primaryWriter, smoosher);
+      }
+    }
+
+    try (SmooshedFileMapper smooshMapper = SmooshedFileMapper.load(columnDir)) {
+      MatcherAssert.assertThat(
+          "Number of value parts written", // ensure the column actually ended up multi-part
+          smooshMapper.getInternalFilenames().stream().filter(s -> s.startsWith("column_value_")).count(),
+          Matchers.greaterThan(1L)
+      );
+
+      final Supplier<ColumnarInts> columnSupplier = CompressedColumnarIntsSupplier.fromByteBuffer(
+          smooshMapper.mapFile(columnName),
+          byteOrder,
+          smooshMapper
+      );
+
+      try (final ColumnarInts column = columnSupplier.get()) {
+        Assert.assertEquals(numRows, column.size());
+      }
+    }
+  }
+
   // this test takes ~30 minutes to run
   @Ignore
   @Test
@@ -168,6 +225,7 @@ public class CompressedColumnarIntsSerializerTest
           CompressedColumnarIntsSupplier.MAX_INTS_IN_BUFFER,
           byteOrder,
           compressionStrategy,
+          GenericIndexedWriter.MAX_FILE_SIZE,
           segmentWriteOutMedium.getCloser()
       );
       serializer.open();
@@ -198,6 +256,7 @@ public class CompressedColumnarIntsSerializerTest
         chunkFactor,
         byteOrder,
         compressionStrategy,
+        GenericIndexedWriter.MAX_FILE_SIZE,
         segmentWriteOutMedium.getCloser()
     );
     CompressedColumnarIntsSupplier supplierFromList = CompressedColumnarIntsSupplier.fromList(
@@ -221,7 +280,8 @@ public class CompressedColumnarIntsSerializerTest
     // read from ByteBuffer and check values
     CompressedColumnarIntsSupplier supplierFromByteBuffer = CompressedColumnarIntsSupplier.fromByteBuffer(
         ByteBuffer.wrap(IOUtils.toByteArray(writeOutBytes.asInputStream())),
-        byteOrder
+        byteOrder,
+        null
     );
     ColumnarInts columnarInts = supplierFromByteBuffer.get();
     Assert.assertEquals(vals.length, columnarInts.size());
@@ -247,6 +307,7 @@ public class CompressedColumnarIntsSerializerTest
             "test",
             compressionStrategy,
             Long.BYTES * 10000,
+            GenericIndexedWriter.MAX_FILE_SIZE,
             segmentWriteOutMedium.getCloser()
         ),
         segmentWriteOutMedium.getCloser()
@@ -264,7 +325,8 @@ public class CompressedColumnarIntsSerializerTest
     // read from ByteBuffer and check values
     CompressedColumnarIntsSupplier supplierFromByteBuffer = CompressedColumnarIntsSupplier.fromByteBuffer(
         mapper.mapFile("test"),
-        byteOrder
+        byteOrder,
+        null
     );
     ColumnarInts columnarInts = supplierFromByteBuffer.get();
     Assert.assertEquals(vals.length, columnarInts.size());
