@@ -32,7 +32,7 @@ import org.apache.druid.segment.CursorHolder;
 import org.apache.druid.segment.QueryableIndex;
 import org.apache.druid.segment.QueryableIndexCursorFactory;
 import org.apache.druid.segment.QueryableIndexSegment;
-import org.apache.druid.segment.ReferenceCountingSegment;
+import org.apache.druid.segment.ReferenceCountedSegmentProvider;
 import org.apache.druid.segment.VirtualColumns;
 import org.apache.druid.segment.column.ColumnCapabilities;
 import org.apache.druid.segment.column.RowSignature;
@@ -40,9 +40,11 @@ import org.apache.druid.segment.join.filter.JoinFilterPreAnalysis;
 import org.apache.druid.timeline.SegmentId;
 import org.junit.Test;
 
+import javax.annotation.Nonnull;
 import javax.annotation.Nullable;
 import java.io.IOException;
 import java.util.List;
+import java.util.Objects;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
 
@@ -173,10 +175,14 @@ public class PostJoinCursorTest extends BaseHashJoinSegmentCursorFactoryTest
       cursorFactory = new InfiniteCursorFactory(new QueryableIndexCursorFactory(index), countDownLatch);
     }
 
+    @Nullable
     @Override
-    public CursorFactory asCursorFactory()
+    public <T> T as(@Nonnull Class<T> clazz)
     {
-      return cursorFactory;
+      if (CursorFactory.class.equals(clazz)) {
+        return (T) cursorFactory;
+      }
+      return super.as(clazz);
     }
   }
 
@@ -259,13 +265,15 @@ public class PostJoinCursorTest extends BaseHashJoinSegmentCursorFactoryTest
     );
 
     HashJoinSegment hashJoinSegment = new HashJoinSegment(
-        ReferenceCountingSegment.wrapRootGenerationSegment(infiniteFactSegment),
+        ReferenceCountedSegmentProvider.unmanaged(infiniteFactSegment).orElseThrow(),
         null,
         joinableClauses,
-        joinFilterPreAnalysis
+        joinFilterPreAnalysis,
+        () -> {}
     );
 
-    try (final CursorHolder cursorHolder = hashJoinSegment.asCursorFactory().makeCursorHolder(CursorBuildSpec.FULL_SCAN)) {
+    try (final CursorHolder cursorHolder = Objects.requireNonNull(hashJoinSegment.as(CursorFactory.class))
+                                                  .makeCursorHolder(CursorBuildSpec.FULL_SCAN)) {
       Cursor cursor = cursorHolder.asCursor();
 
       ((PostJoinCursor) cursor).setValueMatcher(new ValueMatcher()
