@@ -406,6 +406,29 @@ public class DimensionRangeShardSpecTest
         // EffectiveDomain[:3].size > 1 -> ACCEPT
     );
     assertTrue(shard.possibleInDomain(domain));
+
+    // {Earth} * {France} * {Paris}
+    // Tests that we accept the ending point of the range
+    populateDomain(
+        domain,
+        getRangeSet(Range.singleton("Earth")),
+        getRangeSet(Range.singleton("France")),
+        getRangeSet(Range.singleton("Paris"))
+    );
+    assertTrue(shard.possibleInDomain(domain));
+
+    // {Earth} * {USA} * {New York}
+    // Tests that we accept the ending point of the range
+    // This is important because shard specs generated by MSQ with "boosting" do not include the __boost column,
+    // which means that a data point matching the end of a range may be in this segment or may be in the next
+    // segment (so we do need to check both).
+    populateDomain(
+        domain,
+        getRangeSet(Range.singleton("Earth")),
+        getRangeSet(Range.singleton("USA")),
+        getRangeSet(Range.singleton("New York"))
+    );
+    assertTrue(shard.possibleInDomain(domain));
   }
 
   @Test
