@@ -47,9 +47,9 @@ import org.apache.druid.query.QueryContext;
 import org.apache.druid.query.QueryMetrics;
 import org.apache.druid.query.QueryPlus;
 import org.apache.druid.query.QueryRunner;
+import org.apache.druid.query.QueryRunnerFactoryConglomerate;
 import org.apache.druid.query.QueryTimeoutException;
 import org.apache.druid.query.QueryToolChest;
-import org.apache.druid.query.QueryToolChestWarehouse;
 import org.apache.druid.query.QueryWatcher;
 import org.apache.druid.query.ResourceLimitExceededException;
 import org.apache.druid.query.aggregation.MetricManipulatorFns;
@@ -93,7 +93,7 @@ public class DirectDruidClient<T> implements QueryRunner<T>
   private static final Logger log = new Logger(DirectDruidClient.class);
   private static final int VAL_TO_REDUCE_REMAINING_RESPONSES = -1;
 
-  private final QueryToolChestWarehouse warehouse;
+  private final QueryRunnerFactoryConglomerate conglomerate;
   private final QueryWatcher queryWatcher;
   private final ObjectMapper objectMapper;
   private final HttpClient httpClient;
@@ -122,7 +122,7 @@ public class DirectDruidClient<T> implements QueryRunner<T>
   }
 
   public DirectDruidClient(
-      QueryToolChestWarehouse warehouse,
+      QueryRunnerFactoryConglomerate conglomerate,
       QueryWatcher queryWatcher,
       ObjectMapper objectMapper,
       HttpClient httpClient,
@@ -132,7 +132,7 @@ public class DirectDruidClient<T> implements QueryRunner<T>
       ScheduledExecutorService queryCancellationExecutor
   )
   {
-    this.warehouse = warehouse;
+    this.conglomerate = conglomerate;
     this.queryWatcher = queryWatcher;
     this.objectMapper = objectMapper;
     this.httpClient = httpClient;
@@ -154,7 +154,7 @@ public class DirectDruidClient<T> implements QueryRunner<T>
   public Sequence<T> run(final QueryPlus<T> queryPlus, final ResponseContext context)
   {
     final Query<T> query = queryPlus.getQuery();
-    QueryToolChest<T, Query<T>> toolChest = warehouse.getToolChest(query);
+    QueryToolChest<T, Query<T>> toolChest = conglomerate.getToolChest(query);
     boolean isBySegment = query.context().isBySegment();
     final JavaType queryResultType = isBySegment ? toolChest.getBySegmentResultType() : toolChest.getBaseResultType();
 
@@ -174,7 +174,7 @@ public class DirectDruidClient<T> implements QueryRunner<T>
       final long maxQueuedBytes = queryContext.getMaxQueuedBytes(0);
       final boolean usingBackpressure = maxQueuedBytes > 0;
 
-      final HttpResponseHandler<InputStream, InputStream> responseHandler = new HttpResponseHandler<InputStream, InputStream>()
+      final HttpResponseHandler<InputStream, InputStream> responseHandler = new HttpResponseHandler<>()
       {
         private final AtomicLong totalByteCount = new AtomicLong(0);
         private final AtomicLong queuedByteCount = new AtomicLong(0);
@@ -276,7 +276,7 @@ public class DirectDruidClient<T> implements QueryRunner<T>
           totalByteCount.addAndGet(response.getContent().readableBytes());
           return ClientResponse.finished(
               new SequenceInputStream(
-                  new Enumeration<InputStream>()
+                  new Enumeration<>()
                   {
                     @Override
                     public boolean hasMoreElements()
@@ -480,7 +480,7 @@ public class DirectDruidClient<T> implements QueryRunner<T>
       queryWatcher.registerQueryFuture(query, future);
       Futures.addCallback(
           future,
-          new FutureCallback<InputStream>()
+          new FutureCallback<>()
           {
             @Override
             public void onSuccess(InputStream result)
@@ -511,7 +511,7 @@ public class DirectDruidClient<T> implements QueryRunner<T>
           @Override
           public JsonParserIterator<T> make()
           {
-            return new JsonParserIterator<T>(
+            return new JsonParserIterator<>(
                 queryResultType,
                 future,
                 url,
