@@ -20,11 +20,10 @@
 package org.apache.druid.client;
 
 import org.apache.druid.client.selector.ServerSelector;
-import org.apache.druid.query.DataSource;
+import org.apache.druid.query.CloneQueryMode;
 import org.apache.druid.query.LocatedSegmentDescriptor;
 import org.apache.druid.query.SegmentDescriptor;
 import org.apache.druid.query.TableDataSource;
-import org.apache.druid.query.planning.DataSourceAnalysis;
 import org.apache.druid.server.coordination.DruidServerMetadata;
 import org.apache.druid.timeline.TimelineLookup;
 import org.apache.druid.timeline.TimelineObjectHolder;
@@ -44,21 +43,22 @@ public class ServerViewUtil
       TimelineServerView serverView,
       String datasource,
       List<Interval> intervals,
-      int numCandidates
+      int numCandidates,
+      CloneQueryMode cloneQueryMode
   )
   {
-    return getTargetLocations(serverView, new TableDataSource(datasource), intervals, numCandidates);
+    return getTargetLocations(serverView, new TableDataSource(datasource), intervals, numCandidates, cloneQueryMode);
   }
 
   public static List<LocatedSegmentDescriptor> getTargetLocations(
       TimelineServerView serverView,
-      DataSource datasource,
+      TableDataSource datasource,
       List<Interval> intervals,
-      int numCandidates
+      int numCandidates,
+      CloneQueryMode cloneQueryMode
   )
   {
-    final DataSourceAnalysis analysis = datasource.getAnalysis();
-    final Optional<? extends TimelineLookup<String, ServerSelector>> maybeTimeline = serverView.getTimeline(analysis.getBaseTableDataSource());
+    final Optional<? extends TimelineLookup<String, ServerSelector>> maybeTimeline = serverView.getTimeline(datasource);
     if (!maybeTimeline.isPresent()) {
       return Collections.emptyList();
     }
@@ -71,7 +71,7 @@ public class ServerViewUtil
               holder.getInterval(), holder.getVersion(), chunk.getChunkNumber()
           );
           long size = selector.getSegment().getSize();
-          List<DruidServerMetadata> candidates = selector.getCandidates(numCandidates);
+          List<DruidServerMetadata> candidates = selector.getCandidates(numCandidates, cloneQueryMode);
           located.add(new LocatedSegmentDescriptor(descriptor, size, candidates));
         }
       }
