@@ -46,6 +46,8 @@ import org.apache.druid.query.timeseries.TimeseriesQuery;
 import org.apache.druid.query.timeseries.TimeseriesQueryRunnerFactory;
 import org.apache.druid.query.topn.TopNQuery;
 import org.apache.druid.query.topn.TopNQueryRunnerFactory;
+import org.apache.druid.query.union.UnionQuery;
+import org.apache.druid.query.union.UnionQueryLogic;
 import org.apache.druid.server.QueryScheduler;
 import org.apache.druid.server.QuerySchedulerProvider;
 
@@ -87,6 +89,9 @@ public class QueryRunnerFactoryModule extends QueryToolChestModule
       queryFactoryBinder.addBinding(entry.getKey()).to(entry.getValue());
       binder.bind(entry.getValue()).in(LazySingleton.class);
     }
+
+    DruidBinders.queryBinder(binder)
+        .bindQueryLogic(UnionQuery.class, UnionQueryLogic.class);
   }
 
   @LazySingleton
