@@ -48,7 +48,7 @@ public class DruidHttpClientConfig
 
   @JsonProperty
   @Min(1)
-  private int numMaxThreads = Math.max(10, (JvmUtils.getRuntimeInfo().getAvailableProcessors() * 17) / 16 + 2) + 30;
+  private int numMaxThreads = JvmUtils.getRuntimeInfo().getAvailableProcessors() * 3 / 2 + 1;
 
   @JsonProperty
   @Min(1)
