@@ -20,6 +20,8 @@
 package org.apache.druid.metadata;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
+import com.google.common.base.Preconditions;
+import com.google.common.base.Strings;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableSet;
 import com.google.common.collect.Iterators;
@@ -27,18 +29,25 @@ import com.google.common.collect.Lists;
 import com.google.common.collect.UnmodifiableIterator;
 import org.apache.druid.common.utils.IdUtils;
 import org.apache.druid.error.DruidException;
+import org.apache.druid.error.InternalServerError;
+import org.apache.druid.error.InvalidInput;
 import org.apache.druid.java.util.common.CloseableIterators;
 import org.apache.druid.java.util.common.DateTimes;
 import org.apache.druid.java.util.common.IAE;
 import org.apache.druid.java.util.common.Intervals;
+import org.apache.druid.java.util.common.JodaUtils;
 import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.java.util.common.jackson.JacksonUtils;
 import org.apache.druid.java.util.common.logger.Logger;
 import org.apache.druid.java.util.common.parsers.CloseableIterator;
+import org.apache.druid.metadata.segment.cache.SegmentSchemaRecord;
+import org.apache.druid.segment.SchemaPayload;
+import org.apache.druid.segment.metadata.CentralizedDatasourceSchemaConfig;
 import org.apache.druid.segment.realtime.appenderator.SegmentIdWithShardSpec;
 import org.apache.druid.server.http.DataSegmentPlus;
 import org.apache.druid.timeline.DataSegment;
 import org.apache.druid.timeline.SegmentId;
+import org.apache.druid.timeline.SegmentTimeline;
 import org.apache.druid.utils.CloseableUtils;
 import org.joda.time.DateTime;
 import org.joda.time.Interval;
@@ -52,6 +61,7 @@ import org.skife.jdbi.v2.util.StringMapper;
 
 import javax.annotation.Nullable;
 import java.io.IOException;
+import java.sql.ResultSet;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
@@ -60,12 +70,13 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.NoSuchElementException;
+import java.util.Objects;
 import java.util.Set;
 import java.util.stream.Collectors;
 
 /**
- * An object that helps {@link SqlSegmentsMetadataManager} and {@link IndexerSQLMetadataStorageCoordinator} make
- * queries to the metadata store segments table. Each instance of this class is scoped to a single handle and is meant
+ * An object that is used to query the segments table in the metadata store.
+ * Each instance of this class is scoped to a single {@link Handle} and is meant
  * to be short-lived.
  */
 public class SqlSegmentsMetadataQuery
@@ -111,16 +122,25 @@ public class SqlSegmentsMetadataQuery
     return new SqlSegmentsMetadataQuery(handle, connector, dbTables, jsonMapper);
   }
 
+  /**
+   * Create a DateTime object from a string. If the string is null or empty, return null.
+   */
+  @Nullable
+  public static DateTime nullAndEmptySafeDate(String date)
+  {
+    return Strings.isNullOrEmpty(date) ? null : DateTimes.of(date);
+  }
+
   /**
    * Retrieves segments for a given datasource that are marked used (i.e. published) in the metadata store, and that
    * *overlap* any interval in a particular collection of intervals. If the collection of intervals is empty, this
    * method will retrieve all used segments.
-   *
+   * <p>
    * You cannot assume that segments returned by this call are actually active. Because there is some delay between
    * new segment publishing and the marking-unused of older segments, it is possible that some segments returned
    * by this call are overshadowed by other segments. To check for this, use
-   * {@link org.apache.druid.timeline.SegmentTimeline#forSegments(Iterable)}.
-   *
+   * {@link SegmentTimeline#forSegments(Iterable)}.
+   * <p>
    * This call does not return any information about realtime segments.
    *
    * @return a closeable iterator. You should close it when you are done.
@@ -168,8 +188,9 @@ public class SqlSegmentsMetadataQuery
   }
 
   /**
-   * Determines the highest ID amongst unused segments for the given datasource,
-   * interval and version.
+   * Retrieves the ID of the unused segment that has the highest partition
+   * number amongst all unused segments that exactly match the given interval
+   * and version.
    *
    * @return null if no unused segment exists for the given parameters.
    */
@@ -229,6 +250,75 @@ public class SqlSegmentsMetadataQuery
     }
   }
 
+  /**
+   * Retrieves segments and their associated metadata for a given datasource that are marked unused and that are
+   * *fully contained by* an optionally specified interval. If the interval specified is null, this method will
+   * retrieve all unused segments.
+   *
+   * This call does not return any information about realtime segments.
+   *
+   * @param datasource      The name of the datasource
+   * @param interval        an optional interval to search over.
+   * @param limit           an optional maximum number of results to return. If none is specified, the results are
+   *                        not limited.
+   * @param lastSegmentId an optional last segment id from which to search for results. All segments returned are >
+   *                      this segment lexigraphically if sortOrder is null or  {@link SortOrder#ASC}, or < this
+   *                      segment lexigraphically if sortOrder is {@link SortOrder#DESC}. If none is specified, no
+   *                      such filter is used.
+   * @param sortOrder an optional order with which to return the matching segments by id, start time, end time. If
+   *                  none is specified, the order of the results is not guarenteed.
+
+   * Returns an iterable.
+   */
+  public List<DataSegmentPlus> iterateAllUnusedSegmentsForDatasource(
+      final String datasource,
+      @Nullable final Interval interval,
+      @Nullable final Integer limit,
+      @Nullable final String lastSegmentId,
+      @Nullable final SortOrder sortOrder
+  )
+  {
+    final List<Interval> intervals = interval == null ? Intervals.ONLY_ETERNITY : List.of(interval);
+    try (final CloseableIterator<DataSegmentPlus> iterator =
+             retrieveUnusedSegmentsPlus(datasource, intervals, null, limit, lastSegmentId, sortOrder, null)) {
+      return ImmutableList.copyOf(iterator);
+    }
+    catch (IOException e) {
+      throw new RuntimeException(e);
+    }
+  }
+
+  /**
+   * Retrieves unused segments that are fully contained within the given interval.
+   *
+   * @param interval       Returned segments must be fully contained within this
+   *                       interval
+   * @param versions       Optional list of segment versions. If passed as null,
+   *                       all segment versions are eligible.
+   * @param limit          Maximum number of segments to return. If passed as null,
+   *                       all segments are returned.
+   * @param maxUpdatedTime Returned segments must have a {@code used_status_last_updated}
+   *                       which is either null or earlier than this value.
+   */
+  public List<DataSegment> findUnusedSegments(
+      String dataSource,
+      Interval interval,
+      @Nullable List<String> versions,
+      @Nullable Integer limit,
+      @Nullable DateTime maxUpdatedTime
+  )
+  {
+    try (
+        final CloseableIterator<DataSegment> iterator =
+            retrieveUnusedSegments(dataSource, List.of(interval), versions, limit, null, null, maxUpdatedTime)
+    ) {
+      return ImmutableList.copyOf(iterator);
+    }
+    catch (IOException e) {
+      throw InternalServerError.exception(e, "Error while reading unused segments");
+    }
+  }
+
   /**
    * Retrieves segments for a given datasource that are marked unused and that are <b>fully contained by</b> any interval
    * in a particular collection of intervals. If the collection of intervals is empty, this method will retrieve all
@@ -513,7 +603,7 @@ public class SqlSegmentsMetadataQuery
                 return new DataSegmentPlus(
                     JacksonUtils.readValue(jsonMapper, r.getBytes(1), DataSegment.class),
                     null,
-                    DateTimes.of(r.getString(6)),
+                    nullAndEmptySafeDate(r.getString(6)),
                     r.getBoolean(2),
                     schemaFingerprint,
                     numRows,
@@ -540,7 +630,7 @@ public class SqlSegmentsMetadataQuery
               (index, r, ctx) -> new DataSegmentPlus(
                   JacksonUtils.readValue(jsonMapper, r.getBytes(1), DataSegment.class),
                   DateTimes.of(r.getString(5)),
-                  DateTimes.of(r.getString(4)),
+                  nullAndEmptySafeDate(r.getString(4)),
                   r.getBoolean(2),
                   null,
                   null,
@@ -554,15 +644,124 @@ public class SqlSegmentsMetadataQuery
   }
 
   /**
-   * Marks the provided segments as either used or unused.
+   * Retrieves all used schema fingerprints present in the metadata store.
+   */
+  public Set<String> retrieveAllUsedSegmentSchemaFingerprints()
+  {
+    final String sql = StringUtils.format(
+        "SELECT fingerprint FROM %s WHERE version = %s AND used = true",
+        dbTables.getSegmentSchemasTable(), CentralizedDatasourceSchemaConfig.SCHEMA_VERSION
+    );
+    return Set.copyOf(
+        handle.createQuery(sql)
+              .setFetchSize(connector.getStreamingFetchSize())
+              .mapTo(String.class)
+              .list()
+    );
+  }
+
+  /**
+   * Retrieves all used segment schemas present in the metadata store irrespective
+   * of their last updated time.
+   */
+  public List<SegmentSchemaRecord> retrieveAllUsedSegmentSchemas()
+  {
+    final String sql = StringUtils.format(
+        "SELECT fingerprint, payload FROM %s"
+        + " WHERE version = %s AND used = true",
+        dbTables.getSegmentSchemasTable(), CentralizedDatasourceSchemaConfig.SCHEMA_VERSION
+    );
+    return retrieveValidSchemaRecordsWithQuery(handle.createQuery(sql));
+  }
+
+  /**
+   * Retrieves segment schemas from the metadata store for the given fingerprints.
+   */
+  public List<SegmentSchemaRecord> retrieveUsedSegmentSchemasForFingerprints(
+      Set<String> schemaFingerprints
+  )
+  {
+    final List<List<String>> fingerprintBatches = Lists.partition(
+        List.copyOf(schemaFingerprints),
+        MAX_INTERVALS_PER_BATCH
+    );
+
+    final List<SegmentSchemaRecord> records = new ArrayList<>();
+    for (List<String> fingerprintBatch : fingerprintBatches) {
+      records.addAll(
+          retrieveBatchOfSegmentSchemas(fingerprintBatch)
+      );
+    }
+
+    return records;
+  }
+
+  /**
+   * Retrieves a batch of segment schema records for the given fingerprints.
+   */
+  private List<SegmentSchemaRecord> retrieveBatchOfSegmentSchemas(List<String> schemaFingerprints)
+  {
+    final String sql = StringUtils.format(
+        "SELECT fingerprint, payload FROM %s"
+        + " WHERE version = %s AND used = true"
+        + " %s",
+        dbTables.getSegmentSchemasTable(),
+        CentralizedDatasourceSchemaConfig.SCHEMA_VERSION,
+        getParameterizedInConditionForColumn("fingerprint", schemaFingerprints)
+    );
+
+    final Query<Map<String, Object>> query = handle.createQuery(sql);
+    bindColumnValuesToQueryWithInCondition("fingerprint", schemaFingerprints, query);
+
+    return retrieveValidSchemaRecordsWithQuery(query);
+  }
+
+  private List<SegmentSchemaRecord> retrieveValidSchemaRecordsWithQuery(
+      Query<Map<String, Object>> query
+  )
+  {
+    return query.setFetchSize(connector.getStreamingFetchSize())
+                .map((index, r, ctx) -> mapToSchemaRecord(r))
+                .list()
+                .stream()
+                .filter(Objects::nonNull)
+                .collect(Collectors.toList());
+  }
+
+  /**
+   * Marks the given segment IDs as used.
    *
-   * For better performance, please try to
-   * 1) ensure that the caller passes only used segments to this method when marking them as unused.
-   * 2) Similarly, please try to call this method only on unused segments when marking segments as used with this method.
+   * @param segmentIds Segment IDs to update. For better performance, ensure that
+   *                   these segment IDs are not already marked as used.
+   * @param updateTime Updated segments will have their used_status_last_updated
+   *                   column set to this value
+   * @return Number of segments updated in the metadata store.
+   */
+  public int markSegmentsAsUsed(Set<SegmentId> segmentIds, DateTime updateTime)
+  {
+    return markSegments(segmentIds, true, updateTime);
+  }
+
+  /**
+   * Marks the given segment IDs as unused.
+   *
+   * @param segmentIds Segment IDs to update. For better performance, ensure that
+   *                   these segment IDs are not already marked as unused.
+   * @param updateTime Updated segments will have their used_status_last_updated
+   *                   column set to this value
+   * @return Number of segments updated in the metadata store.
+   */
+  public int markSegmentsAsUnused(Set<SegmentId> segmentIds, DateTime updateTime)
+  {
+    return markSegments(segmentIds, false, updateTime);
+  }
+
+  /**
+   * Marks the given segments as either used or unused.
    *
    * @return the number of segments actually modified.
    */
-  public int markSegments(final Collection<SegmentId> segmentIds, final boolean used, DateTime updateTime)
+  private int markSegments(final Set<SegmentId> segmentIds, final boolean used, DateTime updateTime)
   {
     final String dataSource;
 
@@ -600,23 +799,8 @@ public class SqlSegmentsMetadataQuery
    *
    * @param interval   Only used segments fully contained within this interval
    *                   are eligible to be marked as unused
-   * @param updateTime Updated segments will have their used_status_last_updated
-   *                   column set to this value
-   * @return Number of segments updated.
-   */
-  public int markSegmentsUnused(final String dataSource, final Interval interval, final DateTime updateTime)
-  {
-    return markSegmentsUnused(dataSource, interval, null, updateTime);
-  }
-
-  /**
-   * Marks all used segments that are <b>fully contained by</b> a particular interval
-   * filtered by an optional list of versions as unused.
-   *
-   * @param interval   Only used segments fully contained within this interval
-   *                   are eligible to be marked as unused
-   * @param versions   List of eligible segment versions. If null, all versions
-   *                   are considered eligible to be marked as unused.
+   * @param versions   List of eligible segment versions. If null or empty, all
+   *                   versions are considered eligible to be marked as unused.
    * @param updateTime Updated segments will have their used_status_last_updated
    *                   column set to this value
    * @return Number of segments updated.
@@ -690,7 +874,7 @@ public class SqlSegmentsMetadataQuery
       return stmt.execute();
     } else {
       // Retrieve, then drop, since we can't write a WHERE clause directly.
-      final List<SegmentId> segments = ImmutableList.copyOf(
+      final Set<SegmentId> segments = ImmutableSet.copyOf(
           Iterators.transform(
               retrieveSegments(
                   dataSource,
@@ -710,6 +894,263 @@ public class SqlSegmentsMetadataQuery
     }
   }
 
+  public boolean markSegmentAsUsed(SegmentId segmentId, DateTime updateTime)
+  {
+    return markSegments(Set.of(segmentId), true, updateTime) > 0;
+  }
+
+  public int markAllNonOvershadowedSegmentsAsUsed(String dataSource, DateTime updateTime)
+  {
+    return markNonOvershadowedSegmentsAsUsedInternal(dataSource, null, null, updateTime);
+  }
+
+  public int markNonOvershadowedSegmentsAsUsed(
+      String dataSource,
+      Interval interval,
+      @Nullable List<String> versions,
+      DateTime updateTime
+  )
+  {
+    Preconditions.checkNotNull(interval);
+    return markNonOvershadowedSegmentsAsUsedInternal(dataSource, interval, versions, updateTime);
+  }
+
+  private int markNonOvershadowedSegmentsAsUsedInternal(
+      final String dataSourceName,
+      final @Nullable Interval interval,
+      final @Nullable List<String> versions,
+      DateTime updateTime
+  )
+  {
+    final List<DataSegment> unusedSegments = new ArrayList<>();
+    final SegmentTimeline timeline = new SegmentTimeline();
+
+    final List<Interval> intervals =
+        interval == null ? Intervals.ONLY_ETERNITY : Collections.singletonList(interval);
+
+    try (final CloseableIterator<DataSegment> iterator =
+             retrieveUsedSegments(dataSourceName, intervals, versions)) {
+      timeline.addSegments(iterator);
+    }
+    catch (IOException e) {
+      throw new RuntimeException(e);
+    }
+
+    try (final CloseableIterator<DataSegment> iterator =
+             retrieveUnusedSegments(dataSourceName, intervals, versions, null, null, null, null)) {
+      while (iterator.hasNext()) {
+        final DataSegment dataSegment = iterator.next();
+        timeline.add(dataSegment);
+        unusedSegments.add(dataSegment);
+      }
+    }
+    catch (IOException e) {
+      throw new RuntimeException(e);
+    }
+
+    return markNonOvershadowedSegmentsAsUsed(unusedSegments, timeline, updateTime);
+  }
+
+  private int markNonOvershadowedSegmentsAsUsed(
+      List<DataSegment> unusedSegments,
+      SegmentTimeline timeline,
+      DateTime updateTime
+  )
+  {
+    Set<SegmentId> nonOvershadowedSegments =
+        unusedSegments.stream()
+                      .filter(segment -> !timeline.isOvershadowed(segment))
+                      .map(DataSegment::getId)
+                      .collect(Collectors.toSet());
+
+    return markSegmentsAsUsed(nonOvershadowedSegments, updateTime);
+  }
+
+  public int markNonOvershadowedSegmentsAsUsed(
+      final String dataSource,
+      final Set<SegmentId> segmentIds,
+      final DateTime updateTime
+  )
+  {
+    final List<DataSegment> unusedSegments = retrieveUnusedSegments(dataSource, segmentIds);
+    final List<Interval> unusedSegmentsIntervals = JodaUtils.condenseIntervals(
+        unusedSegments.stream().map(DataSegment::getInterval).collect(Collectors.toList())
+    );
+
+    // Create a timeline with all used and unused segments in this interval
+    final SegmentTimeline timeline = SegmentTimeline.forSegments(unusedSegments);
+
+    try (CloseableIterator<DataSegment> usedSegmentsOverlappingUnusedSegmentsIntervals =
+             retrieveUsedSegments(dataSource, unusedSegmentsIntervals)) {
+      timeline.addSegments(usedSegmentsOverlappingUnusedSegmentsIntervals);
+    }
+    catch (IOException e) {
+      throw new RuntimeException(e);
+    }
+
+    return markNonOvershadowedSegmentsAsUsed(unusedSegments, timeline, updateTime);
+  }
+
+  private List<DataSegment> retrieveUnusedSegments(
+      final String dataSource,
+      final Set<SegmentId> segmentIds
+  )
+  {
+    final List<DataSegmentPlus> retrievedSegments = retrieveSegmentsById(dataSource, segmentIds);
+
+    final Set<SegmentId> unknownSegmentIds = new HashSet<>(segmentIds);
+    final List<DataSegment> unusedSegments = new ArrayList<>();
+    for (DataSegmentPlus entry : retrievedSegments) {
+      final DataSegment segment = entry.getDataSegment();
+      unknownSegmentIds.remove(segment.getId());
+      if (Boolean.FALSE.equals(entry.getUsed())) {
+        unusedSegments.add(segment);
+      }
+    }
+
+    if (!unknownSegmentIds.isEmpty()) {
+      throw InvalidInput.exception(
+          "Could not find segment IDs[%s] for datasource[%s]",
+          unknownSegmentIds, dataSource
+      );
+    }
+
+    return unusedSegments;
+  }
+
+  public List<Interval> retrieveUnusedSegmentIntervals(
+      final String dataSource,
+      @Nullable final DateTime minStartTime,
+      final DateTime maxEndTime,
+      final int limit,
+      final DateTime maxUsedStatusLastUpdatedTime
+  )
+  {
+    final boolean filterByStartTime = minStartTime != null;
+
+    // Handle cases where used_status_last_updated IS NULL for backward compatibility
+    final String sql = StringUtils.format(
+        "SELECT start, %2$send%2$s FROM %1$s"
+        + " WHERE dataSource = :dataSource AND used = false"
+        + " AND %2$send%2$s <= :end %3$s"
+        + " AND used_status_last_updated IS NOT NULL"
+        + " AND used_status_last_updated <= :used_status_last_updated"
+        + " ORDER BY start, %2$send%2$s",
+        dbTables.getSegmentsTable(),
+        connector.getQuoteString(),
+        filterByStartTime ? " AND start >= :start" : ""
+    );
+
+    Query<Map<String, Object>> query = handle
+        .createQuery(sql)
+        .setFetchSize(connector.getStreamingFetchSize())
+        .setMaxRows(limit)
+        .bind("dataSource", dataSource)
+        .bind("end", maxEndTime.toString())
+        .bind("used_status_last_updated", maxUsedStatusLastUpdatedTime.toString());
+
+    if (filterByStartTime) {
+      query.bind("start", minStartTime.toString());
+    }
+
+    List<Interval> unusedIntervals = query
+        .map((index, r, ctx) -> mapToInterval(r, dataSource))
+        .list();
+
+    return unusedIntervals.stream().filter(Objects::nonNull).collect(Collectors.toList());
+  }
+
+  /**
+   * Gets unused segment intervals for the specified datasource. There is no
+   * guarantee on the order of intervals in the list or on whether the limited
+   * list contains the earliest or latest intervals present in the datasource.
+   *
+   * @return List of unused segment intervals containing upto {@code limit} entries.
+   */
+  public List<Interval> retrieveUnusedSegmentIntervals(String dataSource, int limit)
+  {
+    final String sql = StringUtils.format(
+        "SELECT start, %2$send%2$s FROM %1$s"
+        + " WHERE dataSource = :dataSource AND used = false"
+        + " GROUP BY start, %2$send%2$s"
+        + "  %3$s",
+        dbTables.getSegmentsTable(), connector.getQuoteString(), connector.limitClause(limit)
+    );
+
+    final List<Interval> intervals = connector.inReadOnlyTransaction(
+        (handle, status) ->
+            handle.createQuery(sql)
+                  .setFetchSize(connector.getStreamingFetchSize())
+                  .bind("dataSource", dataSource)
+                  .map((index, r, ctx) -> mapToInterval(r, dataSource))
+                  .list()
+    );
+
+    return intervals.stream().filter(Objects::nonNull).collect(Collectors.toList());
+  }
+
+  /**
+   * Retrieves unused segments that exactly match the given interval.
+   *
+   * @param interval       Returned segments must exactly match this interval.
+   * @param maxUpdatedTime Returned segments must have a {@code used_status_last_updated}
+   *                       which is either null or earlier than this value.
+   * @param limit          Maximum number of segments to return
+   */
+  public List<DataSegment> retrieveUnusedSegmentsWithExactInterval(
+      String dataSource,
+      Interval interval,
+      DateTime maxUpdatedTime,
+      int limit
+  )
+  {
+    final String sql = StringUtils.format(
+        "SELECT id, payload FROM %1$s"
+        + " WHERE dataSource = :dataSource AND used = false"
+        + " AND %2$send%2$s = :end AND start = :start"
+        + " AND (used_status_last_updated IS NULL OR used_status_last_updated <= :maxUpdatedTime)"
+        + "  %3$s",
+        dbTables.getSegmentsTable(), connector.getQuoteString(), connector.limitClause(limit)
+    );
+
+    final List<DataSegment> segments = connector.inReadOnlyTransaction(
+        (handle, status) ->
+            handle.createQuery(sql)
+                  .setFetchSize(connector.getStreamingFetchSize())
+                  .bind("dataSource", dataSource)
+                  .bind("start", interval.getStart().toString())
+                  .bind("end", interval.getEnd().toString())
+                  .bind("maxUpdatedTime", maxUpdatedTime.toString())
+                  .map((index, r, ctx) -> mapToSegment(r))
+                  .list()
+    );
+
+    return segments.stream().filter(Objects::nonNull).collect(Collectors.toList());
+  }
+
+  /**
+   * Retrieves the versions of unused segments which are perfectly aligned with
+   * the given interval.
+   */
+  public Set<String> retrieveUnusedSegmentVersionsWithInterval(String dataSource, Interval interval)
+  {
+    final String sql = StringUtils.format(
+        "SELECT DISTINCT(version) FROM %1$s"
+        + " WHERE dataSource = :dataSource AND used = false"
+        + " AND %2$send%2$s = :end AND start = :start",
+        dbTables.getSegmentsTable(),
+        connector.getQuoteString()
+    );
+    return Set.copyOf(
+        handle.createQuery(sql)
+              .bind("dataSource", dataSource)
+              .bind("start", interval.getStart().toString())
+              .bind("end", interval.getEnd().toString())
+              .mapTo(String.class)
+              .list()
+    );
+  }
+
   /**
    * Retrieve the used segment for a given id if it exists in the metadata store and null otherwise
    */
@@ -1223,6 +1664,43 @@ public class SqlSegmentsMetadataQuery
     return sql;
   }
 
+  @Nullable
+  private Interval mapToInterval(ResultSet resultSet, String dataSource)
+  {
+    try {
+      return new Interval(
+          DateTimes.of(resultSet.getString("start")),
+          DateTimes.of(resultSet.getString("end"))
+      );
+    }
+    catch (Throwable t) {
+      log.error(t, "Could not read an interval of datasource[%s]", dataSource);
+      return null;
+    }
+  }
+
+  /**
+   * Tries to parse the fields of the result set into a {@link SegmentSchemaRecord}.
+   *
+   * @return null if an error occurred while parsing the result
+   */
+  @Nullable
+  private SegmentSchemaRecord mapToSchemaRecord(ResultSet resultSet)
+  {
+    String fingerprint = null;
+    try {
+      fingerprint = resultSet.getString("fingerprint");
+      return new SegmentSchemaRecord(
+          fingerprint,
+          jsonMapper.readValue(resultSet.getBytes("payload"), SchemaPayload.class)
+      );
+    }
+    catch (Throwable t) {
+      log.error(t, "Could not read segment schema with fingerprint[%s]", fingerprint);
+      return null;
+    }
+  }
+
   private ResultIterator<DataSegment> getDataSegmentResultIterator(Query<Map<String, Object>> sql)
   {
     return sql.map((index, r, ctx) -> JacksonUtils.readValue(jsonMapper, r.getBytes(2), DataSegment.class))
@@ -1240,7 +1718,7 @@ public class SqlSegmentsMetadataQuery
         return new DataSegmentPlus(
             JacksonUtils.readValue(jsonMapper, r.getBytes(2), DataSegment.class),
             DateTimes.of(r.getString(3)),
-            DateTimes.of(r.getString(4)),
+            nullAndEmptySafeDate(r.getString(4)),
             used,
             null,
             null,
@@ -1254,6 +1732,20 @@ public class SqlSegmentsMetadataQuery
     }).iterator();
   }
 
+  @Nullable
+  private DataSegment mapToSegment(ResultSet resultSet)
+  {
+    String segmentId = "";
+    try {
+      segmentId = resultSet.getString("id");
+      return JacksonUtils.readValue(jsonMapper, resultSet.getBytes("payload"), DataSegment.class);
+    }
+    catch (Throwable t) {
+      log.error(t, "Could not read segment with ID[%s]", segmentId);
+      return null;
+    }
+  }
+
   private UnmodifiableIterator<DataSegment> filterDataSegmentIteratorByInterval(
       ResultIterator<DataSegment> resultIterator,
       final Collection<Interval> intervals,
