@@ -62,13 +62,12 @@ import org.apache.druid.segment.IndexIO;
 import org.apache.druid.segment.IndexMerger;
 import org.apache.druid.segment.QueryableIndex;
 import org.apache.druid.segment.QueryableIndexSegment;
-import org.apache.druid.segment.ReferenceCountingSegment;
 import org.apache.druid.segment.SchemaPayload;
 import org.apache.druid.segment.SchemaPayloadPlus;
+import org.apache.druid.segment.Segment;
 import org.apache.druid.segment.SegmentSchemaMapping;
 import org.apache.druid.segment.column.RowSignature;
 import org.apache.druid.segment.incremental.IncrementalIndexAddResult;
-import org.apache.druid.segment.incremental.IndexSizeExceededException;
 import org.apache.druid.segment.incremental.ParseExceptionHandler;
 import org.apache.druid.segment.incremental.RowIngestionMeters;
 import org.apache.druid.segment.indexing.DataSchema;
@@ -85,7 +84,6 @@ import org.apache.druid.timeline.SegmentId;
 import org.joda.time.Interval;
 
 import javax.annotation.Nullable;
-import java.io.Closeable;
 import java.io.File;
 import java.io.IOException;
 import java.nio.channels.FileChannel;
@@ -152,7 +150,6 @@ public class StreamAppenderator implements Appenderator
   private final Set<SegmentIdWithShardSpec> droppingSinks = Sets.newConcurrentHashSet();
   private final long maxBytesTuningConfig;
   private final boolean skipBytesInMemoryOverheadCheck;
-  private final boolean useMaxMemoryEstimates;
 
   private final QuerySegmentWalker texasRanger;
   // This variable updated in add(), persist(), and drop()
@@ -205,13 +202,14 @@ public class StreamAppenderator implements Appenderator
   private final SegmentLoaderConfig segmentLoaderConfig;
   private ScheduledExecutorService exec;
   private final FingerprintGenerator fingerprintGenerator;
+  private final TaskIntervalUnlocker taskIntervalUnlocker;
 
   /**
    * This constructor allows the caller to provide its own SinkQuerySegmentWalker.
-   *
+   * <p>
    * The sinkTimeline is set to the sink timeline of the provided SinkQuerySegmentWalker.
    * If the SinkQuerySegmentWalker is null, a new sink timeline is initialized.
-   *
+   * <p>
    * It is used by UnifiedIndexerAppenderatorsManager which allows queries on data associated with multiple
    * Appenderators.
    */
@@ -230,8 +228,8 @@ public class StreamAppenderator implements Appenderator
       Cache cache,
       RowIngestionMeters rowIngestionMeters,
       ParseExceptionHandler parseExceptionHandler,
-      boolean useMaxMemoryEstimates,
-      CentralizedDatasourceSchemaConfig centralizedDatasourceSchemaConfig
+      CentralizedDatasourceSchemaConfig centralizedDatasourceSchemaConfig,
+      TaskIntervalUnlocker taskIntervalUnlocker
   )
   {
     this.segmentLoaderConfig = segmentLoaderConfig;
@@ -251,7 +249,6 @@ public class StreamAppenderator implements Appenderator
 
     maxBytesTuningConfig = tuningConfig.getMaxBytesInMemoryOrDefault();
     skipBytesInMemoryOverheadCheck = tuningConfig.isSkipBytesInMemoryOverheadCheck();
-    this.useMaxMemoryEstimates = useMaxMemoryEstimates;
     this.centralizedDatasourceSchemaConfig = centralizedDatasourceSchemaConfig;
     this.sinkSchemaAnnouncer = new SinkSchemaAnnouncer();
 
@@ -260,6 +257,7 @@ public class StreamAppenderator implements Appenderator
         Execs.makeThreadFactory("StreamAppenderSegmentRemoval-%s")
     );
     this.fingerprintGenerator = new FingerprintGenerator(objectMapper);
+    this.taskIntervalUnlocker = taskIntervalUnlocker;
   }
 
   @VisibleForTesting
@@ -307,7 +305,7 @@ public class StreamAppenderator implements Appenderator
       final InputRow row,
       @Nullable final Supplier<Committer> committerSupplier,
       final boolean allowIncrementalPersists
-  ) throws IndexSizeExceededException, SegmentNotWritableException
+  ) throws SegmentNotWritableException
   {
     throwPersistErrorIfExists();
 
@@ -327,18 +325,12 @@ public class StreamAppenderator implements Appenderator
     final long bytesInMemoryAfterAdd;
     final IncrementalIndexAddResult addResult;
 
-    try {
-      addResult = sink.add(row, !allowIncrementalPersists);
-      sinkRowsInMemoryAfterAdd = addResult.getRowCount();
-      bytesInMemoryAfterAdd = addResult.getBytesInMemory();
-    }
-    catch (IndexSizeExceededException e) {
-      // Uh oh, we can't do anything about this! We can't persist (commit metadata would be out of sync) and we
-      // can't add the row (it just failed). This should never actually happen, though, because we check
-      // sink.canAddRow after returning from add.
-      log.error(e, "Sink for segment[%s] was unexpectedly full!", identifier);
-      throw e;
-    }
+    addResult = sink.add(row);
+    sinkRowsInMemoryAfterAdd = addResult.getRowCount();
+    bytesInMemoryAfterAdd = addResult.getBytesInMemory();
+
+    final long currTs = System.currentTimeMillis();
+    metrics.reportMessageGap(currTs - row.getTimestampFromEpoch());
 
     if (sinkRowsInMemoryAfterAdd < 0) {
       throw new SegmentNotWritableException("Attempt to add row to swapped-out sink for segment[%s].", identifier);
@@ -363,11 +355,11 @@ public class StreamAppenderator implements Appenderator
       persist = true;
       persistReasons.add("No more rows can be appended to sink");
     }
-    if (System.currentTimeMillis() > nextFlush) {
+    if (currTs > nextFlush) {
       persist = true;
       persistReasons.add(StringUtils.format(
           "current time[%d] is greater than nextFlush[%d]",
-          System.currentTimeMillis(),
+          currTs,
           nextFlush
       ));
     }
@@ -523,8 +515,7 @@ public class StreamAppenderator implements Appenderator
           identifier.getVersion(),
           tuningConfig.getAppendableIndexSpec(),
           tuningConfig.getMaxRowsInMemory(),
-          maxBytesTuningConfig,
-          useMaxMemoryEstimates
+          maxBytesTuningConfig
       );
       bytesCurrentlyInMemory.addAndGet(calculateSinkMemoryInUsed(retVal));
 
@@ -576,6 +567,7 @@ public class StreamAppenderator implements Appenderator
         final ListenableFuture<?> uncommitFuture = persistExecutor.submit(
             () -> {
               try {
+                setTaskThreadContext();
                 commitLock.lock();
                 objectMapper.writeValue(computeCommitFile(), Committed.nil());
               }
@@ -691,6 +683,7 @@ public class StreamAppenderator implements Appenderator
           public Object call() throws IOException
           {
             try {
+              setTaskThreadContext();
               for (Pair<FireHydrant, SegmentIdWithShardSpec> pair : indexesToPersist) {
                 metrics.incrementRowOutputCount(persistHydrant(pair.lhs, pair.rhs));
               }
@@ -805,7 +798,8 @@ public class StreamAppenderator implements Appenderator
         // We should always persist all segments regardless of the input because metadata should be committed for all
         // segments.
         persistAll(committer),
-        (Function<Object, SegmentsAndCommitMetadata>) commitMetadata -> {
+        commitMetadata -> {
+          setTaskThreadContext();
           final List<DataSegment> dataSegments = new ArrayList<>();
           final SegmentSchemaMapping segmentSchemaMapping = new SegmentSchemaMapping(CentralizedDatasourceSchemaConfig.SCHEMA_VERSION);
 
@@ -877,7 +871,6 @@ public class StreamAppenderator implements Appenderator
    * @param identifier    sink identifier
    * @param sink          sink to push
    * @param useUniquePath true if the segment should be written to a path with a unique identifier
-   *
    * @return segment descriptor, or null if the sink is no longer valid
    */
   @Nullable
@@ -948,11 +941,11 @@ public class StreamAppenderator implements Appenderator
       Closer closer = Closer.create();
       try {
         for (FireHydrant fireHydrant : sink) {
-          Pair<ReferenceCountingSegment, Closeable> segmentAndCloseable = fireHydrant.getAndIncrementSegment();
-          final QueryableIndex queryableIndex = segmentAndCloseable.lhs.as(QueryableIndex.class);
+          final Segment segment = fireHydrant.acquireSegment();
+          final QueryableIndex queryableIndex = segment.as(QueryableIndex.class);
           log.debug("Segment[%s] adding hydrant[%s]", identifier, fireHydrant);
           indexes.add(queryableIndex);
-          closer.register(segmentAndCloseable.rhs);
+          closer.register(segment);
         }
 
         mergedFile = indexMerger.mergeQueryableIndex(
@@ -1124,7 +1117,7 @@ public class StreamAppenderator implements Appenderator
    * Unannounces the given base segment and all its upgraded versions.
    *
    * @param baseSegment base segment
-   * @param sink sink corresponding to the base segment
+   * @param sink        sink corresponding to the base segment
    * @return the set of all segment ids associated with the base segment containing the upgraded ids and itself.
    */
   private Set<SegmentIdWithShardSpec> unannounceAllVersionsOfSegment(DataSegment baseSegment, Sink sink)
@@ -1137,17 +1130,15 @@ public class StreamAppenderator implements Appenderator
 
       final Set<SegmentIdWithShardSpec> upgradedVersionsOfSegment = baseSegmentToUpgradedSegments.remove(baseId);
       for (SegmentIdWithShardSpec newId : upgradedVersionsOfSegment) {
-        final DataSegment newSegment = new DataSegment(
-            newId.getDataSource(),
-            newId.getInterval(),
-            newId.getVersion(),
-            baseSegment.getLoadSpec(),
-            baseSegment.getDimensions(),
-            baseSegment.getMetrics(),
-            newId.getShardSpec(),
-            baseSegment.getBinaryVersion(),
-            baseSegment.getSize()
-        );
+        final DataSegment newSegment = DataSegment.builder(newId.asSegmentId())
+                                                  .shardSpec(newId.getShardSpec())
+                                                  .loadSpec(baseSegment.getLoadSpec())
+                                                  .dimensions(baseSegment.getDimensions())
+                                                  .metrics(baseSegment.getMetrics())
+                                                  .projections(baseSegment.getProjections())
+                                                  .binaryVersion(baseSegment.getBinaryVersion())
+                                                  .size(baseSegment.getSize())
+                                                  .build();
         unannounceSegment(newSegment);
         upgradedSegmentToBaseSegment.remove(newId);
       }
@@ -1191,17 +1182,15 @@ public class StreamAppenderator implements Appenderator
 
   private DataSegment getUpgradedSegment(DataSegment baseSegment, SegmentIdWithShardSpec upgradedVersion)
   {
-    return new DataSegment(
-        upgradedVersion.getDataSource(),
-        upgradedVersion.getInterval(),
-        upgradedVersion.getVersion(),
-        baseSegment.getLoadSpec(),
-        baseSegment.getDimensions(),
-        baseSegment.getMetrics(),
-        upgradedVersion.getShardSpec(),
-        baseSegment.getBinaryVersion(),
-        baseSegment.getSize()
-    );
+    return DataSegment.builder(upgradedVersion.asSegmentId())
+                      .shardSpec(upgradedVersion.getShardSpec())
+                      .loadSpec(baseSegment.getLoadSpec())
+                      .dimensions(baseSegment.getDimensions())
+                      .metrics(baseSegment.getMetrics())
+                      .projections(baseSegment.getProjections())
+                      .binaryVersion(baseSegment.getBinaryVersion())
+                      .size(baseSegment.getSize())
+                      .build();
   }
 
   private void lockBasePersistDirectory()
@@ -1411,7 +1400,6 @@ public class StreamAppenderator implements Appenderator
             tuningConfig.getAppendableIndexSpec(),
             tuningConfig.getMaxRowsInMemory(),
             maxBytesTuningConfig,
-            useMaxMemoryEstimates,
             hydrants
         );
         rowsSoFar += currSink.getNumRows();
@@ -1443,7 +1431,7 @@ public class StreamAppenderator implements Appenderator
    * Update the state of the appenderator when adding a sink.
    *
    * @param identifier sink identifier
-   * @param sink sink to be added
+   * @param sink       sink to be added
    */
   private void addSink(SegmentIdWithShardSpec identifier, Sink sink)
   {
@@ -1540,6 +1528,10 @@ public class StreamAppenderator implements Appenderator
                 removeDirectory(computePersistDir(identifier));
               }
 
+              if (tuningConfig.isReleaseLocksOnHandoff()) {
+                unlockIntervalIfApplicable(sink);
+              }
+
               log.info("Dropped segment[%s].", identifier);
             };
 
@@ -1574,6 +1566,30 @@ public class StreamAppenderator implements Appenderator
     );
   }
 
+  /**
+   * Unlock the interval if there are more active sinks writing for this interval.
+   * The interval will be unlocked if there is no other sink writing to any overlapping intervals.
+   */
+  private void unlockIntervalIfApplicable(Sink abandonedSink)
+  {
+    Interval abandonedInterval = abandonedSink.getInterval();
+    boolean isIntervalActive = sinks.entrySet().stream()
+                                    .anyMatch(entry -> {
+                                      return entry.getValue().getInterval().overlaps(abandonedInterval);
+                                    });
+    if (isIntervalActive) {
+      log.info("Interval[%s] is still being appended to by other sinks.", abandonedInterval);
+    } else {
+      log.info("Unlocking interval[%s] as there are no more active sinks for it.", abandonedInterval);
+      try {
+        taskIntervalUnlocker.releaseLock(abandonedInterval);
+      }
+      catch (IOException e) {
+        log.makeAlert(e, "Failed to unlock interval[%s]", abandonedInterval).emit();
+      }
+    }
+  }
+
   private Committed readCommit() throws IOException
   {
     final File commitFile = computeCommitFile();
@@ -1632,7 +1648,6 @@ public class StreamAppenderator implements Appenderator
    *
    * @param indexToPersist hydrant to persist
    * @param identifier     the segment this hydrant is going to be part of
-   *
    * @return the number of rows persisted
    */
   private int persistHydrant(FireHydrant indexToPersist, SegmentIdWithShardSpec identifier)
@@ -1775,6 +1790,7 @@ public class StreamAppenderator implements Appenderator
     @VisibleForTesting
     void computeAndAnnounce()
     {
+      setTaskThreadContext();
       Map<SegmentId, Pair<RowSignature, Integer>> currentSinkSignatureMap = new HashMap<>();
       for (Map.Entry<SegmentIdWithShardSpec, Sink> sinkEntry : StreamAppenderator.this.sinks.entrySet()) {
         SegmentIdWithShardSpec segmentIdWithShardSpec = sinkEntry.getKey();
