@@ -170,7 +170,8 @@ public class UnifiedIndexerAppenderatorsManager implements AppenderatorsManager
       PolicyEnforcer policyEnforcer,
       RowIngestionMeters rowIngestionMeters,
       ParseExceptionHandler parseExceptionHandler,
-      CentralizedDatasourceSchemaConfig centralizedDatasourceSchemaConfig
+      CentralizedDatasourceSchemaConfig centralizedDatasourceSchemaConfig,
+      TaskIntervalUnlocker taskIntervalUnlocker
   )
   {
     synchronized (this) {
@@ -194,7 +195,8 @@ public class UnifiedIndexerAppenderatorsManager implements AppenderatorsManager
           cache,
           rowIngestionMeters,
           parseExceptionHandler,
-          centralizedDatasourceSchemaConfig
+          centralizedDatasourceSchemaConfig,
+          taskIntervalUnlocker
       )
       {
         @Override
@@ -507,6 +509,12 @@ public class UnifiedIndexerAppenderatorsManager implements AppenderatorsManager
     {
       return baseConfig.getNumPersistThreads();
     }
+
+    @Override
+    public boolean isReleaseLocksOnHandoff()
+    {
+      return baseConfig.isReleaseLocksOnHandoff();
+    }
   }
 
   private IndexMerger wrapIndexMerger(IndexMerger baseMerger)
