@@ -39,7 +39,6 @@ import org.apache.druid.query.TruncatedResponseContextException;
 import org.apache.druid.query.context.ResponseContext;
 import org.apache.druid.server.security.AuthConfig;
 import org.apache.druid.server.security.ForbiddenException;
-import org.eclipse.jetty.http.HttpFields;
 import org.eclipse.jetty.http.HttpHeader;
 
 import javax.annotation.Nullable;
@@ -52,6 +51,7 @@ import javax.ws.rs.core.Response;
 import java.io.Closeable;
 import java.io.IOException;
 import java.io.OutputStream;
+import java.util.HashMap;
 import java.util.Map;
 
 public abstract class QueryResultPusher
@@ -67,7 +67,8 @@ public abstract class QueryResultPusher
   private final QueryResource.QueryMetricCounter counter;
   private final MediaType contentType;
   private final Map<String, String> extraHeaders;
-  private final HttpFields trailerFields;
+  private final Map<String, Object> queryContext;
+  private final Map<String, String> trailerFields;
 
   private StreamingHttpResponseAccumulator accumulator;
   private AsyncContext asyncContext;
@@ -81,7 +82,8 @@ public abstract class QueryResultPusher
       QueryResource.QueryMetricCounter counter,
       String queryId,
       MediaType contentType,
-      Map<String, String> extraHeaders
+      Map<String, String> extraHeaders,
+      Map<String, Object> queryContext
   )
   {
     this.request = request;
@@ -92,7 +94,8 @@ public abstract class QueryResultPusher
     this.counter = counter;
     this.contentType = contentType;
     this.extraHeaders = extraHeaders;
-    this.trailerFields = new HttpFields();
+    this.queryContext = queryContext;
+    this.trailerFields = new HashMap<>();
   }
 
   /**
@@ -151,16 +154,11 @@ public abstract class QueryResultPusher
         response.setHeader(entry.getKey(), entry.getValue());
       }
 
-      if (response instanceof org.eclipse.jetty.server.Response) {
-        org.eclipse.jetty.server.Response jettyResponse = (org.eclipse.jetty.server.Response) response;
+      response.setHeader(HttpHeader.TRAILER.toString(), RESULT_TRAILER_HEADERS);
+      response.setTrailerFields(() -> trailerFields);
 
-        jettyResponse.setHeader(HttpHeader.TRAILER.toString(), RESULT_TRAILER_HEADERS);
-        jettyResponse.setTrailers(() -> trailerFields);
-
-        // Start with complete status
-
-        trailerFields.put(QueryResource.RESPONSE_COMPLETE_TRAILER_HEADER, "true");
-      }
+      // Start with complete status
+      trailerFields.put(QueryResource.RESPONSE_COMPLETE_TRAILER_HEADER, "true");
 
       accumulator = new StreamingHttpResponseAccumulator(queryResponse.getResponseContext(), resultsWriter);
 
@@ -259,11 +257,25 @@ public abstract class QueryResultPusher
       resultsWriter.recordFailure(e);
 
       if (accumulator != null && accumulator.isInitialized()) {
-        // We already started sending a response when we got the error message.  In this case we just give up
-        // and hope that the partial stream generates a meaningful failure message for our client.  We could consider
-        // also throwing the exception body into the response to make it easier for the client to choke if it manages
-        // to parse a meaningful object out, but that's potentially an API change so we leave that as an exercise for
-        // the future.
+        // We already started sending a response when we got the error message.  In this case we write the exception
+        // message as a row, assuming the caller (SqlResource, QueryResource or a custom endpoint) would be able to
+        // parse it and throw an exception on their side. It's assumed that if the caller is setting the
+        // WRITE_EXCEPTION_BODY_AS_RESPONSE_ROW context value, they are able to handle this kind of response. If it's
+        // not set, caller will continue to see a json parsing exception.
+        if (queryContext != null
+            && Boolean.parseBoolean(String.valueOf(queryContext.get(QueryResource.WRITE_EXCEPTION_BODY_AS_RESPONSE_ROW)))) {
+          try {
+            accumulator.writer.writeRow(e);
+            accumulator.writer.writeResponseEnd();
+          }
+          catch (IOException ioException) {
+            log.warn(
+                ioException,
+                "Suppressing IOException thrown writing error response for query [%s]",
+                queryId
+            );
+          }
+        }
         trailerFields.put(QueryResource.ERROR_MESSAGE_TRAILER_HEADER, e.getMessage());
         trailerFields.put(QueryResource.RESPONSE_COMPLETE_TRAILER_HEADER, "false");
         return null;
@@ -427,10 +439,7 @@ public abstract class QueryResultPusher
 
         response.setContentType(contentType.toString());
 
-        if (response instanceof org.eclipse.jetty.server.Response) {
-          org.eclipse.jetty.server.Response jettyResponse = (org.eclipse.jetty.server.Response) response;
-          jettyResponse.setTrailers(() -> trailerFields);
-        }
+        response.setTrailerFields(() -> trailerFields);
 
         try {
           out = new CountingOutputStream(response.getOutputStream());
