@@ -209,7 +209,8 @@ public class CompactionStatus
   )
   {
     final Evaluator evaluator = new Evaluator(candidateSegments, config, objectMapper);
-    return CHECKS.stream().map(f -> f.apply(evaluator))
+    return CHECKS.stream()
+                 .map(f -> f.apply(evaluator))
                  .filter(status -> !status.isComplete())
                  .findFirst().orElse(COMPLETE);
   }
@@ -232,19 +233,28 @@ public class CompactionStatus
     }
   }
 
+  @Nullable
   private static List<DimensionSchema> getNonPartitioningDimensions(
       @Nullable final List<DimensionSchema> dimensionSchemas,
-      @Nullable final PartitionsSpec partitionsSpec
+      @Nullable final PartitionsSpec partitionsSpec,
+      @Nullable final IndexSpec indexSpec
   )
   {
+    final IndexSpec effectiveIndexSpec = (indexSpec == null ? IndexSpec.getDefault() : indexSpec).getEffectiveSpec();
     if (dimensionSchemas == null || !(partitionsSpec instanceof DimensionRangePartitionsSpec)) {
-      return dimensionSchemas;
+      if (dimensionSchemas != null) {
+        return dimensionSchemas.stream()
+                               .map(dim -> dim.getEffectiveSchema(effectiveIndexSpec))
+                               .collect(Collectors.toList());
+      }
+      return null;
     }
 
     final List<String> partitionsDimensions = ((DimensionRangePartitionsSpec) partitionsSpec).getPartitionDimensions();
     return dimensionSchemas.stream()
-                     .filter(dim -> !partitionsDimensions.contains(dim.getName()))
-                     .collect(Collectors.toList());
+                           .filter(dim -> !partitionsDimensions.contains(dim.getName()))
+                           .map(dim -> dim.getEffectiveSchema(effectiveIndexSpec))
+                           .collect(Collectors.toList());
   }
 
   /**
@@ -335,8 +345,8 @@ public class CompactionStatus
     {
       return CompactionStatus.completeIfEqual(
           "indexSpec",
-          Configs.valueOrDefault(tuningConfig.getIndexSpec(), IndexSpec.DEFAULT),
-          objectMapper.convertValue(lastCompactionState.getIndexSpec(), IndexSpec.class),
+          Configs.valueOrDefault(tuningConfig.getIndexSpec(), IndexSpec.getDefault()).getEffectiveSpec(),
+          objectMapper.convertValue(lastCompactionState.getIndexSpec(), IndexSpec.class).getEffectiveSpec(),
           String::valueOf
       );
     }
@@ -430,20 +440,22 @@ public class CompactionStatus
             lastCompactionState.getDimensionsSpec() == null
             ? null
             : lastCompactionState.getDimensionsSpec().getDimensions(),
-            lastCompactionState.getPartitionsSpec()
+            lastCompactionState.getPartitionsSpec(),
+            lastCompactionState.getIndexSpec()
         );
         List<DimensionSchema> configuredDimensions = getNonPartitioningDimensions(
             compactionConfig.getDimensionsSpec().getDimensions(),
-            compactionConfig.getTuningConfig() == null ? null : compactionConfig.getTuningConfig().getPartitionsSpec()
+            compactionConfig.getTuningConfig() == null ? null : compactionConfig.getTuningConfig().getPartitionsSpec(),
+            compactionConfig.getTuningConfig() == null
+            ? IndexSpec.getDefault()
+            : compactionConfig.getTuningConfig().getIndexSpec()
+        );
+        return CompactionStatus.completeIfEqual(
+            "dimensionsSpec",
+            configuredDimensions,
+            existingDimensions,
+            String::valueOf
         );
-        {
-          return CompactionStatus.completeIfEqual(
-              "dimensionsSpec",
-              configuredDimensions,
-              existingDimensions,
-              String::valueOf
-          );
-        }
       }
     }
 
