@@ -23,12 +23,16 @@ import com.sun.jersey.spi.container.ResourceFilters;
 import org.apache.druid.audit.AuditManager;
 import org.apache.druid.common.config.ConfigManager.SetResult;
 import org.apache.druid.java.util.common.Intervals;
+import org.apache.druid.server.coordinator.CloneStatusManager;
 import org.apache.druid.server.coordinator.CoordinatorConfigManager;
 import org.apache.druid.server.coordinator.CoordinatorDynamicConfig;
+import org.apache.druid.server.coordinator.ServerCloneStatus;
 import org.apache.druid.server.http.security.ConfigResourceFilter;
+import org.apache.druid.server.http.security.StateResourceFilter;
 import org.apache.druid.server.security.AuthorizationUtils;
 import org.joda.time.Interval;
 
+import javax.annotation.Nullable;
 import javax.inject.Inject;
 import javax.servlet.http.HttpServletRequest;
 import javax.ws.rs.Consumes;
@@ -49,15 +53,21 @@ public class CoordinatorDynamicConfigsResource
 {
   private final CoordinatorConfigManager manager;
   private final AuditManager auditManager;
+  private final CoordinatorDynamicConfigSyncer coordinatorDynamicConfigSyncer;
+  private final CloneStatusManager cloneStatusManager;
 
   @Inject
   public CoordinatorDynamicConfigsResource(
       CoordinatorConfigManager manager,
-      AuditManager auditManager
+      AuditManager auditManager,
+      CoordinatorDynamicConfigSyncer coordinatorDynamicConfigSyncer,
+      CloneStatusManager cloneStatusManager
   )
   {
     this.manager = manager;
     this.auditManager = auditManager;
+    this.coordinatorDynamicConfigSyncer = coordinatorDynamicConfigSyncer;
+    this.cloneStatusManager = cloneStatusManager;
   }
 
   @GET
@@ -84,6 +94,7 @@ public class CoordinatorDynamicConfigsResource
       );
 
       if (setResult.isOk()) {
+        coordinatorDynamicConfigSyncer.queueBroadcastConfigToBrokers();
         return Response.ok().build();
       } else {
         return Response.status(Response.Status.BAD_REQUEST)
@@ -132,4 +143,30 @@ public class CoordinatorDynamicConfigsResource
     ).build();
   }
 
+  @GET
+  @Path("/syncedBrokers")
+  @ResourceFilters(StateResourceFilter.class)
+  @Produces(MediaType.APPLICATION_JSON)
+  public Response getBrokerStatus()
+  {
+    return Response.ok(new ConfigSyncStatus(coordinatorDynamicConfigSyncer.getInSyncBrokers())).build();
+  }
+
+  @GET
+  @Path("/cloneStatus")
+  @ResourceFilters(StateResourceFilter.class)
+  @Produces(MediaType.APPLICATION_JSON)
+  public Response getCloneStatus(@QueryParam("targetServer") @Nullable String targetServer)
+  {
+    if (targetServer != null) {
+      final ServerCloneStatus statusForServer = cloneStatusManager.getStatusForServer(targetServer);
+      if (statusForServer == null) {
+        return Response.status(Response.Status.NOT_FOUND).build();
+      }
+      return Response.ok(statusForServer).build();
+    } else {
+      final CloneStatus statusForAllServers = new CloneStatus(cloneStatusManager.getStatusForAllServers());
+      return Response.ok(statusForAllServers).build();
+    }
+  }
 }
