@@ -20,6 +20,14 @@
 package org.apache.druid.server.initialization;
 
 import com.fasterxml.jackson.annotation.JsonProperty;
+import com.fasterxml.jackson.core.JsonGenerator;
+import com.fasterxml.jackson.core.JsonParser;
+import com.fasterxml.jackson.databind.DeserializationContext;
+import com.fasterxml.jackson.databind.JsonDeserializer;
+import com.fasterxml.jackson.databind.JsonSerializer;
+import com.fasterxml.jackson.databind.SerializerProvider;
+import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
+import com.fasterxml.jackson.databind.annotation.JsonSerialize;
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.collect.ImmutableList;
 import org.apache.druid.common.exception.ErrorResponseTransformStrategy;
@@ -29,12 +37,14 @@ import org.apache.druid.java.util.common.HumanReadableBytesRange;
 import org.apache.druid.query.QueryContexts;
 import org.apache.druid.server.SubqueryGuardrailHelper;
 import org.apache.druid.utils.JvmUtils;
+import org.eclipse.jetty.http.UriCompliance;
 import org.joda.time.Period;
 
 import javax.annotation.Nullable;
 import javax.validation.constraints.Max;
 import javax.validation.constraints.Min;
 import javax.validation.constraints.NotNull;
+import java.io.IOException;
 import java.util.List;
 import java.util.Objects;
 import java.util.concurrent.TimeUnit;
@@ -73,7 +83,9 @@ public class ServerConfig
       boolean showDetailedJettyErrors,
       @NotNull ErrorResponseTransformStrategy errorResponseTransformStrategy,
       @Nullable String contentSecurityPolicy,
-      boolean enableHSTS
+      boolean enableHSTS,
+      @Nullable UriCompliance uriCompliance,
+      boolean enforceStrictSNIHostChecking
   )
   {
     this.numThreads = numThreads;
@@ -97,6 +109,8 @@ public class ServerConfig
     this.errorResponseTransformStrategy = errorResponseTransformStrategy;
     this.contentSecurityPolicy = contentSecurityPolicy;
     this.enableHSTS = enableHSTS;
+    this.uriCompliance = uriCompliance != null ? uriCompliance : UriCompliance.LEGACY;
+    this.enforceStrictSNIHostChecking = enforceStrictSNIHostChecking;
   }
 
   public ServerConfig()
@@ -185,6 +199,11 @@ public class ServerConfig
   @JsonProperty
   private boolean enableHSTS = false;
 
+  @JsonProperty
+  @JsonDeserialize(using = UriComplianceDeserializer.class)
+  @JsonSerialize(using = UriComplianceSerializer.class)
+  private UriCompliance uriCompliance = UriCompliance.LEGACY;
+
   /**
    * This feature flag enables query requests queuing when admins want to reserve some threads for
    * non-query requests. This feature flag is not documented and will be removed in the future.
@@ -195,6 +214,9 @@ public class ServerConfig
   @JsonProperty
   private boolean showDetailedJettyErrors = true;
 
+  @JsonProperty
+  private boolean enforceStrictSNIHostChecking = true;
+
   public int getNumThreads()
   {
     return numThreads;
@@ -306,6 +328,16 @@ public class ServerConfig
     return enableQueryRequestsQueuing;
   }
 
+  public UriCompliance getUriCompliance()
+  {
+    return uriCompliance;
+  }
+
+  public boolean isEnforceStrictSNIHostChecking()
+  {
+    return enforceStrictSNIHostChecking;
+  }
+
   @Override
   public boolean equals(Object o)
   {
@@ -337,7 +369,9 @@ public class ServerConfig
            errorResponseTransformStrategy.equals(that.errorResponseTransformStrategy) &&
            Objects.equals(contentSecurityPolicy, that.getContentSecurityPolicy()) &&
            enableHSTS == that.enableHSTS &&
-           enableQueryRequestsQueuing == that.enableQueryRequestsQueuing;
+           enableQueryRequestsQueuing == that.enableQueryRequestsQueuing &&
+           Objects.equals(uriCompliance, that.uriCompliance) &&
+           enforceStrictSNIHostChecking == that.enforceStrictSNIHostChecking;
   }
 
   @Override
@@ -365,7 +399,9 @@ public class ServerConfig
         showDetailedJettyErrors,
         contentSecurityPolicy,
         enableHSTS,
-        enableQueryRequestsQueuing
+        enableQueryRequestsQueuing,
+        uriCompliance,
+        enforceStrictSNIHostChecking
     );
   }
 
@@ -395,6 +431,8 @@ public class ServerConfig
            ", contentSecurityPolicy=" + contentSecurityPolicy +
            ", enableHSTS=" + enableHSTS +
            ", enableQueryRequestsQueuing=" + enableQueryRequestsQueuing +
+           ", uriCompliance=" + uriCompliance +
+           ", enforceStrictSNIHostChecking=" + enforceStrictSNIHostChecking +
            '}';
   }
 
@@ -402,4 +440,23 @@ public class ServerConfig
   {
     return Math.max(10, (JvmUtils.getRuntimeInfo().getAvailableProcessors() * 17) / 16 + 2) + 30;
   }
+
+  public static class UriComplianceDeserializer extends JsonDeserializer<UriCompliance>
+  {
+    @Override
+    public UriCompliance deserialize(JsonParser p, DeserializationContext ctxt) throws IOException
+    {
+      String value = p.getValueAsString();
+      return UriCompliance.valueOf(value);
+    }
+  }
+
+  public static class UriComplianceSerializer extends JsonSerializer<UriCompliance>
+  {
+    @Override
+    public void serialize(UriCompliance value, JsonGenerator gen, SerializerProvider serializers) throws IOException
+    {
+      gen.writeString(value.getName());
+    }
+  }
 }
