@@ -64,11 +64,13 @@ import org.eclipse.jetty.server.Handler;
 import org.eclipse.jetty.server.HttpConfiguration;
 import org.eclipse.jetty.server.HttpConnectionFactory;
 import org.eclipse.jetty.server.Request;
+import org.eclipse.jetty.server.Response;
 import org.eclipse.jetty.server.SecureRequestCustomizer;
 import org.eclipse.jetty.server.Server;
 import org.eclipse.jetty.server.ServerConnector;
 import org.eclipse.jetty.server.SslConnectionFactory;
 import org.eclipse.jetty.server.handler.ErrorHandler;
+import org.eclipse.jetty.util.Callback;
 import org.eclipse.jetty.util.component.LifeCycle;
 import org.eclipse.jetty.util.ssl.KeyStoreScanner;
 import org.eclipse.jetty.util.ssl.SslContextFactory;
@@ -81,11 +83,7 @@ import javax.net.ssl.TrustManager;
 import javax.net.ssl.TrustManagerFactory;
 import javax.net.ssl.X509ExtendedTrustManager;
 import javax.servlet.RequestDispatcher;
-import javax.servlet.ServletException;
-import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpServletResponse;
 import java.io.BufferedReader;
-import java.io.IOException;
 import java.nio.file.Files;
 import java.nio.file.Paths;
 import java.security.KeyStore;
@@ -127,6 +125,7 @@ public class JettyServerModule extends JerseyServletModule
     binder.bind(ForbiddenExceptionMapper.class).in(LazySingleton.class);
     binder.bind(BadRequestExceptionMapper.class).in(LazySingleton.class);
     binder.bind(ServiceUnavailableExceptionMapper.class).in(LazySingleton.class);
+    binder.bind(HttpExceptionMapper.class).in(LazySingleton.class);
 
     serve("/*").with(GuiceContainer.class);
 
@@ -224,6 +223,7 @@ public class JettyServerModule extends JerseyServletModule
     if (node.isEnablePlaintextPort()) {
       log.info("Creating http connector with port [%d]", node.getPlaintextPort());
       HttpConfiguration httpConfiguration = new HttpConfiguration();
+      httpConfiguration.setUriCompliance(config.getUriCompliance());
       if (config.isEnableForwardedRequestCustomizer()) {
         httpConfiguration.addCustomizer(new ForwardedRequestCustomizer());
       }
@@ -242,10 +242,13 @@ public class JettyServerModule extends JerseyServletModule
 
     if (node.isEnableTlsPort()) {
       log.info("Creating https connector with port [%d]", node.getTlsPort());
-      if (sslContextFactoryBinding == null) {
-        // Never trust all certificates by default
-        sslContextFactory = new IdentityCheckOverrideSslContextFactory(tlsServerConfig, certificateChecker);
+      boolean hasBinding = sslContextFactoryBinding != null;
+      sslContextFactory = hasBinding
+                          ? sslContextFactoryBinding.getProvider().get()
+                          : new IdentityCheckOverrideSslContextFactory(tlsServerConfig, certificateChecker);
 
+      // Never trust all certificates by default
+      if (!hasBinding || tlsServerConfig.isForceApplyConfig()) {
         sslContextFactory.setKeyStorePath(tlsServerConfig.getKeyStorePath());
         sslContextFactory.setKeyStoreType(tlsServerConfig.getKeyStoreType());
         sslContextFactory.setKeyStorePassword(tlsServerConfig.getKeyStorePasswordProvider().getPassword());
@@ -303,17 +306,22 @@ public class JettyServerModule extends JerseyServletModule
             );
           }
         }
-      } else {
-        sslContextFactory = sslContextFactoryBinding.getProvider().get();
       }
 
       final HttpConfiguration httpsConfiguration = new HttpConfiguration();
+      httpsConfiguration.setUriCompliance(config.getUriCompliance());
       if (config.isEnableForwardedRequestCustomizer()) {
         httpsConfiguration.addCustomizer(new ForwardedRequestCustomizer());
       }
       httpsConfiguration.setSecureScheme("https");
       httpsConfiguration.setSecurePort(node.getTlsPort());
-      httpsConfiguration.addCustomizer(new SecureRequestCustomizer());
+
+      // see https://github.com/jetty/jetty.project/pull/5398
+      // This new strict enforcement can break some clients. Allow turning it off via config if necessary
+      final SecureRequestCustomizer secureRequestCustomizer = new SecureRequestCustomizer();
+      secureRequestCustomizer.setSniHostCheck(config.isEnforceStrictSNIHostChecking());
+
+      httpsConfiguration.addCustomizer(secureRequestCustomizer);
       httpsConfiguration.setRequestHeaderSize(config.getMaxRequestHeaderSize());
       httpsConfiguration.setSendServerVersion(false);
       final ServerConnector connector = new ServerConnector(
@@ -363,7 +371,7 @@ public class JettyServerModule extends JerseyServletModule
     if (gracefulStop > 0) {
       server.setStopTimeout(gracefulStop);
     }
-    server.addLifeCycleListener(new LifeCycle.Listener()
+    server.addEventListener(new LifeCycle.Listener()
     {
       @Override
       public void lifeCycleStarting(LifeCycle event)
@@ -466,25 +474,20 @@ public class JettyServerModule extends JerseyServletModule
       server.setErrorHandler(new ErrorHandler()
       {
         @Override
-        public boolean isShowServlet()
-        {
-          return false;
-        }
-
-        @Override
-        public void handle(
-            String target,
+        public boolean handle(
             Request baseRequest,
-            HttpServletRequest request,
-            HttpServletResponse response
-        ) throws IOException, ServletException
+            Response response,
+            Callback callback
+        ) throws Exception
         {
-          request.setAttribute(RequestDispatcher.ERROR_EXCEPTION, null);
-          super.handle(target, baseRequest, request, response);
+          baseRequest.setAttribute(RequestDispatcher.ERROR_EXCEPTION, null);
+          return super.handle(baseRequest, response, callback);
         }
       });
     }
 
+    server.setRequestLog(new JettyRequestLog());
+
     return server;
   }
 
@@ -499,8 +502,7 @@ public class JettyServerModule extends JerseyServletModule
   private static int getTCPAcceptQueueSize()
   {
     if (SystemUtils.IS_OS_LINUX) {
-      try {
-        BufferedReader in = Files.newBufferedReader(Paths.get("/proc/sys/net/core/somaxconn"));
+      try (BufferedReader in = Files.newBufferedReader(Paths.get("/proc/sys/net/core/somaxconn"))) {
         String acceptQueueSize = in.readLine();
         if (acceptQueueSize != null) {
           return Integer.parseInt(acceptQueueSize);
