@@ -30,6 +30,7 @@ import org.apache.druid.client.cache.CachePopulator;
 import org.apache.druid.client.cache.CachePopulatorStats;
 import org.apache.druid.client.cache.ForegroundCachePopulator;
 import org.apache.druid.client.cache.MapCache;
+import org.apache.druid.client.selector.HistoricalFilter;
 import org.apache.druid.client.selector.ServerSelector;
 import org.apache.druid.client.selector.TierSelectorStrategy;
 import org.apache.druid.guice.http.DruidHttpClientConfig;
@@ -212,7 +213,8 @@ public class CachingClusteredClientFunctionalityTest
                     )
                 );
               }
-            }
+            },
+            HistoricalFilter.IDENTITY_FILTER
         )
     ));
   }
@@ -263,7 +265,7 @@ public class CachingClusteredClientFunctionalityTest
           }
 
           @Override
-          public void registerServerRemovedCallback(Executor exec, ServerRemovedCallback callback)
+          public void registerServerCallback(Executor exec, ServerCallback callback)
           {
 
           }
