@@ -20,22 +20,28 @@
 package org.apache.druid.metadata;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
+import com.google.common.base.Suppliers;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableMap;
 import org.apache.druid.java.util.common.DateTimes;
 import org.apache.druid.java.util.common.Intervals;
 import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.segment.TestHelper;
+import org.apache.druid.segment.metadata.CentralizedDatasourceSchemaConfig;
 import org.apache.druid.segment.metadata.SegmentSchemaCache;
 import org.apache.druid.segment.metadata.SegmentSchemaManager;
+import org.apache.druid.server.metrics.NoopServiceEmitter;
 import org.apache.druid.timeline.DataSegment;
+import org.apache.druid.timeline.SegmentId;
 import org.apache.druid.timeline.partition.NoneShardSpec;
+import org.joda.time.DateTime;
+import org.joda.time.Period;
 import org.skife.jdbi.v2.DBI;
 import org.skife.jdbi.v2.tweak.HandleCallback;
 
-import java.io.IOException;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 
 public class SqlSegmentsMetadataManagerTestBase
 {
@@ -64,11 +70,66 @@ public class SqlSegmentsMetadataManagerTestBase
       0
   );
 
-  protected void publishSegment(final DataSegment segment) throws IOException
+  protected void setUp(TestDerbyConnector.DerbyConnectorRule derbyConnectorRule) throws Exception
+  {
+    config = new SegmentsMetadataManagerConfig(Period.seconds(3), null, null);
+    connector = derbyConnectorRule.getConnector();
+    storageConfig = derbyConnectorRule.metadataTablesConfigSupplier().get();
+
+    segmentSchemaCache = new SegmentSchemaCache();
+    segmentSchemaManager = new SegmentSchemaManager(
+        derbyConnectorRule.metadataTablesConfigSupplier().get(),
+        jsonMapper,
+        connector
+    );
+
+    sqlSegmentsMetadataManager = new SqlSegmentsMetadataManager(
+        jsonMapper,
+        Suppliers.ofInstance(config),
+        derbyConnectorRule.metadataTablesConfigSupplier(),
+        connector,
+        segmentSchemaCache,
+        CentralizedDatasourceSchemaConfig.create(),
+        NoopServiceEmitter.instance()
+    );
+    sqlSegmentsMetadataManager.start();
+
+    connector.createSegmentSchemasTable();
+    connector.createSegmentTable();
+  }
+
+  protected void teardownManager()
+  {
+    if (sqlSegmentsMetadataManager.isPollingDatabasePeriodically()) {
+      sqlSegmentsMetadataManager.stopPollingDatabasePeriodically();
+    }
+    sqlSegmentsMetadataManager.stop();
+  }
+
+  protected void publishSegment(final DataSegment segment)
   {
     publishSegment(connector, storageConfig, jsonMapper, segment);
   }
 
+  protected int markSegmentsAsUnused(SegmentId... segmentIds)
+  {
+    return markSegmentsAsUnused(Set.of(segmentIds), connector, storageConfig, jsonMapper, DateTimes.nowUtc());
+  }
+
+  public static int markSegmentsAsUnused(
+      Set<SegmentId> segmentIds,
+      SQLMetadataConnector connector,
+      MetadataStorageTablesConfig storageConfig,
+      ObjectMapper jsonMapper,
+      DateTime updateTime
+  )
+  {
+    return connector.retryWithHandle(
+        handle -> SqlSegmentsMetadataQuery.forHandle(handle, connector, storageConfig, jsonMapper)
+                                          .markSegmentsAsUnused(segmentIds, updateTime)
+    );
+  }
+
   protected static DataSegment createSegment(
       String dataSource,
       String interval,
@@ -99,46 +160,15 @@ public class SqlSegmentsMetadataManagerTestBase
       final MetadataStorageTablesConfig config,
       final ObjectMapper jsonMapper,
       final DataSegment segment
-  ) throws IOException
-  {
-    String now = DateTimes.nowUtc().toString();
-    publishSegment(
-        connector,
-        config,
-        segment.getId().toString(),
-        segment.getDataSource(),
-        now,
-        segment.getInterval().getStart().toString(),
-        segment.getInterval().getEnd().toString(),
-        (segment.getShardSpec() instanceof NoneShardSpec) ? false : true,
-        segment.getVersion(),
-        true,
-        jsonMapper.writeValueAsBytes(segment),
-        now
-    );
-  }
-
-  private static void publishSegment(
-      final SQLMetadataConnector connector,
-      final MetadataStorageTablesConfig config,
-      final String segmentId,
-      final String dataSource,
-      final String createdDate,
-      final String start,
-      final String end,
-      final boolean partitioned,
-      final String version,
-      final boolean used,
-      final byte[] payload,
-      final String usedFlagLastUpdated
   )
   {
+    final String now = DateTimes.nowUtc().toString();
     try {
       final DBI dbi = connector.getDBI();
       List<Map<String, Object>> exists = dbi.withHandle(
           handle ->
               handle.createQuery(StringUtils.format("SELECT id FROM %s WHERE id=:id", config.getSegmentsTable()))
-                    .bind("id", segmentId)
+                    .bind("id", segment.getId().toString())
                     .list()
       );
 
@@ -153,19 +183,20 @@ public class SqlSegmentsMetadataManagerTestBase
           connector.getQuoteString()
       );
 
+      final byte[] payload = jsonMapper.writeValueAsBytes(segment);
       dbi.withHandle(
           (HandleCallback<Void>) handle -> {
             handle.createStatement(publishStatement)
-                  .bind("id", segmentId)
-                  .bind("dataSource", dataSource)
-                  .bind("created_date", createdDate)
-                  .bind("start", start)
-                  .bind("end", end)
-                  .bind("partitioned", partitioned)
-                  .bind("version", version)
-                  .bind("used", used)
+                  .bind("id", segment.getId().toString())
+                  .bind("dataSource", segment.getDataSource())
+                  .bind("created_date", now)
+                  .bind("start", segment.getInterval().getStart().toString())
+                  .bind("end", segment.getInterval().getEnd().toString())
+                  .bind("partitioned", !(segment.getShardSpec() instanceof NoneShardSpec))
+                  .bind("version", segment.getVersion())
+                  .bind("used", true)
                   .bind("payload", payload)
-                  .bind("used_status_last_updated", usedFlagLastUpdated)
+                  .bind("used_status_last_updated", now)
                   .execute();
 
             return null;
