@@ -49,33 +49,64 @@ import java.util.UUID;
 public class TestDerbyConnector extends DerbyConnector
 {
   private final String jdbcUri;
+  private final MetadataStorageTablesConfig dbTables;
 
   public TestDerbyConnector(
-      Supplier<MetadataStorageConnectorConfig> config,
-      Supplier<MetadataStorageTablesConfig> dbTables,
+      MetadataStorageConnectorConfig connectorConfig,
+      MetadataStorageTablesConfig tablesConfig,
       CentralizedDatasourceSchemaConfig centralizedDatasourceSchemaConfig
   )
   {
-    this(config, dbTables, "jdbc:derby:memory:druidTest" + dbSafeUUID(), centralizedDatasourceSchemaConfig);
+    this(
+        connectorConfig,
+        tablesConfig,
+        "jdbc:derby:memory:druidTest" + dbSafeUUID(),
+        centralizedDatasourceSchemaConfig
+    );
   }
 
   public TestDerbyConnector(
-      Supplier<MetadataStorageConnectorConfig> config,
-      Supplier<MetadataStorageTablesConfig> dbTables
+      MetadataStorageConnectorConfig connectorConfig,
+      MetadataStorageTablesConfig tablesConfig
   )
   {
-    this(config, dbTables, "jdbc:derby:memory:druidTest" + dbSafeUUID(), CentralizedDatasourceSchemaConfig.create());
+    this(
+        connectorConfig,
+        tablesConfig,
+        CentralizedDatasourceSchemaConfig.create()
+    );
   }
 
-  protected TestDerbyConnector(
-      Supplier<MetadataStorageConnectorConfig> config,
-      Supplier<MetadataStorageTablesConfig> dbTables,
+  public TestDerbyConnector(
+      MetadataStorageConnectorConfig connectorConfig,
+      MetadataStorageTablesConfig tablesConfig,
       String jdbcUri,
       CentralizedDatasourceSchemaConfig centralizedDatasourceSchemaConfig
   )
   {
-    super(new NoopMetadataStorageProvider().get(), config, dbTables, new DBI(jdbcUri + ";create=true"), centralizedDatasourceSchemaConfig);
+    super(
+        new NoopMetadataStorageProvider().get(),
+        Suppliers.ofInstance(connectorConfig),
+        Suppliers.ofInstance(tablesConfig),
+        new DBI(jdbcUri + ";create=true"),
+        centralizedDatasourceSchemaConfig
+    );
     this.jdbcUri = jdbcUri;
+    this.dbTables = tablesConfig;
+  }
+
+  public TestDerbyConnector()
+  {
+    this(
+        new MetadataStorageConnectorConfig(),
+        MetadataStorageTablesConfig.fromBase("druidTest" + dbSafeUUID()),
+        CentralizedDatasourceSchemaConfig.create()
+    );
+  }
+
+  public MetadataStorageTablesConfig getMetadataTablesConfig()
+  {
+    return this.dbTables;
   }
 
   public void tearDown()
@@ -86,7 +117,11 @@ public class TestDerbyConnector extends DerbyConnector
     catch (UnableToObtainConnectionException e) {
       SQLException cause = (SQLException) e.getCause();
       // error code "08006" indicates proper shutdown
-      Assert.assertEquals(StringUtils.format("Derby not shutdown: [%s]", cause.toString()), "08006", cause.getSQLState());
+      Assert.assertEquals(
+          StringUtils.format("Derby not shutdown: [%s]", cause.toString()),
+          "08006",
+          cause.getSQLState()
+      );
     }
   }
 
@@ -100,10 +135,15 @@ public class TestDerbyConnector extends DerbyConnector
     return jdbcUri;
   }
 
+  public void createDatabase()
+  {
+    this.getDBI().open().close();
+  }
+
   public static class DerbyConnectorRule extends ExternalResource
   {
     private TestDerbyConnector connector;
-    private final Supplier<MetadataStorageTablesConfig> dbTables;
+    private final MetadataStorageTablesConfig tablesConfig;
     private final MetadataStorageConnectorConfig connectorConfig;
     private final CentralizedDatasourceSchemaConfig centralizedDatasourceSchemaConfig;
 
@@ -114,22 +154,28 @@ public class TestDerbyConnector extends DerbyConnector
 
     public DerbyConnectorRule(CentralizedDatasourceSchemaConfig centralizedDatasourceSchemaConfig)
     {
-      this(Suppliers.ofInstance(MetadataStorageTablesConfig.fromBase("druidTest" + dbSafeUUID())), centralizedDatasourceSchemaConfig);
+      this(
+          MetadataStorageTablesConfig.fromBase("druidTest" + dbSafeUUID()),
+          centralizedDatasourceSchemaConfig
+      );
     }
 
     private DerbyConnectorRule(
         final String defaultBase
     )
     {
-      this(Suppliers.ofInstance(MetadataStorageTablesConfig.fromBase(defaultBase)), CentralizedDatasourceSchemaConfig.create());
+      this(
+          MetadataStorageTablesConfig.fromBase(defaultBase),
+          CentralizedDatasourceSchemaConfig.create()
+      );
     }
 
     public DerbyConnectorRule(
-        Supplier<MetadataStorageTablesConfig> dbTables,
+        MetadataStorageTablesConfig tablesConfig,
         CentralizedDatasourceSchemaConfig centralizedDatasourceSchemaConfig
     )
     {
-      this.dbTables = dbTables;
+      this.tablesConfig = tablesConfig;
       this.connectorConfig = new MetadataStorageConnectorConfig()
       {
         @Override
@@ -142,14 +188,18 @@ public class TestDerbyConnector extends DerbyConnector
     }
 
     @Override
-    protected void before()
+    public void before()
     {
-      connector = new TestDerbyConnector(Suppliers.ofInstance(connectorConfig), dbTables, centralizedDatasourceSchemaConfig);
-      connector.getDBI().open().close(); // create db
+      connector = new TestDerbyConnector(
+          connectorConfig,
+          tablesConfig,
+          centralizedDatasourceSchemaConfig
+      );
+      connector.createDatabase(); // create db
     }
 
     @Override
-    protected void after()
+    public void after()
     {
       connector.tearDown();
     }
@@ -166,7 +216,7 @@ public class TestDerbyConnector extends DerbyConnector
 
     public Supplier<MetadataStorageTablesConfig> metadataTablesConfigSupplier()
     {
-      return dbTables;
+      return Suppliers.ofInstance(tablesConfig);
     }
 
     public SegmentsTable segments()
@@ -259,7 +309,7 @@ public class TestDerbyConnector extends DerbyConnector
      * Updates the segments table with the supplied SQL query format and arguments.
      *
      * @param sqlFormat the SQL query format with %s placeholder for the table name and ? for each query {@code args}
-     * @param args the arguments to be substituted into the SQL query
+     * @param args      the arguments to be substituted into the SQL query
      * @return the number of rows affected by the update operation
      */
     public int update(String sqlFormat, Object... args)
@@ -284,9 +334,9 @@ public class TestDerbyConnector extends DerbyConnector
     public String getTableName()
     {
       return this.rule.metadataTablesConfigSupplier()
-                 .get()
-                 .getSegmentsTable()
-                 .toUpperCase(Locale.ENGLISH);
+                      .get()
+                      .getSegmentsTable()
+                      .toUpperCase(Locale.ENGLISH);
     }
   }
 
