@@ -58,7 +58,8 @@ public class CoordinatorBasedSegmentHandoffNotifierTest
     CoordinatorBasedSegmentHandoffNotifier notifier = new CoordinatorBasedSegmentHandoffNotifier(
         "test_ds",
         coordinatorClient,
-        notifierConfig
+        notifierConfig,
+        "test_task"
     );
     final AtomicBoolean callbackCalled = new AtomicBoolean(false);
     notifier.registerSegmentHandoffCallback(
@@ -89,7 +90,8 @@ public class CoordinatorBasedSegmentHandoffNotifierTest
     CoordinatorBasedSegmentHandoffNotifier notifier = new CoordinatorBasedSegmentHandoffNotifier(
         "test_ds",
         coordinatorClient,
-        notifierConfig
+        notifierConfig,
+        "test_task"
     );
 
     notifier.registerSegmentHandoffCallback(
