@@ -19,7 +19,11 @@
 
 package org.apache.druid.segment.metadata;
 
+import com.google.common.collect.Iterables;
 import com.google.common.collect.Lists;
+import com.google.inject.Guice;
+import com.google.inject.Module;
+import com.google.inject.util.Modules;
 import org.apache.druid.client.CachingClusteredClientTest.ServerExpectation;
 import org.apache.druid.client.CachingClusteredClientTest.ServerExpectations;
 import org.apache.druid.client.CoordinatorSegmentWatcherConfig;
@@ -31,21 +35,21 @@ import org.apache.druid.client.ServerInventoryView;
 import org.apache.druid.guice.http.DruidHttpClientConfig;
 import org.apache.druid.java.util.common.Intervals;
 import org.apache.druid.java.util.common.Pair;
-import org.apache.druid.java.util.common.guava.Sequence;
 import org.apache.druid.java.util.common.guava.Sequences;
-import org.apache.druid.java.util.common.guava.Yielder;
-import org.apache.druid.java.util.common.guava.Yielders;
 import org.apache.druid.java.util.emitter.service.ServiceEmitter;
 import org.apache.druid.query.DataSource;
 import org.apache.druid.query.QueryContexts;
 import org.apache.druid.query.QueryPlus;
 import org.apache.druid.query.QueryRunner;
+import org.apache.druid.query.QueryRunnerFactoryConglomerate;
+import org.apache.druid.query.RestrictedDataSource;
 import org.apache.druid.query.SegmentDescriptor;
 import org.apache.druid.query.TableDataSource;
 import org.apache.druid.query.context.ResponseContext;
 import org.apache.druid.query.metadata.metadata.AllColumnIncluderator;
 import org.apache.druid.query.metadata.metadata.SegmentAnalysis;
 import org.apache.druid.query.metadata.metadata.SegmentMetadataQuery;
+import org.apache.druid.query.policy.NoRestrictionPolicy;
 import org.apache.druid.query.spec.MultipleSpecificSegmentSpec;
 import org.apache.druid.server.QueryStackTests;
 import org.apache.druid.server.coordination.ServerType;
@@ -71,7 +75,6 @@ import java.util.Collections;
 import java.util.Comparator;
 import java.util.EnumSet;
 import java.util.HashMap;
-import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Random;
@@ -81,17 +84,19 @@ import java.util.stream.Collectors;
 public class SegmentMetadataQuerySegmentWalkerTest
 {
   private final String DATASOURCE = "testDatasource";
-  private DruidHttpClientConfig httpClientConfig;
   private DruidServer[] servers;
   private Random random;
 
+  private TestCoordinatorServerView testCoordinatorServerView;
+  private Module module;
+
   @ClassRule
   public static QueryStackTests.Junit4ConglomerateRule conglomerateRule = new QueryStackTests.Junit4ConglomerateRule();
 
   @Before
   public void setUp()
   {
-    httpClientConfig = new DruidHttpClientConfig()
+    DruidHttpClientConfig httpClientConfig = new DruidHttpClientConfig()
     {
       @Override
       public long getMaxQueuedBytes()
@@ -99,7 +104,6 @@ public class SegmentMetadataQuerySegmentWalkerTest
         return 0L;
       }
     };
-
     servers =
         new DruidServer[]{
             new DruidServer("test1", "test1", null, 10, ServerType.HISTORICAL, "bye", 0),
@@ -108,95 +112,127 @@ public class SegmentMetadataQuerySegmentWalkerTest
         };
 
     random = new Random(0);
+    module = Modules.combine(
+        binder -> binder.bind(CoordinatorServerView.class).toInstance(testCoordinatorServerView),
+        binder -> binder.bind(DruidHttpClientConfig.class).toInstance(httpClientConfig),
+        binder -> binder.bind(QueryRunnerFactoryConglomerate.class).toInstance(conglomerateRule.getConglomerate()),
+        binder -> binder.bind(ServerConfig.class).toInstance(new ServerConfig()),
+        binder -> binder.bind(ServiceEmitter.class).toInstance(new NoopServiceEmitter())
+    );
   }
 
   @Test
   public void testWalker() throws IOException
   {
-    Map<DataSource, VersionedIntervalTimeline<String, SegmentLoadInfo>> timelines = new HashMap<>();
+    Map<String, VersionedIntervalTimeline<String, SegmentLoadInfo>> timelines = new HashMap<>();
     Map<String, QueryRunner> queryRunnerMap = new HashMap<>();
-
     Map<String, ServerExpectations> serverExpectationsMap =
         populateTimeline(
             timelines,
             queryRunnerMap,
             Lists.newArrayList(
                 Pair.of(Intervals.of("2011-01-01/2011-01-02"), Lists.newArrayList(0, 4, 5)),
-                Pair.of(Intervals.of("2011-01-05/2011-01-07"), Lists.newArrayList(0, 1, 1)))
+                Pair.of(Intervals.of("2011-01-05/2011-01-07"), Lists.newArrayList(0, 1, 1))
+            )
         );
+    testCoordinatorServerView = new TestCoordinatorServerView(timelines, queryRunnerMap);
 
     List<SegmentDescriptor> segmentDescriptors =
         serverExpectationsMap.values()
                              .stream()
                              .flatMap(serverExpectations -> Lists.newArrayList(serverExpectations.iterator()).stream())
-                             .map(
-                                 ServerExpectation::getSegment)
+                             .map(ServerExpectation::getSegment)
                              .map(segment -> segment.getId().toDescriptor())
-                             .collect(
-                                 Collectors.toList());
-
+                             .collect(Collectors.toList());
     SegmentMetadataQuery segmentMetadataQuery = new SegmentMetadataQuery(
         new TableDataSource(DATASOURCE),
-        new MultipleSpecificSegmentSpec(
-            segmentDescriptors
-        ),
+        new MultipleSpecificSegmentSpec(segmentDescriptors),
         new AllColumnIncluderator(),
         false,
-        QueryContexts.override(
-            Collections.emptyMap(),
-            QueryContexts.BROKER_PARALLEL_MERGE_KEY,
-            false
-        ),
+        QueryContexts.override(Collections.emptyMap(), QueryContexts.BROKER_PARALLEL_MERGE_KEY, false),
         EnumSet.noneOf(SegmentMetadataQuery.AnalysisType.class),
         false,
         null,
         null
     );
 
-    SegmentMetadataQuerySegmentWalker walker = new SegmentMetadataQuerySegmentWalker(
-        new TestCoordinatorServerView(timelines, queryRunnerMap),
-        httpClientConfig,
-        conglomerateRule.getConglomerate(),
-        new ServerConfig(),
-        new NoopServiceEmitter()
-    );
+    SegmentMetadataQuerySegmentWalker walker = Guice.createInjector(module)
+                                                    .getInstance(SegmentMetadataQuerySegmentWalker.class);
+    Set<String> actualSegmentIds = walker.getQueryRunnerForSegments(segmentMetadataQuery, segmentDescriptors)
+                                         .run(QueryPlus.wrap(segmentMetadataQuery))
+                                         .toList()
+                                         .stream()
+                                         .map(SegmentAnalysis::getId)
+                                         .collect(Collectors.toSet());
 
-    Sequence<SegmentAnalysis> resultSequence = walker.getQueryRunnerForSegments(
-        segmentMetadataQuery,
-        segmentDescriptors
-    ).run(QueryPlus.wrap(segmentMetadataQuery));
+    Set<String> expectedSegmentIds = serverExpectationsMap.values()
+                                                          .stream()
+                                                          .flatMap(serverExpectations -> Lists.newArrayList(
+                                                              serverExpectations.iterator()).stream())
+                                                          .map(ServerExpectation::getSegment)
+                                                          .map(segment -> segment.getId().toString())
+                                                          .collect(Collectors.toSet());
+    Assert.assertEquals(expectedSegmentIds, actualSegmentIds);
+  }
 
+  @Test
+  public void testWalkerWithRestriction() throws IOException
+  {
+    Map<String, VersionedIntervalTimeline<String, SegmentLoadInfo>> timelines = new HashMap<>();
+    Map<String, QueryRunner> queryRunnerMap = new HashMap<>();
+    Map<String, ServerExpectations> serverExpectationsMap =
+        populateTimeline(
+            timelines,
+            queryRunnerMap,
+            Lists.newArrayList(
+                Pair.of(Intervals.of("2011-01-01/2011-01-02"), Lists.newArrayList(0, 4, 5)),
+                Pair.of(Intervals.of("2011-01-05/2011-01-07"), Lists.newArrayList(0, 1, 1))
+            )
+        );
+    testCoordinatorServerView = new TestCoordinatorServerView(timelines, queryRunnerMap);
 
-    Yielder<SegmentAnalysis> yielder = Yielders.each(resultSequence);
-    Set<String> actualSegmentIds = new HashSet<>();
-    try {
-      while (!yielder.isDone()) {
-        final SegmentAnalysis analysis = yielder.get();
-        actualSegmentIds.add(analysis.getId());
-        yielder = yielder.next(null);
-      }
-    }
-    finally {
-      yielder.close();
-    }
-
-    Set<String> expectedSegmentIds =
+    List<SegmentDescriptor> segmentDescriptors =
         serverExpectationsMap.values()
                              .stream()
-                             .flatMap(serverExpectations -> Lists.newArrayList(
-                                 serverExpectations.iterator()).stream())
-                             .map(
-                                 ServerExpectation::getSegment)
-                             .map(segment -> segment.getId().toString())
-                             .collect(
-                                 Collectors.toSet());
+                             .flatMap(serverExpectations -> Lists.newArrayList(serverExpectations.iterator()).stream())
+                             .map(ServerExpectation::getSegment)
+                             .map(segment -> segment.getId().toDescriptor())
+                             .collect(Collectors.toList());
+    SegmentMetadataQuery segmentMetadataQuery = new SegmentMetadataQuery(
+        RestrictedDataSource.create(new TableDataSource(DATASOURCE), NoRestrictionPolicy.instance()),
+        new MultipleSpecificSegmentSpec(segmentDescriptors),
+        new AllColumnIncluderator(),
+        false,
+        QueryContexts.override(Collections.emptyMap(), QueryContexts.BROKER_PARALLEL_MERGE_KEY, false),
+        EnumSet.noneOf(SegmentMetadataQuery.AnalysisType.class),
+        false,
+        null,
+        null
+    );
+
+    SegmentMetadataQuerySegmentWalker walker = Guice.createInjector(module)
+                                                    .getInstance(SegmentMetadataQuerySegmentWalker.class);
+    Set<String> actualSegmentIds = walker.getQueryRunnerForSegments(segmentMetadataQuery, segmentDescriptors)
+                                         .run(QueryPlus.wrap(segmentMetadataQuery))
+                                         .toList()
+                                         .stream()
+                                         .map(SegmentAnalysis::getId)
+                                         .collect(Collectors.toSet());
+
+    Set<String> expectedSegmentIds = serverExpectationsMap.values()
+                                                          .stream()
+                                                          .flatMap(serverExpectations -> Lists.newArrayList(
+                                                              serverExpectations.iterator()).stream())
+                                                          .map(ServerExpectation::getSegment)
+                                                          .map(segment -> segment.getId().toString())
+                                                          .collect(Collectors.toSet());
     Assert.assertEquals(expectedSegmentIds, actualSegmentIds);
   }
 
   @Test
   public void testQueryAppendedSegments() throws IOException
   {
-    Map<DataSource, VersionedIntervalTimeline<String, SegmentLoadInfo>> timelines = new HashMap<>();
+    Map<String, VersionedIntervalTimeline<String, SegmentLoadInfo>> timelines = new HashMap<>();
     Map<String, QueryRunner> queryRunnerMap = new HashMap<>();
 
     // populate the core partition set
@@ -209,6 +245,7 @@ public class SegmentMetadataQuerySegmentWalkerTest
     );
 
     queryRunnerMap.clear();
+    testCoordinatorServerView = new TestCoordinatorServerView(timelines, queryRunnerMap);
 
     // append 2 new segments
     Map<String, ServerExpectations> serverExpectationsMap =
@@ -224,77 +261,50 @@ public class SegmentMetadataQuerySegmentWalkerTest
         serverExpectationsMap.values()
                              .stream()
                              .flatMap(serverExpectations -> Lists.newArrayList(serverExpectations.iterator()).stream())
-                             .map(
-                                 ServerExpectation::getSegment)
+                             .map(ServerExpectation::getSegment)
                              .map(segment -> segment.getId().toDescriptor())
-                             .collect(
-                                 Collectors.toList());
+                             .collect(Collectors.toList());
 
     SegmentMetadataQuery segmentMetadataQuery = new SegmentMetadataQuery(
         new TableDataSource(DATASOURCE),
-        new MultipleSpecificSegmentSpec(
-            segmentDescriptors
-        ),
+        new MultipleSpecificSegmentSpec(segmentDescriptors),
         new AllColumnIncluderator(),
         false,
-        QueryContexts.override(
-            Collections.emptyMap(),
-            QueryContexts.BROKER_PARALLEL_MERGE_KEY,
-            false
-        ),
+        QueryContexts.override(Collections.emptyMap(), QueryContexts.BROKER_PARALLEL_MERGE_KEY, false),
         EnumSet.noneOf(SegmentMetadataQuery.AnalysisType.class),
         false,
         null,
         null
     );
 
-    SegmentMetadataQuerySegmentWalker walker = new SegmentMetadataQuerySegmentWalker(
-        new TestCoordinatorServerView(timelines, queryRunnerMap),
-        httpClientConfig,
-        conglomerateRule.getConglomerate(),
-        new ServerConfig(),
-        new NoopServiceEmitter()
-    );
-
-    Sequence<SegmentAnalysis> resultSequence = walker.getQueryRunnerForSegments(
-        segmentMetadataQuery,
-        segmentDescriptors
-    ).run(QueryPlus.wrap(segmentMetadataQuery));
-
-    Yielder<SegmentAnalysis> yielder = Yielders.each(resultSequence);
-    Set<String> actualSegmentIds = new HashSet<>();
-    try {
-      while (!yielder.isDone()) {
-        final SegmentAnalysis analysis = yielder.get();
-        actualSegmentIds.add(analysis.getId());
-        yielder = yielder.next(null);
-      }
-    }
-    finally {
-      yielder.close();
-    }
+    SegmentMetadataQuerySegmentWalker walker = Guice.createInjector(module)
+                                                    .getInstance(SegmentMetadataQuerySegmentWalker.class);
+    Set<String> actualSegmentIds = walker.getQueryRunnerForSegments(segmentMetadataQuery, segmentDescriptors)
+                                         .run(QueryPlus.wrap(segmentMetadataQuery))
+                                         .toList()
+                                         .stream()
+                                         .map(SegmentAnalysis::getId)
+                                         .collect(Collectors.toSet());
 
     Set<String> expectedSegmentIds =
         serverExpectationsMap.values()
                              .stream()
                              .flatMap(serverExpectations -> Lists.newArrayList(
                                  serverExpectations.iterator()).stream())
-                             .map(
-                                 ServerExpectation::getSegment)
+                             .map(ServerExpectation::getSegment)
                              .map(segment -> segment.getId().toString())
-                             .collect(
-                                 Collectors.toSet());
+                             .collect(Collectors.toSet());
     Assert.assertEquals(expectedSegmentIds, actualSegmentIds);
   }
 
   private Map<String, ServerExpectations> populateTimeline(
-      final Map<DataSource, VersionedIntervalTimeline<String, SegmentLoadInfo>> timelines,
+      final Map<String, VersionedIntervalTimeline<String, SegmentLoadInfo>> timelines,
       final Map<String, QueryRunner> queryRunnerMap,
       final List<Pair<Interval, List<Integer>>> intervalAndChunks
   )
   {
     VersionedIntervalTimeline<String, SegmentLoadInfo> timeline = new VersionedIntervalTimeline<>(Comparator.naturalOrder());
-    timelines.put(new TableDataSource(DATASOURCE), timeline);
+    timelines.put(DATASOURCE, timeline);
 
     Map<String, ServerExpectations> serverExpectationsMap = new HashMap<>();
 
@@ -350,9 +360,12 @@ public class SegmentMetadataQuerySegmentWalkerTest
         segmentLoadInfo.addServer(server.getMetadata());
         serverExpectationsMap.get(server.getName()).addExpectation(expectation);
 
-        queryRunnerMap.computeIfAbsent(server.getName(), v -> serverExpectationsMap.get(server.getName()).getQueryRunner());
+        queryRunnerMap.computeIfAbsent(
+            server.getName(),
+            v -> serverExpectationsMap.get(server.getName()).getQueryRunner()
+        );
         timeline.add(interval, "0", shardSpec.createChunk(segmentLoadInfo));
-        timelines.put(new TableDataSource(DATASOURCE), timeline);
+        timelines.put(DATASOURCE, timeline);
       }
     }
 
@@ -376,17 +389,17 @@ public class SegmentMetadataQuerySegmentWalkerTest
       SegmentAnalysis mockSegmentAnalysis = EasyMock.mock(SegmentAnalysis.class);
       EasyMock.expect(mockSegmentAnalysis.getId()).andReturn(serverExpectation.getSegmentId().toString()).anyTimes();
       EasyMock.expect(mockSegmentAnalysis.compareTo(EasyMock.isA(SegmentAnalysis.class)))
-          .andAnswer(new IAnswer<>()
-          {
-            @Override
-            public Integer answer()
-            {
-              SegmentAnalysis otherSegment = (SegmentAnalysis) EasyMock.getCurrentArguments()[0];
-              String thisId = mockSegmentAnalysis.getId();
-              String otherId = otherSegment.getId();
-              return thisId.compareTo(otherId);
-            }
-          }).anyTimes();
+              .andAnswer(new IAnswer<>()
+              {
+                @Override
+                public Integer answer()
+                {
+                  SegmentAnalysis otherSegment = (SegmentAnalysis) EasyMock.getCurrentArguments()[0];
+                  String thisId = mockSegmentAnalysis.getId();
+                  String otherId = otherSegment.getId();
+                  return thisId.compareTo(otherId);
+                }
+              }).anyTimes();
       EasyMock.replay(mockSegmentAnalysis);
       segmentAnalyses.add(mockSegmentAnalysis);
     }
@@ -396,11 +409,11 @@ public class SegmentMetadataQuerySegmentWalkerTest
 
   private static class TestCoordinatorServerView extends CoordinatorServerView
   {
-    private final Map<DataSource, VersionedIntervalTimeline<String, SegmentLoadInfo>> timelines;
+    private final Map<String, VersionedIntervalTimeline<String, SegmentLoadInfo>> timelines;
     private final Map<String, QueryRunner> queryRunnerMap;
 
     public TestCoordinatorServerView(
-        final Map<DataSource, VersionedIntervalTimeline<String, SegmentLoadInfo>> timelines,
+        final Map<String, VersionedIntervalTimeline<String, SegmentLoadInfo>> timelines,
         final Map<String, QueryRunner> queryRunnerMap
     )
     {
@@ -423,7 +436,7 @@ public class SegmentMetadataQuerySegmentWalkerTest
     @Override
     public VersionedIntervalTimeline<String, SegmentLoadInfo> getTimeline(DataSource dataSource)
     {
-      return timelines.get(dataSource);
+      return timelines.get(Iterables.getOnlyElement(dataSource.getTableNames()));
     }
   }
 }
