@@ -38,10 +38,10 @@ import org.apache.druid.java.util.common.guava.Sequences;
 import org.apache.druid.query.aggregation.CountAggregatorFactory;
 import org.apache.druid.segment.RowAdapters;
 import org.apache.druid.segment.RowBasedSegment;
+import org.apache.druid.segment.SegmentMapFunction;
 import org.apache.druid.segment.column.ColumnType;
 import org.apache.druid.segment.column.RowSignature;
 import org.apache.druid.segment.incremental.IncrementalIndex;
-import org.apache.druid.segment.incremental.IndexSizeExceededException;
 import org.apache.druid.segment.indexing.DataSchema;
 import org.apache.druid.segment.indexing.TuningConfig;
 import org.apache.druid.segment.realtime.FireHydrant;
@@ -62,7 +62,6 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.List;
 import java.util.Map;
-import java.util.function.Function;
 
 /**
  *
@@ -93,8 +92,7 @@ public class SinkTest extends InitializedNullHandlingTest
         version,
         TuningConfig.DEFAULT_APPENDABLE_INDEX,
         MAX_ROWS_IN_MEMORY,
-        TuningConfig.DEFAULT_APPENDABLE_INDEX.getDefaultMaxBytesInMemory(),
-        true
+        TuningConfig.DEFAULT_APPENDABLE_INDEX.getDefaultMaxBytesInMemory()
     );
 
     sink.add(
@@ -141,8 +139,7 @@ public class SinkTest extends InitializedNullHandlingTest
           {
             return 0;
           }
-        },
-        false
+        }
     );
 
     FireHydrant currHydrant = sink.getCurrHydrant();
@@ -195,8 +192,7 @@ public class SinkTest extends InitializedNullHandlingTest
           {
             return 0;
           }
-        },
-        false
+        }
     );
 
     Assert.assertEquals(currHydrant, swapHydrant);
@@ -211,7 +207,7 @@ public class SinkTest extends InitializedNullHandlingTest
   {
     Assert.assertEquals(
         Collections.emptyList(),
-        Sink.acquireSegmentReferences(Collections.emptyList(), Function.identity(), false)
+        Sink.acquireSegmentReferences(Collections.emptyList(), SegmentMapFunction.IDENTITY, false)
     );
   }
 
@@ -219,7 +215,7 @@ public class SinkTest extends InitializedNullHandlingTest
   public void testAcquireSegmentReferences_two() throws IOException
   {
     final List<FireHydrant> hydrants = twoHydrants();
-    final List<SinkSegmentReference> references = Sink.acquireSegmentReferences(hydrants, Function.identity(), false);
+    final List<SinkSegmentReference> references = Sink.acquireSegmentReferences(hydrants, SegmentMapFunction.IDENTITY, false);
     Assert.assertNotNull(references);
     Assert.assertEquals(2, references.size());
     Assert.assertEquals(0, references.get(0).getHydrantNumber());
@@ -233,7 +229,7 @@ public class SinkTest extends InitializedNullHandlingTest
   public void testAcquireSegmentReferences_two_skipIncremental() throws IOException
   {
     final List<FireHydrant> hydrants = twoHydrants();
-    final List<SinkSegmentReference> references = Sink.acquireSegmentReferences(hydrants, Function.identity(), true);
+    final List<SinkSegmentReference> references = Sink.acquireSegmentReferences(hydrants, SegmentMapFunction.IDENTITY, true);
     Assert.assertNotNull(references);
     Assert.assertEquals(1, references.size());
     Assert.assertEquals(1, references.get(0).getHydrantNumber());
@@ -248,12 +244,12 @@ public class SinkTest extends InitializedNullHandlingTest
     final List<FireHydrant> hydrants = twoHydrants();
     hydrants.get(1).swapSegment(null);
 
-    final List<SinkSegmentReference> references = Sink.acquireSegmentReferences(hydrants, Function.identity(), false);
+    final List<SinkSegmentReference> references = Sink.acquireSegmentReferences(hydrants, SegmentMapFunction.IDENTITY, false);
     Assert.assertNull(references);
   }
 
   @Test
-  public void testGetSinkSignature() throws IndexSizeExceededException
+  public void testGetSinkSignature()
   {
     final DataSchema schema =
         DataSchema.builder()
@@ -276,15 +272,16 @@ public class SinkTest extends InitializedNullHandlingTest
         version,
         TuningConfig.DEFAULT_APPENDABLE_INDEX,
         MAX_ROWS_IN_MEMORY,
-        TuningConfig.DEFAULT_APPENDABLE_INDEX.getDefaultMaxBytesInMemory(),
-        true
+        TuningConfig.DEFAULT_APPENDABLE_INDEX.getDefaultMaxBytesInMemory()
     );
 
-    sink.add(new MapBasedInputRow(
-        DateTimes.of("2013-01-01"),
-        ImmutableList.of("dim1", "dimLong"),
-        ImmutableMap.of("dim1", "value1", "dimLong", "20")
-    ), false);
+    sink.add(
+        new MapBasedInputRow(
+            DateTimes.of("2013-01-01"),
+            ImmutableList.of("dim1", "dimLong"),
+            ImmutableMap.of("dim1", "value1", "dimLong", "20")
+        )
+    );
 
     Map<String, ColumnType> expectedColumnTypeMap = Maps.newLinkedHashMap();
     expectedColumnTypeMap.put("__time", ColumnType.LONG);
@@ -295,11 +292,13 @@ public class SinkTest extends InitializedNullHandlingTest
     RowSignature signature = sink.getSignature();
     Assert.assertEquals(toRowSignature(expectedColumnTypeMap), signature);
 
-    sink.add(new MapBasedInputRow(
-        DateTimes.of("2013-01-01"),
-        ImmutableList.of("dim1", "dimLong", "newCol1"),
-        ImmutableMap.of("dim1", "value2", "dimLong", "30", "newCol1", "value")
-    ), false);
+    sink.add(
+        new MapBasedInputRow(
+            DateTimes.of("2013-01-01"),
+            ImmutableList.of("dim1", "dimLong", "newCol1"),
+            ImmutableMap.of("dim1", "value2", "dimLong", "30", "newCol1", "value")
+        )
+    );
 
     expectedColumnTypeMap.remove("rows");
     expectedColumnTypeMap.put("newCol1", ColumnType.STRING);
@@ -309,32 +308,38 @@ public class SinkTest extends InitializedNullHandlingTest
 
     sink.swap();
 
-    sink.add(new MapBasedInputRow(
-        DateTimes.of("2013-01-01"),
-        ImmutableList.of("dim1", "dimLong", "newCol2"),
-        ImmutableMap.of("dim1", "value3", "dimLong", "30", "newCol2", "value")
-    ), false);
+    sink.add(
+        new MapBasedInputRow(
+            DateTimes.of("2013-01-01"),
+            ImmutableList.of("dim1", "dimLong", "newCol2"),
+            ImmutableMap.of("dim1", "value3", "dimLong", "30", "newCol2", "value")
+        )
+    );
 
     expectedColumnTypeMap.put("newCol2", ColumnType.STRING);
     signature = sink.getSignature();
     Assert.assertEquals(toRowSignature(expectedColumnTypeMap), signature);
 
-    sink.add(new MapBasedInputRow(
-        DateTimes.of("2013-01-01"),
-        ImmutableList.of("dim1", "dimLong", "newCol3"),
-        ImmutableMap.of("dim1", "value3", "dimLong", "30", "newCol3", "value")
-    ), false);
+    sink.add(
+        new MapBasedInputRow(
+            DateTimes.of("2013-01-01"),
+            ImmutableList.of("dim1", "dimLong", "newCol3"),
+            ImmutableMap.of("dim1", "value3", "dimLong", "30", "newCol3", "value")
+        )
+    );
 
     expectedColumnTypeMap.put("newCol3", ColumnType.STRING);
     signature = sink.getSignature();
     Assert.assertEquals(toRowSignature(expectedColumnTypeMap), signature);
     sink.swap();
 
-    sink.add(new MapBasedInputRow(
-        DateTimes.of("2013-01-01"),
-        ImmutableList.of("dim1", "dimLong", "newCol4"),
-        ImmutableMap.of("dim1", "value3", "dimLong", "30", "newCol4", "value")
-    ), false);
+    sink.add(
+        new MapBasedInputRow(
+            DateTimes.of("2013-01-01"),
+            ImmutableList.of("dim1", "dimLong", "newCol4"),
+            ImmutableMap.of("dim1", "value3", "dimLong", "30", "newCol4", "value")
+        )
+    );
 
     expectedColumnTypeMap.put("newCol4", ColumnType.STRING);
     signature = sink.getSignature();
@@ -362,7 +367,6 @@ public class SinkTest extends InitializedNullHandlingTest
         new FireHydrant(EasyMock.createMock(IncrementalIndex.class), 0, segmentId),
         new FireHydrant(
             new RowBasedSegment<>(
-                segmentId,
                 Sequences.empty(),
                 RowAdapters.standardRow(),
                 RowSignature.empty()
