@@ -742,7 +742,7 @@ public class NewestSegmentFirstPolicyTest
   public void testIteratorReturnsNothingAsSegmentsWasCompactedAndHaveSameSegmentGranularityAndSameTimezone()
   {
     // Same indexSpec as what is set in the auto compaction config
-    IndexSpec indexSpec = IndexSpec.DEFAULT;
+    IndexSpec indexSpec = IndexSpec.getDefault();
     // Same partitionsSpec as what is set in the auto compaction config
     PartitionsSpec partitionsSpec = CompactionStatus.findPartitionsSpecFromConfig(ClientCompactionTaskQueryTuningConfig.from(
         null));
@@ -771,7 +771,7 @@ public class NewestSegmentFirstPolicyTest
   public void testIteratorReturnsNothingAsSegmentsWasCompactedAndHaveSameSegmentGranularityInLastCompactionState()
   {
     // Same indexSpec as what is set in the auto compaction config
-    IndexSpec indexSpec = IndexSpec.DEFAULT;
+    IndexSpec indexSpec = IndexSpec.getDefault();
     // Same partitionsSpec as what is set in the auto compaction config
     PartitionsSpec partitionsSpec = CompactionStatus.findPartitionsSpecFromConfig(ClientCompactionTaskQueryTuningConfig.from(
         null));
@@ -807,7 +807,7 @@ public class NewestSegmentFirstPolicyTest
   public void testIteratorReturnsSegmentsAsSegmentsWasCompactedAndHaveDifferentSegmentGranularity()
   {
     // Same indexSpec as what is set in the auto compaction config
-    IndexSpec indexSpec = IndexSpec.DEFAULT;
+    IndexSpec indexSpec = IndexSpec.getDefault();
     // Same partitionsSpec as what is set in the auto compaction config
     PartitionsSpec partitionsSpec = CompactionStatus.findPartitionsSpecFromConfig(ClientCompactionTaskQueryTuningConfig.from(
         null));
@@ -855,7 +855,7 @@ public class NewestSegmentFirstPolicyTest
   public void testIteratorReturnsSegmentsAsSegmentsWasCompactedAndHaveDifferentSegmentGranularityInLastCompactionState()
   {
     // Same indexSpec as what is set in the auto compaction config
-    IndexSpec indexSpec = IndexSpec.DEFAULT;
+    IndexSpec indexSpec = IndexSpec.getDefault();
     // Same partitionsSpec as what is set in the auto compaction config
     PartitionsSpec partitionsSpec = CompactionStatus.findPartitionsSpecFromConfig(ClientCompactionTaskQueryTuningConfig.from(
         null));
@@ -904,7 +904,7 @@ public class NewestSegmentFirstPolicyTest
   public void testIteratorReturnsSegmentsAsSegmentsWasCompactedAndHaveDifferentTimezone()
   {
     // Same indexSpec as what is set in the auto compaction config
-    IndexSpec indexSpec = IndexSpec.DEFAULT;
+    IndexSpec indexSpec = IndexSpec.getDefault();
     // Same partitionsSpec as what is set in the auto compaction config
     PartitionsSpec partitionsSpec = CompactionStatus.findPartitionsSpecFromConfig(ClientCompactionTaskQueryTuningConfig.from(
         null));
@@ -954,7 +954,7 @@ public class NewestSegmentFirstPolicyTest
   public void testIteratorReturnsSegmentsAsSegmentsWasCompactedAndHaveDifferentOrigin()
   {
     // Same indexSpec as what is set in the auto compaction config
-    IndexSpec indexSpec = IndexSpec.DEFAULT;
+    IndexSpec indexSpec = IndexSpec.getDefault();
     // Same partitionsSpec as what is set in the auto compaction config
     PartitionsSpec partitionsSpec = CompactionStatus.findPartitionsSpecFromConfig(ClientCompactionTaskQueryTuningConfig.from(
         null));
@@ -1003,7 +1003,7 @@ public class NewestSegmentFirstPolicyTest
   public void testIteratorReturnsSegmentsAsSegmentsWasCompactedAndHaveDifferentRollup()
   {
     // Same indexSpec as what is set in the auto compaction config
-    IndexSpec indexSpec = IndexSpec.DEFAULT;
+    IndexSpec indexSpec = IndexSpec.getDefault();
     // Same partitionsSpec as what is set in the auto compaction config
     PartitionsSpec partitionsSpec = CompactionStatus.findPartitionsSpecFromConfig(ClientCompactionTaskQueryTuningConfig.from(
         null));
@@ -1092,7 +1092,7 @@ public class NewestSegmentFirstPolicyTest
   public void testIteratorReturnsSegmentsAsSegmentsWasCompactedAndHaveDifferentQueryGranularity()
   {
     // Same indexSpec as what is set in the auto compaction config
-    IndexSpec indexSpec = IndexSpec.DEFAULT;
+    IndexSpec indexSpec = IndexSpec.getDefault();
     // Same partitionsSpec as what is set in the auto compaction config
     PartitionsSpec partitionsSpec = CompactionStatus.findPartitionsSpecFromConfig(ClientCompactionTaskQueryTuningConfig.from(
         null));
@@ -1187,7 +1187,7 @@ public class NewestSegmentFirstPolicyTest
   public void testIteratorReturnsSegmentsAsSegmentsWasCompactedAndHaveDifferentDimensions()
   {
     // Same indexSpec as what is set in the auto compaction config
-    IndexSpec indexSpec = IndexSpec.DEFAULT;
+    IndexSpec indexSpec = IndexSpec.getDefault();
     // Same partitionsSpec as what is set in the auto compaction config
     PartitionsSpec partitionsSpec = CompactionStatus.findPartitionsSpecFromConfig(ClientCompactionTaskQueryTuningConfig.from(
         null));
@@ -1306,7 +1306,7 @@ public class NewestSegmentFirstPolicyTest
   public void testIteratorDoesNotReturnsSegmentsWhenPartitionDimensionsPrefixed()
   {
     // Same indexSpec as what is set in the auto compaction config
-    IndexSpec indexSpec = IndexSpec.DEFAULT;
+    IndexSpec indexSpec = IndexSpec.getDefault();
     // Set range partitions spec with dimensions ["dim2", "dim4"] -- the same as what is set in the auto compaction config
     PartitionsSpec partitionsSpec = new DimensionRangePartitionsSpec(
         null,
@@ -1377,7 +1377,7 @@ public class NewestSegmentFirstPolicyTest
                                1000L,
                                null,
                                partitionsSpec,
-                               IndexSpec.DEFAULT,
+                               IndexSpec.getDefault(),
                                null,
                                null,
                                null,
@@ -1416,7 +1416,7 @@ public class NewestSegmentFirstPolicyTest
   public void testIteratorReturnsSegmentsAsSegmentsWasCompactedAndHaveDifferentFilter() throws Exception
   {
     // Same indexSpec as what is set in the auto compaction config
-    IndexSpec indexSpec = IndexSpec.DEFAULT;
+    IndexSpec indexSpec = IndexSpec.getDefault();
     // Same partitionsSpec as what is set in the auto compaction config
     PartitionsSpec partitionsSpec = CompactionStatus.findPartitionsSpecFromConfig(ClientCompactionTaskQueryTuningConfig.from(
         null));
@@ -1538,7 +1538,7 @@ public class NewestSegmentFirstPolicyTest
             .addValue(ExprMacroTable.class.getName(), TestExprMacroTable.INSTANCE)
     );
     // Same indexSpec as what is set in the auto compaction config
-    IndexSpec indexSpec = IndexSpec.DEFAULT;
+    IndexSpec indexSpec = IndexSpec.getDefault();
     // Same partitionsSpec as what is set in the auto compaction config
     PartitionsSpec partitionsSpec = CompactionStatus.findPartitionsSpecFromConfig(ClientCompactionTaskQueryTuningConfig.from(
         null));
@@ -1746,7 +1746,7 @@ public class NewestSegmentFirstPolicyTest
             .startingAt("2017-10-01")
             .withNumPartitions(4)
             .withCompactionState(
-                new CompactionState(partitionsSpec, null, null, null, IndexSpec.DEFAULT, null, null)
+                new CompactionState(partitionsSpec, null, null, null, IndexSpec.getDefault(), null, null)
             )
     );
 
@@ -1759,7 +1759,7 @@ public class NewestSegmentFirstPolicyTest
                 1000L,
                 null,
                 partitionsSpec,
-                IndexSpec.DEFAULT,
+                IndexSpec.getDefault(),
                 null,
                 null,
                 null,
@@ -1787,7 +1787,7 @@ public class NewestSegmentFirstPolicyTest
                 1000L,
                 null,
                 partitionsSpec,
-                IndexSpec.DEFAULT,
+                IndexSpec.getDefault(),
                 null,
                 null,
                 null,
