@@ -38,11 +38,12 @@ import org.apache.druid.java.util.emitter.EmittingLogger;
 import org.apache.druid.java.util.http.client.HttpClient;
 import org.apache.druid.java.util.metrics.MetricsVerifier;
 import org.apache.druid.java.util.metrics.StubServiceEmitter;
-import org.apache.druid.metadata.SegmentsMetadataManager;
+import org.apache.druid.metadata.segment.cache.NoopSegmentMetadataCache;
 import org.apache.druid.rpc.indexing.NoopOverlordClient;
 import org.apache.druid.rpc.indexing.SegmentUpdateResponse;
 import org.apache.druid.segment.metadata.CentralizedDatasourceSchemaConfig;
 import org.apache.druid.server.compaction.CompactionStatusTracker;
+import org.apache.druid.server.coordinator.CloneStatusManager;
 import org.apache.druid.server.coordinator.CoordinatorConfigManager;
 import org.apache.druid.server.coordinator.CoordinatorDynamicConfig;
 import org.apache.druid.server.coordinator.DruidCompactionConfig;
@@ -63,6 +64,7 @@ import org.apache.druid.server.coordinator.duty.CoordinatorCustomDutyGroups;
 import org.apache.druid.server.coordinator.loading.LoadQueueTaskMaster;
 import org.apache.druid.server.coordinator.loading.SegmentLoadQueueManager;
 import org.apache.druid.server.coordinator.rules.Rule;
+import org.apache.druid.server.http.CoordinatorDynamicConfigSyncer;
 import org.apache.druid.server.http.SegmentsToUpdateFilter;
 import org.apache.druid.server.lookup.cache.LookupCoordinatorManager;
 import org.apache.druid.timeline.DataSegment;
@@ -82,6 +84,7 @@ import java.util.concurrent.ExecutorService;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
+import java.util.stream.Collectors;
 
 /**
  * Builder for {@link CoordinatorSimulation}.
@@ -210,7 +213,7 @@ public class CoordinatorSimulationBuilder
         env.coordinatorInventoryView,
         env.serviceEmitter,
         env.executorFactory,
-        new SimOverlordClient(env.metadataManager.segments()),
+        new SimOverlordClient(env.segmentManager),
         env.loadQueueTaskMaster,
         env.loadQueueManager,
         new ServiceAnnouncer.Noop(),
@@ -220,7 +223,9 @@ public class CoordinatorSimulationBuilder
         env.leaderSelector,
         null,
         CentralizedDatasourceSchemaConfig.create(),
-        new CompactionStatusTracker(OBJECT_MAPPER)
+        new CompactionStatusTracker(OBJECT_MAPPER),
+        env.configSyncer,
+        env.cloneStatusManager
     );
 
     return new SimulationImpl(coordinator, env);
@@ -323,8 +328,19 @@ public class CoordinatorSimulationBuilder
       return env.coordinatorInventoryView.getInventoryValue(serverName);
     }
 
+    @Override
+    public void loadQueuedSegmentsSkipCallbacks()
+    {
+      loadSegments(false);
+    }
+
     @Override
     public void loadQueuedSegments()
+    {
+      loadSegments(true);
+    }
+
+    private void loadSegments(boolean executeCallbacks)
     {
       verifySimulationRunning();
       Preconditions.checkState(
@@ -333,7 +349,9 @@ public class CoordinatorSimulationBuilder
       );
 
       final BlockingExecutorService loadQueueExecutor = env.executorFactory.loadQueueExecutor;
-      while (loadQueueExecutor.hasPendingTasks()) {
+      final BlockingExecutorService loadCallbackExecutor = env.executorFactory.loadCallbackExecutor;
+      while (loadQueueExecutor.hasPendingTasks()
+             || (executeCallbacks && loadCallbackExecutor.hasPendingTasks())) {
         // Drain all the items from the load queue executor
         // This sends at most 1 load/drop request to each server
         loadQueueExecutor.finishAllPendingTasks();
@@ -341,7 +359,9 @@ public class CoordinatorSimulationBuilder
         // Load all the queued segments, handle their responses and execute callbacks
         int loadedSegments = env.executorFactory.historicalLoader.finishAllPendingTasks();
         loadQueueExecutor.finishNextPendingTasks(loadedSegments);
-        env.executorFactory.loadCallbackExecutor.finishAllPendingTasks();
+        if (executeCallbacks) {
+          env.executorFactory.loadCallbackExecutor.finishAllPendingTasks();
+        }
       }
     }
 
@@ -365,6 +385,16 @@ public class CoordinatorSimulationBuilder
       }
     }
 
+    @Override
+    public void deleteSegments(List<DataSegment> segments)
+    {
+      if (segments != null) {
+        env.segmentManager.markSegmentsAsUnused(
+            segments.stream().map(DataSegment::getId).collect(Collectors.toSet())
+        );
+      }
+    }
+
     private void verifySimulationRunning()
     {
       if (!running.get()) {
@@ -420,6 +450,8 @@ public class CoordinatorSimulationBuilder
     private final MetadataManager metadataManager;
     private final LookupCoordinatorManager lookupCoordinatorManager;
     private final DruidCoordinatorConfig coordinatorConfig;
+    private final CoordinatorDynamicConfigSyncer configSyncer;
+    private final CloneStatusManager cloneStatusManager;
 
     private final boolean loadImmediately;
     private final boolean autoSyncInventory;
@@ -481,8 +513,15 @@ public class CoordinatorSimulationBuilder
           null,
           ruleManager,
           null,
-          null
+          null,
+          NoopSegmentMetadataCache.instance()
       );
+
+      this.configSyncer = EasyMock.niceMock(CoordinatorDynamicConfigSyncer.class);
+      this.cloneStatusManager = EasyMock.niceMock(CloneStatusManager.class);
+
+      mocks.add(configSyncer);
+      mocks.add(cloneStatusManager);
     }
 
     private void setUp() throws Exception
@@ -624,9 +663,9 @@ public class CoordinatorSimulationBuilder
 
   private static class SimOverlordClient extends NoopOverlordClient
   {
-    private final SegmentsMetadataManager segmentsMetadataManager;
+    private final TestSegmentsMetadataManager segmentsMetadataManager;
 
-    private SimOverlordClient(SegmentsMetadataManager segmentsMetadataManager)
+    private SimOverlordClient(TestSegmentsMetadataManager segmentsMetadataManager)
     {
       this.segmentsMetadataManager = segmentsMetadataManager;
     }
