@@ -123,74 +123,19 @@ public class JettyTest extends BaseJettyTest
       File trustStore = new File(JettyTest.class.getClassLoader().getResource("truststore.jks").getFile());
       Path tmpTrustStore = Files.copy(trustStore.toPath(), new File(folder.newFolder(), "truststore.jks").toPath());
       PasswordProvider pp = () -> "druid123";
-      tlsConfig = new TLSServerConfig()
-      {
-        @Override
-        public String getKeyStorePath()
-        {
-          return tmpKeyStore.toString();
-        }
-
-        @Override
-        public String getKeyStoreType()
-        {
-          return "jks";
-        }
-
-        @Override
-        public PasswordProvider getKeyStorePasswordProvider()
-        {
-          return pp;
-        }
-
-        @Override
-        public PasswordProvider getKeyManagerPasswordProvider()
-        {
-          return pp;
-        }
-
-        @Override
-        public String getTrustStorePath()
-        {
-          return tmpTrustStore.toString();
-        }
-
-        @Override
-        public String getTrustStoreAlgorithm()
-        {
-          return "PKIX";
-        }
-
-        @Override
-        public PasswordProvider getTrustStorePasswordProvider()
-        {
-          return pp;
-        }
-
-        @Override
-        public String getCertAlias()
-        {
-          return "druid";
-        }
-
-        @Override
-        public boolean isRequireClientCertificate()
-        {
-          return false;
-        }
-
-        @Override
-        public boolean isRequestClientCertificate()
-        {
-          return false;
-        }
-
-        @Override
-        public boolean isValidateHostnames()
-        {
-          return false;
-        }
-      };
+      tlsConfig = TLSServerConfig.builder()
+          .keyStorePath(tmpKeyStore.toString())
+          .keyStoreType("jks")
+          .keyStorePasswordProvider(pp)
+          .keyManagerPasswordProvider(pp)
+          .trustStorePath(tmpTrustStore.toString())
+          .trustStoreAlgorithm("PKIX")
+          .trustStorePasswordProvider(pp)
+          .certAlias("druid")
+          .requireClientCertificate(false)
+          .requestClientCertificate(false)
+          .validateHostnames(false)
+          .build();
 
       sslConfig =
           HttpClientConfig.builder()
@@ -563,13 +508,6 @@ public class JettyTest extends BaseJettyTest
     Assert.assertTrue(endpointIdentificationAlgorithm == null || endpointIdentificationAlgorithm.isEmpty());
   }
 
-  @Test
-  public void testJettyErrorHandlerWithFilter()
-  {
-    // Response filter is disabled by default hence we show servlet information
-    Assert.assertTrue(server.getErrorHandler().isShowServlet());
-  }
-
   private void waitForJettyServerModuleActiveConnectionsZero(JettyServerModule jsm) throws InterruptedException
   {
     // it can take a bit to close the connection, so maybe sleep for a while and hope it closes
