@@ -19,9 +19,6 @@
 
 package org.apache.druid.server.initialization;
 
-import org.junit.Assert;
-import org.junit.Test;
-
 public class JettyWithResponseFilterEnabledTest extends JettyTest
 {
   @Override
@@ -31,12 +28,4 @@ public class JettyWithResponseFilterEnabledTest extends JettyTest
     super.setProperties();
     System.setProperty("druid.server.http.showDetailedJettyErrors", "false");
   }
-
-  @Test
-  @Override
-  public void testJettyErrorHandlerWithFilter()
-  {
-    // Response filter is enabled by config hence we do not show servlet information
-    Assert.assertFalse(server.getErrorHandler().isShowServlet());
-  }
 }
