@@ -32,28 +32,27 @@ import com.google.inject.Module;
 import com.google.inject.Provider;
 import com.google.inject.Provides;
 import com.google.inject.TypeLiteral;
-import com.google.inject.multibindings.MapBinder;
 import com.google.inject.name.Names;
 import com.google.inject.util.Providers;
 import org.apache.druid.client.CoordinatorSegmentWatcherConfig;
 import org.apache.druid.client.CoordinatorServerView;
 import org.apache.druid.client.DirectDruidClientFactory;
 import org.apache.druid.client.HttpServerInventoryViewResource;
-import org.apache.druid.client.InternalQueryConfig;
 import org.apache.druid.client.coordinator.Coordinator;
 import org.apache.druid.discovery.DruidLeaderSelector;
 import org.apache.druid.discovery.NodeRole;
-import org.apache.druid.guice.DruidBinders;
 import org.apache.druid.guice.Jerseys;
 import org.apache.druid.guice.JsonConfigProvider;
 import org.apache.druid.guice.JsonConfigurator;
 import org.apache.druid.guice.LazySingleton;
 import org.apache.druid.guice.LifecycleModule;
 import org.apache.druid.guice.ManageLifecycle;
+import org.apache.druid.guice.MetadataConfigModule;
+import org.apache.druid.guice.MetadataManagerModule;
 import org.apache.druid.guice.QueryableModule;
+import org.apache.druid.guice.SegmentSchemaCacheModule;
 import org.apache.druid.guice.SupervisorCleanupModule;
 import org.apache.druid.guice.annotations.EscalatedGlobal;
-import org.apache.druid.guice.annotations.Global;
 import org.apache.druid.guice.http.JettyHttpClientModule;
 import org.apache.druid.java.util.common.IAE;
 import org.apache.druid.java.util.common.ISE;
@@ -64,41 +63,18 @@ import org.apache.druid.java.util.common.concurrent.ScheduledExecutorFactory;
 import org.apache.druid.java.util.common.lifecycle.Lifecycle;
 import org.apache.druid.java.util.common.logger.Logger;
 import org.apache.druid.java.util.http.client.HttpClient;
-import org.apache.druid.metadata.MetadataRuleManager;
-import org.apache.druid.metadata.MetadataRuleManagerConfig;
-import org.apache.druid.metadata.MetadataRuleManagerProvider;
 import org.apache.druid.metadata.MetadataStorage;
 import org.apache.druid.metadata.MetadataStorageProvider;
-import org.apache.druid.metadata.SegmentsMetadataManager;
-import org.apache.druid.metadata.SegmentsMetadataManagerConfig;
-import org.apache.druid.metadata.SegmentsMetadataManagerProvider;
-import org.apache.druid.query.DefaultGenericQueryMetricsFactory;
-import org.apache.druid.query.DefaultQueryConfig;
-import org.apache.druid.query.GenericQueryMetricsFactory;
-import org.apache.druid.query.MapQueryToolChestWarehouse;
-import org.apache.druid.query.Query;
-import org.apache.druid.query.QueryRunnerFactory;
-import org.apache.druid.query.QuerySegmentWalker;
-import org.apache.druid.query.QueryToolChest;
-import org.apache.druid.query.QueryToolChestWarehouse;
-import org.apache.druid.query.QueryWatcher;
-import org.apache.druid.query.RetryQueryRunnerConfig;
+import org.apache.druid.msq.guice.MSQDurableStorageModule;
+import org.apache.druid.msq.guice.MSQExternalDataSourceModule;
+import org.apache.druid.msq.guice.MSQIndexingModule;
 import org.apache.druid.query.lookup.LookupSerdeModule;
-import org.apache.druid.query.metadata.SegmentMetadataQueryConfig;
-import org.apache.druid.query.metadata.SegmentMetadataQueryQueryToolChest;
-import org.apache.druid.query.metadata.SegmentMetadataQueryRunnerFactory;
-import org.apache.druid.query.metadata.metadata.SegmentMetadataQuery;
-import org.apache.druid.segment.metadata.CentralizedDatasourceSchemaConfig;
 import org.apache.druid.segment.metadata.CoordinatorSegmentMetadataCache;
 import org.apache.druid.segment.metadata.SegmentMetadataCacheConfig;
-import org.apache.druid.segment.metadata.SegmentMetadataQuerySegmentWalker;
-import org.apache.druid.segment.metadata.SegmentSchemaCache;
-import org.apache.druid.server.QueryScheduler;
-import org.apache.druid.server.QuerySchedulerProvider;
 import org.apache.druid.server.compaction.CompactionStatusTracker;
+import org.apache.druid.server.coordinator.CloneStatusManager;
 import org.apache.druid.server.coordinator.CoordinatorConfigManager;
 import org.apache.druid.server.coordinator.DruidCoordinator;
-import org.apache.druid.server.coordinator.MetadataManager;
 import org.apache.druid.server.coordinator.balancer.BalancerStrategyFactory;
 import org.apache.druid.server.coordinator.config.CoordinatorKillConfigs;
 import org.apache.druid.server.coordinator.config.CoordinatorPeriodConfig;
@@ -112,6 +88,7 @@ import org.apache.druid.server.coordinator.loading.LoadQueueTaskMaster;
 import org.apache.druid.server.http.ClusterResource;
 import org.apache.druid.server.http.CoordinatorCompactionConfigsResource;
 import org.apache.druid.server.http.CoordinatorCompactionResource;
+import org.apache.druid.server.http.CoordinatorDynamicConfigSyncer;
 import org.apache.druid.server.http.CoordinatorDynamicConfigsResource;
 import org.apache.druid.server.http.CoordinatorRedirectInfo;
 import org.apache.druid.server.http.CoordinatorResource;
@@ -156,7 +133,7 @@ public class CliCoordinator extends ServerRunnable
   private static final String AS_OVERLORD_PROPERTY = "druid.coordinator.asOverlord.enabled";
   private Properties properties;
   private boolean beOverlord;
-  private boolean isSegmentMetadataCacheEnabled;
+  private boolean isSegmentSchemaCacheEnabled;
 
   public CliCoordinator()
   {
@@ -168,7 +145,7 @@ public class CliCoordinator extends ServerRunnable
   {
     this.properties = properties;
     beOverlord = isOverlord(properties);
-    isSegmentMetadataCacheEnabled = isSegmentMetadataCacheEnabled(properties);
+    isSegmentSchemaCacheEnabled = MetadataConfigModule.isSegmentSchemaCacheEnabled(properties);
 
     if (beOverlord) {
       log.info("Coordinator is configured to act as Overlord as well (%s = true).", AS_OVERLORD_PROPERTY);
@@ -190,10 +167,11 @@ public class CliCoordinator extends ServerRunnable
     List<Module> modules = new ArrayList<>();
 
     modules.add(JettyHttpClientModule.global());
+    modules.add(new MetadataManagerModule());
 
-    if (isSegmentMetadataCacheEnabled) {
+    if (isSegmentSchemaCacheEnabled) {
       validateCentralizedDatasourceSchemaConfig(properties);
-      modules.add(new CoordinatorSegmentMetadataCacheModule());
+      modules.add(new SegmentSchemaCacheModule());
       modules.add(new QueryableModule());
     }
 
@@ -211,8 +189,6 @@ public class CliCoordinator extends ServerRunnable
 
             binder.bind(MetadataStorage.class).toProvider(MetadataStorageProvider.class);
 
-            JsonConfigProvider.bind(binder, SegmentsMetadataManagerConfig.CONFIG_PREFIX, SegmentsMetadataManagerConfig.class);
-            JsonConfigProvider.bind(binder, "druid.manager.rules", MetadataRuleManagerConfig.class);
             JsonConfigProvider.bind(binder, "druid.manager.lookups", LookupCoordinatorManagerConfig.class);
             JsonConfigProvider.bind(binder, "druid.coordinator", CoordinatorRunConfig.class);
             JsonConfigProvider.bind(binder, "druid.coordinator.kill", CoordinatorKillConfigs.class);
@@ -224,6 +200,7 @@ public class CliCoordinator extends ServerRunnable
             binder.bind(DruidCoordinatorConfig.class);
 
             binder.bind(RedirectFilter.class).in(LazySingleton.class);
+            binder.bind(CoordinatorDynamicConfigSyncer.class).in(ManageLifecycle.class);
             if (beOverlord) {
               binder.bind(RedirectInfo.class).to(CoordinatorOverlordRedirectInfo.class).in(LazySingleton.class);
             } else {
@@ -232,23 +209,14 @@ public class CliCoordinator extends ServerRunnable
 
             LifecycleModule.register(binder, CoordinatorServerView.class);
 
-            if (!isSegmentMetadataCacheEnabled) {
+            if (!isSegmentSchemaCacheEnabled) {
               binder.bind(CoordinatorSegmentMetadataCache.class).toProvider(Providers.of(null));
               binder.bind(DirectDruidClientFactory.class).toProvider(Providers.of(null));
             }
 
-            binder.bind(SegmentsMetadataManager.class)
-                  .toProvider(SegmentsMetadataManagerProvider.class)
-                  .in(ManageLifecycle.class);
-
-            binder.bind(MetadataRuleManager.class)
-                  .toProvider(MetadataRuleManagerProvider.class)
-                  .in(ManageLifecycle.class);
-
             binder.bind(LookupCoordinatorManager.class).in(LazySingleton.class);
+            binder.bind(CloneStatusManager.class).in(LazySingleton.class);
 
-            binder.bind(CoordinatorConfigManager.class);
-            binder.bind(MetadataManager.class);
             binder.bind(DruidCoordinator.class);
             binder.bind(CompactionStatusTracker.class).in(LazySingleton.class);
 
@@ -333,6 +301,9 @@ public class CliCoordinator extends ServerRunnable
       // the injector to get confused due to having multiple bindings for the same classes.
       modules.add(new LookupSerdeModule());
       modules.add(new SupervisorCleanupModule());
+      modules.add(new MSQIndexingModule());
+      modules.add(new MSQDurableStorageModule());
+      modules.add(new MSQExternalDataSourceModule());
     }
 
     return modules;
@@ -437,46 +408,4 @@ public class CliCoordinator extends ServerRunnable
     }
   }
 
-  private static class CoordinatorSegmentMetadataCacheModule implements Module
-  {
-    @Override
-    public void configure(Binder binder)
-    {
-      JsonConfigProvider.bind(binder, "druid.coordinator.segmentMetadata", SegmentMetadataQueryConfig.class);
-      JsonConfigProvider.bind(binder, "druid.coordinator.query.scheduler", QuerySchedulerProvider.class, Global.class);
-      JsonConfigProvider.bind(binder, "druid.coordinator.query.default", DefaultQueryConfig.class);
-      JsonConfigProvider.bind(binder, "druid.coordinator.query.retryPolicy", RetryQueryRunnerConfig.class);
-      JsonConfigProvider.bind(binder, "druid.coordinator.internal.query.config", InternalQueryConfig.class);
-      JsonConfigProvider.bind(binder, CentralizedDatasourceSchemaConfig.PROPERTY_PREFIX, CentralizedDatasourceSchemaConfig.class);
-
-      MapBinder<Class<? extends Query>, QueryToolChest> toolChests = DruidBinders.queryToolChestBinder(binder);
-      toolChests.addBinding(SegmentMetadataQuery.class).to(SegmentMetadataQueryQueryToolChest.class);
-      binder.bind(SegmentMetadataQueryQueryToolChest.class).in(LazySingleton.class);
-      binder.bind(QueryToolChestWarehouse.class).to(MapQueryToolChestWarehouse.class);
-
-      final MapBinder<Class<? extends Query>, QueryRunnerFactory> queryFactoryBinder =
-          DruidBinders.queryRunnerFactoryBinder(binder);
-      queryFactoryBinder.addBinding(SegmentMetadataQuery.class).to(SegmentMetadataQueryRunnerFactory.class);
-      DruidBinders.queryBinder(binder);
-      binder.bind(SegmentMetadataQueryRunnerFactory.class).in(LazySingleton.class);
-
-      binder.bind(GenericQueryMetricsFactory.class).to(DefaultGenericQueryMetricsFactory.class);
-
-      binder.bind(QueryScheduler.class)
-            .toProvider(Key.get(QuerySchedulerProvider.class, Global.class))
-            .in(LazySingleton.class);
-      binder.bind(QuerySchedulerProvider.class).in(LazySingleton.class);
-      binder.bind(SegmentSchemaCache.class).in(LazySingleton.class);
-      binder.bind(QuerySegmentWalker.class).to(SegmentMetadataQuerySegmentWalker.class).in(LazySingleton.class);
-
-      LifecycleModule.register(binder, CoordinatorSegmentMetadataCache.class);
-    }
-
-    @LazySingleton
-    @Provides
-    public QueryWatcher getWatcher(QueryScheduler scheduler)
-    {
-      return scheduler;
-    }
-  }
 }
