@@ -35,14 +35,13 @@ import org.apache.druid.server.security.AuthConfig;
 import org.apache.druid.server.security.AuthenticationUtils;
 import org.apache.druid.server.security.Authenticator;
 import org.apache.druid.server.security.AuthenticatorMapper;
+import org.eclipse.jetty.ee8.servlet.DefaultServlet;
+import org.eclipse.jetty.ee8.servlet.FilterHolder;
+import org.eclipse.jetty.ee8.servlet.ServletContextHandler;
+import org.eclipse.jetty.ee8.servlet.ServletHolder;
 import org.eclipse.jetty.rewrite.handler.RewriteHandler;
 import org.eclipse.jetty.server.Handler;
 import org.eclipse.jetty.server.Server;
-import org.eclipse.jetty.server.handler.HandlerList;
-import org.eclipse.jetty.servlet.DefaultServlet;
-import org.eclipse.jetty.servlet.FilterHolder;
-import org.eclipse.jetty.servlet.ServletContextHandler;
-import org.eclipse.jetty.servlet.ServletHolder;
 
 import java.util.List;
 import java.util.Properties;
@@ -136,17 +135,13 @@ class CoordinatorJettyServerInitializer implements JettyServerInitializer
     RewriteHandler rewriteHandler = WebConsoleJettyServerInitializer.createWebConsoleRewriteHandler();
     JettyServerInitUtils.maybeAddHSTSPatternRule(serverConfig, rewriteHandler);
 
-    HandlerList handlerList = new HandlerList();
-    handlerList.setHandlers(
-        new Handler[]{
-            rewriteHandler,
-            JettyServerInitUtils.getJettyRequestLogHandler(),
-            JettyServerInitUtils.wrapWithDefaultGzipHandler(
-                root,
-                serverConfig.getInflateBufferSize(),
-                serverConfig.getCompressionLevel()
-            )
-        }
+    Handler.Sequence handlerList = new Handler.Sequence(
+        rewriteHandler,
+        JettyServerInitUtils.wrapWithDefaultGzipHandler(
+            root,
+            serverConfig.getInflateBufferSize(),
+            serverConfig.getCompressionLevel()
+        )
     );
 
     server.setHandler(handlerList);
