@@ -156,7 +156,7 @@ public class DruidJsonValidatorTest
                 null,
                 null,
                 new DynamicPartitionsSpec(10000, null),
-                IndexSpec.DEFAULT,
+                IndexSpec.getDefault(),
                 null,
                 3,
                 false,
