@@ -286,17 +286,28 @@ public class EmbeddedClusterApis implements EmbeddedResource
    */
   public void waitForAllSegmentsToBeAvailable(String dataSource, EmbeddedCoordinator coordinator, EmbeddedBroker broker)
   {
-    final int numSegments = coordinator
+    final Set<DataSegment> segments = coordinator
         .bindings()
         .segmentsMetadataStorage()
-        .retrieveAllUsedSegments(dataSource, Segments.INCLUDING_OVERSHADOWED)
-        .size();
+        .retrieveAllUsedSegments(dataSource, Segments.INCLUDING_OVERSHADOWED);
 
-    broker.latchableEmitter().waitForEventAggregate(
-        event -> event.hasMetricName("segment/schemaCache/refresh/count")
-                      .hasDimension(DruidMetrics.DATASOURCE, dataSource),
-        agg -> agg.hasSumAtLeast(numSegments)
-    );
+    final int numTombstones = (int) segments.stream().filter(DataSegment::isTombstone).count();
+    final int numSegments = segments.size() - numTombstones;
+
+    if (numSegments > 0) {
+      broker.latchableEmitter().waitForEventAggregate(
+          event -> event.hasMetricName("segment/schemaCache/refresh/count")
+                        .hasDimension(DruidMetrics.DATASOURCE, dataSource),
+          agg -> agg.hasSumAtLeast(numSegments)
+      );
+    }
+    if (numTombstones > 0) {
+      broker.latchableEmitter().waitForEventAggregate(
+          event -> event.hasMetricName("segment/schemaCache/refresh/tombstone/count")
+                        .hasDimension(DruidMetrics.DATASOURCE, dataSource),
+          agg -> agg.hasSumAtLeast(numTombstones)
+      );
+    }
   }
 
   /**
