@@ -22,8 +22,6 @@ package org.apache.druid.sql.calcite.aggregation.builtin;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.Iterables;
 import org.apache.calcite.rel.core.AggregateCall;
-import org.apache.calcite.rel.core.Project;
-import org.apache.calcite.rex.RexBuilder;
 import org.apache.calcite.rex.RexNode;
 import org.apache.calcite.sql.SqlAggFunction;
 import org.apache.calcite.sql.fun.SqlStdOperatorTable;
@@ -32,16 +30,14 @@ import org.apache.druid.math.expr.ExprMacroTable;
 import org.apache.druid.query.aggregation.AggregatorFactory;
 import org.apache.druid.query.aggregation.post.ArithmeticPostAggregator;
 import org.apache.druid.query.aggregation.post.FieldAccessPostAggregator;
-import org.apache.druid.segment.VirtualColumn;
-import org.apache.druid.segment.column.RowSignature;
-import org.apache.druid.segment.column.ValueType;
+import org.apache.druid.segment.column.ColumnType;
 import org.apache.druid.sql.calcite.aggregation.Aggregation;
 import org.apache.druid.sql.calcite.aggregation.Aggregations;
 import org.apache.druid.sql.calcite.aggregation.SqlAggregator;
 import org.apache.druid.sql.calcite.expression.DruidExpression;
-import org.apache.druid.sql.calcite.expression.Expressions;
 import org.apache.druid.sql.calcite.planner.Calcites;
 import org.apache.druid.sql.calcite.planner.PlannerContext;
+import org.apache.druid.sql.calcite.rel.InputAccessor;
 import org.apache.druid.sql.calcite.rel.VirtualColumnRegistry;
 
 import javax.annotation.Nullable;
@@ -59,12 +55,10 @@ public class AvgSqlAggregator implements SqlAggregator
   @Override
   public Aggregation toDruidAggregation(
       final PlannerContext plannerContext,
-      final RowSignature rowSignature,
       final VirtualColumnRegistry virtualColumnRegistry,
-      final RexBuilder rexBuilder,
       final String name,
       final AggregateCall aggregateCall,
-      final Project project,
+      final InputAccessor inputAccessor,
       final List<Aggregation> existingAggregations,
       final boolean finalizeAggregations
   )
@@ -72,9 +66,8 @@ public class AvgSqlAggregator implements SqlAggregator
 
     final List<DruidExpression> arguments = Aggregations.getArgumentsForSimpleAggregator(
         plannerContext,
-        rowSignature,
         aggregateCall,
-        project
+        inputAccessor
     );
 
     if (arguments == null) {
@@ -85,47 +78,39 @@ public class AvgSqlAggregator implements SqlAggregator
     final AggregatorFactory count = CountSqlAggregator.createCountAggregatorFactory(
         countName,
         plannerContext,
-        rowSignature,
+        inputAccessor.getInputRowSignature(),
         virtualColumnRegistry,
-        rexBuilder,
+        inputAccessor.getRexBuilder(),
         aggregateCall,
-        project
+        inputAccessor
     );
 
-    final String fieldName;
-    final String expression;
     final DruidExpression arg = Iterables.getOnlyElement(arguments);
 
-
-    final ExprMacroTable macroTable = plannerContext.getExprMacroTable();
-    final ValueType sumType;
+    final ExprMacroTable macroTable = plannerContext.getPlannerToolbox().exprMacroTable();
+    final ColumnType sumType;
     // Use 64-bit sum regardless of the type of the AVG aggregator.
     if (SqlTypeName.INT_TYPES.contains(aggregateCall.getType().getSqlTypeName())) {
-      sumType = ValueType.LONG;
+      sumType = ColumnType.LONG;
     } else {
-      sumType = ValueType.DOUBLE;
+      sumType = ColumnType.DOUBLE;
     }
 
+    final String fieldName;
+
     if (arg.isDirectColumnAccess()) {
       fieldName = arg.getDirectColumn();
-      expression = null;
     } else {
-      // if the filter or anywhere else defined a virtual column for us, re-use it
-      final RexNode resolutionArg = Expressions.fromFieldAccess(
-          rowSignature,
-          project,
-          Iterables.getOnlyElement(aggregateCall.getArgList())
-      );
-      VirtualColumn vc = virtualColumnRegistry.getVirtualColumnByExpression(arg.getExpression(), resolutionArg.getType());
-      fieldName = vc != null ? vc.getOutputName() : null;
-      expression = vc != null ? null : arg.getExpression();
+      final RexNode resolutionArg = inputAccessor.getField(
+          Iterables.getOnlyElement(aggregateCall.getArgList()));
+      fieldName = virtualColumnRegistry.getOrCreateVirtualColumnForExpression(arg, resolutionArg.getType());
     }
+
     final String sumName = Calcites.makePrefixedName(name, "sum");
     final AggregatorFactory sum = SumSqlAggregator.createSumAggregatorFactory(
         sumType,
         sumName,
         fieldName,
-        expression,
         macroTable
     );
 
