@@ -21,17 +21,21 @@ package org.apache.druid.sql.calcite.expression.builtin;
 
 import org.apache.calcite.sql.SqlFunction;
 import org.apache.calcite.sql.SqlFunctionCategory;
+import org.apache.calcite.sql.SqlOperator;
 import org.apache.calcite.sql.type.OperandTypes;
 import org.apache.calcite.sql.type.SqlTypeFamily;
 import org.apache.calcite.sql.type.SqlTypeName;
+import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.sql.calcite.expression.DirectOperatorConversion;
 import org.apache.druid.sql.calcite.expression.OperatorConversions;
 
 public class StringToArrayOperatorConversion extends DirectOperatorConversion
 {
+  public static final String FUNCTION_NAME = "string_to_array";
+
   // note: since this function produces an array
   private static final SqlFunction SQL_FUNCTION = OperatorConversions
-      .operatorBuilder("STRING_TO_ARRAY")
+      .operatorBuilder(StringUtils.toUpperCase(FUNCTION_NAME))
       .operandTypeChecker(
           OperandTypes.sequence(
               "'STRING_TO_ARRAY(string, expr)'",
@@ -45,6 +49,11 @@ public class StringToArrayOperatorConversion extends DirectOperatorConversion
 
   public StringToArrayOperatorConversion()
   {
-    super(SQL_FUNCTION, "string_to_array");
+    super(SQL_FUNCTION, FUNCTION_NAME);
+  }
+
+  protected StringToArrayOperatorConversion(SqlOperator operator, String druidFunctionName)
+  {
+    super(operator, druidFunctionName);
   }
 }
