@@ -20,7 +20,6 @@
 package org.apache.druid.sql.calcite.planner;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
-import com.google.common.base.Joiner;
 import com.google.common.base.Preconditions;
 import org.apache.calcite.plan.RelOptPlanner;
 import org.apache.calcite.runtime.CalciteContextException;
@@ -28,8 +27,6 @@ import org.apache.calcite.schema.SchemaPlus;
 import org.apache.calcite.sql.SqlExplain;
 import org.apache.calcite.sql.SqlKind;
 import org.apache.calcite.sql.SqlNode;
-import org.apache.calcite.sql.parser.SqlParseException;
-import org.apache.calcite.sql.parser.SqlParserPos;
 import org.apache.calcite.tools.FrameworkConfig;
 import org.apache.calcite.tools.ValidationException;
 import org.apache.druid.error.DruidException;
@@ -40,13 +37,10 @@ import org.apache.druid.server.security.Resource;
 import org.apache.druid.server.security.ResourceAction;
 import org.apache.druid.sql.calcite.parser.DruidSqlInsert;
 import org.apache.druid.sql.calcite.parser.DruidSqlReplace;
-import org.apache.druid.sql.calcite.parser.ParseException;
-import org.apache.druid.sql.calcite.parser.Token;
 import org.apache.druid.sql.calcite.run.SqlEngine;
 import org.joda.time.DateTimeZone;
 
 import java.io.Closeable;
-import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.Map;
 import java.util.Set;
@@ -64,9 +58,6 @@ import java.util.function.Function;
  */
 public class DruidPlanner implements Closeable
 {
-  public static final Joiner SPACE_JOINER = Joiner.on(" ");
-  public static final Joiner COMMA_JOINER = Joiner.on(", ");
-
   public enum State
   {
     START, VALIDATED, PREPARED, PLANNED
@@ -136,18 +127,8 @@ public class DruidPlanner implements Closeable
 
     // Validate query context.
     engine.validateContext(plannerContext.queryContextMap());
-
-    // Parse the query string.
-    String sql = plannerContext.getSql();
-    hook.captureSql(sql);
-    SqlNode root;
-    try {
-      root = planner.parse(sql);
-    }
-    catch (SqlParseException e1) {
-      throw translateException(e1);
-    }
-    root = rewriteParameters(root);
+    planner.skipParse();
+    final SqlNode root = rewriteParameters(plannerContext.getSqlNode());
     hook.captureSqlNode(root);
     handler = createHandler(root);
     handler.validate();
@@ -351,59 +332,6 @@ public class DruidPlanner implements Closeable
     catch (ValidationException inner) {
       return parseValidationMessage(inner);
     }
-    catch (SqlParseException inner) {
-      final Throwable cause = inner.getCause();
-      if (cause instanceof DruidException) {
-        return (DruidException) cause;
-      }
-
-      if (cause instanceof ParseException) {
-        ParseException parseException = (ParseException) cause;
-        final SqlParserPos failurePosition = inner.getPos();
-        // When calcite catches a syntax error at the top level
-        // expected token sequences can be null.
-        // In such a case return the syntax error to the user
-        // wrapped in a DruidException with invalid input
-        if (parseException.expectedTokenSequences == null) {
-          return DruidException.forPersona(DruidException.Persona.USER)
-                               .ofCategory(DruidException.Category.INVALID_INPUT)
-                               .withErrorCode("invalidInput")
-                               .build(inner, "%s", inner.getMessage()).withContext("sourceType", "sql");
-        } else {
-          final String theUnexpectedToken = getUnexpectedTokenString(parseException);
-
-          final String[] tokenDictionary = inner.getTokenImages();
-          final int[][] expectedTokenSequences = inner.getExpectedTokenSequences();
-          final ArrayList<String> expectedTokens = new ArrayList<>(expectedTokenSequences.length);
-          for (int[] expectedTokenSequence : expectedTokenSequences) {
-            String[] strings = new String[expectedTokenSequence.length];
-            for (int i = 0; i < expectedTokenSequence.length; ++i) {
-              strings[i] = tokenDictionary[expectedTokenSequence[i]];
-            }
-            expectedTokens.add(SPACE_JOINER.join(strings));
-          }
-
-          return InvalidSqlInput
-              .exception(
-                  inner,
-                  "Received an unexpected token [%s] (line [%s], column [%s]), acceptable options: [%s]",
-                  theUnexpectedToken,
-                  failurePosition.getLineNum(),
-                  failurePosition.getColumnNum(),
-                  COMMA_JOINER.join(expectedTokens)
-              )
-              .withContext("line", failurePosition.getLineNum())
-              .withContext("column", failurePosition.getColumnNum())
-              .withContext("endLine", failurePosition.getEndLineNum())
-              .withContext("endColumn", failurePosition.getEndColumnNum())
-              .withContext("token", theUnexpectedToken)
-              .withContext("expected", expectedTokens);
-
-        }
-      }
-
-      return InvalidSqlInput.exception(inner.getMessage());
-    }
     catch (RelOptPlanner.CannotPlanException inner) {
       return DruidException.forPersona(DruidException.Persona.USER)
                            .ofCategory(DruidException.Category.INVALID_INPUT)
@@ -454,76 +382,4 @@ public class DruidPlanner implements Closeable
                            .build(e, "Uncategorized calcite error message: [%s]", e.getMessage());
     }
   }
-
-  /**
-   * Grabs the unexpected token string.  This code is borrowed with minimal adjustments from
-   * {@link ParseException#getMessage()}.  It is possible that if that code changes, we need to also
-   * change this code to match it.
-   *
-   * @param parseException the parse exception to extract from
-   * @return the String representation of the unexpected token string
-   */
-  private static String getUnexpectedTokenString(ParseException parseException)
-  {
-    int maxSize = 0;
-    for (int[] ints : parseException.expectedTokenSequences) {
-      if (maxSize < ints.length) {
-        maxSize = ints.length;
-      }
-    }
-
-    StringBuilder bob = new StringBuilder();
-    Token tok = parseException.currentToken.next;
-    for (int i = 0; i < maxSize; i++) {
-      if (i != 0) {
-        bob.append(" ");
-      }
-      if (tok.kind == 0) {
-        bob.append("<EOF>");
-        break;
-      }
-      char ch;
-      for (int i1 = 0; i1 < tok.image.length(); i1++) {
-        switch (tok.image.charAt(i1)) {
-          case 0:
-            continue;
-          case '\b':
-            bob.append("\\b");
-            continue;
-          case '\t':
-            bob.append("\\t");
-            continue;
-          case '\n':
-            bob.append("\\n");
-            continue;
-          case '\f':
-            bob.append("\\f");
-            continue;
-          case '\r':
-            bob.append("\\r");
-            continue;
-          case '\"':
-            bob.append("\\\"");
-            continue;
-          case '\'':
-            bob.append("\\\'");
-            continue;
-          case '\\':
-            bob.append("\\\\");
-            continue;
-          default:
-            if ((ch = tok.image.charAt(i1)) < 0x20 || ch > 0x7e) {
-              String s = "0000" + Integer.toString(ch, 16);
-              bob.append("\\u").append(s.substring(s.length() - 4, s.length()));
-            } else {
-              bob.append(ch);
-            }
-            continue;
-        }
-      }
-      tok = tok.next;
-    }
-    return bob.toString();
-  }
-
 }
