@@ -23,8 +23,10 @@ import org.apache.calcite.plan.RelOptRule;
 import org.apache.calcite.plan.RelOptRuleCall;
 import org.apache.calcite.rel.RelNode;
 import org.apache.calcite.rel.core.Union;
+import org.apache.druid.sql.calcite.planner.PlannerContext;
 import org.apache.druid.sql.calcite.rel.DruidRel;
 import org.apache.druid.sql.calcite.rel.DruidUnionRel;
+import org.apache.druid.sql.calcite.run.EngineFeature;
 
 import java.util.List;
 
@@ -33,9 +35,9 @@ import java.util.List;
  */
 public class DruidUnionRule extends RelOptRule
 {
-  private static final DruidUnionRule INSTANCE = new DruidUnionRule();
+  private final PlannerContext plannerContext;
 
-  private DruidUnionRule()
+  public DruidUnionRule(PlannerContext plannerContext)
   {
     super(
         operand(
@@ -44,21 +46,21 @@ public class DruidUnionRule extends RelOptRule
             operand(DruidRel.class, none())
         )
     );
-  }
-
-  public static DruidUnionRule instance()
-  {
-    return INSTANCE;
+    this.plannerContext = plannerContext;
   }
 
   @Override
   public boolean matches(RelOptRuleCall call)
   {
+    if (plannerContext != null && !plannerContext.featureAvailable(EngineFeature.ALLOW_TOP_LEVEL_UNION_ALL)) {
+      plannerContext.setPlanningError("Queries cannot be planned using top level union all");
+      return false;
+    }
     // Make DruidUnionRule and DruidUnionDataSourceRule mutually exclusive.
     final Union unionRel = call.rel(0);
     final DruidRel<?> firstDruidRel = call.rel(1);
     final DruidRel<?> secondDruidRel = call.rel(2);
-    return !DruidUnionDataSourceRule.isCompatible(unionRel, firstDruidRel, secondDruidRel);
+    return !DruidUnionDataSourceRule.isCompatible(unionRel, firstDruidRel, secondDruidRel, null);
   }
 
   @Override
@@ -72,12 +74,14 @@ public class DruidUnionRule extends RelOptRule
     if (unionRel.all) {
       call.transformTo(
           DruidUnionRel.create(
-              someDruidRel.getQueryMaker(),
+              someDruidRel.getPlannerContext(),
               unionRel.getRowType(),
               inputs,
               -1
           )
       );
+    } else {
+      plannerContext.setPlanningError("SQL requires 'UNION' but only 'UNION ALL' is supported.");
     }
   }
 }
