@@ -21,6 +21,7 @@ package org.apache.druid.quidem;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
 import com.google.common.collect.ImmutableList;
+import com.google.inject.Injector;
 import net.hydromatic.quidem.AbstractCommand;
 import net.hydromatic.quidem.Command;
 import net.hydromatic.quidem.CommandHandler;
@@ -33,8 +34,10 @@ import org.apache.calcite.runtime.Hook;
 import org.apache.calcite.sql.SqlExplainFormat;
 import org.apache.calcite.sql.SqlExplainLevel;
 import org.apache.calcite.util.Util;
+import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.query.Query;
 import org.apache.druid.sql.calcite.BaseCalciteQueryTest;
+import org.apache.druid.sql.calcite.SqlTestFrameworkConfig;
 import org.apache.druid.sql.calcite.rel.DruidRel;
 import org.apache.druid.sql.hook.DruidHook;
 import org.apache.druid.sql.hook.DruidHook.HookKey;
@@ -46,6 +49,10 @@ import java.sql.ResultSet;
 import java.sql.Statement;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
+
+import static org.junit.Assume.assumeFalse;
 
 public class DruidQuidemCommandHandler implements CommandHandler
 {
@@ -70,15 +77,18 @@ public class DruidQuidemCommandHandler implements CommandHandler
     if (line.startsWith("msqPlan")) {
       return new MSQPlanCommand(lines, content);
     }
+    if (line.startsWith("disabled")) {
+      return new DisabledCommand(lines, content, line);
+    }
     return null;
   }
 
-  abstract static class AbstractPlanCommand extends AbstractCommand
+  public abstract static class AbstractPlanCommand extends AbstractCommand
   {
     private final List<String> content;
     private final List<String> lines;
 
-    AbstractPlanCommand(List<String> lines, List<String> content)
+    public AbstractPlanCommand(List<String> lines, List<String> content)
     {
       this.lines = ImmutableList.copyOf(lines);
       this.content = content;
@@ -98,6 +108,9 @@ public class DruidQuidemCommandHandler implements CommandHandler
           executeExplain(context);
         }
         catch (Exception e) {
+          // This is packaged as an Error because Quidem grabs anything else and pushes it into the output file
+          // believing that you are wanting to validate the error.  By repackaging it, we get a nice failure in the
+          // runner instead
           throw new Error(e);
         }
       } else {
@@ -110,9 +123,7 @@ public class DruidQuidemCommandHandler implements CommandHandler
     {
       DruidHookDispatcher dhp = unwrapDruidHookDispatcher(context);
       List<T> logged = new ArrayList<>();
-      try (Closeable unhook = dhp.withHook(hook, (key, value) -> {
-        logged.add(value);
-      })) {
+      try (Closeable unhook = dhp.withHook(hook, (key, value) -> logged.add(value))) {
         executeExplainQuery(context);
       }
       return logged;
@@ -160,7 +171,9 @@ public class DruidQuidemCommandHandler implements CommandHandler
     protected abstract void executeExplain(Context context) throws Exception;
   }
 
-  /** Command that prints the plan for the current query. */
+  /**
+   * Command that prints the plan for the current query.
+   */
   static class NativePlanCommand extends AbstractPlanCommand
   {
     NativePlanCommand(List<String> lines, List<String> content)
@@ -304,6 +317,61 @@ public class DruidQuidemCommandHandler implements CommandHandler
     }
   }
 
+  /**
+   * Usage:
+   * <pre>
+   * !disabled StandardComponentSupplier reason for disabling
+   * </pre>
+   */
+  static class DisabledCommand extends AbstractCommand
+  {
+    private String supplierName;
+    private String message;
+    private Pattern DISABLED_PATTERN = Pattern.compile("disabled\\s+([\\w\\d]+)(\\s+([^\\s].+))?\\s*");
+
+    private final List<String> content;
+    private final List<String> lines;
+
+    DisabledCommand(List<String> lines, List<String> content, String line)
+    {
+      super();
+      this.lines = ImmutableList.copyOf(lines);
+      this.content = content;
+      Matcher m = DISABLED_PATTERN.matcher(line);
+      if (!m.matches()) {
+        throw new IllegalArgumentException("usage: !disabled <supplier> [<reason>]");
+      }
+      supplierName = m.group(1);
+      message = buildMessage(supplierName, m.group(3));
+    }
+
+    private static String buildMessage(String supplierName, String message)
+    {
+      return StringUtils.format("Test disabled on supplier [%s]. Reason: [%s]", supplierName, message);
+    }
+
+    @Override
+    public final void execute(Context context, boolean execute)
+    {
+      if (execute) {
+        try {
+          Injector injector = DruidConnectionExtras.unwrapOrThrow(context.connection()).getInjector();
+          SqlTestFrameworkConfig cfg = injector.getInstance(SqlTestFrameworkConfig.class);
+          assumeFalse(message, cfg.componentSupplier.getSimpleName().equals(supplierName));
+        }
+        catch (Exception e) {
+          // This is packaged as an Error because Quidem grabs anything else and pushes it into the output file
+          // believing that you are wanting to validate the error.  By repackaging it, we get a nice failure in the
+          // runner instead
+          throw new Error(e);
+        }
+      } else {
+        context.echo(content);
+      }
+      context.echo(lines);
+    }
+  }
+
   static class ConvertedPlanCommand extends AbstractRelPlanCommand
   {
     ConvertedPlanCommand(List<String> lines, List<String> content)
@@ -311,6 +379,7 @@ public class DruidQuidemCommandHandler implements CommandHandler
       super(lines, content, DruidHook.CONVERTED_PLAN);
     }
   }
+
   static class MSQPlanCommand extends AbstractStringCaptureCommand
   {
     MSQPlanCommand(List<String> lines, List<String> content)
