@@ -84,6 +84,7 @@ import org.apache.druid.server.security.AuthenticationResult;
 import org.apache.druid.server.security.ForbiddenException;
 import org.apache.druid.server.security.ResourceAction;
 import org.apache.druid.sql.SqlStatementFactory;
+import org.apache.druid.sql.calcite.DrillWindowQueryTest.ArrayRowCmp;
 import org.apache.druid.sql.calcite.QueryTestRunner.QueryResults;
 import org.apache.druid.sql.calcite.expression.DruidExpression;
 import org.apache.druid.sql.calcite.planner.Calcites;
@@ -1019,7 +1020,7 @@ public class BaseCalciteQueryTest extends CalciteTestBase
     }
   }
 
-  public void assertResultsValid(final ResultMatchMode matchMode, final List<Object[]> expected, final QueryResults queryResults)
+  public static void assertResultsValid(final ResultMatchMode matchMode, final List<Object[]> expected, final QueryResults queryResults)
   {
     final List<Object[]> results = queryResults.results;
     Assert.assertEquals("Result count mismatch", expected.size(), results.size());
@@ -1388,7 +1389,7 @@ public class BaseCalciteQueryTest extends CalciteTestBase
     return new DefaultResultsVerifier(expectedResults, expectedResultMatchMode, expectedSignature);
   }
 
-  public class DefaultResultsVerifier implements ResultsVerifier
+  public static class DefaultResultsVerifier implements ResultsVerifier
   {
     protected final List<Object[]> expectedResults;
     @Nullable
@@ -1428,7 +1429,22 @@ public class BaseCalciteQueryTest extends CalciteTestBase
         throw e;
       }
     }
+  }
 
+  public static class UnorderedResultsVerifier extends DefaultResultsVerifier
+  {
+    public UnorderedResultsVerifier(List<Object[]> expectedResults, ResultMatchMode expectedResultMatchMode,
+        RowSignature expectedSignature)
+    {
+      super(ImmutableList.sortedCopyOf(new ArrayRowCmp(), expectedResults), expectedResultMatchMode, expectedSignature);
+    }
+
+    @Override
+    public void verify(String sql, QueryResults queryResults)
+    {
+      queryResults.results.sort(new ArrayRowCmp());
+      super.verify(sql, queryResults);
+    }
   }
 
   /**
