@@ -22,8 +22,8 @@ package org.apache.druid.sql.calcite.run;
 import com.fasterxml.jackson.databind.ObjectMapper;
 import com.google.common.collect.ImmutableList;
 import com.google.common.collect.ImmutableSortedSet;
+import nl.jqno.equalsverifier.EqualsVerifier;
 import org.apache.calcite.sql.type.SqlTypeName;
-import org.apache.druid.common.config.NullHandling;
 import org.apache.druid.error.DruidException;
 import org.apache.druid.java.util.common.StringUtils;
 import org.apache.druid.segment.TestHelper;
@@ -42,7 +42,7 @@ import java.util.List;
 
 public class SqlResultsTest extends InitializedNullHandlingTest
 {
-  private static final SqlResults.Context DEFAULT_CONTEXT = new SqlResults.Context(DateTimeZone.UTC, true, false);
+  private static final SqlResults.Context DEFAULT_CONTEXT = new SqlResults.Context(DateTimeZone.UTC, false);
 
   private ObjectMapper jsonMapper;
 
@@ -204,7 +204,7 @@ public class SqlResultsTest extends InitializedNullHandlingTest
   @Test
   public void testCoerceString()
   {
-    assertCoerce(NullHandling.defaultStringValue(), null, SqlTypeName.VARCHAR);
+    assertCoerce(null, null, SqlTypeName.VARCHAR);
     assertCoerce("1", 1, SqlTypeName.VARCHAR);
     assertCoerce("true", true, SqlTypeName.VARCHAR);
     assertCoerce("abc", "abc", SqlTypeName.VARCHAR);
@@ -246,6 +246,12 @@ public class SqlResultsTest extends InitializedNullHandlingTest
     Assert.assertEquals("hello", SqlResults.coerceArrayToList("hello", false));
   }
 
+  @Test
+  public void testContextEqualsAndHashcode()
+  {
+    EqualsVerifier.forClass(SqlResults.Context.class).usingGetClass().verify();
+  }
+
   private void assertCoerce(Object expected, Object toCoerce, SqlTypeName typeName)
   {
     Assert.assertEquals(
