@@ -17,8 +17,7 @@
  */
 
 import { UNIFIED_CONSOLE_URL } from './druid';
-import { createBrowserNormal as createBrowser } from './playwright';
-import { createPage } from './playwright';
+import { createBrowser, createPage } from './playwright';
 
 export async function waitTillWebConsoleReady() {
   const browser = await createBrowser();
@@ -26,8 +25,8 @@ export async function waitTillWebConsoleReady() {
   try {
     const page = await createPage(browser);
     await page.goto(UNIFIED_CONSOLE_URL);
-    await page.waitFor('//*[contains(text(),"console will not function at the moment")]', {
-      visibility: 'hidden',
+    await page.waitForSelector('//*[contains(text(),"console will not function at the moment")]', {
+      state: 'hidden',
     });
   } finally {
     await browser.close();
