@@ -19,110 +19,116 @@
 // Hand picked from https://druid.apache.org/docs/latest/querying/sql.html
 
 export const SQL_KEYWORDS = [
-  'EXPLAIN PLAN FOR',
-  'WITH',
-  'AS',
-  'SELECT',
   'ALL',
-  'DISTINCT',
-  'FROM',
-  'WHERE',
-  'GROUP BY',
-  'CUBE',
-  'ROLLUP',
-  'GROUPING SETS',
-  'HAVING',
-  'ORDER BY',
-  'ASC',
-  'DESC',
-  'LIMIT',
-  'OFFSET',
-  'UNION ALL',
-  'JOIN',
-  'LEFT',
-  'INNER',
-  'ON',
-  'RIGHT',
-  'OUTER',
-  'FULL',
-  'CROSS',
-  'USING',
-  'NATURAL',
-  'FETCH',
-  'FIRST',
-  'NEXT',
-  'ROW',
-  'ROWS',
-  'ONLY',
-  'VALUES',
-  'PARTITIONED BY',
-  'CLUSTERED BY',
-  'TIME',
-  'INSERT INTO',
-  'REPLACE INTO',
-  'MERGE INTO',
-  'OVERWRITE',
-  'RETURNING',
-  'OVER',
-  'PARTITION BY',
-  'WINDOW',
-  'RANGE',
-  'PRECEDING',
-  'FOLLOWING',
-  'CURRENT',
-  'UNBOUNDED',
-  'EXTEND',
-  'PIVOT',
-  'UNPIVOT',
-  'MATCHED',
-  'UPDATE SET',
-];
-
-export const SQL_EXPRESSION_PARTS = [
-  'FILTER',
-  'END',
-  'ELSE',
-  'WHEN',
-  'THEN',
-  'CASE',
-  'OR',
   'AND',
-  'NOT',
-  'IN',
   'ANY',
-  'SOME',
-  'IS',
-  'TO',
+  'AS',
+  'ASC',
   'BETWEEN',
-  'SYMMETRIC',
-  'LIKE',
-  'SIMILAR',
-  'ESCAPE',
   'BOTH',
-  'LEADING',
-  'TRAILING',
-  'EPOCH',
-  'SECOND',
-  'SECONDS',
-  'MINUTE',
-  'MINUTES',
-  'HOUR',
-  'HOURS',
+  'CASE',
+  'CENTURY',
+  'CLUSTERED BY',
+  'CROSS',
+  'CSV',
+  'CUBE',
+  'CURRENT',
   'DAY',
   'DAYS',
+  'DECADE',
+  'DESC',
+  'DISTINCT',
   'DOW',
   'DOY',
-  'WEEK',
-  'WEEKS',
+  'ELSE',
+  'END',
+  'EPOCH',
+  'ESCAPE',
+  'EXPLAIN PLAN FOR',
+  'EXTEND',
+  'FETCH',
+  'FILTER',
+  'FIRST',
+  'FOLLOWING',
+  'FROM',
+  'FULL',
+  'GROUP BY',
+  'GROUPING SETS',
+  'HAVING',
+  'HOUR',
+  'HOURS',
+  'IN',
+  'INNER',
+  'INSERT INTO',
+  'INTERVAL',
+  'IS',
+  'ISODOW',
+  'ISOYEAR',
+  'JOIN',
+  'KEY',
+  'LEADING',
+  'LEFT',
+  'LIKE',
+  'LIMIT',
+  'MATCHED',
+  'MERGE INTO',
+  'MILLENNIUM',
+  'MILLISECOND',
+  'MINUTE',
+  'MINUTES',
   'MONTH',
   'MONTHS',
+  'NATURAL',
+  'NEXT',
+  'NOT',
+  'OFFSET',
+  'ON',
+  'ONLY',
+  'OR',
+  'ORDER BY',
+  'OUTER',
+  'OVER',
+  'OVERWRITE',
+  'PARTITION BY',
+  'PARTITIONED BY',
+  'PIVOT',
+  'PRECEDING',
   'QUARTER',
   'QUARTERS',
+  'RANGE',
+  'REPLACE INTO',
+  'RETURNING',
+  'RIGHT',
+  'ROLLUP',
+  'ROW',
+  'ROWS',
+  'SECOND',
+  'SECONDS',
+  'SELECT',
+  'SET',
+  'SIMILAR',
+  'SOME',
+  'SYMMETRIC',
+  'THEN',
+  'TIME',
+  'TIMESTAMP',
+  'TO',
+  'TRAILING',
+  'UNBOUNDED',
+  'UNION ALL',
+  'UNPIVOT',
+  'UPDATE SET',
+  'USING',
+  'VALUE',
+  'VALUES',
+  'WEEK',
+  'WEEKS',
+  'WHEN',
+  'WHERE',
+  'WINDOW',
+  'WITH',
   'YEAR',
   'YEARS',
-  'TIMESTAMP',
-  'INTERVAL',
-  'CSV',
 ];
 
 export const SQL_CONSTANTS = ['NULL', 'FALSE', 'TRUE'];
