@@ -17,9 +17,8 @@
  */
 
 import type { ButtonProps } from '@blueprintjs/core';
-import { Button, ButtonGroup, Menu, MenuDivider, MenuItem } from '@blueprintjs/core';
+import { Button, ButtonGroup, Menu, MenuDivider, MenuItem, Popover } from '@blueprintjs/core';
 import { IconNames } from '@blueprintjs/icons';
-import { Popover2 } from '@blueprintjs/popover2';
 import classNames from 'classnames';
 import React, { useState } from 'react';
 
@@ -77,7 +76,7 @@ export const TimedButton = React.memo(function TimedButton(props: TimedButtonPro
   return (
     <ButtonGroup className={classNames('timed-button', className)}>
       <Button {...other} text={text} icon={icon} onClick={() => onRefresh(false)} />
-      <Popover2
+      <Popover
         content={
           <Menu>
             <MenuDivider title={label} />
@@ -93,7 +92,7 @@ export const TimedButton = React.memo(function TimedButton(props: TimedButtonPro
         }
       >
         <Button {...other} rightIcon={IconNames.CARET_DOWN} />
-      </Popover2>
+      </Popover>
     </ButtonGroup>
   );
 });
