@@ -42,13 +42,13 @@ export const DatasourceColumnsTable = React.memo(function DatasourceColumnsTable
 ) {
   const [columnsState] = useQueryManager<string, DatasourceColumnsTableRow[]>({
     initQuery: props.datasource,
-    processQuery: async (datasourceId, cancelToken) => {
+    processQuery: async (datasourceId, signal) => {
       return await queryDruidSql<ColumnMetadata>(
         {
           query: `SELECT COLUMN_NAME, DATA_TYPE FROM INFORMATION_SCHEMA.COLUMNS
           WHERE TABLE_SCHEMA = 'druid' AND TABLE_NAME = ${L(datasourceId)}`,
         },
-        cancelToken,
+        signal,
       );
     },
   });
