@@ -58,9 +58,9 @@ export const KillDatasourceDialog = function KillDatasourceDialog(
       className="kill-datasource-dialog"
       action={async () => {
         const resp = await Api.instance.delete(
-          `/druid/indexer/v1/datasources/${Api.encodePath(datasource)}/intervals/${Api.encodePath(
-            interval.replace(/\//g, '_'),
-          )}`,
+          `/druid/coordinator/v1/datasources/${Api.encodePath(
+            datasource,
+          )}/intervals/${Api.encodePath(interval.replace(/\//g, '_'))}`,
           {},
         );
         return resp.data;
