@@ -54,7 +54,7 @@ export const RetentionDialog = React.memo(function RetentionDialog(props: Retent
 
   const [tiersState] = useQueryManager<Capabilities, string[]>({
     initQuery: capabilities,
-    processQuery: async (capabilities, cancelToken) => {
+    processQuery: async (capabilities, signal) => {
       if (capabilities.hasSql()) {
         const sqlResp = await queryDruidSql<{ tier: string }>(
           {
@@ -64,13 +64,13 @@ WHERE "server_type" = 'historical'
 GROUP BY 1
 ORDER BY 1`,
           },
-          cancelToken,
+          signal,
         );
 
         return sqlResp.map(d => d.tier);
       } else if (capabilities.hasCoordinatorAccess()) {
         return filterMap(
-          await getApiArray('/druid/coordinator/v1/servers?simple', cancelToken),
+          await getApiArray('/druid/coordinator/v1/servers?simple', signal),
           (s: any) => (s.type === 'historical' ? s.tier : undefined),
         );
       } else {
@@ -83,10 +83,10 @@ ORDER BY 1`,
 
   const [historyQueryState] = useQueryManager<string, any[]>({
     initQuery: props.datasource,
-    processQuery: async (datasource, cancelToken) => {
+    processQuery: async (datasource, signal) => {
       return await getApiArray(
         `/druid/coordinator/v1/rules/${Api.encodePath(datasource)}/history?count=200`,
-        cancelToken,
+        signal,
       );
     },
   });
