@@ -25,8 +25,11 @@ export * from './download';
 export * from './download-query-detail-archive';
 export * from './druid-lookup';
 export * from './druid-query';
+export * from './explain';
 export * from './formatter';
 export * from './general';
+export * from './hjson-context';
+export * from './json-completion';
 export * from './local-storage-backed-visibility';
 export * from './local-storage-keys';
 export * from './mouse-tooltip/mouse-tooltip';
