@@ -57,6 +57,7 @@ import type {
 import {
   END_OF_TIME_DATE,
   formatCompactionInfo,
+  getConsoleViewIcon,
   getDatasourceColor,
   RuleUtil,
   START_OF_TIME_DATE,
@@ -438,21 +439,21 @@ GROUP BY 1, 2`;
     this.datasourceQueryManager = new QueryManager<DatasourceQuery, DatasourcesAndDefaultRules>({
       processQuery: async (
         { capabilities, visibleColumns, showUnused },
-        cancelToken,
+        signal,
         setIntermediateQuery,
       ) => {
         let datasources: DatasourceQueryResultRow[];
         if (capabilities.hasSql()) {
           const query = DatasourcesView.query(visibleColumns);
           setIntermediateQuery(query);
-          datasources = await queryDruidSql({ query }, cancelToken);
+          datasources = await queryDruidSql({ query }, signal);
         } else if (capabilities.hasCoordinatorAccess()) {
           const datasourcesResp = await getApiArray(
             '/druid/coordinator/v1/datasources?simple',
-            cancelToken,
+            signal,
           );
           const loadstatusResp = await Api.instance.get('/druid/coordinator/v1/loadstatus?simple', {
-            cancelToken,
+            signal,
           });
           const loadstatus = loadstatusResp.data;
           datasources = datasourcesResp.map((d: any): DatasourceQueryResultRow => {
@@ -492,13 +493,13 @@ GROUP BY 1, 2`;
 
         if (visibleColumns.shown('Running tasks')) {
           if (capabilities.hasSql()) {
-            auxiliaryQueries.push(async (datasourcesAndDefaultRules, cancelToken) => {
+            auxiliaryQueries.push(async (datasourcesAndDefaultRules, signal) => {
               try {
                 const runningTasks = await queryDruidSql<RunningTaskRow>(
                   {
                     query: DatasourcesView.RUNNING_TASK_SQL,
                   },
-                  cancelToken,
+                  signal,
                 );
 
                 const runningTasksByDatasource = groupByAsMap(
@@ -529,12 +530,9 @@ GROUP BY 1, 2`;
               }
             });
           } else if (capabilities.hasOverlordAccess()) {
-            auxiliaryQueries.push(async (datasourcesAndDefaultRules, cancelToken) => {
+            auxiliaryQueries.push(async (datasourcesAndDefaultRules, signal) => {
               try {
-                const taskList = await getApiArray(
-                  `/druid/indexer/v1/tasks?state=running`,
-                  cancelToken,
-                );
+                const taskList = await getApiArray(`/druid/indexer/v1/tasks?state=running`, signal);
 
                 const runningTasksByDatasource = groupByAsMap(
                   taskList,
@@ -587,11 +585,11 @@ GROUP BY 1, 2`;
           }
 
           // Rules
-          auxiliaryQueries.push(async (datasourcesAndDefaultRules, cancelToken) => {
+          auxiliaryQueries.push(async (datasourcesAndDefaultRules, signal) => {
             try {
               const rules = (
                 await Api.instance.get<Record<string, Rule[]>>('/druid/coordinator/v1/rules', {
-                  cancelToken,
+                  signal,
                 })
               ).data;
 
@@ -613,12 +611,12 @@ GROUP BY 1, 2`;
           });
 
           // Compaction
-          auxiliaryQueries.push(async (datasourcesAndDefaultRules, cancelToken) => {
+          auxiliaryQueries.push(async (datasourcesAndDefaultRules, signal) => {
             try {
               const compactionConfigsAndMore = (
                 await Api.instance.get<CompactionConfigs>(
                   '/druid/indexer/v1/compaction/config/datasources',
-                  { cancelToken },
+                  { signal },
                 )
               ).data;
               const compactionConfigs = lookupBy(
@@ -628,7 +626,7 @@ GROUP BY 1, 2`;
 
               const compactionStatusesResp = await Api.instance.get<{
                 latestStatus: CompactionStatus[];
-              }>('/druid/indexer/v1/compaction/status/datasources', { cancelToken });
+              }>('/druid/indexer/v1/compaction/status/datasources', { signal });
               const compactionStatuses = lookupBy(
                 compactionStatusesResp.data.latestStatus || [],
                 c => c.dataSource,
@@ -708,7 +706,7 @@ GROUP BY 1, 2`;
       <AsyncActionDialog
         action={async () => {
           const resp = await Api.instance.delete(
-            `/druid/coordinator/v1/datasources/${Api.encodePath(
+            `/druid/indexer/v1/datasources/${Api.encodePath(
               datasourceToMarkAsUnusedAllSegmentsIn,
             )}`,
             {},
@@ -749,7 +747,7 @@ GROUP BY 1, 2`;
       <AsyncActionDialog
         action={async () => {
           const resp = await Api.instance.post(
-            `/druid/coordinator/v1/datasources/${Api.encodePath(
+            `/druid/indexer/v1/datasources/${Api.encodePath(
               datasourceToMarkAllNonOvershadowedSegmentsAsUsedIn,
             )}`,
             {},
@@ -792,7 +790,7 @@ GROUP BY 1, 2`;
           if (!useUnuseInterval) return;
           const param = isUse ? 'markUsed' : 'markUnused';
           const resp = await Api.instance.post(
-            `/druid/coordinator/v1/datasources/${Api.encodePath(
+            `/druid/indexer/v1/datasources/${Api.encodePath(
               datasourceToMarkSegmentsByIntervalIn,
             )}/${Api.encodePath(param)}`,
             {
@@ -861,7 +859,7 @@ GROUP BY 1, 2`;
       >
         {capabilities.hasSql() && (
           <MenuItem
-            icon={IconNames.APPLICATION}
+            icon={getConsoleViewIcon('workbench')}
             text="View SQL query for table"
             disabled={typeof lastDatasourcesQuery !== 'string'}
             onClick={() => {
@@ -1004,23 +1002,10 @@ GROUP BY 1, 2`;
     rules: Rule[] | undefined,
     compactionInfo: CompactionInfo | undefined,
   ): BasicAction[] {
-    const { goToQuery, capabilities } = this.props;
-
-    const goToActions: BasicAction[] = [];
-
-    if (capabilities.hasSql()) {
-      goToActions.push({
-        icon: IconNames.APPLICATION,
-        title: 'Query with SQL',
-        onAction: () => goToQuery({ queryString: SqlQuery.create(T(datasource)).toString() }),
-      });
-    }
-
-    if (!capabilities.hasCoordinatorAccess()) {
-      return goToActions;
-    }
+    const { goToQuery, goToSegments, capabilities } = this.props;
 
     if (unused) {
+      if (!capabilities.hasOverlordAccess()) return [];
       return [
         {
           icon: IconNames.EXPORT,
@@ -1047,77 +1032,102 @@ GROUP BY 1, 2`;
         },
       ];
     } else {
-      return goToActions.concat(
-        compact([
-          {
-            icon: IconNames.AUTOMATIC_UPDATES,
-            title: 'Edit retention rules',
-            onAction: () => {
-              const defaultRules = this.state.datasourcesAndDefaultRulesState.data?.defaultRules;
-              if (!defaultRules) return;
-              this.setState({
-                retentionDialogOpenOn: {
-                  datasource,
-                  rules: rules || [],
-                  defaultRules,
-                },
-              });
-            },
+      return compact([
+        capabilities.hasSql()
+          ? {
+              icon: getConsoleViewIcon('workbench'),
+              title: 'Query with SQL',
+              onAction: () =>
+                goToQuery({ queryString: SqlQuery.selectStarFrom(T(datasource)).toString() }),
+            }
+          : undefined,
+        {
+          icon: getConsoleViewIcon('segments'),
+          title: 'Go to segments',
+          onAction: () => {
+            goToSegments({ datasource });
           },
-          {
-            icon: IconNames.REFRESH,
-            title: 'Mark as used all segments (will lead to reapplying retention rules)',
-            onAction: () =>
-              this.setState({
-                datasourceToMarkAllNonOvershadowedSegmentsAsUsedIn: datasource,
-              }),
-          },
-          compactionInfo
-            ? {
-                icon: IconNames.COMPRESSED,
-                title: 'Edit compaction configuration',
-                onAction: () => {
-                  this.setState({
-                    compactionDialogOpenOn: {
-                      datasource,
-                      compactionConfig: compactionInfo.config,
-                    },
-                  });
-                },
-              }
-            : undefined,
-          {
-            icon: IconNames.EXPORT,
-            title: 'Mark as used segments by interval',
-            onAction: () =>
-              this.setState({
-                datasourceToMarkSegmentsByIntervalIn: datasource,
-                useUnuseAction: 'use',
-              }),
-          },
-          {
-            icon: IconNames.IMPORT,
-            title: 'Mark as unused segments by interval',
-            onAction: () =>
-              this.setState({
-                datasourceToMarkSegmentsByIntervalIn: datasource,
-                useUnuseAction: 'unuse',
-              }),
-          },
-          {
-            icon: IconNames.IMPORT,
-            title: 'Mark as unused all segments',
-            intent: Intent.DANGER,
-            onAction: () => this.setState({ datasourceToMarkAsUnusedAllSegmentsIn: datasource }),
-          },
-          {
-            icon: IconNames.TRASH,
-            title: 'Delete unused segments (issue kill task)',
-            intent: Intent.DANGER,
-            onAction: () => this.setState({ killDatasource: datasource }),
-          },
-        ]),
-      );
+        },
+        capabilities.hasCoordinatorAccess()
+          ? {
+              icon: IconNames.AUTOMATIC_UPDATES,
+              title: 'Edit retention rules',
+              onAction: () => {
+                const defaultRules = this.state.datasourcesAndDefaultRulesState.data?.defaultRules;
+                if (!defaultRules) return;
+                this.setState({
+                  retentionDialogOpenOn: {
+                    datasource,
+                    rules: rules || [],
+                    defaultRules,
+                  },
+                });
+              },
+            }
+          : undefined,
+        capabilities.hasOverlordAccess()
+          ? {
+              icon: IconNames.REFRESH,
+              title: 'Mark as used all segments (will lead to reapplying retention rules)',
+              onAction: () =>
+                this.setState({
+                  datasourceToMarkAllNonOvershadowedSegmentsAsUsedIn: datasource,
+                }),
+            }
+          : undefined,
+        capabilities.hasCoordinatorAccess() && compactionInfo
+          ? {
+              icon: IconNames.COMPRESSED,
+              title: 'Edit compaction configuration',
+              onAction: () => {
+                this.setState({
+                  compactionDialogOpenOn: {
+                    datasource,
+                    compactionConfig: compactionInfo.config,
+                  },
+                });
+              },
+            }
+          : undefined,
+        capabilities.hasOverlordAccess()
+          ? {
+              icon: IconNames.EXPORT,
+              title: 'Mark as used segments by interval',
+              onAction: () =>
+                this.setState({
+                  datasourceToMarkSegmentsByIntervalIn: datasource,
+                  useUnuseAction: 'use',
+                }),
+            }
+          : undefined,
+        capabilities.hasOverlordAccess()
+          ? {
+              icon: IconNames.IMPORT,
+              title: 'Mark as unused segments by interval',
+              onAction: () =>
+                this.setState({
+                  datasourceToMarkSegmentsByIntervalIn: datasource,
+                  useUnuseAction: 'unuse',
+                }),
+            }
+          : undefined,
+        capabilities.hasOverlordAccess()
+          ? {
+              icon: IconNames.IMPORT,
+              title: 'Mark as unused all segments',
+              intent: Intent.DANGER,
+              onAction: () => this.setState({ datasourceToMarkAsUnusedAllSegmentsIn: datasource }),
+            }
+          : undefined,
+        capabilities.hasOverlordAccess()
+          ? {
+              icon: IconNames.TRASH,
+              title: 'Delete unused segments (issue kill task)',
+              intent: Intent.DANGER,
+              onAction: () => this.setState({ killDatasource: datasource }),
+            }
+          : undefined,
+      ]);
     }
   }
 
