@@ -16,11 +16,14 @@
  * limitations under the License.
  */
 
-import { Callout } from '@blueprintjs/core';
+import { Button, Callout, Popover } from '@blueprintjs/core';
+import { IconNames } from '@blueprintjs/icons';
 import classNames from 'classnames';
 import type { QueryResult, SqlQuery } from 'druid-query-toolkit';
+import { dedupe } from 'druid-query-toolkit';
 import React from 'react';
 
+import { PopoverText } from '../../../../components';
 import { useQueryManager } from '../../../../hooks';
 import { formatEmpty } from '../../../../utils';
 
@@ -38,27 +41,35 @@ function getPreviewValues(queryResult: QueryResult): any[] {
 export interface PreviewPaneProps {
   previewQuery: string | undefined;
   runSqlQuery(query: string | SqlQuery): Promise<QueryResult>;
+  deduplicate?: boolean;
+  info?: string;
 }
 
 export const PreviewPane = React.memo(function PreviewPane(props: PreviewPaneProps) {
-  const { previewQuery, runSqlQuery } = props;
+  const { previewQuery, runSqlQuery, deduplicate, info } = props;
 
   const [previewState] = useQueryManager({
     query: previewQuery,
     processQuery: runSqlQuery,
-    debounceIdle: 1000,
+    debounceIdle: 2000,
+    debounceLoading: 3000,
   });
 
   const previewValues = previewState.data ? getPreviewValues(previewState.data) : undefined;
   return (
     <Callout className="preview-pane" title="Preview">
+      {info && (
+        <Popover className="info-popover" content={<PopoverText>{info}</PopoverText>}>
+          <Button icon={IconNames.INFO_SIGN} minimal />
+        </Popover>
+      )}
       {previewState.loading && 'Loading...'}
       {previewState.error && <div className="preview-error">{previewState.getErrorMessage()}</div>}
       {previewValues &&
         (previewValues.length ? (
           <div className="preview-values-wrapper">
             <div className="preview-values">
-              {previewValues.map((v, i) => (
+              {(deduplicate ? dedupe(previewValues) : previewValues).map((v, i) => (
                 <div
                   className={classNames('preview-value', { special: v == null || v === '' })}
                   key={i}
