@@ -16,9 +16,9 @@
  * limitations under the License.
  */
 
-import { IconNames } from '@blueprintjs/icons';
 import React from 'react';
 
+import { getConsoleViewIcon } from '../../../druid-models';
 import type { Capabilities } from '../../../helpers';
 import { useQueryManager } from '../../../hooks';
 import { getApiArray, pluralIfNeeded, queryDruidSql } from '../../../utils';
@@ -31,17 +31,17 @@ export interface DatasourcesCardProps {
 export const DatasourcesCard = React.memo(function DatasourcesCard(props: DatasourcesCardProps) {
   const [datasourceCountState] = useQueryManager<Capabilities, number>({
     initQuery: props.capabilities,
-    processQuery: async (capabilities, cancelToken) => {
+    processQuery: async (capabilities, signal) => {
       let datasources: string[];
       if (capabilities.hasSql()) {
         datasources = await queryDruidSql(
           {
             query: `SELECT datasource FROM sys.segments GROUP BY 1`,
           },
-          cancelToken,
+          signal,
         );
       } else if (capabilities.hasCoordinatorAccess()) {
-        datasources = await getApiArray<string>('/druid/coordinator/v1/datasources', cancelToken);
+        datasources = await getApiArray<string>('/druid/coordinator/v1/datasources', signal);
       } else {
         throw new Error(`must have SQL or coordinator access`);
       }
@@ -54,7 +54,7 @@ export const DatasourcesCard = React.memo(function DatasourcesCard(props: Dataso
     <HomeViewCard
       className="datasources-card"
       href="#datasources"
-      icon={IconNames.MULTI_SELECT}
+      icon={getConsoleViewIcon('datasources')}
       title="Datasources"
       loading={datasourceCountState.loading}
       error={datasourceCountState.error}
