@@ -19,8 +19,9 @@
 import { Button, ButtonGroup, Intent, Label, MenuItem, Tag } from '@blueprintjs/core';
 import { IconNames } from '@blueprintjs/icons';
 import { max, sum } from 'd3-array';
-import React from 'react';
-import type { Filter } from 'react-table';
+import memoize from 'memoize-one';
+import React, { createContext, useContext } from 'react';
+import type { Column, Filter } from 'react-table';
 import ReactTable from 'react-table';
 
 import {
@@ -37,8 +38,13 @@ import {
 } from '../../components';
 import { AsyncActionDialog } from '../../dialogs';
 import type { QueryWithContext } from '../../druid-models';
+import { getConsoleViewIcon } from '../../druid-models';
 import type { Capabilities, CapabilitiesMode } from '../../helpers';
 import {
+  booleanCustomTableFilter,
+  combineModeAndNeedle,
+  DEFAULT_TABLE_CLASS_NAME,
+  parseFilterModeAndNeedle,
   STANDARD_TABLE_PAGE_SIZE,
   STANDARD_TABLE_PAGE_SIZE_OPTIONS,
   suggestibleFilterInput,
@@ -51,6 +57,7 @@ import {
   filterMap,
   formatBytes,
   formatBytesCompact,
+  formatDate,
   formatDurationWithMsIfNeeded,
   getApiArray,
   hasOverlayOpen,
@@ -59,7 +66,6 @@ import {
   lookupBy,
   oneOf,
   pluralIfNeeded,
-  prettyFormatIsoDateWithMsIfNeeded,
   queryDruidSql,
   QueryManager,
   QueryState,
@@ -67,6 +73,8 @@ import {
 } from '../../utils';
 import type { BasicAction } from '../../utils/basic-action';
 
+import { FillIndicator } from './fill-indicator/fill-indicator';
+
 import './services-view.scss';
 
 const TABLE_COLUMNS_BY_MODE: Record<CapabilitiesMode, TableColumnSelectorColumn[]> = {
@@ -80,6 +88,8 @@ const TABLE_COLUMNS_BY_MODE: Record<CapabilitiesMode, TableColumnSelectorColumn[
     'Max size',
     'Usage',
     'Start time',
+    'Version',
+    'Labels',
     'Detail',
   ],
   'no-sql': [
@@ -103,6 +113,7 @@ const TABLE_COLUMNS_BY_MODE: Record<CapabilitiesMode, TableColumnSelectorColumn[
     'Max size',
     'Usage',
     'Start time',
+    'Version',
   ],
 };
 
@@ -119,7 +130,7 @@ export interface ServicesViewProps {
 }
 
 export interface ServicesViewState {
-  servicesState: QueryState<ServiceResultRow[]>;
+  servicesState: QueryState<ServicesWithAuxiliaryInfo>;
   groupServicesBy?: 'service_type' | 'tier';
 
   middleManagerDisableWorkerHost?: string;
@@ -139,10 +150,18 @@ interface ServiceResultRow {
   readonly plaintext_port: number;
   readonly tls_port: number;
   readonly start_time: string;
-  readonly loadQueueInfo?: LoadQueueInfo;
-  readonly workerInfo?: WorkerInfo;
+  readonly version: string;
+  readonly labels: string | null;
 }
 
+interface ServicesWithAuxiliaryInfo {
+  readonly services: ServiceResultRow[];
+  readonly loadQueueInfo: Record<string, LoadQueueInfo>;
+  readonly workerInfo: Record<string, WorkerInfo>;
+}
+
+export const LoadQueueInfoContext = createContext<Record<string, LoadQueueInfo>>({});
+
 interface LoadQueueInfo {
   readonly segmentsToDrop: NumberLike;
   readonly segmentsToDropSize: NumberLike;
@@ -188,6 +207,11 @@ function aggregateLoadQueueInfos(loadQueueInfos: LoadQueueInfo[]): LoadQueueInfo
   };
 }
 
+function defaultDisplayFn(value: any): string {
+  if (value === undefined || value === null) return '';
+  return String(value);
+}
+
 interface WorkerInfo {
   readonly availabilityGroups: string[];
   readonly blacklistedUntil: string | null;
@@ -206,7 +230,7 @@ interface WorkerInfo {
 }
 
 export class ServicesView extends React.PureComponent<ServicesViewProps, ServicesViewState> {
-  private readonly serviceQueryManager: QueryManager<ServicesQuery, ServiceResultRow[]>;
+  private readonly serviceQueryManager: QueryManager<ServicesQuery, ServicesWithAuxiliaryInfo>;
 
   // Ranking
   //   coordinator => 8
@@ -228,7 +252,9 @@ export class ServicesView extends React.PureComponent<ServicesViewProps, Service
   "curr_size",
   "max_size",
   "is_leader",
-  "start_time"
+  "start_time",
+  "version",
+  "labels"
 FROM sys.servers
 ORDER BY
   (
@@ -257,12 +283,12 @@ ORDER BY
     };
 
     this.serviceQueryManager = new QueryManager({
-      processQuery: async ({ capabilities, visibleColumns }, cancelToken) => {
+      processQuery: async ({ capabilities, visibleColumns }, signal) => {
         let services: ServiceResultRow[];
         if (capabilities.hasSql()) {
-          services = await queryDruidSql({ query: ServicesView.SERVICE_SQL }, cancelToken);
+          services = await queryDruidSql({ query: ServicesView.SERVICE_SQL }, signal);
         } else if (capabilities.hasCoordinatorAccess()) {
-          services = (await getApiArray('/druid/coordinator/v1/servers?simple', cancelToken)).map(
+          services = (await getApiArray('/druid/coordinator/v1/servers?simple', signal)).map(
             (s: any): ServiceResultRow => {
               const hostParts = s.host.split(':');
               const port = parseInt(hostParts[1], 10);
@@ -277,6 +303,8 @@ ORDER BY
                 max_size: s.maxSize,
                 start_time: '1970:01:01T00:00:00Z',
                 is_leader: 0,
+                version: '',
+                labels: null,
               };
             },
           );
@@ -284,38 +312,38 @@ ORDER BY
           throw new Error(`must have SQL or coordinator access`);
         }
 
-        const auxiliaryQueries: AuxiliaryQueryFn<ServiceResultRow[]>[] = [];
+        const auxiliaryQueries: AuxiliaryQueryFn<ServicesWithAuxiliaryInfo>[] = [];
 
-        if (capabilities.hasCoordinatorAccess() && visibleColumns.shown('Details')) {
-          auxiliaryQueries.push(async (services, cancelToken) => {
+        if (capabilities.hasCoordinatorAccess() && visibleColumns.shown('Detail')) {
+          auxiliaryQueries.push(async (servicesWithAuxiliaryInfo, signal) => {
             try {
               const loadQueueInfos = (
                 await Api.instance.get<Record<string, LoadQueueInfo>>(
                   '/druid/coordinator/v1/loadqueue?simple',
-                  { cancelToken },
+                  { signal },
                 )
               ).data;
-              return services.map(s => ({
-                ...s,
-                loadQueueInfo: loadQueueInfos[s.service],
-              }));
+              return {
+                ...servicesWithAuxiliaryInfo,
+                loadQueueInfo: loadQueueInfos,
+              };
             } catch {
               AppToaster.show({
                 icon: IconNames.ERROR,
                 intent: Intent.DANGER,
                 message: 'There was an error getting the load queue info',
               });
-              return services;
+              return servicesWithAuxiliaryInfo;
             }
           });
         }
 
         if (capabilities.hasOverlordAccess()) {
-          auxiliaryQueries.push(async (services, cancelToken) => {
+          auxiliaryQueries.push(async (servicesWithAuxiliaryInfo, signal) => {
             try {
               const workerInfos = await getApiArray<WorkerInfo>(
                 '/druid/indexer/v1/workers',
-                cancelToken,
+                signal,
               );
 
               const workerInfoLookup: Record<string, WorkerInfo> = lookupBy(
@@ -323,10 +351,10 @@ ORDER BY
                 m => m.worker?.host,
               );
 
-              return services.map(s => ({
-                ...s,
-                workerInfo: workerInfoLookup[s.service],
-              }));
+              return {
+                ...servicesWithAuxiliaryInfo,
+                workerInfo: workerInfoLookup,
+              };
             } catch (e) {
               // Swallow this error because it simply a reflection of a local task runner.
               if (
@@ -338,12 +366,15 @@ ORDER BY
                   message: 'There was an error getting the worker info',
                 });
               }
-              return services;
+              return servicesWithAuxiliaryInfo;
             }
           });
         }
 
-        return new ResultWithAuxiliaryWork(services, auxiliaryQueries);
+        return new ResultWithAuxiliaryWork<ServicesWithAuxiliaryInfo>(
+          { services, loadQueueInfo: {}, workerInfo: {} },
+          auxiliaryQueries,
+        );
       },
       onStateChange: servicesState => {
         this.setState({
@@ -367,7 +398,10 @@ ORDER BY
     this.serviceQueryManager.runQuery({ capabilities, visibleColumns });
   };
 
-  private renderFilterableCell(field: string) {
+  private renderFilterableCell(
+    field: string,
+    displayFn: (value: string) => string = defaultDisplayFn,
+  ) {
     const { filters, onFiltersChange } = this.props;
 
     return function FilterableCell(row: { value: any }) {
@@ -377,326 +411,367 @@ ORDER BY
           value={row.value}
           filters={filters}
           onFiltersChange={onFiltersChange}
+          displayValue={displayFn(row.value)}
         >
-          {row.value}
+          {displayFn(row.value)}
         </TableFilterableCell>
       );
     };
   }
 
   renderServicesTable() {
-    const { capabilities, filters, onFiltersChange } = this.props;
+    const { filters, onFiltersChange } = this.props;
     const { servicesState, groupServicesBy, visibleColumns } = this.state;
 
-    const fillIndicator = (value: number) => {
-      let formattedValue = (value * 100).toFixed(1);
-      if (formattedValue === '0.0' && value > 0) formattedValue = '~' + formattedValue;
-      return (
-        <div className="fill-indicator">
-          <div className="bar" style={{ width: `${value * 100}%` }} />
-          <div className="label">{formattedValue + '%'}</div>
-        </div>
-      );
+    const { services, loadQueueInfo, workerInfo } = servicesState.data || {
+      services: [],
+      loadQueueInfo: {},
+      workerInfo: {},
     };
 
-    const services = servicesState.data || [];
     return (
-      <ReactTable
-        data={services}
-        loading={servicesState.loading}
-        noDataText={
-          servicesState.isEmpty() ? 'No historicals' : servicesState.getErrorMessage() || ''
-        }
-        filterable
-        filtered={filters}
-        onFilteredChange={onFiltersChange}
-        pivotBy={groupServicesBy ? [groupServicesBy] : []}
-        defaultPageSize={STANDARD_TABLE_PAGE_SIZE}
-        pageSizeOptions={STANDARD_TABLE_PAGE_SIZE_OPTIONS}
-        showPagination={services.length > STANDARD_TABLE_PAGE_SIZE}
-        columns={[
-          {
-            Header: 'Service',
-            show: visibleColumns.shown('Service'),
-            accessor: 'service',
-            width: 300,
-            Cell: this.renderFilterableCell('service'),
-            Aggregated: () => '',
-          },
-          {
-            Header: 'Type',
-            show: visibleColumns.shown('Type'),
-            Filter: suggestibleFilterInput([
-              'coordinator',
-              'overlord',
-              'router',
-              'broker',
-              'historical',
-              'indexer',
-              'middle_manager',
-              'peon',
-            ]),
-            accessor: 'service_type',
-            width: 150,
-            Cell: this.renderFilterableCell('service_type'),
-          },
-          {
-            Header: 'Tier',
-            show: visibleColumns.shown('Tier'),
-            id: 'tier',
-            width: 180,
-            accessor: row => {
-              if (row.tier) return row.tier;
-              return deepGet(row, 'workerInfo.worker.category');
-            },
-            Cell: this.renderFilterableCell('tier'),
-          },
-          {
-            Header: 'Host',
-            show: visibleColumns.shown('Host'),
-            accessor: 'host',
-            width: 200,
-            Cell: this.renderFilterableCell('host'),
-            Aggregated: () => '',
-          },
-          {
-            Header: 'Port',
-            show: visibleColumns.shown('Port'),
-            id: 'port',
-            width: 100,
-            accessor: row => {
-              const ports: string[] = [];
-              if (row.plaintext_port !== -1) {
-                ports.push(`${row.plaintext_port} (plain)`);
-              }
-              if (row.tls_port !== -1) {
-                ports.push(`${row.tls_port} (TLS)`);
-              }
-              return ports.join(', ') || 'No port';
-            },
-            Cell: this.renderFilterableCell('port'),
-            Aggregated: () => '',
-          },
-          {
-            Header: 'Current size',
-            show: visibleColumns.shown('Current size'),
-            id: 'curr_size',
-            width: 100,
-            filterable: false,
-            accessor: 'curr_size',
-            className: 'padded',
-            Aggregated: ({ subRows }) => {
-              const originalRows = subRows.map(r => r._original);
-              if (!originalRows.some(r => r.service_type === 'historical')) return '';
-              const totalCurr = sum(originalRows, s => s.curr_size);
-              return formatBytes(totalCurr);
-            },
-            Cell: ({ value, aggregated, original }) => {
-              if (aggregated || original.service_type !== 'historical') return '';
-              if (value === null) return '';
-              return formatBytes(value);
-            },
-          },
-          {
-            Header: 'Max size',
-            show: visibleColumns.shown('Max size'),
-            id: 'max_size',
-            width: 100,
-            filterable: false,
-            accessor: 'max_size',
-            className: 'padded',
-            Aggregated: ({ subRows }) => {
-              const originalRows = subRows.map(r => r._original);
-              if (!originalRows.some(r => r.service_type === 'historical')) return '';
-              const totalMax = sum(originalRows, s => s.max_size);
-              return formatBytes(totalMax);
-            },
-            Cell: ({ value, aggregated, original }) => {
-              if (aggregated || original.service_type !== 'historical') return '';
-              if (value === null) return '';
-              return formatBytes(value);
-            },
-          },
-          {
-            Header: 'Usage',
-            show: visibleColumns.shown('Usage'),
-            id: 'usage',
-            width: 140,
-            filterable: false,
-            className: 'padded',
-            accessor: row => {
-              if (oneOf(row.service_type, 'middle_manager', 'indexer')) {
-                const { workerInfo } = row;
-                if (!workerInfo) return 0;
-                return (
-                  (Number(workerInfo.currCapacityUsed) || 0) / Number(workerInfo.worker?.capacity)
-                );
-              } else {
-                return row.max_size ? Number(row.curr_size) / Number(row.max_size) : null;
-              }
-            },
-            Aggregated: ({ subRows }) => {
-              const originalRows = subRows.map(r => r._original);
-
-              if (originalRows.some(r => r.service_type === 'historical')) {
-                const totalCurr = sum(originalRows, s => Number(s.curr_size));
-                const totalMax = sum(originalRows, s => Number(s.max_size));
-                return fillIndicator(totalCurr / totalMax);
-              } else if (
-                originalRows.some(
-                  r => r.service_type === 'indexer' || r.service_type === 'middle_manager',
-                )
-              ) {
-                const workerInfos: WorkerInfo[] = filterMap(originalRows, r => r.workerInfo);
-                if (!workerInfos.length) return '';
-
-                const totalCurrCapacityUsed = sum(
-                  workerInfos,
-                  w => Number(w.currCapacityUsed) || 0,
-                );
-                const totalWorkerCapacity = sum(
-                  workerInfos,
-                  s => deepGet(s, 'worker.capacity') || 0,
-                );
-                return `Slots used: ${totalCurrCapacityUsed} of ${totalWorkerCapacity}`;
-              } else {
-                return '';
-              }
-            },
-            Cell: ({ value, aggregated, original }) => {
-              if (aggregated) return '';
-              const { service_type } = original;
-              switch (service_type) {
-                case 'historical':
-                  return fillIndicator(value);
-
-                case 'indexer':
-                case 'middle_manager': {
-                  if (!deepGet(original, 'workerInfo')) return '';
-                  const currCapacityUsed = deepGet(original, 'workerInfo.currCapacityUsed') || 0;
-                  const capacity = deepGet(original, 'workerInfo.worker.capacity');
-                  if (typeof capacity === 'number') {
-                    return `Slots used: ${currCapacityUsed} of ${capacity}`;
-                  } else {
-                    return 'Slots used: -';
-                  }
-                }
-
-                default:
-                  return '';
-              }
-            },
-          },
-          {
-            Header: 'Start time',
-            show: visibleColumns.shown('Start time'),
-            accessor: 'start_time',
-            width: 200,
-            Cell: this.renderFilterableCell('start_time'),
-            Aggregated: () => '',
-          },
-          {
-            Header: 'Detail',
-            show: visibleColumns.shown('Detail'),
-            id: 'queue',
-            width: 400,
-            filterable: false,
-            className: 'padded',
-            accessor: row => {
-              switch (row.service_type) {
-                case 'middle_manager':
-                case 'indexer': {
-                  const { workerInfo } = row;
-                  if (!workerInfo) return '';
-
-                  if (workerInfo.worker.version === '') return 'Disabled';
-
-                  const details: string[] = [];
-                  if (workerInfo.lastCompletedTaskTime) {
-                    details.push(
-                      `Last completed task: ${prettyFormatIsoDateWithMsIfNeeded(
-                        workerInfo.lastCompletedTaskTime,
-                      )}`,
-                    );
-                  }
-                  if (workerInfo.blacklistedUntil) {
-                    details.push(
-                      `Blacklisted until: ${prettyFormatIsoDateWithMsIfNeeded(
-                        workerInfo.blacklistedUntil,
-                      )}`,
-                    );
-                  }
-                  return details.join(' ');
-                }
-
-                case 'coordinator':
-                case 'overlord':
-                  return row.is_leader === 1 ? 'Leader' : '';
-
-                case 'historical': {
-                  const { loadQueueInfo } = row;
-                  if (!loadQueueInfo) return 0;
-                  return (
-                    (Number(loadQueueInfo.segmentsToLoad) || 0) +
-                    (Number(loadQueueInfo.segmentsToDrop) || 0)
-                  );
-                }
-
-                default:
-                  return 0;
-              }
-            },
-            Cell: ({ value, aggregated, original }) => {
-              if (aggregated) return '';
-              const { service_type } = original;
-              switch (service_type) {
-                case 'middle_manager':
-                case 'indexer':
-                case 'coordinator':
-                case 'overlord':
-                  return value;
-
-                case 'historical': {
-                  const { loadQueueInfo } = original;
-                  return loadQueueInfo ? formatLoadQueueInfo(loadQueueInfo) : '';
-                }
-
-                default:
-                  return '';
-              }
-            },
-            Aggregated: ({ subRows }) => {
-              const originalRows = subRows.map(r => r._original);
-              if (!originalRows.some(r => r.service_type === 'historical')) return '';
-              const loadQueueInfos: LoadQueueInfo[] = filterMap(originalRows, r => r.loadQueueInfo);
-              return loadQueueInfos.length
-                ? formatLoadQueueInfo(aggregateLoadQueueInfos(loadQueueInfos))
-                : '';
-            },
-          },
-          {
-            Header: ACTION_COLUMN_LABEL,
-            show: capabilities.hasOverlordAccess(),
-            id: ACTION_COLUMN_ID,
-            width: ACTION_COLUMN_WIDTH,
-            accessor: row => row.workerInfo,
-            filterable: false,
-            sortable: false,
-            Cell: ({ value, aggregated }) => {
-              if (aggregated) return '';
-              if (!value) return null;
-              const { worker } = value;
-              const disabled = worker.version === '';
-              const workerActions = this.getWorkerActions(worker.host, disabled);
-              return <ActionCell actions={workerActions} menuTitle={worker.host} />;
-            },
-            Aggregated: () => '',
-          },
-        ]}
-      />
+      <LoadQueueInfoContext.Provider value={loadQueueInfo}>
+        <ReactTable
+          data={services}
+          loading={servicesState.loading}
+          noDataText={
+            servicesState.isEmpty() ? 'No services' : servicesState.getErrorMessage() || ''
+          }
+          filterable
+          filtered={filters}
+          className={`centered-table ${DEFAULT_TABLE_CLASS_NAME}`}
+          onFilteredChange={onFiltersChange}
+          pivotBy={groupServicesBy ? [groupServicesBy] : []}
+          defaultPageSize={STANDARD_TABLE_PAGE_SIZE}
+          pageSizeOptions={STANDARD_TABLE_PAGE_SIZE_OPTIONS}
+          showPagination={services.length > STANDARD_TABLE_PAGE_SIZE}
+          columns={this.getTableColumns(visibleColumns, filters, onFiltersChange, workerInfo)}
+        />
+      </LoadQueueInfoContext.Provider>
     );
   }
 
+  private readonly getTableColumns = memoize(
+    (
+      visibleColumns: LocalStorageBackedVisibility,
+      _filters: Filter[],
+      _onFiltersChange: (filters: Filter[]) => void,
+      workerInfoLookup: Record<string, WorkerInfo>,
+    ): Column<ServiceResultRow>[] => {
+      const { capabilities } = this.props;
+
+      return [
+        {
+          Header: 'Service',
+          show: visibleColumns.shown('Service'),
+          accessor: 'service',
+          width: 300,
+          Cell: this.renderFilterableCell('service'),
+          Aggregated: () => '',
+        },
+        {
+          Header: 'Type',
+          show: visibleColumns.shown('Type'),
+          Filter: suggestibleFilterInput([
+            'coordinator',
+            'overlord',
+            'router',
+            'broker',
+            'historical',
+            'indexer',
+            'middle_manager',
+            'peon',
+          ]),
+          accessor: 'service_type',
+          width: 150,
+          Cell: this.renderFilterableCell('service_type'),
+        },
+        {
+          Header: 'Tier',
+          show: visibleColumns.shown('Tier'),
+          id: 'tier',
+          width: 180,
+          accessor: row => {
+            if (row.tier) return row.tier;
+            return workerInfoLookup[row.service]?.worker?.category;
+          },
+          Cell: this.renderFilterableCell('tier'),
+        },
+        {
+          Header: 'Host',
+          show: visibleColumns.shown('Host'),
+          accessor: 'host',
+          width: 200,
+          Cell: this.renderFilterableCell('host'),
+          Aggregated: () => '',
+        },
+        {
+          Header: 'Port',
+          show: visibleColumns.shown('Port'),
+          id: 'port',
+          width: 100,
+          accessor: row => {
+            const ports: string[] = [];
+            if (row.plaintext_port !== -1) {
+              ports.push(`${row.plaintext_port} (plain)`);
+            }
+            if (row.tls_port !== -1) {
+              ports.push(`${row.tls_port} (TLS)`);
+            }
+            return ports.join(', ') || 'No port';
+          },
+          Cell: this.renderFilterableCell('port'),
+          Aggregated: () => '',
+        },
+        {
+          Header: 'Current size',
+          show: visibleColumns.shown('Current size'),
+          id: 'curr_size',
+          width: 100,
+          filterable: false,
+          accessor: 'curr_size',
+          className: 'padded',
+          Aggregated: ({ subRows }) => {
+            const originalRows = subRows.map(r => r._original);
+            if (!originalRows.some(r => r.service_type === 'historical')) return '';
+            const totalCurr = sum(originalRows, s => s.curr_size);
+            return formatBytes(totalCurr);
+          },
+          Cell: ({ value, aggregated, original }) => {
+            if (aggregated || original.service_type !== 'historical') return '';
+            if (value === null) return '';
+            return formatBytes(value);
+          },
+        },
+        {
+          Header: 'Max size',
+          show: visibleColumns.shown('Max size'),
+          id: 'max_size',
+          width: 100,
+          filterable: false,
+          accessor: 'max_size',
+          className: 'padded',
+          Aggregated: ({ subRows }) => {
+            const originalRows = subRows.map(r => r._original);
+            if (!originalRows.some(r => r.service_type === 'historical')) return '';
+            const totalMax = sum(originalRows, s => s.max_size);
+            return formatBytes(totalMax);
+          },
+          Cell: ({ value, aggregated, original }) => {
+            if (aggregated || original.service_type !== 'historical') return '';
+            if (value === null) return '';
+            return formatBytes(value);
+          },
+        },
+        {
+          Header: 'Usage',
+          show: visibleColumns.shown('Usage'),
+          id: 'usage',
+          width: 140,
+          filterable: false,
+          className: 'padded',
+          accessor: row => {
+            if (oneOf(row.service_type, 'middle_manager', 'indexer')) {
+              const workerInfo = workerInfoLookup[row.service];
+              if (!workerInfo) return 0;
+              return (
+                (Number(workerInfo.currCapacityUsed) || 0) / Number(workerInfo.worker?.capacity)
+              );
+            } else {
+              return row.max_size ? Number(row.curr_size) / Number(row.max_size) : null;
+            }
+          },
+          Aggregated: ({ subRows }) => {
+            const originalRows = subRows.map(r => r._original);
+
+            if (originalRows.some(r => r.service_type === 'historical')) {
+              const totalCurr = sum(originalRows, s => Number(s.curr_size));
+              const totalMax = sum(originalRows, s => Number(s.max_size));
+              return <FillIndicator value={totalCurr / totalMax} />;
+            } else if (
+              originalRows.some(
+                r => r.service_type === 'indexer' || r.service_type === 'middle_manager',
+              )
+            ) {
+              const workerInfos: WorkerInfo[] = filterMap(
+                originalRows,
+                r => workerInfoLookup[r.service],
+              );
+
+              if (!workerInfos.length) return '';
+
+              const totalCurrCapacityUsed = sum(workerInfos, w => Number(w.currCapacityUsed) || 0);
+              const totalWorkerCapacity = sum(workerInfos, s => deepGet(s, 'worker.capacity') || 0);
+              return `Slots used: ${totalCurrCapacityUsed} of ${totalWorkerCapacity}`;
+            } else {
+              return '';
+            }
+          },
+          Cell: ({ value, aggregated, original }) => {
+            if (aggregated) return '';
+            const { service_type } = original;
+
+            switch (service_type) {
+              case 'historical':
+                return <FillIndicator value={value} />;
+
+              case 'indexer':
+              case 'middle_manager': {
+                const workerInfo = workerInfoLookup[original.service];
+                if (!workerInfo) return '';
+
+                const currCapacityUsed = workerInfo.currCapacityUsed || 0;
+                const capacity = deepGet(workerInfo, 'worker.capacity');
+                if (typeof capacity === 'number') {
+                  return `Slots used: ${currCapacityUsed} of ${capacity}`;
+                } else {
+                  return 'Slots used: -';
+                }
+              }
+
+              default:
+                return '';
+            }
+          },
+        },
+        {
+          Header: 'Start time',
+          show: visibleColumns.shown('Start time'),
+          accessor: 'start_time',
+          id: 'start_time',
+          width: 220,
+          Cell: this.renderFilterableCell('start_time', formatDate),
+          Aggregated: () => '',
+          filterMethod: (filter: Filter, row: ServiceResultRow) => {
+            const modeAndNeedle = parseFilterModeAndNeedle(filter);
+            if (!modeAndNeedle) return true;
+            const parsedRowTime = formatDate(row.start_time);
+            if (modeAndNeedle.mode === '~') {
+              return booleanCustomTableFilter(filter, parsedRowTime);
+            }
+            const parsedFilterTime = formatDate(modeAndNeedle.needle);
+            filter.value = combineModeAndNeedle(modeAndNeedle.mode, parsedFilterTime);
+            return booleanCustomTableFilter(filter, parsedRowTime);
+          },
+        },
+        {
+          Header: 'Version',
+          show: visibleColumns.shown('Version'),
+          accessor: 'version',
+          width: 200,
+          Cell: this.renderFilterableCell('version'),
+          Aggregated: () => '',
+        },
+        {
+          Header: 'Labels',
+          show: visibleColumns.shown('Labels'),
+          accessor: 'labels',
+          className: 'padded',
+          filterable: false,
+          width: 200,
+          Cell: ({ value }: { value: string | null }) => {
+            if (!value) return '';
+            return (
+              <ul className="labels-list">
+                {Object.entries(JSON.parse(value)).map(([key, val]) => {
+                  return (
+                    <li key={key}>
+                      {key}: {String(val)}
+                    </li>
+                  );
+                })}
+              </ul>
+            );
+          },
+          Aggregated: () => '',
+        },
+        {
+          Header: 'Detail',
+          show: visibleColumns.shown('Detail'),
+          id: 'queue',
+          width: 400,
+          filterable: false,
+          className: 'padded',
+          accessor: 'service',
+          Cell: ({ original }) => {
+            const { service_type, service, is_leader } = original;
+            const loadQueueInfoContext = useContext(LoadQueueInfoContext);
+
+            switch (service_type) {
+              case 'middle_manager':
+              case 'indexer': {
+                const workerInfo = workerInfoLookup[service];
+                if (!workerInfo) return null;
+
+                if (workerInfo.worker.version === '') return 'Disabled';
+
+                const details: string[] = [];
+                if (workerInfo.lastCompletedTaskTime) {
+                  details.push(
+                    `Last completed task: ${formatDate(workerInfo.lastCompletedTaskTime)}`,
+                  );
+                }
+                if (workerInfo.blacklistedUntil) {
+                  details.push(`Blacklisted until: ${formatDate(workerInfo.blacklistedUntil)}`);
+                }
+                return details.join(' ') || null;
+              }
+
+              case 'coordinator':
+              case 'overlord':
+                return is_leader === 1 ? 'Leader' : '';
+
+              case 'historical': {
+                const loadQueueInfo = loadQueueInfoContext[service];
+                if (!loadQueueInfo) return null;
+
+                return formatLoadQueueInfo(loadQueueInfo);
+              }
+
+              default:
+                return null;
+            }
+          },
+          Aggregated: ({ subRows }) => {
+            const loadQueueInfoContext = useContext(LoadQueueInfoContext);
+            const originalRows = subRows.map(r => r._original);
+            if (!originalRows.some(r => r.service_type === 'historical')) return '';
+
+            const loadQueueInfos: LoadQueueInfo[] = filterMap(
+              originalRows,
+              r => loadQueueInfoContext[r.service],
+            );
+
+            return loadQueueInfos.length
+              ? formatLoadQueueInfo(aggregateLoadQueueInfos(loadQueueInfos))
+              : '';
+          },
+        },
+        {
+          Header: ACTION_COLUMN_LABEL,
+          show: capabilities.hasOverlordAccess(),
+          id: ACTION_COLUMN_ID,
+          width: ACTION_COLUMN_WIDTH,
+          accessor: 'service',
+          filterable: false,
+          sortable: false,
+          Cell: ({ value, aggregated }) => {
+            if (aggregated) return '';
+
+            const workerInfo = workerInfoLookup[value];
+            if (!workerInfo) return null;
+
+            const { worker } = workerInfo;
+            const disabled = worker.version === '';
+            const workerActions = this.getWorkerActions(worker.host, disabled);
+            return <ActionCell actions={workerActions} menuTitle={worker.host} />;
+          },
+          Aggregated: () => '',
+        },
+      ];
+    },
+  );
+
   private getWorkerActions(workerHost: string, disabled: boolean): BasicAction[] {
     if (disabled) {
       return [
@@ -790,7 +865,7 @@ ORDER BY
       <MoreButton>
         {capabilities.hasSql() && (
           <MenuItem
-            icon={IconNames.APPLICATION}
+            icon={getConsoleViewIcon('workbench')}
             text="View SQL query for table"
             onClick={() => goToQuery({ queryString: ServicesView.SERVICE_SQL })}
           />
