@@ -16,7 +16,18 @@
  * limitations under the License.
  */
 
-import { AnchorButton, Button, Intent, Menu, MenuItem, Popover, Position } from '@blueprintjs/core';
+import {
+  AnchorButton,
+  Button,
+  ControlGroup,
+  InputGroup,
+  Intent,
+  Label,
+  Menu,
+  MenuItem,
+  Popover,
+  Position,
+} from '@blueprintjs/core';
 import { IconNames } from '@blueprintjs/icons';
 import React, { useState } from 'react';
 import ReactTable from 'react-table';
@@ -47,7 +58,7 @@ function resultFormatToExtension(resultFormat: ResultFormat): string {
   }
 }
 
-const RESULT_FORMAT_LABEL: Record<ResultFormat, string> = {
+const RESULT_FORMAT_DESCRIPTION: Record<ResultFormat, string> = {
   object: 'Array of objects',
   array: 'Array of arrays',
   objectLines: 'JSON Lines',
@@ -63,6 +74,7 @@ export const DestinationPagesPane = React.memo(function DestinationPagesPane(
   props: DestinationPagesPaneProps,
 ) {
   const { execution } = props;
+  const [prefix, setPrefix] = useState(execution.id);
   const [desiredResultFormat, setDesiredResultFormat] = useState<ResultFormat>('objectLines');
   const desiredExtension = resultFormatToExtension(desiredResultFormat);
 
@@ -70,27 +82,26 @@ export const DestinationPagesPane = React.memo(function DestinationPagesPane(
   const pages = execution.destinationPages;
   if (!pages) return null;
   const numPages = pages.length;
-  const id = Api.encodePath(execution.id);
 
   const numTotalRows = destination?.numTotalRows;
 
   function getResultUrl(pageIndex: number) {
     return UrlBaser.base(
-      `/druid/v2/sql/statements/${id}/results?${
+      `/druid/v2/sql/statements/${Api.encodePath(execution.id)}/results?${
         pageIndex < 0 ? '' : `page=${pageIndex}&`
       }resultFormat=${desiredResultFormat}&filename=${getPageFilename(pageIndex)}`,
     );
   }
 
   function getFilenamePageInfo(pageIndex: number) {
-    if (pageIndex < 0) return 'all_data';
+    if (pageIndex < 0) return '';
     const numPagesString = String(numPages);
     const pageNumberString = String(pageIndex + 1).padStart(numPagesString.length, '0');
-    return `page_${pageNumberString}_of_${numPagesString}`;
+    return `.page_${pageNumberString}_of_${numPagesString}`;
   }
 
   function getPageFilename(pageIndex: number) {
-    return `${id}_${getFilenamePageInfo(pageIndex)}.${desiredExtension}`;
+    return `${prefix}${getFilenamePageInfo(pageIndex)}.${desiredExtension}`;
   }
 
   return (
@@ -101,29 +112,38 @@ export const DestinationPagesPane = React.memo(function DestinationPagesPane(
         } have been written to ${pluralIfNeeded(numPages, 'page')}. `}
       </p>
       <p>
-        Format when downloading:{' '}
-        <Popover
-          minimal
-          position={Position.BOTTOM_LEFT}
-          content={
-            <Menu>
-              {RESULT_FORMATS.map((resultFormat, i) => (
-                <MenuItem
-                  key={i}
-                  icon={tickIcon(desiredResultFormat === resultFormat)}
-                  text={RESULT_FORMAT_LABEL[resultFormat]}
-                  label={resultFormat}
-                  onClick={() => setDesiredResultFormat(resultFormat)}
-                />
-              ))}
-            </Menu>
-          }
-        >
-          <Button
-            text={RESULT_FORMAT_LABEL[desiredResultFormat]}
-            rightIcon={IconNames.CARET_DOWN}
+        <Label>Download as</Label>
+        <ControlGroup className="download-as-controls">
+          <InputGroup
+            value={prefix}
+            onChange={(e: any) => setPrefix(e.target.value.slice(0, 200))}
+            placeholder="file_prefix"
+            rightElement={<Button disabled text={`.${desiredExtension}`} />}
+            fill
           />
-        </Popover>{' '}
+          <Popover
+            minimal
+            position={Position.BOTTOM_LEFT}
+            content={
+              <Menu>
+                {RESULT_FORMATS.map((resultFormat, i) => (
+                  <MenuItem
+                    key={i}
+                    icon={tickIcon(desiredResultFormat === resultFormat)}
+                    text={RESULT_FORMAT_DESCRIPTION[resultFormat]}
+                    label={resultFormat}
+                    onClick={() => setDesiredResultFormat(resultFormat)}
+                  />
+                ))}
+              </Menu>
+            }
+          >
+            <Button
+              text={RESULT_FORMAT_DESCRIPTION[desiredResultFormat]}
+              rightIcon={IconNames.CARET_DOWN}
+            />
+          </Popover>
+        </ControlGroup>
         <AnchorButton
           intent={Intent.PRIMARY}
           icon={IconNames.DOWNLOAD}
