@@ -157,7 +157,7 @@ export interface ExecutionStagesPaneProps {
   execution: Execution;
   onErrorClick?(): void;
   onWarningClick?(): void;
-  goToTask(taskId: string): void;
+  goToTask?(taskId: string): void;
 }
 
 export const ExecutionStagesPane = React.memo(function ExecutionStagesPane(
@@ -245,8 +245,10 @@ export const ExecutionStagesPane = React.memo(function ExecutionStagesPane(
             Header: 'Worker',
             id: 'worker',
             accessor: d => d.index,
+            className: goToTask ? undefined : 'padded',
             width: 95,
             Cell({ value }) {
+              if (!goToTask) return `Worker${value}`;
               const taskId = `${execution.id}-worker${value}_0`;
               return (
                 <TableClickableCell
