@@ -20,7 +20,7 @@ import { Button, Icon, Intent, Menu, MenuItem, Popover } from '@blueprintjs/core
 import { IconNames } from '@blueprintjs/icons';
 import classNames from 'classnames';
 import type { Column, QueryResult, SqlExpression, SqlQuery } from 'druid-query-toolkit';
-import { C, F, SqlAlias, SqlFunction, SqlLiteral, SqlStar } from 'druid-query-toolkit';
+import { C, F, SqlAlias, SqlFunction, SqlLiteral, SqlStar, SqlType } from 'druid-query-toolkit';
 import * as JSONBig from 'json-bigint-native';
 import type { JSX } from 'react';
 import React, { useEffect, useState } from 'react';
@@ -62,6 +62,30 @@ function getJsonPaths(jsons: Record<string, any>[]): string[] {
   return ['$.'].concat(computeFlattenExprsForData(jsons, 'include-arrays', true));
 }
 
+function isStringJsonObject(value: string): boolean {
+  if (!(value.startsWith('{') && value.endsWith('}'))) {
+    return false;
+  }
+
+  try {
+    return typeof JSON.parse(value) === 'object';
+  } catch {
+    return false;
+  }
+}
+
+function isStringJsonString(value: string): boolean {
+  if (!(value.startsWith('"') && value.endsWith('"'))) {
+    return false;
+  }
+
+  try {
+    return typeof JSON.parse(value) === 'string';
+  } catch {
+    return false;
+  }
+}
+
 function getExpressionIfAlias(query: SqlQuery, columnIndex: number, numColumns: number): string {
   const selectExpressionsArray = query.getSelectExpressionsArray();
   // If there is a * before
@@ -182,15 +206,18 @@ export const ResultTablePane = React.memo(function ResultTablePane(props: Result
         );
       }
 
-      // Casts
+      // Expression changers
       if (selectExpression) {
         const underlyingExpression = selectExpression.getUnderlyingExpression();
-        if (underlyingExpression instanceof SqlFunction && underlyingExpression.getCastType()) {
+        const columnValues = queryResult.getColumnByIndex(headerIndex)!;
+
+        // Remove outer function
+        if (underlyingExpression instanceof SqlFunction && underlyingExpression.getArg(0)) {
           menuItems.push(
             <MenuItem
               key="uncast"
               icon={IconNames.CROSS}
-              text="Remove cast"
+              text={`Remove outer ${underlyingExpression.getEffectiveFunctionName()} function`}
               onClick={() => {
                 if (!selectExpression || !underlyingExpression) return;
                 handleQueryAction(q =>
@@ -204,6 +231,7 @@ export const ResultTablePane = React.memo(function ResultTablePane(props: Result
           );
         }
 
+        // Add a CAST
         menuItems.push(
           <MenuItem key="cast" icon={IconNames.EXCHANGE} text="Cast to...">
             {filterMap(CAST_TARGETS, asType => {
@@ -217,8 +245,7 @@ export const ResultTablePane = React.memo(function ResultTablePane(props: Result
                     handleQueryAction(q =>
                       q.changeSelect(
                         headerIndex,
-                        selectExpression
-                          .getUnderlyingExpression()
+                        underlyingExpression
                           .cast(asType)
                           .setAlias(selectExpression.getOutputName()),
                       ),
@@ -229,47 +256,91 @@ export const ResultTablePane = React.memo(function ResultTablePane(props: Result
             })}
           </MenuItem>,
         );
-      }
 
-      // JSON hint
-      if (selectExpression && column.nativeType === 'COMPLEX<json>') {
-        const paths = getJsonPaths(
-          filterMap(queryResult.rows, row => {
-            const v = row[headerIndex];
-            // Strangely multi-stage-query-engine and broker deal with JSON differently
-            if (v && typeof v === 'object') return v;
-            try {
-              return JSONBig.parse(v);
-            } catch {
-              return;
-            }
-          }),
-        );
+        // Parse as JSON
+        if (column.nativeType === 'STRING' && queryResult.getNumResults()) {
+          if (columnValues.every(isStringJsonObject)) {
+            menuItems.push(
+              <MenuItem
+                key="parse_json"
+                icon={IconNames.DIAGRAM_TREE}
+                text="Parse as JSON"
+                onClick={() => {
+                  if (!selectExpression) return;
+                  handleQueryAction(q =>
+                    q.changeSelect(
+                      headerIndex,
+                      F('TRY_PARSE_JSON', underlyingExpression).setAlias(
+                        selectExpression.getOutputName(),
+                      ),
+                    ),
+                  );
+                }}
+              />,
+            );
+          } else if (columnValues.every(isStringJsonString)) {
+            menuItems.push(
+              <MenuItem
+                key="unquote_json_string"
+                icon={IconNames.DOCUMENT_SHARE}
+                text="Unquote JSON string"
+                onClick={() => {
+                  if (!selectExpression) return;
+                  handleQueryAction(q =>
+                    q.changeSelect(
+                      headerIndex,
+                      SqlFunction.jsonValue(
+                        F('TRY_PARSE_JSON', underlyingExpression),
+                        '$',
+                        SqlType.VARCHAR,
+                      ).setAlias(selectExpression.getOutputName()),
+                    ),
+                  );
+                }}
+              />,
+            );
+          }
+        }
 
-        if (paths.length) {
-          menuItems.push(
-            <MenuItem key="json_value" icon={IconNames.DIAGRAM_TREE} text="Get JSON value for...">
-              {paths.map(path => {
-                return (
-                  <MenuItem
-                    key={path}
-                    text={path}
-                    onClick={() => {
-                      if (!selectExpression) return;
-                      handleQueryAction(q =>
-                        q.addSelect(
-                          F('JSON_VALUE', selectExpression.getUnderlyingExpression(), path).as(
-                            selectExpression.getOutputName() + path.replace(/^\$/, ''),
-                          ),
-                          { insertIndex: headerIndex + 1 },
-                        ),
-                      );
-                    }}
-                  />
-                );
-              })}
-            </MenuItem>,
+        // Extract a JSON path
+        if (column.nativeType === 'COMPLEX<json>' && queryResult.getNumResults()) {
+          const paths = getJsonPaths(
+            filterMap(columnValues, (v: any) => {
+              // Strangely, multi-stage-query-engine and broker deal with JSON differently
+              if (v && typeof v === 'object') return v;
+              try {
+                return JSONBig.parse(v);
+              } catch {
+                return;
+              }
+            }),
           );
+
+          if (paths.length) {
+            menuItems.push(
+              <MenuItem key="json_value" icon={IconNames.DIAGRAM_TREE} text="Get JSON value for...">
+                {paths.map(path => {
+                  return (
+                    <MenuItem
+                      key={path}
+                      text={path}
+                      onClick={() => {
+                        if (!selectExpression) return;
+                        handleQueryAction(q =>
+                          q.addSelect(
+                            SqlFunction.jsonValue(underlyingExpression, path).setAlias(
+                              selectExpression.getOutputName() + path.replace(/^\$/, ''),
+                            ),
+                            { insertIndex: headerIndex + 1 },
+                          ),
+                        );
+                      }}
+                    />
+                  );
+                })}
+              </MenuItem>,
+            );
+          }
         }
       }
 
