@@ -207,35 +207,35 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
 
   const emptyQuery = query.isEmptyQuery();
   const ingestMode = query.isIngestQuery();
-  const queryContext = query.queryContext;
-  const numContextKeys = Object.keys(queryContext).length;
+  const queryContext = query.getQueryStringContext();
   const queryParameters = query.queryParameters;
+  const effectiveDefaultContext = { ...defaultQueryContext, ...query.queryContext };
 
   // Extract the context parts that have UI
   const sqlTimeZone = queryContext.sqlTimeZone;
 
-  const useCache = getQueryContextKey('useCache', queryContext, defaultQueryContext);
+  const useCache = getQueryContextKey('useCache', queryContext, effectiveDefaultContext);
   const useApproximateTopN = getQueryContextKey(
     'useApproximateTopN',
     queryContext,
-    defaultQueryContext,
+    effectiveDefaultContext,
   );
   const useApproximateCountDistinct = getQueryContextKey(
     'useApproximateCountDistinct',
     queryContext,
-    defaultQueryContext,
+    effectiveDefaultContext,
   );
 
   const arrayIngestMode = queryContext.arrayIngestMode;
   const maxParseExceptions = getQueryContextKey(
     'maxParseExceptions',
     queryContext,
-    defaultQueryContext,
+    effectiveDefaultContext,
   );
   const failOnEmptyInsert = getQueryContextKey(
     'failOnEmptyInsert',
     queryContext,
-    defaultQueryContext,
+    effectiveDefaultContext,
   );
   const finalizeAggregations = queryContext.finalizeAggregations;
   const waitUntilSegmentsLoad = queryContext.waitUntilSegmentsLoad;
@@ -243,20 +243,20 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
   const sqlJoinAlgorithm = getQueryContextKey(
     'sqlJoinAlgorithm',
     queryContext,
-    defaultQueryContext,
+    effectiveDefaultContext,
   );
   const selectDestination = getQueryContextKey(
     'selectDestination',
     queryContext,
-    defaultQueryContext,
+    effectiveDefaultContext,
   );
   const durableShuffleStorage = getQueryContextKey(
     'durableShuffleStorage',
     queryContext,
-    defaultQueryContext,
+    effectiveDefaultContext,
   );
 
-  const indexSpec: IndexSpec | undefined = deepGet(queryContext, 'indexSpec');
+  const indexSpec: IndexSpec | undefined = deepGet(query.queryContext, 'indexSpec');
 
   const handleRun = useCallback(() => {
     if (!onRun) return;
@@ -297,6 +297,10 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
     onQueryChange(query.changeQueryContext(removeUndefinedValues(queryContext)));
   }
 
+  function changeQueryStringContext(queryContext: QueryContext) {
+    onQueryChange(query.changeQueryStringContext(removeUndefinedValues(queryContext)));
+  }
+
   const overloadWarning =
     query.unlimited &&
     (queryEngine === 'sql-native' ||
@@ -360,41 +364,22 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
                         />
                       );
                     })}
-
                     <MenuDivider />
                   </>
                 )}
-                {show('edit-query-context') && (
-                  <MenuItem
-                    icon={IconNames.PROPERTIES}
-                    text="Edit query context..."
-                    onClick={() => setEditContextDialogOpen(true)}
-                    label={pluralIfNeeded(numContextKeys, 'key')}
-                  />
-                )}
-                {show('define-parameters') && (
-                  <MenuItem
-                    icon={IconNames.HELP}
-                    text="Define parameters..."
-                    onClick={() => setEditParametersDialogOpen(true)}
-                    label={
-                      queryParameters ? pluralIfNeeded(queryParameters.length, 'parameter') : ''
-                    }
-                  />
-                )}
                 {show('timezone') && (
                   <MenuItem
                     icon={IconNames.GLOBE_NETWORK}
                     text="Timezone"
-                    label={sqlTimeZone ?? defaultQueryContext.sqlTimeZone}
+                    label={sqlTimeZone ?? effectiveDefaultContext.sqlTimeZone}
                   >
                     <MenuDivider title="Timezone type" />
                     <TimezoneMenuItems
                       sqlTimeZone={sqlTimeZone}
                       setSqlTimeZone={sqlTimeZone =>
-                        changeQueryContext({ ...queryContext, sqlTimeZone })
+                        changeQueryStringContext({ ...queryContext, sqlTimeZone })
                       }
-                      defaultSqlTimeZone={defaultQueryContext.sqlTimeZone}
+                      defaultSqlTimeZone={effectiveDefaultContext.sqlTimeZone}
                     />
                     <MenuItem
                       icon={IconNames.BLANK}
@@ -409,7 +394,7 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
                     text="Approximate COUNT(DISTINCT)"
                     value={useApproximateCountDistinct}
                     onValueChange={useApproximateCountDistinct =>
-                      changeQueryContext({
+                      changeQueryStringContext({
                         ...queryContext,
                         useApproximateCountDistinct,
                       })
@@ -423,7 +408,7 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
                     text="Approximate TopN"
                     value={useApproximateTopN}
                     onValueChange={useApproximateTopN =>
-                      changeQueryContext({
+                      changeQueryStringContext({
                         ...queryContext,
                         useApproximateTopN,
                       })
@@ -446,7 +431,9 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
                         icon={tickIcon(sqlJoinAlgorithm === o)}
                         text={SQL_JOIN_ALGORITHM_LABEL[o]}
                         shouldDismissPopover={false}
-                        onClick={() => changeQueryContext({ ...queryContext, sqlJoinAlgorithm: o })}
+                        onClick={() =>
+                          changeQueryStringContext({ ...queryContext, sqlJoinAlgorithm: o })
+                        }
                       />
                     ))}
                   </MenuItem>
@@ -457,13 +444,49 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
                     icon={IconNames.BRING_DATA}
                     text="INSERT / REPLACE / EXTERN specific context"
                   >
+                    <MenuItem
+                      text="Array ingest mode"
+                      label={
+                        arrayIngestMode
+                          ? ARRAY_INGEST_MODE_LABEL[arrayIngestMode]
+                          : '(server default)'
+                      }
+                    >
+                      {([undefined, 'array', 'mvd'] as (ArrayIngestMode | undefined)[]).map(
+                        (m, i) => (
+                          <MenuItem
+                            key={i}
+                            icon={tickIcon(m === arrayIngestMode)}
+                            text={
+                              m
+                                ? ARRAY_INGEST_MODE_DESCRIPTION[m]
+                                : `(server default${
+                                    effectiveDefaultContext.arrayIngestMode
+                                      ? `: ${effectiveDefaultContext.arrayIngestMode}`
+                                      : ''
+                                  })`
+                            }
+                            onClick={() =>
+                              changeQueryStringContext({ ...queryContext, arrayIngestMode: m })
+                            }
+                          />
+                        ),
+                      )}
+                      <MenuDivider />
+                      <MenuItem
+                        icon={IconNames.HELP}
+                        text="Documentation"
+                        href={`${getLink('DOCS')}/querying/arrays#arrayingestmode`}
+                        target="_blank"
+                      />
+                    </MenuItem>
                     <MenuBoolean
                       text="Fail on empty insert"
                       value={failOnEmptyInsert}
                       showUndefined
                       undefinedEffectiveValue={false}
                       onValueChange={failOnEmptyInsert =>
-                        changeQueryContext({ ...queryContext, failOnEmptyInsert })
+                        changeQueryStringContext({ ...queryContext, failOnEmptyInsert })
                       }
                       optionsText={ENABLED_DISABLED_OPTIONS_TEXT}
                     />
@@ -473,7 +496,7 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
                       showUndefined
                       undefinedEffectiveValue={ingestMode}
                       onValueChange={waitUntilSegmentsLoad =>
-                        changeQueryContext({ ...queryContext, waitUntilSegmentsLoad })
+                        changeQueryStringContext({ ...queryContext, waitUntilSegmentsLoad })
                       }
                       optionsText={ENABLED_DISABLED_OPTIONS_TEXT}
                     />
@@ -484,7 +507,7 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
                           icon={tickIcon(v === maxParseExceptions)}
                           text={v === -1 ? '∞ (-1)' : String(v)}
                           onClick={() =>
-                            changeQueryContext({ ...queryContext, maxParseExceptions: v })
+                            changeQueryStringContext({ ...queryContext, maxParseExceptions: v })
                           }
                           shouldDismissPopover={false}
                         />
@@ -509,7 +532,7 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
                     showUndefined
                     undefinedEffectiveValue={!ingestMode}
                     onValueChange={finalizeAggregations =>
-                      changeQueryContext({ ...queryContext, finalizeAggregations })
+                      changeQueryStringContext({ ...queryContext, finalizeAggregations })
                     }
                     optionsText={ENABLED_DISABLED_OPTIONS_TEXT}
                   />
@@ -522,7 +545,10 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
                     showUndefined
                     undefinedEffectiveValue={!ingestMode}
                     onValueChange={groupByEnableMultiValueUnnesting =>
-                      changeQueryContext({ ...queryContext, groupByEnableMultiValueUnnesting })
+                      changeQueryStringContext({
+                        ...queryContext,
+                        groupByEnableMultiValueUnnesting,
+                      })
                     }
                     optionsText={ENABLED_DISABLED_OPTIONS_TEXT}
                   />
@@ -534,7 +560,7 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
                     text="Use cache"
                     value={useCache}
                     onValueChange={useCache =>
-                      changeQueryContext({
+                      changeQueryStringContext({
                         ...queryContext,
                         useCache,
                         populateCache: useCache,
@@ -563,7 +589,7 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
                     text="Durable shuffle storage"
                     value={durableShuffleStorage}
                     onValueChange={durableShuffleStorage =>
-                      changeQueryContext({
+                      changeQueryStringContext({
                         ...queryContext,
                         durableShuffleStorage,
                       })
@@ -588,7 +614,7 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
                         text={SELECT_DESTINATION_LABEL[o]}
                         shouldDismissPopover={false}
                         onClick={() =>
-                          changeQueryContext({ ...queryContext, selectDestination: o })
+                          changeQueryStringContext({ ...queryContext, selectDestination: o })
                         }
                       />
                     ))}
@@ -607,6 +633,25 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
                     />
                   </MenuItem>
                 )}
+                {(show('edit-query-context') || show('define-parameters')) && <MenuDivider />}
+                {show('edit-query-context') && (
+                  <MenuItem
+                    icon={IconNames.PROPERTIES}
+                    text="Edit query context..."
+                    onClick={() => setEditContextDialogOpen(true)}
+                    label={pluralIfNeeded(Object.keys(query.queryContext).length, 'key')}
+                  />
+                )}
+                {show('define-parameters') && (
+                  <MenuItem
+                    icon={IconNames.HELP}
+                    text="Define parameters..."
+                    onClick={() => setEditParametersDialogOpen(true)}
+                    label={
+                      queryParameters ? pluralIfNeeded(queryParameters.length, 'parameter') : ''
+                    }
+                  />
+                )}
               </Menu>
             }
           >
@@ -624,53 +669,14 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
             <MaxTasksButton
               clusterCapacity={clusterCapacity}
               queryContext={queryContext}
-              changeQueryContext={changeQueryContext}
-              defaultQueryContext={defaultQueryContext}
+              changeQueryContext={changeQueryStringContext}
+              defaultQueryContext={effectiveDefaultContext}
               menuHeader={maxTasksMenuHeader}
               maxTasksLabelFn={maxTasksLabelFn}
               maxTasksOptions={maxTasksOptions}
               fullClusterCapacityLabelFn={fullClusterCapacityLabelFn}
             />
           )}
-          {ingestMode && (
-            <Popover
-              position={Position.BOTTOM_LEFT}
-              content={
-                <Menu>
-                  {([undefined, 'array', 'mvd'] as (ArrayIngestMode | undefined)[]).map((m, i) => (
-                    <MenuItem
-                      key={i}
-                      icon={tickIcon(m === arrayIngestMode)}
-                      text={
-                        m
-                          ? ARRAY_INGEST_MODE_DESCRIPTION[m]
-                          : `(server default${
-                              defaultQueryContext.arrayIngestMode
-                                ? `: ${defaultQueryContext.arrayIngestMode}`
-                                : ''
-                            })`
-                      }
-                      onClick={() => changeQueryContext({ ...queryContext, arrayIngestMode: m })}
-                    />
-                  ))}
-                  <MenuDivider />
-                  <MenuItem
-                    icon={IconNames.HELP}
-                    text="Documentation"
-                    href={`${getLink('DOCS')}/querying/arrays#arrayingestmode`}
-                    target="_blank"
-                  />
-                </Menu>
-              }
-            >
-              <Button
-                text={`Array ingest mode: ${
-                  arrayIngestMode ? ARRAY_INGEST_MODE_LABEL[arrayIngestMode] : '(server default)'
-                }`}
-                rightIcon={IconNames.CARET_DOWN}
-              />
-            </Popover>
-          )}
         </ButtonGroup>
       )}
       {moreMenu && (
@@ -680,7 +686,7 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
       )}
       {editContextDialogOpen && (
         <EditContextDialog
-          initQueryContext={queryContext}
+          initQueryContext={query.queryContext}
           onQueryContextChange={changeQueryContext}
           onClose={() => {
             setEditContextDialogOpen(false);
@@ -708,7 +714,7 @@ export const RunPanel = React.memo(function RunPanel(props: RunPanelProps) {
       {indexSpecDialogSpec && (
         <IndexSpecDialog
           onClose={() => setIndexSpecDialogSpec(undefined)}
-          onSave={indexSpec => changeQueryContext({ ...queryContext, indexSpec })}
+          onSave={indexSpec => changeQueryContext({ ...query.queryContext, indexSpec })}
           indexSpec={indexSpecDialogSpec}
         />
       )}
