@@ -19,11 +19,23 @@
 import { createStore } from 'zustand';
 
 interface WorkState {
-  version: number;
-  increment(): void;
+  msqTaskVersion: number;
+  msqDartVersion: number;
+  incrementMsqTask(): void;
+  incrementMsqDart(): void;
 }
 
-export const workStateStore = createStore<WorkState>(set => ({
-  version: 0,
-  increment: () => set(state => ({ version: state.version + 1 })),
+export const WORK_STATE_STORE = createStore<WorkState>(set => ({
+  msqTaskVersion: 0,
+  msqDartVersion: 0,
+  incrementMsqTask: () => set(state => ({ msqTaskVersion: state.msqTaskVersion + 1 })),
+  incrementMsqDart: () => set(state => ({ msqDartVersion: state.msqDartVersion + 1 })),
 }));
+
+export function getMsqTaskVersion(store: WorkState): number {
+  return store.msqTaskVersion;
+}
+
+export function getMsqDartVersion(store: WorkState): number {
+  return store.msqDartVersion;
+}
